declare const thermostatSystemModes4: KeyValue;
declare const thermostatPresets: KeyValue;
declare const tuyaHPSCheckingResult: KeyValue;
declare const toZigbee: {
    tuya_alecto_smoke: ToZigbeeConverter;
    matsee_garage_door_opener: ToZigbeeConverter;
    connecte_thermostat: ToZigbeeConverter;
    moes_thermostat_child_lock: ToZigbeeConverter;
    moes_thermostat_current_heating_setpoint: ToZigbeeConverter;
    moes_thermostat_deadzone_temperature: ToZigbeeConverter;
    moes_thermostat_calibration: ToZigbeeConverter;
    moes_thermostat_min_temperature_limit: ToZigbeeConverter;
    moes_thermostat_max_temperature_limit: ToZigbeeConverter;
    moes_thermostat_mode: ToZigbeeConverter;
    moes_thermostat_standby: ToZigbeeConverter;
    moes_thermostat_program_schedule: ToZigbeeConverter;
    moesS_thermostat_system_mode: ToZigbeeConverter;
    moesS_thermostat_preset: ToZigbeeConverter;
    moesS_thermostat_current_heating_setpoint: ToZigbeeConverter;
    moesS_thermostat_boost_heating: ToZigbeeConverter;
    moesS_thermostat_window_detection: ToZigbeeConverter;
    moesS_thermostat_child_lock: ToZigbeeConverter;
    moesS_thermostat_boostHeatingCountdownTimeSet: ToZigbeeConverter;
    moesS_thermostat_temperature_calibration: ToZigbeeConverter;
    moesS_thermostat_moesSecoMode: ToZigbeeConverter;
    moesS_thermostat_eco_temperature: ToZigbeeConverter;
    moesS_thermostat_max_temperature: ToZigbeeConverter;
    moesS_thermostat_min_temperature: ToZigbeeConverter;
    moesS_thermostat_schedule_programming: ToZigbeeConverter;
    hgkg_thermostat_standby: ToZigbeeConverter;
    moes_switch: ToZigbeeConverter;
    moes_thermostat_sensor: ToZigbeeConverter;
    tuya_dimmer_state: ToZigbeeConverter;
    tuya_dimmer_level: ToZigbeeConverter;
    tuya_switch_state: ToZigbeeConverter;
    frankever_threshold: ToZigbeeConverter;
    frankever_timer: ToZigbeeConverter;
    ZVG1_timer: ToZigbeeConverter;
    ZVG1_weather_delay: ToZigbeeConverter;
    ZVG1_cycle_timer: ToZigbeeConverter;
    ZVG1_normal_schedule_timer: ToZigbeeConverter;
    etop_thermostat_system_mode: ToZigbeeConverter;
    etop_thermostat_away_mode: ToZigbeeConverter;
    tuya_thermostat_weekly_schedule: ToZigbeeConverter;
    tuya_thermostat_child_lock: ToZigbeeConverter;
    tuya_thermostat_window_detection: ToZigbeeConverter;
    siterwell_thermostat_window_detection: ToZigbeeConverter;
    tuya_thermostat_valve_detection: ToZigbeeConverter;
    tuya_thermostat_current_heating_setpoint: ToZigbeeConverter;
    tuya_thermostat_system_mode: ToZigbeeConverter;
    tuya_thermostat_preset: ToZigbeeConverter;
    tuya_thermostat_away_mode: ToZigbeeConverter;
    tuya_thermostat_fan_mode: ToZigbeeConverter;
    tuya_thermostat_bac_fan_mode: ToZigbeeConverter;
    tuya_thermostat_auto_lock: ToZigbeeConverter;
    tuya_thermostat_calibration: ToZigbeeConverter;
    tuya_thermostat_min_temp: ToZigbeeConverter;
    tuya_thermostat_max_temp: ToZigbeeConverter;
    tuya_thermostat_boost_time: ToZigbeeConverter;
    tuya_thermostat_comfort_temp: ToZigbeeConverter;
    tuya_thermostat_eco_temp: ToZigbeeConverter;
    tuya_thermostat_force: ToZigbeeConverter;
    tuya_thermostat_force_to_mode: ToZigbeeConverter;
    tuya_thermostat_away_preset: ToZigbeeConverter;
    tuya_thermostat_window_detect: ToZigbeeConverter;
    tuya_thermostat_schedule: ToZigbeeConverter;
    tuya_thermostat_schedule_programming_mode: ToZigbeeConverter;
    tuya_thermostat_week: ToZigbeeConverter;
    tuya_cover_control: ToZigbeeConverter;
    tuya_cover_options: ToZigbeeConverter;
    neo_nas_pd07: ToZigbeeConverter;
    neo_t_h_alarm: ToZigbeeConverter;
    neo_alarm: ToZigbeeConverter;
    nous_lcd_temperature_humidity_sensor: ToZigbeeConverter;
    saswell_thermostat_current_heating_setpoint: ToZigbeeConverter;
    saswell_thermostat_mode: ToZigbeeConverter;
    saswell_thermostat_away: ToZigbeeConverter;
    saswell_thermostat_child_lock: ToZigbeeConverter;
    saswell_thermostat_window_detection: ToZigbeeConverter;
    saswell_thermostat_frost_detection: ToZigbeeConverter;
    saswell_thermostat_anti_scaling: ToZigbeeConverter;
    saswell_thermostat_calibration: ToZigbeeConverter;
    evanell_thermostat_current_heating_setpoint: ToZigbeeConverter;
    evanell_thermostat_system_mode: ToZigbeeConverter;
    evanell_thermostat_child_lock: ToZigbeeConverter;
    silvercrest_smart_led_string: ToZigbeeConverter;
    tuya_data_point_test: ToZigbeeConverter;
    hy_thermostat: ToZigbeeConverter;
    ZB003X: ToZigbeeConverter;
    ZB006X_settings: ToZigbeeConverter;
    tuya_motion_sensor: ToZigbeeConverter;
    javis_microwave_sensor: ToZigbeeConverter;
    moes_thermostat_tv: ToZigbeeConverter;
    tuya_light_wz5: ToZigbeeConverter;
    ZMAM02_cover: ToZigbeeConverter;
    tuya_smart_human_presense_sensor: ToZigbeeConverter;
    ZG204ZL_lms: ToZigbeeConverter;
    moes_cover: ToZigbeeConverter;
    hoch_din: ToZigbeeConverter;
};
declare const fromZigbee: {
    tuya_thermostat_weekly_schedule_1: FromZigbeeConverter;
    tuya_alecto_smoke: FromZigbeeConverter;
    WXKG11LM_click: FromZigbeeConverter;
    SmartButton_skip: FromZigbeeConverter;
    konke_click: FromZigbeeConverter;
    xiaomi_action_click_multistate: FromZigbeeConverter;
    WXKG12LM_action_click_multistate: FromZigbeeConverter;
    terncy_raw: FromZigbeeConverter;
    CCTSwitch_D0001_on_off: FromZigbeeConverter;
    ptvo_switch_buttons: FromZigbeeConverter;
    ZGRC013_brightness_onoff: FromZigbeeConverter;
    ZGRC013_brightness_stop: FromZigbeeConverter;
    ZGRC013_scene: FromZigbeeConverter;
    ZGRC013_cmdOn: FromZigbeeConverter;
    ZGRC013_cmdOff: FromZigbeeConverter;
    ZGRC013_brightness: FromZigbeeConverter;
    CTR_U_scene: FromZigbeeConverter;
    st_button_state: FromZigbeeConverter;
    QBKG11LM_click: FromZigbeeConverter;
    QBKG12LM_click: FromZigbeeConverter;
    QBKG03LM_QBKG12LM_click: FromZigbeeConverter;
    QBKG04LM_QBKG11LM_click: FromZigbeeConverter;
    cover_stop: FromZigbeeConverter;
    cover_open: FromZigbeeConverter;
    cover_close: FromZigbeeConverter;
    WXKG03LM_click: FromZigbeeConverter;
    TS0218_click: FromZigbeeConverter;
    xiaomi_on_off_action: FromZigbeeConverter;
    WXKG02LM_click: FromZigbeeConverter;
    WXKG02LM_click_multistate: FromZigbeeConverter;
    WXKG01LM_click: FromZigbeeConverter;
    scenes_recall_click: FromZigbeeConverter;
    AV2010_34_click: FromZigbeeConverter;
    E1743_brightness_down: FromZigbeeConverter;
    E1743_brightness_up: FromZigbeeConverter;
    E1743_brightness_stop: FromZigbeeConverter;
    genOnOff_cmdOn: FromZigbeeConverter;
    genOnOff_cmdOff: FromZigbeeConverter;
    RM01_on_click: FromZigbeeConverter;
    RM01_off_click: FromZigbeeConverter;
    RM01_down_hold: FromZigbeeConverter;
    RM01_up_hold: FromZigbeeConverter;
    RM01_stop: FromZigbeeConverter;
    xiaomi_multistate_action: FromZigbeeConverter;
    E1744_play_pause: FromZigbeeConverter;
    E1744_skip: FromZigbeeConverter;
    cmd_move: FromZigbeeConverter;
    cmd_move_with_onoff: FromZigbeeConverter;
    cmd_stop: FromZigbeeConverter;
    cmd_stop_with_onoff: FromZigbeeConverter;
    cmd_move_to_level_with_onoff: FromZigbeeConverter;
    immax_07046L_arm: FromZigbeeConverter;
    KEF1PA_arm: FromZigbeeConverter;
    QBKG25LM_click: FromZigbeeConverter;
    QBKG03LM_buttons: FromZigbeeConverter;
    CTR_U_brightness_updown_click: FromZigbeeConverter;
    CTR_U_brightness_updown_hold: FromZigbeeConverter;
    CTR_U_brightness_updown_release: FromZigbeeConverter;
    osram_lightify_switch_cmdOn: FromZigbeeConverter;
    osram_lightify_switch_cmdOff: FromZigbeeConverter;
    osram_lightify_switch_cmdMoveWithOnOff: FromZigbeeConverter;
    osram_lightify_switch_AC0251100NJ_cmdStop: FromZigbeeConverter;
    osram_lightify_switch_cmdMove: FromZigbeeConverter;
    osram_lightify_switch_cmdMoveHue: FromZigbeeConverter;
    osram_lightify_switch_cmdMoveToSaturation: FromZigbeeConverter;
    osram_lightify_switch_cmdMoveToLevelWithOnOff: FromZigbeeConverter;
    osram_lightify_switch_cmdMoveToColorTemp: FromZigbeeConverter;
    osram_lightify_switch_73743_cmdStop: FromZigbeeConverter;
    osram_lightify_switch_AB371860355_cmdOn: FromZigbeeConverter;
    osram_lightify_switch_AB371860355_cmdOff: FromZigbeeConverter;
    osram_lightify_switch_AB371860355_cmdStepColorTemp: FromZigbeeConverter;
    osram_lightify_switch_AB371860355_cmdMoveWithOnOff: FromZigbeeConverter;
    osram_lightify_switch_AB371860355_cmdMove: FromZigbeeConverter;
    osram_lightify_switch_AB371860355_cmdStop: FromZigbeeConverter;
    osram_lightify_switch_AB371860355_cmdMoveHue: FromZigbeeConverter;
    osram_lightify_switch_AB371860355_cmdMoveSat: FromZigbeeConverter;
    insta_scene_click: FromZigbeeConverter;
    insta_down_hold: FromZigbeeConverter;
    insta_up_hold: FromZigbeeConverter;
    insta_stop: FromZigbeeConverter;
    tint404011_brightness_updown_click: FromZigbeeConverter;
    tint404011_brightness_updown_hold: FromZigbeeConverter;
    tint404011_brightness_updown_release: FromZigbeeConverter;
    tint404011_move_to_color_temp: FromZigbeeConverter;
    tint404011_move_to_color: FromZigbeeConverter;
    heiman_smart_controller_armmode: FromZigbeeConverter;
    LZL4B_onoff: FromZigbeeConverter;
    eria_81825_updown: FromZigbeeConverter;
    ZYCT202_stop: FromZigbeeConverter;
    ZYCT202_up_down: FromZigbeeConverter;
    STS_PRS_251_beeping: FromZigbeeConverter;
    dimmer_passthru_brightness: FromZigbeeConverter;
    bitron_thermostat_att_report: FromZigbeeConverter;
    thermostat_att_report: FromZigbeeConverter;
    stelpro_thermostat: FromZigbeeConverter;
    viessmann_thermostat_att_report: FromZigbeeConverter;
    eurotronic_thermostat: FromZigbeeConverter;
    wiser_thermostat: FromZigbeeConverter;
    hvac_user_interface: FromZigbeeConverter;
    thermostat_weekly_schedule_rsp: FromZigbeeConverter;
    terncy_knob: FromZigbeeConverter;
    wiser_itrv_battery: FromZigbeeConverter;
    ubisys_c4_scenes: FromZigbeeConverter;
    ubisys_c4_onoff: FromZigbeeConverter;
    ubisys_c4_level: FromZigbeeConverter;
    ubisys_c4_cover: FromZigbeeConverter;
    hue_dimmer_switch: FromZigbeeConverter;
    blitzwolf_occupancy_with_timeout: FromZigbeeConverter;
    moes_thermostat: FromZigbeeConverter;
    moesS_thermostat: FromZigbeeConverter;
    tuya_air_quality: FromZigbeeConverter;
    tuya_CO: FromZigbeeConverter;
    connecte_thermostat: FromZigbeeConverter;
    saswell_thermostat: FromZigbeeConverter;
    evanell_thermostat: FromZigbeeConverter;
    etop_thermostat: FromZigbeeConverter;
    tuya_thermostat: FromZigbeeConverter;
    tuya_dimmer: FromZigbeeConverter;
    tuya_motion_sensor: FromZigbeeConverter;
    tuya_smart_vibration_sensor: FromZigbeeConverter;
    matsee_garage_door_opener: FromZigbeeConverter;
    moes_thermostat_tv: FromZigbeeConverter;
    hoch_din: FromZigbeeConverter;
    tuya_light_wz5: FromZigbeeConverter;
    ZMAM02_cover: FromZigbeeConverter;
    tm081: FromZigbeeConverter;
    tuya_remote: FromZigbeeConverter;
    tuya_smart_human_presense_sensor: FromZigbeeConverter;
    ZG204ZL_lms: FromZigbeeConverter;
    moes_cover: FromZigbeeConverter;
    tuya_temperature_humidity_sensor: FromZigbeeConverter;
    nous_lcd_temperature_humidity_sensor: FromZigbeeConverter;
    tuya_illuminance_temperature_humidity_sensor: FromZigbeeConverter;
    tuya_illuminance_sensor: FromZigbeeConverter;
    hy_thermostat: FromZigbeeConverter;
    neo_nas_pd07: FromZigbeeConverter;
    neo_t_h_alarm: FromZigbeeConverter;
    neo_alarm: FromZigbeeConverter;
    ZB006X_settings: FromZigbeeConverter;
    tuya_cover: FromZigbeeConverter;
    moes_switch: FromZigbeeConverter;
    tuya_water_leak: FromZigbeeConverter;
    wls100z_water_leak: FromZigbeeConverter;
    silvercrest_smart_led_string: FromZigbeeConverter;
    frankever_valve: FromZigbeeConverter;
    tuya_woox_smoke: FromZigbeeConverter;
    tuya_switch: FromZigbeeConverter;
    tuya_dinrail_switch: FromZigbeeConverter;
    ZVG1: FromZigbeeConverter;
    ZB003X: FromZigbeeConverter;
    tuya_thermostat_weekly_schedule_2: FromZigbeeConverter;
    tuya_data_point_dump: FromZigbeeConverter;
    javis_microwave_sensor: FromZigbeeConverter;
    SLUXZB: FromZigbeeConverter;
};
declare const thermostatControlSequenceOfOperations: {
    0: string;
    1: string;
    2: string;
    3: string;
    4: string;
    5: string;
};
declare const thermostatSystemModes: {
    0: string;
    1: string;
    3: string;
    4: string;
    5: string;
    6: string;
    7: string;
    8: string;
    9: string;
};
export { fromZigbee, toZigbee, thermostatControlSequenceOfOperations, thermostatSystemModes, tuyaHPSCheckingResult, thermostatSystemModes4, thermostatPresets, };
//# sourceMappingURL=legacy.d.ts.map