import exposes = require("../lib/exposes");
export namespace fan {
    const cluster: string;
    const type: string[];
    function convert(model: any, msg: any, publish: any, options: any, meta: any): {
        fan_mode: any;
        fan_state: string;
    };
}
export namespace thermostat {
    const cluster_1: string;
    export { cluster_1 as cluster };
    const type_1: string[];
    export { type_1 as type };
    export function convert_1(model: any, msg: any, publish: any, options: any, meta: any): {};
    export { convert_1 as convert };
}
export namespace thermostat_weekly_schedule {
    const cluster_2: string;
    export { cluster_2 as cluster };
    const type_2: string[];
    export { type_2 as type };
    export function convert_2(model: any, msg: any, publish: any, options: any, meta: any): {
        [x: number]: {
            days: any[];
            transitions: {
                time: any;
            }[];
        };
    };
    export { convert_2 as convert };
}
export namespace hvac_user_interface {
    const cluster_3: string;
    export { cluster_3 as cluster };
    const type_3: string[];
    export { type_3 as type };
    export function convert_3(model: any, msg: any, publish: any, options: any, meta: any): {
        keypad_lockout: any;
        temperature_display_mode: any;
    };
    export { convert_3 as convert };
}
export namespace lock_operation_event {
    const cluster_4: string;
    export { cluster_4 as cluster };
    const type_4: string;
    export { type_4 as type };
    export function convert_4(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
        action_user: any;
        action_source: any;
        action_source_name: any;
    };
    export { convert_4 as convert };
}
export namespace lock_programming_event {
    const cluster_5: string;
    export { cluster_5 as cluster };
    const type_5: string;
    export { type_5 as type };
    export function convert_5(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
        action_user: any;
        action_source: any;
        action_source_name: any;
    };
    export { convert_5 as convert };
}
export namespace lock {
    const cluster_6: string;
    export { cluster_6 as cluster };
    const type_6: string[];
    export { type_6 as type };
    export function convert_6(model: any, msg: any, publish: any, options: any, meta: any): {
        state: string;
        lock_state: string;
        auto_relock_time: any;
        sound_volume: string;
        door_state: any;
    };
    export { convert_6 as convert };
}
export namespace lock_pin_code_response {
    const cluster_7: string;
    export { cluster_7 as cluster };
    const type_7: string[];
    export { type_7 as type };
    export const options: exposes.Binary[];
    export function convert_7(model: any, msg: any, publish: any, options: any, meta: any): {
        users: {};
    };
    export { convert_7 as convert };
}
export namespace lock_user_status_response {
    const cluster_8: string;
    export { cluster_8 as cluster };
    const type_8: string[];
    export { type_8 as type };
    const options_1: exposes.Binary[];
    export { options_1 as options };
    export function convert_8(model: any, msg: any, publish: any, options: any, meta: any): {
        users: {};
    };
    export { convert_8 as convert };
}
export namespace linkquality_from_basic {
    const cluster_9: string;
    export { cluster_9 as cluster };
    const type_9: string[];
    export { type_9 as type };
    export function convert_9(model: any, msg: any, publish: any, options: any, meta: any): {
        linkquality: any;
    };
    export { convert_9 as convert };
}
export namespace battery {
    const cluster_10: string;
    export { cluster_10 as cluster };
    const type_10: string[];
    export { type_10 as type };
    export function convert_10(model: any, msg: any, publish: any, options: any, meta: any): {
        battery: any;
        voltage: number;
        battery_low: boolean;
    };
    export { convert_10 as convert };
}
export namespace temperature {
    const cluster_11: string;
    export { cluster_11 as cluster };
    const type_11: string[];
    export { type_11 as type };
    const options_2: exposes.Numeric[];
    export { options_2 as options };
    export function convert_11(model: any, msg: any, publish: any, options: any, meta: any): {
        [x: number]: any;
    };
    export { convert_11 as convert };
}
export namespace device_temperature {
    const cluster_12: string;
    export { cluster_12 as cluster };
    const type_12: string[];
    export { type_12 as type };
    const options_3: exposes.Numeric[];
    export { options_3 as options };
    export function convert_12(model: any, msg: any, publish: any, options: any, meta: any): {
        device_temperature: any;
    };
    export { convert_12 as convert };
}
export namespace humidity {
    const cluster_13: string;
    export { cluster_13 as cluster };
    const type_13: string[];
    export { type_13 as type };
    const options_4: exposes.Numeric[];
    export { options_4 as options };
    export function convert_13(model: any, msg: any, publish: any, options: any, meta: any): {
        humidity: any;
    };
    export { convert_13 as convert };
}
export namespace pm25 {
    const cluster_14: string;
    export { cluster_14 as cluster };
    const type_14: string[];
    export { type_14 as type };
    export function convert_14(model: any, msg: any, publish: any, options: any, meta: any): {
        pm25: any;
    };
    export { convert_14 as convert };
}
export namespace soil_moisture {
    const cluster_15: string;
    export { cluster_15 as cluster };
    const type_15: string[];
    export { type_15 as type };
    const options_5: exposes.Numeric[];
    export { options_5 as options };
    export function convert_15(model: any, msg: any, publish: any, options: any, meta: any): {
        soil_moisture: any;
    };
    export { convert_15 as convert };
}
export namespace illuminance {
    const cluster_16: string;
    export { cluster_16 as cluster };
    const type_16: string[];
    export { type_16 as type };
    const options_6: exposes.Numeric[];
    export { options_6 as options };
    export function convert_16(model: any, msg: any, publish: any, options: any, meta: any): {
        illuminance: any;
        illuminance_lux: any;
    };
    export { convert_16 as convert };
}
export namespace pressure {
    const cluster_17: string;
    export { cluster_17 as cluster };
    const type_17: string[];
    export { type_17 as type };
    const options_7: exposes.Numeric[];
    export { options_7 as options };
    export function convert_17(model: any, msg: any, publish: any, options: any, meta: any): {
        pressure: any;
    };
    export { convert_17 as convert };
}
export namespace co2 {
    const cluster_18: string;
    export { cluster_18 as cluster };
    const type_18: string[];
    export { type_18 as type };
    export function convert_18(model: any, msg: any, publish: any, options: any, meta: any): {
        co2: number;
    };
    export { convert_18 as convert };
}
export namespace occupancy {
    const cluster_19: string;
    export { cluster_19 as cluster };
    const type_19: string[];
    export { type_19 as type };
    const options_8: exposes.List[];
    export { options_8 as options };
    export function convert_19(model: any, msg: any, publish: any, options: any, meta: any): {
        occupancy: boolean;
    };
    export { convert_19 as convert };
}
export namespace occupancy_with_timeout {
    const cluster_20: string;
    export { cluster_20 as cluster };
    const type_20: string[];
    export { type_20 as type };
    const options_9: (exposes.Numeric | exposes.List)[];
    export { options_9 as options };
    export function convert_20(model: any, msg: any, publish: any, options: any, meta: any): {
        occupancy: boolean;
    };
    export { convert_20 as convert };
}
export namespace occupancy_timeout {
    const cluster_21: string;
    export { cluster_21 as cluster };
    const type_21: string[];
    export { type_21 as type };
    export function convert_21(model: any, msg: any, publish: any, options: any, meta: any): {
        occupancy_timeout: any;
    };
    export { convert_21 as convert };
}
export namespace brightness {
    const cluster_22: string;
    export { cluster_22 as cluster };
    const type_22: string[];
    export { type_22 as type };
    export function convert_22(model: any, msg: any, publish: any, options: any, meta: any): {
        [x: number]: any;
    };
    export { convert_22 as convert };
}
export namespace level_config {
    const cluster_23: string;
    export { cluster_23 as cluster };
    const type_23: string[];
    export { type_23 as type };
    export function convert_23(model: any, msg: any, publish: any, options: any, meta: any): {
        level_config: {};
    };
    export { convert_23 as convert };
}
export namespace color_colortemp {
    const cluster_24: string;
    export { cluster_24 as cluster };
    const type_24: string[];
    export { type_24 as type };
    const options_10: exposes.Binary[];
    export { options_10 as options };
    export function convert_24(model: any, msg: any, publish: any, options: any, meta: any): {
        color_temp: any;
        color_temp_startup: any;
        color_mode: any;
        color: {
            x: number;
            y: number;
            saturation: number;
            hue: number;
        };
        color_options: {
            execute_if_off: boolean;
        };
    } & {
        color_mode: any;
        color: any;
        color_temp: any;
    };
    export { convert_24 as convert };
}
export namespace metering_datek {
    const cluster_25: string;
    export { cluster_25 as cluster };
    const type_25: string[];
    export { type_25 as type };
    export function convert_25(model: any, msg: any, publish: any, options: any, meta: any): {
        power: any;
        energy: any;
    };
    export { convert_25 as convert };
}
export namespace meter_identification {
    const cluster_26: string;
    export { cluster_26 as cluster };
    const type_26: string[];
    export { type_26 as type };
    export function convert_26(model: any, msg: any, publish: any, options: any, meta: any): {};
    export { convert_26 as convert };
}
export namespace metering {
    const cluster_27: string;
    export { cluster_27 as cluster };
    const type_27: string[];
    export { type_27 as type };
    export function options_11(definition: any): exposes.Numeric[];
    export { options_11 as options };
    export function convert_27(model: any, msg: any, publish: any, options: any, meta: any): {
        power: any;
        energy: any;
    };
    export { convert_27 as convert };
}
export namespace EKO09738_metering {
    const cluster_28: string;
    export { cluster_28 as cluster };
    const type_28: string[];
    export { type_28 as type };
    export function convert_28(model: any, msg: any, publish: any, options: any, meta: any): {
        power: any;
        energy: any;
    };
    export { convert_28 as convert };
}
export namespace electrical_measurement {
    const cluster_29: string;
    export { cluster_29 as cluster };
    const type_29: string[];
    export { type_29 as type };
    const options_12: exposes.Numeric[];
    export { options_12 as options };
    export function convert_29(model: any, msg: any, publish: any, options: any, meta: any): {
        power_factor: any;
    };
    export { convert_29 as convert };
}
export namespace on_off {
    const cluster_30: string;
    export { cluster_30 as cluster };
    const type_30: string[];
    export { type_30 as type };
    const options_13: exposes.Binary[];
    export { options_13 as options };
    export function convert_30(model: any, msg: any, publish: any, options: any, meta: any): {};
    export { convert_30 as convert };
}
export namespace on_off_force_multiendpoint {
    const cluster_31: string;
    export { cluster_31 as cluster };
    const type_31: string[];
    export { type_31 as type };
    const options_14: exposes.Binary[];
    export { options_14 as options };
    export function convert_31(model: any, msg: any, publish: any, options: any, meta: any): {};
    export { convert_31 as convert };
}
export namespace on_off_skip_duplicate_transaction {
    const cluster_32: string;
    export { cluster_32 as cluster };
    const type_32: string[];
    export { type_32 as type };
    const options_15: exposes.Binary[];
    export { options_15 as options };
    export function convert_32(model: any, msg: any, publish: any, options: any, meta: any): {};
    export { convert_32 as convert };
}
export namespace power_on_behavior {
    const cluster_33: string;
    export { cluster_33 as cluster };
    const type_33: string[];
    export { type_33 as type };
    export function convert_33(model: any, msg: any, publish: any, options: any, meta: any): {
        [x: number]: any;
    };
    export { convert_33 as convert };
}
export namespace ias_no_alarm {
    const cluster_34: string;
    export { cluster_34 as cluster };
    const type_34: string[];
    export { type_34 as type };
    export function convert_34(model: any, msg: any, publish: any, options: any, meta: any): {
        tamper: boolean;
        battery_low: boolean;
    };
    export { convert_34 as convert };
}
export namespace ias_siren {
    const cluster_35: string;
    export { cluster_35 as cluster };
    const type_35: string;
    export { type_35 as type };
    export function convert_35(model: any, msg: any, publish: any, options: any, meta: any): {
        alarm: boolean;
        tamper: boolean;
        battery_low: boolean;
        supervision_reports: boolean;
        restore_reports: boolean;
        ac_status: boolean;
        test: boolean;
    };
    export { convert_35 as convert };
}
export namespace ias_water_leak_alarm_1 {
    const cluster_36: string;
    export { cluster_36 as cluster };
    const type_36: string;
    export { type_36 as type };
    export function convert_36(model: any, msg: any, publish: any, options: any, meta: any): {
        water_leak: boolean;
        tamper: boolean;
        battery_low: boolean;
    };
    export { convert_36 as convert };
}
export namespace ias_water_leak_alarm_1_report {
    const cluster_37: string;
    export { cluster_37 as cluster };
    const type_37: string;
    export { type_37 as type };
    export function convert_37(model: any, msg: any, publish: any, options: any, meta: any): {
        water_leak: boolean;
        tamper: boolean;
        battery_low: boolean;
    };
    export { convert_37 as convert };
}
export namespace ias_vibration_alarm_1 {
    const cluster_38: string;
    export { cluster_38 as cluster };
    const type_38: string;
    export { type_38 as type };
    export function convert_38(model: any, msg: any, publish: any, options: any, meta: any): {
        vibration: boolean;
        tamper: boolean;
        battery_low: boolean;
    };
    export { convert_38 as convert };
}
export namespace ias_vibration_alarm_1_with_timeout {
    const cluster_39: string;
    export { cluster_39 as cluster };
    const type_39: string;
    export { type_39 as type };
    const options_16: exposes.Numeric[];
    export { options_16 as options };
    export function convert_39(model: any, msg: any, publish: any, options: any, meta: any): {
        vibration: boolean;
        tamper: boolean;
        battery_low: boolean;
    };
    export { convert_39 as convert };
}
export namespace ias_gas_alarm_1 {
    const cluster_40: string;
    export { cluster_40 as cluster };
    const type_40: string;
    export { type_40 as type };
    export function convert_40(model: any, msg: any, publish: any, options: any, meta: any): {
        gas: boolean;
        tamper: boolean;
        battery_low: boolean;
    };
    export { convert_40 as convert };
}
export namespace ias_gas_alarm_2 {
    const cluster_41: string;
    export { cluster_41 as cluster };
    const type_41: string;
    export { type_41 as type };
    export function convert_41(model: any, msg: any, publish: any, options: any, meta: any): {
        gas: boolean;
        tamper: boolean;
        battery_low: boolean;
    };
    export { convert_41 as convert };
}
export namespace ias_smoke_alarm_1 {
    const cluster_42: string;
    export { cluster_42 as cluster };
    const type_42: string[];
    export { type_42 as type };
    export function convert_42(model: any, msg: any, publish: any, options: any, meta: any): {
        smoke: boolean;
        tamper: boolean;
        battery_low: boolean;
        supervision_reports: boolean;
        restore_reports: boolean;
        trouble: boolean;
        ac_status: boolean;
        test: boolean;
        battery_defect: boolean;
    };
    export { convert_42 as convert };
}
export namespace ias_contact_alarm_1 {
    const cluster_43: string;
    export { cluster_43 as cluster };
    const type_43: string;
    export { type_43 as type };
    export function convert_43(model: any, msg: any, publish: any, options: any, meta: any): {
        [x: number]: boolean;
    };
    export { convert_43 as convert };
}
export namespace ias_contact_alarm_1_report {
    const cluster_44: string;
    export { cluster_44 as cluster };
    const type_44: string;
    export { type_44 as type };
    export function convert_44(model: any, msg: any, publish: any, options: any, meta: any): {
        contact: boolean;
        tamper: boolean;
        battery_low: boolean;
    };
    export { convert_44 as convert };
}
export namespace ias_carbon_monoxide_alarm_1 {
    const cluster_45: string;
    export { cluster_45 as cluster };
    const type_45: string;
    export { type_45 as type };
    export function convert_45(model: any, msg: any, publish: any, options: any, meta: any): {
        carbon_monoxide: boolean;
        tamper: boolean;
        battery_low: boolean;
    };
    export { convert_45 as convert };
}
export namespace ias_carbon_monoxide_alarm_1_gas_alarm_2 {
    const cluster_46: string;
    export { cluster_46 as cluster };
    const type_46: string;
    export { type_46 as type };
    export function convert_46(model: any, msg: any, publish: any, options: any, meta: any): {
        carbon_monoxide: boolean;
        gas: boolean;
        tamper: boolean;
        battery_low: boolean;
        trouble: boolean;
        ac_connected: boolean;
        test: boolean;
        battery_defect: boolean;
    };
    export { convert_46 as convert };
}
export namespace ias_sos_alarm_2 {
    const cluster_47: string;
    export { cluster_47 as cluster };
    const type_47: string;
    export { type_47 as type };
    export function convert_47(model: any, msg: any, publish: any, options: any, meta: any): {
        sos: boolean;
        tamper: boolean;
        battery_low: boolean;
    };
    export { convert_47 as convert };
}
export namespace ias_occupancy_alarm_1 {
    const cluster_48: string;
    export { cluster_48 as cluster };
    const type_48: string;
    export { type_48 as type };
    export function convert_48(model: any, msg: any, publish: any, options: any, meta: any): {
        occupancy: boolean;
        tamper: boolean;
        battery_low: boolean;
    };
    export { convert_48 as convert };
}
export namespace ias_occupancy_alarm_1_report {
    const cluster_49: string;
    export { cluster_49 as cluster };
    const type_49: string;
    export { type_49 as type };
    export function convert_49(model: any, msg: any, publish: any, options: any, meta: any): {
        occupancy: boolean;
        tamper: boolean;
        battery_low: boolean;
    };
    export { convert_49 as convert };
}
export namespace ias_occupancy_alarm_2 {
    const cluster_50: string;
    export { cluster_50 as cluster };
    const type_50: string;
    export { type_50 as type };
    export function convert_50(model: any, msg: any, publish: any, options: any, meta: any): {
        occupancy: boolean;
        tamper: boolean;
        battery_low: boolean;
    };
    export { convert_50 as convert };
}
export namespace ias_alarm_only_alarm_1 {
    const cluster_51: string;
    export { cluster_51 as cluster };
    const type_51: string;
    export { type_51 as type };
    export function convert_51(model: any, msg: any, publish: any, options: any, meta: any): {
        alarm: boolean;
    };
    export { convert_51 as convert };
}
export namespace ias_occupancy_only_alarm_2 {
    const cluster_52: string;
    export { cluster_52 as cluster };
    const type_52: string;
    export { type_52 as type };
    export function convert_52(model: any, msg: any, publish: any, options: any, meta: any): {
        occupancy: boolean;
    };
    export { convert_52 as convert };
}
export namespace ias_occupancy_alarm_1_with_timeout {
    const cluster_53: string;
    export { cluster_53 as cluster };
    const type_53: string;
    export { type_53 as type };
    const options_17: exposes.Numeric[];
    export { options_17 as options };
    export function convert_53(model: any, msg: any, publish: any, options: any, meta: any): {
        occupancy: boolean;
        tamper: boolean;
        battery_low: boolean;
    };
    export { convert_53 as convert };
}
export namespace command_store {
    const cluster_54: string;
    export { cluster_54 as cluster };
    const type_54: string;
    export { type_54 as type };
    export function convert_54(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_54 as convert };
}
export namespace command_recall {
    const cluster_55: string;
    export { cluster_55 as cluster };
    const type_55: string;
    export { type_55 as type };
    export function convert_55(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_55 as convert };
}
export namespace command_panic {
    const cluster_56: string;
    export { cluster_56 as cluster };
    const type_56: string;
    export { type_56 as type };
    export function convert_56(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_56 as convert };
}
export namespace command_arm {
    const cluster_57: string;
    export { cluster_57 as cluster };
    const type_57: string;
    export { type_57 as type };
    export function convert_57(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
        action_code: any;
        action_zone: any;
    };
    export { convert_57 as convert };
}
export namespace command_arm_with_transaction {
    const cluster_58: string;
    export { cluster_58 as cluster };
    const type_58: string;
    export { type_58 as type };
    export function convert_58(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
        action_code: any;
        action_zone: any;
    };
    export { convert_58 as convert };
}
export namespace command_cover_stop {
    const cluster_59: string;
    export { cluster_59 as cluster };
    const type_59: string;
    export { type_59 as type };
    export function convert_59(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_59 as convert };
}
export namespace command_cover_open {
    const cluster_60: string;
    export { cluster_60 as cluster };
    const type_60: string;
    export { type_60 as type };
    export function convert_60(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_60 as convert };
}
export namespace command_cover_close {
    const cluster_61: string;
    export { cluster_61 as cluster };
    const type_61: string;
    export { type_61 as type };
    export function convert_61(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_61 as convert };
}
export namespace command_on {
    const cluster_62: string;
    export { cluster_62 as cluster };
    const type_62: string;
    export { type_62 as type };
    export function convert_62(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_62 as convert };
}
export namespace command_off {
    const cluster_63: string;
    export { cluster_63 as cluster };
    const type_63: string;
    export { type_63 as type };
    export function convert_63(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_63 as convert };
}
export namespace command_off_with_effect {
    const cluster_64: string;
    export { cluster_64 as cluster };
    const type_64: string;
    export { type_64 as type };
    export function convert_64(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_64 as convert };
}
export namespace command_toggle {
    const cluster_65: string;
    export { cluster_65 as cluster };
    const type_65: string;
    export { type_65 as type };
    export function convert_65(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_65 as convert };
}
export namespace command_move_to_level {
    const cluster_66: string;
    export { cluster_66 as cluster };
    const type_66: string[];
    export { type_66 as type };
    const options_18: exposes.Composite[];
    export { options_18 as options };
    export function convert_66(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
        action_level: any;
        action_transition_time: number;
    };
    export { convert_66 as convert };
}
export namespace command_move {
    const cluster_67: string;
    export { cluster_67 as cluster };
    const type_67: string[];
    export { type_67 as type };
    const options_19: exposes.Composite[];
    export { options_19 as options };
    export function convert_67(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
        action_rate: any;
    };
    export { convert_67 as convert };
}
export namespace command_step {
    const cluster_68: string;
    export { cluster_68 as cluster };
    const type_68: string[];
    export { type_68 as type };
    const options_20: exposes.Composite[];
    export { options_20 as options };
    export function convert_68(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
        action_step_size: any;
        action_transition_time: number;
    };
    export { convert_68 as convert };
}
export namespace command_stop {
    const cluster_69: string;
    export { cluster_69 as cluster };
    const type_69: string[];
    export { type_69 as type };
    const options_21: exposes.Composite[];
    export { options_21 as options };
    export function convert_69(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_69 as convert };
}
export namespace command_move_color_temperature {
    const cluster_70: string;
    export { cluster_70 as cluster };
    const type_70: string[];
    export { type_70 as type };
    export function convert_70(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
        action_rate: any;
        action_minimum: any;
        action_maximum: any;
    };
    export { convert_70 as convert };
}
export namespace command_step_color_temperature {
    const cluster_71: string;
    export { cluster_71 as cluster };
    const type_71: string;
    export { type_71 as type };
    export function convert_71(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
        action_step_size: any;
    };
    export { convert_71 as convert };
}
export namespace command_ehanced_move_to_hue_and_saturation {
    const cluster_72: string;
    export { cluster_72 as cluster };
    const type_72: string;
    export { type_72 as type };
    export function convert_72(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
        action_enhanced_hue: any;
        action_hue: number;
        action_saturation: any;
        action_transition_time: any;
    };
    export { convert_72 as convert };
}
export namespace command_step_hue {
    const cluster_73: string;
    export { cluster_73 as cluster };
    const type_73: string[];
    export { type_73 as type };
    export function convert_73(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
        action_step_size: any;
        action_transition_time: number;
    };
    export { convert_73 as convert };
}
export namespace command_step_saturation {
    const cluster_74: string;
    export { cluster_74 as cluster };
    const type_74: string[];
    export { type_74 as type };
    export function convert_74(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
        action_step_size: any;
        action_transition_time: number;
    };
    export { convert_74 as convert };
}
export namespace command_color_loop_set {
    const cluster_75: string;
    export { cluster_75 as cluster };
    const type_75: string;
    export { type_75 as type };
    export function convert_75(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
        action_update_flags: {
            action: boolean;
            direction: boolean;
            time: boolean;
            start_hue: boolean;
        };
        action_action: any;
        action_direction: string;
        action_time: any;
        action_start_hue: any;
    };
    export { convert_75 as convert };
}
export namespace command_move_to_color_temp {
    const cluster_76: string;
    export { cluster_76 as cluster };
    const type_76: string;
    export { type_76 as type };
    export function convert_76(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
        action_color_temperature: any;
        action_transition_time: any;
    };
    export { convert_76 as convert };
}
export namespace command_move_to_color {
    const cluster_77: string;
    export { cluster_77 as cluster };
    const type_77: string;
    export { type_77 as type };
    export function convert_77(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
        action_color: {
            x: any;
            y: any;
        };
        action_transition_time: any;
    };
    export { convert_77 as convert };
}
export namespace command_move_hue {
    const cluster_78: string;
    export { cluster_78 as cluster };
    const type_78: string;
    export { type_78 as type };
    export function convert_78(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
        action_rate: any;
    };
    export { convert_78 as convert };
}
export namespace command_move_to_saturation {
    const cluster_79: string;
    export { cluster_79 as cluster };
    const type_79: string;
    export { type_79 as type };
    export function convert_79(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
        action_saturation: any;
        action_transition_time: any;
    };
    export { convert_79 as convert };
}
export namespace command_move_to_hue {
    const cluster_80: string;
    export { cluster_80 as cluster };
    const type_80: string;
    export { type_80 as type };
    export function convert_80(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
        action_hue: any;
        action_transition_time: number;
        action_direction: string;
    };
    export { convert_80 as convert };
}
export namespace command_emergency {
    const cluster_81: string;
    export { cluster_81 as cluster };
    const type_81: string;
    export { type_81 as type };
    export function convert_81(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_81 as convert };
}
export namespace command_on_state {
    const cluster_82: string;
    export { cluster_82 as cluster };
    const type_82: string;
    export { type_82 as type };
    export function convert_82(model: any, msg: any, publish: any, options: any, meta: any): {
        [x: number]: string;
    };
    export { convert_82 as convert };
}
export namespace command_off_state {
    const cluster_83: string;
    export { cluster_83 as cluster };
    const type_83: string;
    export { type_83 as type };
    export function convert_83(model: any, msg: any, publish: any, options: any, meta: any): {
        [x: number]: string;
    };
    export { convert_83 as convert };
}
export namespace identify {
    const cluster_84: string;
    export { cluster_84 as cluster };
    const type_84: string[];
    export { type_84 as type };
    export function convert_84(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_84 as convert };
}
export namespace cover_position_tilt {
    const cluster_85: string;
    export { cluster_85 as cluster };
    const type_85: string[];
    export { type_85 as type };
    const options_22: exposes.Binary[];
    export { options_22 as options };
    export function convert_85(model: any, msg: any, publish: any, options: any, meta: any): {};
    export { convert_85 as convert };
}
export namespace cover_position_via_brightness {
    const cluster_86: string;
    export { cluster_86 as cluster };
    const type_86: string[];
    export { type_86 as type };
    const options_23: exposes.Binary[];
    export { options_23 as options };
    export function convert_86(model: any, msg: any, publish: any, options: any, meta: any): {
        state: string;
        position: number;
    };
    export { convert_86 as convert };
}
export namespace cover_state_via_onoff {
    const cluster_87: string;
    export { cluster_87 as cluster };
    const type_87: string[];
    export { type_87 as type };
    export function convert_87(model: any, msg: any, publish: any, options: any, meta: any): {
        state: string;
    };
    export { convert_87 as convert };
}
export namespace curtain_position_analog_output {
    const cluster_88: string;
    export { cluster_88 as cluster };
    const type_88: string[];
    export { type_88 as type };
    const options_24: exposes.Binary[];
    export { options_24 as options };
    export function convert_88(model: any, msg: any, publish: any, options: any, meta: any): {
        position: any;
    };
    export { convert_88 as convert };
}
export namespace lighting_ballast_configuration {
    const cluster_89: string;
    export { cluster_89 as cluster };
    const type_89: string[];
    export { type_89 as type };
    export function convert_89(model: any, msg: any, publish: any, options: any, meta: any): {
        ballast_status_non_operational: boolean;
        ballast_status_lamp_failure: boolean;
        ballast_minimum_level: any;
        ballast_maximum_level: any;
        ballast_power_on_level: any;
        ballast_power_on_fade_time: any;
        ballast_intrinsic_ballast_factor: any;
        ballast_ballast_factor_adjustment: any;
        ballast_lamp_quantity: any;
        ballast_lamp_type: any;
        ballast_lamp_manufacturer: any;
        ballast_lamp_rated_hours: any;
        ballast_lamp_burn_hours: any;
        ballast_lamp_alarm_lamp_burn_hours: boolean;
        ballast_lamp_burn_hours_trip_point: any;
    };
    export { convert_89 as convert };
}
export namespace checkin_presence {
    const cluster_90: string;
    export { cluster_90 as cluster };
    const type_90: string[];
    export { type_90 as type };
    const options_25: exposes.Numeric[];
    export { options_25 as options };
    export function convert_90(model: any, msg: any, publish: any, options: any, meta: any): {
        presence: boolean;
    };
    export { convert_90 as convert };
}
export namespace ias_enroll {
    const cluster_91: string;
    export { cluster_91 as cluster };
    const type_91: string[];
    export { type_91 as type };
    export function convert_91(model: any, msg: any, publish: any, options: any, meta: any): {
        enrolled: boolean;
        ias_cie_address: any;
        zone_id: any;
    };
    export { convert_91 as convert };
}
export namespace ias_wd {
    const cluster_92: string;
    export { cluster_92 as cluster };
    const type_92: string[];
    export { type_92 as type };
    export function convert_92(model: any, msg: any, publish: any, options: any, meta: any): {
        max_duration: any;
    };
    export { convert_92 as convert };
}
export namespace power_source {
    const cluster_93: string;
    export { cluster_93 as cluster };
    const type_93: string[];
    export { type_93 as type };
    export function convert_93(model: any, msg: any, publish: any, options: any, meta: any): {
        power_source: any;
        ac_connected: boolean;
        charging: boolean;
    };
    export { convert_93 as convert };
}
export namespace namron_thermostat {
    const cluster_94: string;
    export { cluster_94 as cluster };
    const type_94: string[];
    export { type_94 as type };
    export function convert_94(model: any, msg: any, publish: any, options: any, meta: any): {
        lcd_brightness: any;
        button_vibration_level: any;
        floor_sensor_type: any;
        sensor: any;
        powerup_status: any;
        floor_sensor_calibration: number;
        dry_time: any;
        mode_after_dry: any;
        temperature_display: any;
        window_open_check: number;
        hysterersis: number;
        display_auto_off_enabled: string;
        alarm_airtemp_overvalue: any;
        away_mode: string;
    };
    export { convert_94 as convert };
}
export namespace namron_hvac_user_interface {
    const cluster_95: string;
    export { cluster_95 as cluster };
    const type_95: string[];
    export { type_95 as type };
    export function convert_95(model: any, msg: any, publish: any, options: any, meta: any): {
        child_lock: string;
    };
    export { convert_95 as convert };
}
export namespace elko_thermostat {
    const cluster_96: string;
    export { cluster_96 as cluster };
    const type_96: string[];
    export { type_96 as type };
    export function convert_96(model: any, msg: any, publish: any, options: any, meta: any): {
        load: any;
        display_text: any;
        sensor: any;
        regulator_time: any;
        regulator_mode: string;
        system_mode: string;
        mean_power: any;
        floor_temp: number;
        night_switching: string;
        frost_guard: string;
        child_lock: string;
        max_floor_temp: any;
        running_state: string;
        local_temperature_calibration: number;
    };
    export { convert_96 as convert };
}
export namespace ias_smoke_alarm_1_develco {
    const cluster_97: string;
    export { cluster_97 as cluster };
    const type_97: string;
    export { type_97 as type };
    export function convert_97(model: any, msg: any, publish: any, options: any, meta: any): {
        smoke: boolean;
        battery_low: boolean;
        supervision_reports: boolean;
        restore_reports: boolean;
        test: boolean;
    };
    export { convert_97 as convert };
}
export namespace command_on_presence {
    const cluster_98: string;
    export { cluster_98 as cluster };
    const type_98: string;
    export { type_98 as type };
    export function convert_98(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
        presence: boolean;
    };
    export { convert_98 as convert };
}
export namespace ts0201_temperature_humidity_alarm {
    const cluster_99: string;
    export { cluster_99 as cluster };
    const type_99: string[];
    export { type_99 as type };
    export function convert_99(model: any, msg: any, publish: any, options: any, meta: any): {
        alarm_temperature_max: any;
        alarm_temperature_min: any;
        alarm_humidity_max: any;
        alarm_humidity_min: any;
        alarm_humidity: any;
        alarm_temperature: any;
    };
    export { convert_99 as convert };
}
export namespace ias_ace_occupancy_with_timeout {
    const cluster_100: string;
    export { cluster_100 as cluster };
    const type_100: string;
    export { type_100 as type };
    const options_26: exposes.Numeric[];
    export { options_26 as options };
    export function convert_100(model: any, msg: any, publish: any, options: any, meta: any): {
        occupancy: boolean;
    };
    export { convert_100 as convert };
}
export namespace tuya_led_controller {
    const cluster_101: string;
    export { cluster_101 as cluster };
    const type_101: string[];
    export { type_101 as type };
    const options_27: exposes.Binary[];
    export { options_27 as options };
    export function convert_101(model: any, msg: any, publish: any, options: any, meta: any): {
        color_temp: number;
        brightness: any;
        color_mode: string;
        color: {
            hue: number;
            h: number;
            saturation: number;
            s: number;
        };
    } & {
        color_mode: any;
        color: any;
        color_temp: any;
    };
    export { convert_101 as convert };
}
export namespace wiser_device_info {
    const cluster_102: string;
    export { cluster_102 as cluster };
    const type_102: string;
    export { type_102 as type };
    export function convert_102(model: any, msg: any, publish: any, options: any, meta: any): {
        ALG: any;
        occupied_heating_setpoint: number;
        local_temperature: number;
        pi_heating_demand: number;
        ADC: any;
        boost: string;
        MOT: any;
    };
    export { convert_102 as convert };
}
export namespace tuya_doorbell_button {
    const cluster_103: string;
    export { cluster_103 as cluster };
    const type_103: string;
    export { type_103 as type };
    export function convert_103(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
        tamper: boolean;
        battery_low: boolean;
    };
    export { convert_103 as convert };
}
export namespace terncy_knob {
    const cluster_104: string;
    export { cluster_104 as cluster };
    const type_104: string[];
    export { type_104 as type };
    export function convert_104(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
        action_direction: string;
        action_number: number;
    };
    export { convert_104 as convert };
}
export namespace DTB190502A1 {
    const cluster_105: string;
    export { cluster_105 as cluster };
    const type_105: string[];
    export { type_105 as type };
    export function convert_105(model: any, msg: any, publish: any, options: any, meta: any): {
        cpu_temperature: any;
        key_state: any;
        led_state: any;
    };
    export { convert_105 as convert };
}
export namespace ZNMS12LM_low_battery {
    const cluster_106: string;
    export { cluster_106 as cluster };
    const type_106: string[];
    export { type_106 as type };
    export function convert_106(model: any, msg: any, publish: any, options: any, meta: any): {
        battery_low: boolean;
    };
    export { convert_106 as convert };
}
export namespace xiaomi_lock_report {
    const cluster_107: string;
    export { cluster_107 as cluster };
    const type_107: string[];
    export { type_107 as type };
    export function convert_107(model: any, msg: any, publish: any, options: any, meta: any): {
        keyerror: boolean;
        inserted: any;
        forgotten?: undefined;
    } | {
        inserted: any;
        keyerror?: undefined;
        forgotten?: undefined;
    } | {
        forgotten: any;
        keyerror?: undefined;
        inserted?: undefined;
    };
    export { convert_107 as convert };
}
export namespace SP600_power {
    const cluster_108: string;
    export { cluster_108 as cluster };
    const type_108: string[];
    export { type_108 as type };
    export function convert_108(model: any, msg: any, publish: any, options: any, meta: any): {};
    export { convert_108 as convert };
}
export namespace stelpro_thermostat {
    const cluster_109: string;
    export { cluster_109 as cluster };
    const type_109: string[];
    export { type_109 as type };
    export function convert_109(model: any, msg: any, publish: any, options: any, meta: any): {};
    export { convert_109 as convert };
}
export namespace viessmann_thermostat {
    const cluster_110: string;
    export { cluster_110 as cluster };
    const type_110: string[];
    export { type_110 as type };
    export function convert_110(model: any, msg: any, publish: any, options: any, meta: any): {};
    export { convert_110 as convert };
}
export namespace ZigUP {
    const cluster_111: string;
    export { cluster_111 as cluster };
    const type_111: string[];
    export { type_111 as type };
    export function convert_111(model: any, msg: any, publish: any, options: any, meta: any): {
        [x: string]: any;
        state: string;
        cpu_temperature: any;
        external_temperature: any;
        external_humidity: any;
        s0_counts: any;
        adc_volt: any;
        dig_input: any;
        reason: any;
    };
    export { convert_111 as convert };
}
export namespace eurotronic_thermostat {
    const cluster_112: string;
    export { cluster_112 as cluster };
    const type_112: string[];
    export { type_112 as type };
    export function convert_112(model: any, msg: any, publish: any, options: any, meta: any): {};
    export { convert_112 as convert };
}
export namespace terncy_contact {
    const cluster_113: string;
    export { cluster_113 as cluster };
    const type_113: string;
    export { type_113 as type };
    export function convert_113(model: any, msg: any, publish: any, options: any, meta: any): {
        contact: boolean;
    };
    export { convert_113 as convert };
}
export namespace terncy_temperature {
    const cluster_114: string;
    export { cluster_114 as cluster };
    const type_114: string[];
    export { type_114 as type };
    const options_28: exposes.Numeric[];
    export { options_28 as options };
    export function convert_114(model: any, msg: any, publish: any, options: any, meta: any): {
        temperature: any;
    };
    export { convert_114 as convert };
}
export namespace ts0216_siren {
    const cluster_115: string;
    export { cluster_115 as cluster };
    const type_115: string[];
    export { type_115 as type };
    export function convert_115(model: any, msg: any, publish: any, options: any, meta: any): {
        duration: any;
        volume: number;
        alarm: boolean;
    };
    export { convert_115 as convert };
}
export namespace tuya_cover_options {
    const cluster_116: string;
    export { cluster_116 as cluster };
    const type_116: string[];
    export { type_116 as type };
    export function convert_116(model: any, msg: any, publish: any, options: any, meta: any): {};
    export { convert_116 as convert };
}
export namespace WSZ01_on_off_action {
    const cluster_117: number;
    export { cluster_117 as cluster };
    const type_117: string;
    export { type_117 as type };
    export function convert_117(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
    };
    export { convert_117 as convert };
}
export namespace tuya_on_off_action {
    const cluster_118: string;
    export { cluster_118 as cluster };
    const type_118: string;
    export { type_118 as type };
    export function convert_118(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
    };
    export { convert_118 as convert };
}
export namespace tuya_switch_scene {
    const cluster_119: string;
    export { cluster_119 as cluster };
    const type_119: string;
    export { type_119 as type };
    export function convert_119(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
        action_scene: any;
    };
    export { convert_119 as convert };
}
export namespace livolo_switch_state {
    const cluster_120: string;
    export { cluster_120 as cluster };
    const type_120: string[];
    export { type_120 as type };
    export function convert_120(model: any, msg: any, publish: any, options: any, meta: any): {
        state_left: string;
        state_right: string;
    };
    export { convert_120 as convert };
}
export namespace livolo_socket_state {
    const cluster_121: string;
    export { cluster_121 as cluster };
    const type_121: string[];
    export { type_121 as type };
    export function convert_121(model: any, msg: any, publish: any, options: any, meta: any): {
        state: string;
    };
    export { convert_121 as convert };
}
export namespace livolo_new_switch_state {
    const cluster_122: string;
    export { cluster_122 as cluster };
    const type_122: string[];
    export { type_122 as type };
    export function convert_122(model: any, msg: any, publish: any, options: any, meta: any): {
        state: string;
    };
    export { convert_122 as convert };
}
export namespace livolo_new_switch_state_2gang {
    const cluster_123: string;
    export { cluster_123 as cluster };
    const type_123: string[];
    export { type_123 as type };
    export function convert_123(model: any, msg: any, publish: any, options: any, meta: any): {
        state_left: string;
        state_right: string;
    };
    export { convert_123 as convert };
}
export namespace livolo_new_switch_state_4gang {
    const cluster_124: string;
    export { cluster_124 as cluster };
    const type_124: string[];
    export { type_124 as type };
    export function convert_124(model: any, msg: any, publish: any, options: any, meta: any): {
        state_left: string;
        state_right: string;
        state_bottom_left: string;
        state_bottom_right: string;
    };
    export { convert_124 as convert };
}
export namespace livolo_curtain_switch_state {
    const cluster_125: string;
    export { cluster_125 as cluster };
    const type_125: string[];
    export { type_125 as type };
    export function convert_125(model: any, msg: any, publish: any, options: any, meta: any): {
        state_left: string;
        state_right: string;
    };
    export { convert_125 as convert };
}
export namespace livolo_dimmer_state {
    const cluster_126: string;
    export { cluster_126 as cluster };
    const type_126: string[];
    export { type_126 as type };
    export function convert_126(model: any, msg: any, publish: any, options: any, meta: any): {
        state: string;
        brightness?: undefined;
        brightness_percent?: undefined;
        level?: undefined;
    } | {
        brightness: number;
        brightness_percent: number;
        level: number;
        state?: undefined;
    };
    export { convert_126 as convert };
}
export namespace livolo_cover_state {
    const cluster_127: string;
    export { cluster_127 as cluster };
    const type_127: string[];
    export { type_127 as type };
    export function convert_127(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_127 as convert };
}
export namespace livolo_pir_state {
    const cluster_128: string;
    export { cluster_128 as cluster };
    const type_128: string[];
    export { type_128 as type };
    export function convert_128(model: any, msg: any, publish: any, options: any, meta: any): {
        occupancy: boolean;
    };
    export { convert_128 as convert };
}
export namespace easycode_action {
    const cluster_129: string;
    export { cluster_129 as cluster };
    const type_129: string;
    export { type_129 as type };
    export function convert_129(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_129 as convert };
}
export namespace easycodetouch_action {
    const cluster_130: string;
    export { cluster_130 as cluster };
    const type_130: string;
    export { type_130 as type };
    export function convert_130(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_130 as convert };
}
export namespace livolo_switch_state_raw {
    const cluster_131: string;
    export { cluster_131 as cluster };
    const type_131: string[];
    export { type_131 as type };
    export function convert_131(model: any, msg: any, publish: any, options: any, meta: any): {
        state_left: string;
        state_right: string;
    };
    export { convert_131 as convert };
}
export namespace ptvo_switch_uart {
    const cluster_132: string;
    export { cluster_132 as cluster };
    const type_132: string[];
    export { type_132 as type };
    export function convert_132(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_132 as convert };
}
export namespace ptvo_switch_analog_input {
    const cluster_133: string;
    export { cluster_133 as cluster };
    const type_133: string[];
    export { type_133 as type };
    export function convert_133(model: any, msg: any, publish: any, options: any, meta: any): {};
    export { convert_133 as convert };
}
export namespace keypad20states {
    const cluster_134: string;
    export { cluster_134 as cluster };
    const type_134: string[];
    export { type_134 as type };
    export function convert_134(model: any, msg: any, publish: any, options: any, meta: any): {
        [x: number]: boolean;
    };
    export { convert_134 as convert };
}
export namespace keypad20_battery {
    const cluster_135: string;
    export { cluster_135 as cluster };
    const type_135: string[];
    export { type_135 as type };
    export function convert_135(model: any, msg: any, publish: any, options: any, meta: any): {
        battery: number;
        voltage: number;
    };
    export { convert_135 as convert };
}
export namespace plaid_battery {
    const cluster_136: string;
    export { cluster_136 as cluster };
    const type_136: string[];
    export { type_136 as type };
    export function convert_136(model: any, msg: any, publish: any, options: any, meta: any): {
        voltage: any;
        battery: number;
    };
    export { convert_136 as convert };
}
export namespace heiman_ir_remote {
    const cluster_137: string;
    export { cluster_137 as cluster };
    const type_137: string[];
    export { type_137 as type };
    export function convert_137(model: any, msg: any, publish: any, options: any, meta: any): {
        devices: any;
    } | {
        action: string;
        action_result: string;
        action_key_code: any;
        action_id: any;
        action_model_type?: undefined;
    } | {
        action: string;
        action_result: string;
        action_model_type: any;
        action_id: any;
        action_key_code?: undefined;
    };
    export { convert_137 as convert };
}
export namespace meazon_meter {
    const cluster_138: string;
    export { cluster_138 as cluster };
    const type_138: string[];
    export { type_138 as type };
    export function convert_138(model: any, msg: any, publish: any, options: any, meta: any): {
        inlet_temperature: any;
        inletTemperature: any;
        status: any;
        line_frequency: any;
        linefrequency: any;
        power: any;
        voltage: any;
        current: any;
        reactive_power: any;
        reactivepower: any;
        energy_consumed: any;
        energyconsumed: any;
        energy: any;
        energy_produced: any;
        energyproduced: any;
        reactive_summation: any;
        reactivesummation: any;
        measure_serial: any;
        measureserial: any;
    };
    export { convert_138 as convert };
}
export namespace danfoss_thermostat {
    const cluster_139: string;
    export { cluster_139 as cluster };
    const type_139: string[];
    export { type_139 as type };
    export function convert_139(model: any, msg: any, publish: any, options: any, meta: any): {};
    export { convert_139 as convert };
}
export namespace danfoss_thermostat_setpoint_scheduled {
    const cluster_140: string;
    export { cluster_140 as cluster };
    const type_140: string[];
    export { type_140 as type };
    export function convert_140(model: any, msg: any, publish: any, options: any, meta: any): {};
    export { convert_140 as convert };
}
export namespace danfoss_icon_battery {
    const cluster_141: string;
    export { cluster_141 as cluster };
    const type_141: string[];
    export { type_141 as type };
    export function convert_141(model: any, msg: any, publish: any, options: any, meta: any): {};
    export { convert_141 as convert };
}
export namespace danfoss_icon_regulator {
    const cluster_142: string;
    export { cluster_142 as cluster };
    const type_142: string[];
    export { type_142 as type };
    export function convert_142(model: any, msg: any, publish: any, options: any, meta: any): {};
    export { convert_142 as convert };
}
export namespace orvibo_raw_1 {
    const cluster_143: number;
    export { cluster_143 as cluster };
    const type_143: string;
    export { type_143 as type };
    export function convert_143(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
    };
    export { convert_143 as convert };
}
export namespace orvibo_raw_2 {
    const cluster_144: number;
    export { cluster_144 as cluster };
    const type_144: string;
    export { type_144 as type };
    export function convert_144(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
    };
    export { convert_144 as convert };
}
export namespace tint_scene {
    const cluster_145: string;
    export { cluster_145 as cluster };
    const type_145: string;
    export { type_145 as type };
    export function convert_145(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
    };
    export { convert_145 as convert };
}
export namespace tint404011_move_to_color_temp {
    const cluster_146: string;
    export { cluster_146 as cluster };
    const type_146: string;
    export { type_146 as type };
    export function convert_146(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
        action_color_temperature: any;
        action_transition_time: any;
        action_color_temperature_direction: string;
    };
    export { convert_146 as convert };
}
export namespace ZNMS11LM_closuresDoorLock_report {
    const cluster_147: string;
    export { cluster_147 as cluster };
    const type_147: string[];
    export { type_147 as type };
    const options_29: exposes.Binary[];
    export { options_29 as options };
    export function convert_147(model: any, msg: any, publish: any, options: any, meta: any): {
        data: any;
        action: any;
        action_user: number;
        action_action: string;
        action_repeat: number;
        repeat: number;
        user: number;
    };
    export { convert_147 as convert };
}
export namespace ZNMS12LM_ZNMS13LM_closuresDoorLock_report {
    const cluster_148: string;
    export { cluster_148 as cluster };
    const type_148: string[];
    export { type_148 as type };
    const options_30: exposes.Binary[];
    export { options_30 as options };
    export function convert_148(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
        state: string;
        reverse: string;
        action_user: number;
        action_repeat: number;
        repeat: number;
        user: number;
    };
    export { convert_148 as convert };
}
export namespace restorable_brightness {
    const cluster_149: string;
    export { cluster_149 as cluster };
    const type_149: string[];
    export { type_149 as type };
    export function convert_149(model: any, msg: any, publish: any, options: any, meta: any): {
        brightness: any;
    } | {
        brightness?: undefined;
    };
    export { convert_149 as convert };
}
export namespace E1524_E1810_toggle {
    const cluster_150: string;
    export { cluster_150 as cluster };
    const type_150: string;
    export { type_150 as type };
    export function convert_150(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_150 as convert };
}
export namespace ikea_arrow_click {
    const cluster_151: string;
    export { cluster_151 as cluster };
    const type_151: string;
    export { type_151 as type };
    export function convert_151(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
    };
    export { convert_151 as convert };
}
export namespace ikea_arrow_hold {
    const cluster_152: string;
    export { cluster_152 as cluster };
    const type_152: string;
    export { type_152 as type };
    export function convert_152(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
    };
    export { convert_152 as convert };
}
export namespace ikea_arrow_release {
    const cluster_153: string;
    export { cluster_153 as cluster };
    const type_153: string;
    export { type_153 as type };
    const options_31: exposes.Binary[];
    export { options_31 as options };
    export function convert_153(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
        duration: number;
        action_duration: number;
    };
    export { convert_153 as convert };
}
export namespace E1524_E1810_levelctrl {
    const cluster_154: string;
    export { cluster_154 as cluster };
    const type_154: string[];
    export { type_154 as type };
    export function convert_154(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_154 as convert };
}
export namespace ewelink_action {
    const cluster_155: string;
    export { cluster_155 as cluster };
    const type_155: string[];
    export { type_155 as type };
    export function convert_155(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_155 as convert };
}
export namespace diyruz_contact {
    const cluster_156: string;
    export { cluster_156 as cluster };
    const type_156: string[];
    export { type_156 as type };
    export function convert_156(model: any, msg: any, publish: any, options: any, meta: any): {
        contact: boolean;
    };
    export { convert_156 as convert };
}
export namespace diyruz_rspm {
    const cluster_157: string;
    export { cluster_157 as cluster };
    const type_157: string[];
    export { type_157 as type };
    export function convert_157(model: any, msg: any, publish: any, options: any, meta: any): {
        state: string;
        cpu_temperature: any;
        power: any;
        current: any;
        action: string;
    };
    export { convert_157 as convert };
}
export namespace K4003C_binary_input {
    const cluster_158: string;
    export { cluster_158 as cluster };
    const type_158: string;
    export { type_158 as type };
    export function convert_158(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
    };
    export { convert_158 as convert };
}
export namespace enocean_ptm215z {
    const cluster_159: string;
    export { cluster_159 as cluster };
    const type_159: string[];
    export { type_159 as type };
    export function convert_159(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_159 as convert };
}
export namespace enocean_ptm215ze {
    const cluster_160: string;
    export { cluster_160 as cluster };
    const type_160: string[];
    export { type_160 as type };
    export function convert_160(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_160 as convert };
}
export namespace enocean_ptm216z {
    const cluster_161: string;
    export { cluster_161 as cluster };
    const type_161: string[];
    export { type_161 as type };
    export function convert_161(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_161 as convert };
}
export namespace lifecontrolVoc {
    const cluster_162: string;
    export { cluster_162 as cluster };
    const type_162: string[];
    export { type_162 as type };
    const options_32: exposes.Numeric[];
    export { options_32 as options };
    export function convert_162(model: any, msg: any, publish: any, options: any, meta: any): {
        temperature: any;
        humidity: any;
        eco2: number;
        voc: number;
    };
    export { convert_162 as convert };
}
export namespace _8840100H_water_leak_alarm {
    const cluster_163: string;
    export { cluster_163 as cluster };
    const type_163: string;
    export { type_163 as type };
    export function convert_163(model: any, msg: any, publish: any, options: any, meta: any): {
        water_leak: boolean;
    };
    export { convert_163 as convert };
}
export namespace E1E_G7F_action {
    const cluster_164: number;
    export { cluster_164 as cluster };
    const type_164: string[];
    export { type_164 as type };
    export function convert_164(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_164 as convert };
}
export namespace diyruz_freepad_clicks {
    const cluster_165: string;
    export { cluster_165 as cluster };
    const type_165: string[];
    export { type_165 as type };
    export function convert_165(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
    };
    export { convert_165 as convert };
}
export namespace kmpcil_res005_occupancy {
    const cluster_166: string;
    export { cluster_166 as cluster };
    const type_166: string[];
    export { type_166 as type };
    export function convert_166(model: any, msg: any, publish: any, options: any, meta: any): {
        occupancy: boolean;
    };
    export { convert_166 as convert };
}
export namespace kmpcil_res005_on_off {
    const cluster_167: string;
    export { cluster_167 as cluster };
    const type_167: string[];
    export { type_167 as type };
    export function convert_167(model: any, msg: any, publish: any, options: any, meta: any): {
        state: string;
    };
    export { convert_167 as convert };
}
export namespace _3310_humidity {
    const cluster_168: string;
    export { cluster_168 as cluster };
    const type_168: string[];
    export { type_168 as type };
    const options_33: exposes.Numeric[];
    export { options_33 as options };
    export function convert_168(model: any, msg: any, publish: any, options: any, meta: any): {
        humidity: any;
    };
    export { convert_168 as convert };
}
export namespace smartthings_acceleration {
    const cluster_169: string;
    export { cluster_169 as cluster };
    const type_169: string[];
    export { type_169 as type };
    export function convert_169(model: any, msg: any, publish: any, options: any, meta: any): {
        moving: boolean;
        x_axis: any;
        y_axis: any;
        z_axis: number;
    };
    export { convert_169 as convert };
}
export namespace byun_smoke_false {
    const cluster_170: string;
    export { cluster_170 as cluster };
    const type_170: string[];
    export { type_170 as type };
    export function convert_170(model: any, msg: any, publish: any, options: any, meta: any): {
        smoke: boolean;
    };
    export { convert_170 as convert };
}
export namespace byun_smoke_true {
    const cluster_171: string;
    export { cluster_171 as cluster };
    const type_171: string[];
    export { type_171 as type };
    export function convert_171(model: any, msg: any, publish: any, options: any, meta: any): {
        smoke: boolean;
    };
    export { convert_171 as convert };
}
export namespace byun_gas_false {
    const cluster_172: number;
    export { cluster_172 as cluster };
    const type_172: string[];
    export { type_172 as type };
    export function convert_172(model: any, msg: any, publish: any, options: any, meta: any): {
        gas: boolean;
    };
    export { convert_172 as convert };
}
export namespace byun_gas_true {
    const cluster_173: string;
    export { cluster_173 as cluster };
    const type_173: string[];
    export { type_173 as type };
    export function convert_173(model: any, msg: any, publish: any, options: any, meta: any): {
        gas: boolean;
    };
    export { convert_173 as convert };
}
export namespace hue_smart_button_event {
    const cluster_174: string;
    export { cluster_174 as cluster };
    const type_174: string;
    export { type_174 as type };
    export function convert_174(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_174 as convert };
}
export namespace legrand_binary_input_moving {
    const cluster_175: string;
    export { cluster_175 as cluster };
    const type_175: string[];
    export { type_175 as type };
    export function convert_175(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
    };
    export { convert_175 as convert };
}
export namespace legrand_binary_input_on_off {
    const cluster_176: string;
    export { cluster_176 as cluster };
    const type_176: string[];
    export { type_176 as type };
    export function convert_176(model: any, msg: any, publish: any, options: any, meta: any): {
        [x: number]: string;
    };
    export { convert_176 as convert };
}
export namespace bticino_4027C_binary_input_moving {
    const cluster_177: string;
    export { cluster_177 as cluster };
    const type_177: string[];
    export { type_177 as type };
    const options_34: exposes.Binary[];
    export { options_34 as options };
    export function convert_177(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
        position: number;
    } | {
        action: string;
        position?: undefined;
    };
    export { convert_177 as convert };
}
export namespace legrand_scenes {
    const cluster_178: string;
    export { cluster_178 as cluster };
    const type_178: string;
    export { type_178 as type };
    export function convert_178(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_178 as convert };
}
export namespace legrand_master_switch_center {
    const cluster_179: string;
    export { cluster_179 as cluster };
    const type_179: string;
    export { type_179 as type };
    export function convert_179(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
    };
    export { convert_179 as convert };
}
export namespace legrand_cluster_fc01 {
    const cluster_180: string;
    export { cluster_180 as cluster };
    const type_180: string[];
    export { type_180 as type };
    export function convert_180(model: any, msg: any, publish: any, options: any, meta: any): {
        device_mode: string;
        led_when_off: string;
        led_when_on: string;
    };
    export { convert_180 as convert };
}
export namespace legrand_cable_outlet_mode {
    const cluster_181: string;
    export { cluster_181 as cluster };
    const type_181: string[];
    export { type_181 as type };
    export function convert_181(model: any, msg: any, publish: any, options: any, meta: any): {
        cable_outlet_mode: string;
    };
    export { convert_181 as convert };
}
export namespace legrand_power_alarm {
    const cluster_182: string;
    export { cluster_182 as cluster };
    const type_182: string[];
    export { type_182 as type };
    export function convert_182(model: any, msg: any, publish: any, options: any, meta: any): {
        power_alarm_active_value: any;
        power_alarm_active: boolean;
        power_alarm_enabled: any;
        power_alarm_wh_threshold: any;
    };
    export { convert_182 as convert };
}
export namespace legrand_greenpower_254 {
    const cluster_183: string;
    export { cluster_183 as cluster };
    const type_183: string[];
    export { type_183 as type };
    export function convert_183(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_183 as convert };
}
export namespace legrand_zlgp17_zlgp18 {
    const cluster_184: string;
    export { cluster_184 as cluster };
    const type_184: string[];
    export { type_184 as type };
    export function convert_184(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_184 as convert };
}
export namespace xiaomi_power {
    const cluster_185: string;
    export { cluster_185 as cluster };
    const type_185: string[];
    export { type_185 as type };
    const options_35: exposes.Numeric[];
    export { options_35 as options };
    export function convert_185(model: any, msg: any, publish: any, options: any, meta: any): {
        power: any;
    };
    export { convert_185 as convert };
}
export namespace xiaomi_basic {
    const cluster_186: string;
    export { cluster_186 as cluster };
    const type_186: string[];
    export { type_186 as type };
    const options_36: any;
    export { options_36 as options };
    export function convert_186(model: any, msg: any, publish: any, options: any, meta: any): Promise<any>;
    export { convert_186 as convert };
}
export namespace xiaomi_basic_raw {
    const cluster_187: string;
    export { cluster_187 as cluster };
    const type_187: string[];
    export { type_187 as type };
    const options_37: any;
    export { options_37 as options };
    export function convert_187(model: any, msg: any, publish: any, options: any, meta: any): Promise<{}>;
    export { convert_187 as convert };
}
export namespace aqara_opple {
    const cluster_188: string;
    export { cluster_188 as cluster };
    const type_188: string[];
    export { type_188 as type };
    const options_38: any;
    export { options_38 as options };
    export function convert_188(model: any, msg: any, publish: any, options: any, meta: any): Promise<any>;
    export { convert_188 as convert };
}
export namespace xiaomi_on_off_action {
    const cluster_189: string;
    export { cluster_189 as cluster };
    const type_189: string[];
    export { type_189 as type };
    const options_39: exposes.Binary[];
    export { options_39 as options };
    export function convert_189(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
    };
    export { convert_189 as convert };
}
export namespace xiaomi_multistate_action {
    const cluster_190: string;
    export { cluster_190 as cluster };
    const type_190: string[];
    export { type_190 as type };
    export function convert_190(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_190 as convert };
}
export namespace RTCGQ11LM_illuminance {
    const cluster_191: string;
    export { cluster_191 as cluster };
    const type_191: string[];
    export { type_191 as type };
    const options_40: exposes.Numeric[];
    export { options_40 as options };
    export function convert_191(model: any, msg: any, publish: any, options: any, meta: any): {
        occupancy: boolean;
    };
    export { convert_191 as convert };
}
export namespace aqara_occupancy_illuminance {
    const cluster_192: string;
    export { cluster_192 as cluster };
    const type_192: string[];
    export { type_192 as type };
    const options_41: (exposes.Numeric | exposes.List)[];
    export { options_41 as options };
    export function convert_192(model: any, msg: any, publish: any, options: any, meta: any): {
        occupancy: boolean;
        illuminance: any;
    };
    export { convert_192 as convert };
}
export namespace RTCGQ13LM_occupancy {
    const cluster_193: string;
    export { cluster_193 as cluster };
    const type_193: string[];
    export { type_193 as type };
    const options_42: (exposes.Numeric | exposes.List)[];
    export { options_42 as options };
    export function convert_193(model: any, msg: any, publish: any, options: any, meta: any): {
        occupancy: boolean;
    };
    export { convert_193 as convert };
}
export namespace xiaomi_WXKG01LM_action {
    const cluster_194: string;
    export { cluster_194 as cluster };
    const type_194: string[];
    export { type_194 as type };
    const options_43: any[];
    export { options_43 as options };
    export function convert_194(model: any, msg: any, publish: any, options: any, meta: any): void;
    export { convert_194 as convert };
}
export namespace xiaomi_contact {
    const cluster_195: string;
    export { cluster_195 as cluster };
    const type_195: string[];
    export { type_195 as type };
    export function convert_195(model: any, msg: any, publish: any, options: any, meta: any): {
        contact: boolean;
    };
    export { convert_195 as convert };
}
export namespace W2_module_carbon_monoxide {
    const cluster_196: string;
    export { cluster_196 as cluster };
    const type_196: string;
    export { type_196 as type };
    export function convert_196(model: any, msg: any, publish: any, options: any, meta: any): {
        carbon_monoxide: boolean;
    };
    export { convert_196 as convert };
}
export namespace xiaomi_temperature {
    const cluster_197: string;
    export { cluster_197 as cluster };
    const options_44: exposes.Numeric[];
    export { options_44 as options };
    const type_197: string[];
    export { type_197 as type };
    export function convert_197(model: any, msg: any, publish: any, options: any, meta: any): {
        temperature: any;
    };
    export { convert_197 as convert };
}
export namespace xiaomi_WXKG11LM_action {
    const cluster_198: string;
    export { cluster_198 as cluster };
    const type_198: string[];
    export { type_198 as type };
    export function convert_198(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_198 as convert };
}
export namespace command_status_change_notification_action {
    const cluster_199: string;
    export { cluster_199 as cluster };
    const type_199: string;
    export { type_199 as type };
    export function convert_199(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_199 as convert };
}
export namespace ptvo_multistate_action {
    const cluster_200: string;
    export { cluster_200 as cluster };
    const type_200: string[];
    export { type_200 as type };
    export function convert_200(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_200 as convert };
}
export namespace terncy_raw {
    const cluster_201: string;
    export { cluster_201 as cluster };
    const type_201: string;
    export { type_201 as type };
    export function convert_201(model: any, msg: any, publish: any, options: any, meta: any): {
        occupancy: boolean;
    } | {
        action: any;
    };
    export { convert_201 as convert };
}
export namespace konke_action {
    const cluster_202: string;
    export { cluster_202 as cluster };
    const type_202: string[];
    export { type_202 as type };
    export function convert_202(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_202 as convert };
}
export namespace xiaomi_curtain_position {
    const cluster_203: string;
    export { cluster_203 as cluster };
    const type_203: string[];
    export { type_203 as type };
    const options_45: exposes.Binary[];
    export { options_45 as options };
    export function convert_203(model: any, msg: any, publish: any, options: any, meta: any): {
        position: any;
    };
    export { convert_203 as convert };
}
export namespace xiaomi_curtain_position_tilt {
    const cluster_204: string;
    export { cluster_204 as cluster };
    const type_204: string[];
    export { type_204 as type };
    const options_46: exposes.Binary[];
    export { options_46 as options };
    export function convert_204(model: any, msg: any, publish: any, options: any, meta: any): {};
    export { convert_204 as convert };
}
export namespace xiaomi_curtain_hagl04_status {
    const cluster_205: string;
    export { cluster_205 as cluster };
    const type_205: string[];
    export { type_205 as type };
    export function convert_205(model: any, msg: any, publish: any, options: any, meta: any): {
        motor_state: any;
        running: boolean;
    };
    export { convert_205 as convert };
}
export namespace xiaomi_curtain_hagl07_status {
    const cluster_206: string;
    export { cluster_206 as cluster };
    const type_206: string[];
    export { type_206 as type };
    export function convert_206(model: any, msg: any, publish: any, options: any, meta: any): {
        motor_state: any;
        running: boolean;
    };
    export { convert_206 as convert };
}
export namespace xiaomi_curtain_acn002_status {
    const cluster_207: string;
    export { cluster_207 as cluster };
    const type_207: string[];
    export { type_207 as type };
    export function convert_207(model: any, msg: any, publish: any, options: any, meta: any): {
        motor_state: any;
        running: boolean;
    };
    export { convert_207 as convert };
}
export namespace xiaomi_operation_mode_basic {
    const cluster_208: string;
    export { cluster_208 as cluster };
    const type_208: string[];
    export { type_208 as type };
    export function convert_208(model: any, msg: any, publish: any, options: any, meta: any): {
        operation_mode: any;
    };
    export { convert_208 as convert };
}
export namespace qlwz_letv8key_switch {
    const cluster_209: string;
    export { cluster_209 as cluster };
    const type_209: string[];
    export { type_209 as type };
    export function convert_209(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
    };
    export { convert_209 as convert };
}
export namespace aqara_opple_multistate {
    const cluster_210: string;
    export { cluster_210 as cluster };
    const type_210: string[];
    export { type_210 as type };
    export function convert_210(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
    };
    export { convert_210 as convert };
}
export namespace aqara_opple_on {
    const cluster_211: string;
    export { cluster_211 as cluster };
    const type_211: string;
    export { type_211 as type };
    export function convert_211(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
    };
    export { convert_211 as convert };
}
export namespace aqara_opple_off {
    const cluster_212: string;
    export { cluster_212 as cluster };
    const type_212: string;
    export { type_212 as type };
    export function convert_212(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
    };
    export { convert_212 as convert };
}
export namespace aqara_opple_step {
    const cluster_213: string;
    export { cluster_213 as cluster };
    const type_213: string;
    export { type_213 as type };
    export function convert_213(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
    };
    export { convert_213 as convert };
}
export namespace aqara_opple_stop {
    const cluster_214: string;
    export { cluster_214 as cluster };
    const type_214: string;
    export { type_214 as type };
    const options_47: exposes.Binary[];
    export { options_47 as options };
    export function convert_214(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
        duration: number;
        action_duration: number;
    };
    export { convert_214 as convert };
}
export namespace aqara_opple_move {
    const cluster_215: string;
    export { cluster_215 as cluster };
    const type_215: string;
    export { type_215 as type };
    export function convert_215(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
    };
    export { convert_215 as convert };
}
export namespace aqara_opple_step_color_temp {
    const cluster_216: string;
    export { cluster_216 as cluster };
    const type_216: string;
    export { type_216 as type };
    export function convert_216(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
    };
    export { convert_216 as convert };
}
export namespace aqara_opple_move_color_temp {
    const cluster_217: string;
    export { cluster_217 as cluster };
    const type_217: string;
    export { type_217 as type };
    const options_48: exposes.Binary[];
    export { options_48 as options };
    export function convert_217(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
        duration: number;
        action_duration: number;
    } | {
        action: string;
        duration?: undefined;
        action_duration?: undefined;
    };
    export { convert_217 as convert };
}
export namespace keen_home_smart_vent_pressure {
    const cluster_218: string;
    export { cluster_218 as cluster };
    const type_218: string[];
    export { type_218 as type };
    const options_49: exposes.Numeric[];
    export { options_49 as options };
    export function convert_218(model: any, msg: any, publish: any, options: any, meta: any): {
        pressure: any;
    };
    export { convert_218 as convert };
}
export namespace U02I007C01_contact {
    const cluster_219: string;
    export { cluster_219 as cluster };
    const type_219: string;
    export { type_219 as type };
    export function convert_219(model: any, msg: any, publish: any, options: any, meta: any): {
        contact: boolean;
    };
    export { convert_219 as convert };
}
export namespace U02I007C01_water_leak {
    const cluster_220: string;
    export { cluster_220 as cluster };
    const type_220: string;
    export { type_220 as type };
    export function convert_220(model: any, msg: any, publish: any, options: any, meta: any): {
        water_leak: boolean;
    };
    export { convert_220 as convert };
}
export namespace heiman_hcho {
    const cluster_221: string;
    export { cluster_221 as cluster };
    const type_221: string[];
    export { type_221 as type };
    export function convert_221(model: any, msg: any, publish: any, options: any, meta: any): {
        hcho: number;
    };
    export { convert_221 as convert };
}
export namespace heiman_air_quality {
    const cluster_222: string;
    export { cluster_222 as cluster };
    const type_222: string[];
    export { type_222 as type };
    export function convert_222(model: any, msg: any, publish: any, options: any, meta: any): {
        battery_state: any;
        voc: any;
        aqi: any;
        pm10: any;
    };
    export { convert_222 as convert };
}
export namespace scenes_recall_scene_65024 {
    const cluster_223: number;
    export { cluster_223 as cluster };
    const type_223: string[];
    export { type_223 as type };
    export function convert_223(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
    };
    export { convert_223 as convert };
}
export namespace color_stop_raw {
    const cluster_224: string;
    export { cluster_224 as cluster };
    const type_224: string[];
    export { type_224 as type };
    export function convert_224(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_224 as convert };
}
export namespace MFKZQ01LM_action_multistate {
    const cluster_225: string;
    export { cluster_225 as cluster };
    const type_225: string[];
    export { type_225 as type };
    const options_50: exposes.Binary[];
    export { options_50 as options };
    export function convert_225(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
        side: number;
        action_from_side?: undefined;
        action_to_side?: undefined;
        action_side?: undefined;
        from_side?: undefined;
        to_side?: undefined;
    } | {
        action: string;
        action_from_side: number;
        action_to_side: number;
        action_side: number;
        from_side: number;
        to_side: number;
        side: number;
    } | {
        action: string;
        side?: undefined;
        action_from_side?: undefined;
        action_to_side?: undefined;
        action_side?: undefined;
        from_side?: undefined;
        to_side?: undefined;
    };
    export { convert_225 as convert };
}
export namespace MFKZQ01LM_action_analog {
    const cluster_226: string;
    export { cluster_226 as cluster };
    const type_226: string[];
    export { type_226 as type };
    const options_51: exposes.Binary[];
    export { options_51 as options };
    export function convert_226(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
        angle: number;
        action_angle: number;
    };
    export { convert_226 as convert };
}
export namespace tradfri_occupancy {
    const cluster_227: string;
    export { cluster_227 as cluster };
    const type_227: string;
    export { type_227 as type };
    const options_52: (exposes.Numeric | exposes.Binary)[];
    export { options_52 as options };
    export function convert_227(model: any, msg: any, publish: any, options: any, meta: any): {
        occupancy: boolean;
        illuminance_above_threshold: boolean;
    };
    export { convert_227 as convert };
}
export namespace almond_click {
    const cluster_228: string;
    export { cluster_228 as cluster };
    const type_228: string[];
    export { type_228 as type };
    export function convert_228(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_228 as convert };
}
export namespace SAGE206612_state {
    const cluster_229: string;
    export { cluster_229 as cluster };
    const type_229: string[];
    export { type_229 as type };
    export function convert_229(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_229 as convert };
}
export namespace ZMCSW032D_cover_position {
    const cluster_230: string;
    export { cluster_230 as cluster };
    const type_230: string[];
    export { type_230 as type };
    const options_53: any[];
    export { options_53 as options };
    export function convert_230(model: any, msg: any, publish: any, options: any, meta: any): {
        position: any;
        state: string;
    };
    export { convert_230 as convert };
}
export namespace PGC410EU_presence {
    const cluster_231: string;
    export { cluster_231 as cluster };
    const type_231: string;
    export { type_231 as type };
    const options_54: exposes.Numeric[];
    export { options_54 as options };
    export function convert_231(model: any, msg: any, publish: any, options: any, meta: any): {
        presence: boolean;
    };
    export { convert_231 as convert };
}
export namespace STS_PRS_251_presence {
    const cluster_232: string;
    export { cluster_232 as cluster };
    const type_232: string[];
    export { type_232 as type };
    const options_55: exposes.Numeric[];
    export { options_55 as options };
    export function convert_232(model: any, msg: any, publish: any, options: any, meta: any): {
        presence: boolean;
    };
    export { convert_232 as convert };
}
export namespace E1745_requested_brightness {
    const cluster_233: string;
    export { cluster_233 as cluster };
    const type_233: string;
    export { type_233 as type };
    export function convert_233(model: any, msg: any, publish: any, options: any, meta: any): {
        requested_brightness_level: any;
        requested_brightness_percent: number;
    };
    export { convert_233 as convert };
}
export namespace xiaomi_bulb_interval {
    const cluster_234: string;
    export { cluster_234 as cluster };
    const type_234: string[];
    export { type_234 as type };
    export function convert_234(model: any, msg: any, publish: any, options: any, meta: any): {
        state: string;
        brightness: any;
        color_temp: any;
    };
    export { convert_234 as convert };
}
export namespace heiman_scenes {
    const cluster_235: string;
    export { cluster_235 as cluster };
    const type_235: string[];
    export { type_235 as type };
    export function convert_235(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_235 as convert };
}
export namespace javis_lock_report {
    const cluster_236: string;
    export { cluster_236 as cluster };
    const type_236: string;
    export { type_236 as type };
    export function convert_236(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
        action_user: number;
        action_source: number;
        action_source_name: any;
    };
    export { convert_236 as convert };
}
export namespace diyruz_freepad_config {
    const cluster_237: string;
    export { cluster_237 as cluster };
    const type_237: string[];
    export { type_237 as type };
    export function convert_237(model: any, msg: any, publish: any, options: any, meta: any): {
        [x: string]: string;
    };
    export { convert_237 as convert };
}
export namespace diyruz_geiger {
    const cluster_238: string;
    export { cluster_238 as cluster };
    const type_238: string[];
    export { type_238 as type };
    export function convert_238(model: any, msg: any, publish: any, options: any, meta: any): {
        radioactive_events_per_minute: any;
        radiation_dose_per_hour: any;
    };
    export { convert_238 as convert };
}
export namespace diyruz_geiger_config {
    const cluster_239: string;
    export { cluster_239 as cluster };
    const type_239: string;
    export { type_239 as type };
    export function convert_239(model: any, msg: any, publish: any, options: any, meta: any): {
        led_feedback: string;
        buzzer_feedback: string;
        sensitivity: any;
        sensors_count: any;
        sensors_type: string;
        alert_threshold: any;
    };
    export { convert_239 as convert };
}
export namespace diyruz_airsense_config_co2 {
    const cluster_240: string;
    export { cluster_240 as cluster };
    const type_240: string;
    export { type_240 as type };
    export function convert_240(model: any, msg: any, publish: any, options: any, meta: any): {
        led_feedback: string;
        enable_abc: string;
        threshold1: any;
        threshold2: any;
    };
    export { convert_240 as convert };
}
export namespace diyruz_airsense_config_temp {
    const cluster_241: string;
    export { cluster_241 as cluster };
    const type_241: string;
    export { type_241 as type };
    export function convert_241(model: any, msg: any, publish: any, options: any, meta: any): {
        temperature_offset: any;
    };
    export { convert_241 as convert };
}
export namespace diyruz_airsense_config_pres {
    const cluster_242: string;
    export { cluster_242 as cluster };
    const type_242: string;
    export { type_242 as type };
    export function convert_242(model: any, msg: any, publish: any, options: any, meta: any): {
        pressure_offset: any;
    };
    export { convert_242 as convert };
}
export namespace diyruz_airsense_config_hum {
    const cluster_243: string;
    export { cluster_243 as cluster };
    const type_243: string;
    export { type_243 as type };
    export function convert_243(model: any, msg: any, publish: any, options: any, meta: any): {
        humidity_offset: any;
    };
    export { convert_243 as convert };
}
export namespace diyruz_zintercom_config {
    const cluster_244: string;
    export { cluster_244 as cluster };
    const type_244: string[];
    export { type_244 as type };
    export function convert_244(model: any, msg: any, publish: any, options: any, meta: any): {
        state: string;
        mode: string;
        sound: string;
        time_ring: any;
        time_talk: any;
        time_open: any;
        time_bell: any;
        time_report: any;
    };
    export { convert_244 as convert };
}
export namespace JTQJBF01LMBW_gas_density {
    const cluster_245: string;
    export { cluster_245 as cluster };
    const type_245: string[];
    export { type_245 as type };
    export function convert_245(model: any, msg: any, publish: any, options: any, meta: any): {
        gas_density: any;
    };
    export { convert_245 as convert };
}
export namespace JTYJGD01LMBW_smoke {
    const cluster_246: string;
    export { cluster_246 as cluster };
    const type_246: string;
    export { type_246 as type };
    export function convert_246(model: any, msg: any, publish: any, options: any, meta: any): {
        smoke: boolean;
        tamper: boolean;
        battery_low: boolean;
        supervision_reports: boolean;
        restore_reports: boolean;
        trouble: boolean;
        ac_status: boolean;
        test: boolean;
        battery_defect: boolean;
    };
    export { convert_246 as convert };
}
export namespace JTQJBF01LMBW_sensitivity {
    const cluster_247: string;
    export { cluster_247 as cluster };
    const type_247: string[];
    export { type_247 as type };
    export function convert_247(model: any, msg: any, publish: any, options: any, meta: any): {
        sensitivity: any;
    };
    export { convert_247 as convert };
}
export namespace DJT11LM_vibration {
    const cluster_248: string;
    export { cluster_248 as cluster };
    const type_248: string[];
    export { type_248 as type };
    const options_56: exposes.Numeric[];
    export { options_56 as options };
    export function convert_248(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
        vibration: boolean;
        angle: any;
        strength: number;
        angle_x: number;
        angle_y: number;
        angle_z: number;
        angle_x_absolute: number;
        angle_y_absolute: number;
    };
    export { convert_248 as convert };
}
export namespace DJT12LM_vibration {
    const cluster_249: string;
    export { cluster_249 as cluster };
    const type_249: string;
    export { type_249 as type };
    export function convert_249(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
    };
    export { convert_249 as convert };
}
export namespace CC2530ROUTER_led {
    const cluster_250: string;
    export { cluster_250 as cluster };
    const type_250: string[];
    export { type_250 as type };
    export function convert_250(model: any, msg: any, publish: any, options: any, meta: any): {
        led: boolean;
    };
    export { convert_250 as convert };
}
export namespace CC2530ROUTER_meta {
    const cluster_251: string;
    export { cluster_251 as cluster };
    const type_251: string[];
    export { type_251 as type };
    export function convert_251(model: any, msg: any, publish: any, options: any, meta: any): {
        description: any;
        type: any;
        rssi: any;
    };
    export { convert_251 as convert };
}
export namespace KAMI_contact {
    const cluster_252: string;
    export { cluster_252 as cluster };
    const type_252: string[];
    export { type_252 as type };
    export function convert_252(model: any, msg: any, publish: any, options: any, meta: any): {
        contact: boolean;
    };
    export { convert_252 as convert };
}
export namespace KAMI_occupancy {
    const cluster_253: string;
    export { cluster_253 as cluster };
    const type_253: string[];
    export { type_253 as type };
    export function convert_253(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
    };
    export { convert_253 as convert };
}
export namespace DNCKAT_S00X_buttons {
    const cluster_254: string;
    export { cluster_254 as cluster };
    const type_254: string[];
    export { type_254 as type };
    const options_57: exposes.Binary[];
    export { options_57 as options };
    export function convert_254(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_254 as convert };
}
export namespace xiaomi_on_off_ignore_endpoint_4_5_6 {
    const cluster_255: string;
    export { cluster_255 as cluster };
    const type_255: string[];
    export { type_255 as type };
    export function convert_255(model: any, msg: any, publish: any, options: any, meta: any): {
        [x: number]: string;
    };
    export { convert_255 as convert };
}
export namespace hue_motion_sensitivity {
    const cluster_256: string;
    export { cluster_256 as cluster };
    const type_256: string[];
    export { type_256 as type };
    export function convert_256(model: any, msg: any, publish: any, options: any, meta: any): {
        motion_sensitivity: string;
    };
    export { convert_256 as convert };
}
export namespace hue_motion_led_indication {
    const cluster_257: string;
    export { cluster_257 as cluster };
    const type_257: string[];
    export { type_257 as type };
    export function convert_257(model: any, msg: any, publish: any, options: any, meta: any): {
        led_indication: boolean;
    };
    export { convert_257 as convert };
}
export namespace hue_wall_switch_device_mode {
    const cluster_258: string;
    export { cluster_258 as cluster };
    const type_258: string[];
    export { type_258 as type };
    export function convert_258(model: any, msg: any, publish: any, options: any, meta: any): {
        device_mode: string;
    };
    export { convert_258 as convert };
}
export namespace CCTSwitch_D0001_levelctrl {
    const cluster_259: string;
    export { cluster_259 as cluster };
    const options_58: exposes.Binary[];
    export { options_58 as options };
    const type_259: string[];
    export { type_259 as type };
    export function convert_259(model: any, msg: any, publish: any, options: any, meta: any): {
        click: string;
        action: string;
        duration: number;
        action_duration: number;
        rate: any;
        action_rate: any;
        action_brightness: any;
        action_transition: number;
        brightness: any;
        transition: number;
    };
    export { convert_259 as convert };
}
export namespace CCTSwitch_D0001_lighting {
    const cluster_260: string;
    export { cluster_260 as cluster };
    const type_260: string[];
    export { type_260 as type };
    const options_59: exposes.Binary[];
    export { options_59 as options };
    export function convert_260(model: any, msg: any, publish: any, options: any, meta: any): {
        click: any;
        rate: any;
        action_rate: any;
        action: string;
        duration: number;
        action_duration: number;
        color_temp: any;
        transition: number;
        action_color_temp: any;
        action_transition: number;
        brightness: any;
        action_brightness: any;
    };
    export { convert_260 as convert };
}
export namespace hue_wall_switch {
    const cluster_261: string;
    export { cluster_261 as cluster };
    const type_261: string;
    export { type_261 as type };
    export function convert_261(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
    };
    export { convert_261 as convert };
}
export namespace hue_dimmer_switch {
    const cluster_262: string;
    export { cluster_262 as cluster };
    const type_262: string;
    export { type_262 as type };
    const options_60: exposes.Composite[];
    export { options_60 as options };
    export function convert_262(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
    };
    export { convert_262 as convert };
}
export namespace hue_tap {
    const cluster_263: string;
    export { cluster_263 as cluster };
    const type_263: string[];
    export { type_263 as type };
    export function convert_263(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_263 as convert };
}
export namespace tuya_relay_din_led_indicator {
    const cluster_264: string;
    export { cluster_264 as cluster };
    const type_264: string[];
    export { type_264 as type };
    export function convert_264(model: any, msg: any, publish: any, options: any, meta: any): {
        [x: number]: any;
    };
    export { convert_264 as convert };
}
export namespace ias_keypad {
    const cluster_265: string;
    export { cluster_265 as cluster };
    const type_265: string;
    export { type_265 as type };
    export function convert_265(model: any, msg: any, publish: any, options: any, meta: any): {
        tamper: boolean;
        battery_low: boolean;
        restore_reports: boolean;
    };
    export { convert_265 as convert };
}
export namespace itcmdr_clicks {
    const cluster_266: string;
    export { cluster_266 as cluster };
    const type_266: string[];
    export { type_266 as type };
    export function convert_266(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_266 as convert };
}
export namespace ZB003X_attr {
    const cluster_267: string;
    export { cluster_267 as cluster };
    const type_267: string[];
    export { type_267 as type };
    export function convert_267(model: any, msg: any, publish: any, options: any, meta: any): {
        sensitivity: any;
        keep_time?: undefined;
    } | {
        keep_time: any;
        sensitivity?: undefined;
    };
    export { convert_267 as convert };
}
export namespace ZB003X_occupancy {
    const cluster_268: string;
    export { cluster_268 as cluster };
    const type_268: string;
    export { type_268 as type };
    export function convert_268(model: any, msg: any, publish: any, options: any, meta: any): {
        occupancy: boolean;
        tamper: boolean;
    };
    export { convert_268 as convert };
}
export namespace ZM35HQ_attr {
    const cluster_269: string;
    export { cluster_269 as cluster };
    const type_269: string[];
    export { type_269 as type };
    export function convert_269(model: any, msg: any, publish: any, options: any, meta: any): {
        sensitivity: any;
        keep_time: any;
    };
    export { convert_269 as convert };
}
export namespace idlock {
    const cluster_270: string;
    export { cluster_270 as cluster };
    const type_270: string[];
    export { type_270 as type };
    export function convert_270(model: any, msg: any, publish: any, options: any, meta: any): {
        master_pin_mode: boolean;
        rfid_enable: boolean;
        service_mode: any;
        lock_mode: any;
        relock_enabled: boolean;
    };
    export { convert_270 as convert };
}
export namespace idlock_fw {
    const cluster_271: string;
    export { cluster_271 as cluster };
    const type_271: string[];
    export { type_271 as type };
    export function convert_271(model: any, msg: any, publish: any, options: any, meta: any): {
        idlock_lock_fw: any;
    };
    export { convert_271 as convert };
}
export namespace schneider_pilot_mode {
    const cluster_272: string;
    export { cluster_272 as cluster };
    const type_272: string[];
    export { type_272 as type };
    export function convert_272(model: any, msg: any, publish: any, options: any, meta: any): {
        schneider_pilot_mode: any;
    };
    export { convert_272 as convert };
}
export namespace schneider_lighting_ballast_configuration {
    const cluster_273: string;
    export { cluster_273 as cluster };
    const type_273: string[];
    export { type_273 as type };
    export function convert_273(model: any, msg: any, publish: any, options: any, meta: any): {
        ballast_status_non_operational: boolean;
        ballast_status_lamp_failure: boolean;
        ballast_minimum_level: any;
        ballast_maximum_level: any;
        ballast_power_on_level: any;
        ballast_power_on_fade_time: any;
        ballast_intrinsic_ballast_factor: any;
        ballast_ballast_factor_adjustment: any;
        ballast_lamp_quantity: any;
        ballast_lamp_type: any;
        ballast_lamp_manufacturer: any;
        ballast_lamp_rated_hours: any;
        ballast_lamp_burn_hours: any;
        ballast_lamp_alarm_lamp_burn_hours: boolean;
        ballast_lamp_burn_hours_trip_point: any;
    };
    export { convert_273 as convert };
}
export namespace wiser_lighting_ballast_configuration {
    const cluster_274: string;
    export { cluster_274 as cluster };
    const type_274: string[];
    export { type_274 as type };
    export function convert_274(model: any, msg: any, publish: any, options: any, meta: any): {
        ballast_status_non_operational: boolean;
        ballast_status_lamp_failure: boolean;
        ballast_minimum_level: any;
        ballast_maximum_level: any;
        ballast_power_on_level: any;
        ballast_power_on_fade_time: any;
        ballast_intrinsic_ballast_factor: any;
        ballast_ballast_factor_adjustment: any;
        ballast_lamp_quantity: any;
        ballast_lamp_type: any;
        ballast_lamp_manufacturer: any;
        ballast_lamp_rated_hours: any;
        ballast_lamp_burn_hours: any;
        ballast_lamp_alarm_lamp_burn_hours: boolean;
        ballast_lamp_burn_hours_trip_point: any;
    };
    export { convert_274 as convert };
}
export namespace schneider_ui_action {
    const cluster_275: string;
    export { cluster_275 as cluster };
    const type_275: string;
    export { type_275 as type };
    export function convert_275(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_275 as convert };
}
export namespace schneider_temperature {
    const cluster_276: string;
    export { cluster_276 as cluster };
    const type_276: string[];
    export { type_276 as type };
    const options_61: exposes.Numeric[];
    export { options_61 as options };
    export function convert_276(model: any, msg: any, publish: any, options: any, meta: any): {
        [x: number]: any;
    };
    export { convert_276 as convert };
}
export namespace wiser_smart_thermostat_client {
    const cluster_277: string;
    export { cluster_277 as cluster };
    const type_277: string;
    export { type_277 as type };
    export function convert_277(model: any, msg: any, publish: any, options: any, meta: any): Promise<void>;
    export { convert_277 as convert };
}
export namespace wiser_smart_thermostat {
    const cluster_278: string;
    export { cluster_278 as cluster };
    const type_278: string[];
    export { type_278 as type };
    export function convert_278(model: any, msg: any, publish: any, options: any, meta: any): Promise<void>;
    export { convert_278 as convert };
}
export namespace wiser_smart_setpoint_command_client {
    const cluster_279: string;
    export { cluster_279 as cluster };
    const type_279: string[];
    export { type_279 as type };
    export function convert_279(model: any, msg: any, publish: any, options: any, meta: any): {
        occupied_heating_setpoint: number;
    };
    export { convert_279 as convert };
}
export namespace ZNCJMB14LM {
    const cluster_280: string;
    export { cluster_280 as cluster };
    const type_280: string[];
    export { type_280 as type };
    export function convert_280(model: any, msg: any, publish: any, options: any, meta: any): {
        theme: any;
        screen_saver_style: any;
        standby_enabled: boolean;
        beep_volume: any;
        lcd_brightness: any;
        available_switches: any;
        font_size: any;
        homepage: any;
        language: any;
        standby_time: any;
        lcd_auto_brightness_enabled: boolean;
        screen_saver_enabled: boolean;
        standby_lcd_brightness: any;
        switch_1_icon: any;
        switch_1_text: string;
        switch_2_icon: any;
        switch_2_text: string;
        switch_3_icon: any;
        switch_3_text: string;
    };
    export { convert_280 as convert };
}
export namespace rc_110_level_to_scene {
    const cluster_281: string;
    export { cluster_281 as cluster };
    const type_281: string[];
    export { type_281 as type };
    export function convert_281(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
    };
    export { convert_281 as convert };
}
export namespace xiaomi_tvoc {
    const cluster_282: string;
    export { cluster_282 as cluster };
    const type_282: string[];
    export { type_282 as type };
    export function convert_282(model: any, msg: any, publish: any, options: any, meta: any): {
        voc: any;
    };
    export { convert_282 as convert };
}
export namespace heiman_doorbell_button {
    const cluster_283: string;
    export { cluster_283 as cluster };
    const type_283: string;
    export { type_283 as type };
    export function convert_283(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
        tamper: boolean;
        battery_low: boolean;
    };
    export { convert_283 as convert };
}
export namespace aqara_knob_rotation {
    const cluster_284: string;
    export { cluster_284 as cluster };
    const type_284: string[];
    export { type_284 as type };
    export function convert_284(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
        action_rotation_angle: any;
        action_rotation_angle_speed: any;
        action_rotation_percent: any;
        action_rotation_percent_speed: any;
        action_rotation_time: any;
    };
    export { convert_284 as convert };
}
export namespace sihas_people_cnt {
    const cluster_285: string;
    export { cluster_285 as cluster };
    const type_285: string[];
    export { type_285 as type };
    export function convert_285(model: any, msg: any, publish: any, options: any, meta: any): {
        people: any;
        status: any;
    };
    export { convert_285 as convert };
}
export namespace sihas_action {
    const cluster_286: string;
    export { cluster_286 as cluster };
    const type_286: string[];
    export { type_286 as type };
    export function convert_286(model: any, msg: any, publish: any, options: any, meta: any): {
        action: string;
    };
    export { convert_286 as convert };
}
export namespace tuya_operation_mode {
    const cluster_287: string;
    export { cluster_287 as cluster };
    const type_287: string[];
    export { type_287 as type };
    export function convert_287(model: any, msg: any, publish: any, options: any, meta: any): {
        operation_mode: any;
    };
    export { convert_287 as convert };
}
export namespace sunricher_switch2801K2 {
    const cluster_288: string;
    export { cluster_288 as cluster };
    const type_288: string[];
    export { type_288 as type };
    export function convert_288(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_288 as convert };
}
export namespace sunricher_switch2801K4 {
    const cluster_289: string;
    export { cluster_289 as cluster };
    const type_289: string[];
    export { type_289 as type };
    export function convert_289(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_289 as convert };
}
export namespace command_stop_move_raw {
    const cluster_290: string;
    export { cluster_290 as cluster };
    const type_290: string;
    export { type_290 as type };
    export function convert_290(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_290 as convert };
}
export namespace tuya_multi_action {
    const cluster_291: string;
    export { cluster_291 as cluster };
    const type_291: string;
    export { type_291 as type };
    export function convert_291(model: any, msg: any, publish: any, options: any, meta: any): {
        action: any;
    };
    export { convert_291 as convert };
}
export namespace led_on_motion {
    const cluster_292: string;
    export { cluster_292 as cluster };
    const type_292: string[];
    export { type_292 as type };
    export function convert_292(model: any, msg: any, publish: any, options: any, meta: any): {
        led_on_motion: boolean;
    };
    export { convert_292 as convert };
}
export namespace hw_version {
    const cluster_293: string;
    export { cluster_293 as cluster };
    const type_293: string[];
    export { type_293 as type };
    export function convert_293(model: any, msg: any, publish: any, options: any, meta: any): {
        hw_version: any;
    };
    export { convert_293 as convert };
}
export namespace SNZB02_temperature {
    const cluster_294: string;
    export { cluster_294 as cluster };
    const type_294: string[];
    export { type_294 as type };
    const options_62: exposes.Numeric[];
    export { options_62 as options };
    export function convert_294(model: any, msg: any, publish: any, options: any, meta: any): {
        [x: number]: any;
    };
    export { convert_294 as convert };
}
export namespace SNZB02_humidity {
    const cluster_295: string;
    export { cluster_295 as cluster };
    const type_295: string[];
    export { type_295 as type };
    const options_63: exposes.Numeric[];
    export { options_63 as options };
    export function convert_295(model: any, msg: any, publish: any, options: any, meta: any): {
        humidity: any;
    };
    export { convert_295 as convert };
}
export namespace ignore_onoff_report {
    const cluster_296: string;
    export { cluster_296 as cluster };
    const type_296: string[];
    export { type_296 as type };
    export function convert_296(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_296 as convert };
}
export namespace ignore_basic_report {
    const cluster_297: string;
    export { cluster_297 as cluster };
    const type_297: string[];
    export { type_297 as type };
    export function convert_297(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_297 as convert };
}
export namespace ignore_illuminance_report {
    const cluster_298: string;
    export { cluster_298 as cluster };
    const type_298: string[];
    export { type_298 as type };
    export function convert_298(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_298 as convert };
}
export namespace ignore_occupancy_report {
    const cluster_299: string;
    export { cluster_299 as cluster };
    const type_299: string[];
    export { type_299 as type };
    export function convert_299(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_299 as convert };
}
export namespace ignore_temperature_report {
    const cluster_300: string;
    export { cluster_300 as cluster };
    const type_300: string[];
    export { type_300 as type };
    export function convert_300(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_300 as convert };
}
export namespace ignore_humidity_report {
    const cluster_301: string;
    export { cluster_301 as cluster };
    const type_301: string[];
    export { type_301 as type };
    export function convert_301(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_301 as convert };
}
export namespace ignore_pressure_report {
    const cluster_302: string;
    export { cluster_302 as cluster };
    const type_302: string[];
    export { type_302 as type };
    export function convert_302(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_302 as convert };
}
export namespace ignore_analog_report {
    const cluster_303: string;
    export { cluster_303 as cluster };
    const type_303: string[];
    export { type_303 as type };
    export function convert_303(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_303 as convert };
}
export namespace ignore_multistate_report {
    const cluster_304: string;
    export { cluster_304 as cluster };
    const type_304: string[];
    export { type_304 as type };
    export function convert_304(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_304 as convert };
}
export namespace ignore_power_report {
    const cluster_305: string;
    export { cluster_305 as cluster };
    const type_305: string[];
    export { type_305 as type };
    export function convert_305(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_305 as convert };
}
export namespace ignore_light_brightness_report {
    const cluster_306: string;
    export { cluster_306 as cluster };
    const type_306: string[];
    export { type_306 as type };
    export function convert_306(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_306 as convert };
}
export namespace ignore_light_color_colortemp_report {
    const cluster_307: string;
    export { cluster_307 as cluster };
    const type_307: string[];
    export { type_307 as type };
    export function convert_307(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_307 as convert };
}
export namespace ignore_closuresWindowCovering_report {
    const cluster_308: string;
    export { cluster_308 as cluster };
    const type_308: string[];
    export { type_308 as type };
    export function convert_308(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_308 as convert };
}
export namespace ignore_thermostat_report {
    const cluster_309: string;
    export { cluster_309 as cluster };
    const type_309: string[];
    export { type_309 as type };
    export function convert_309(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_309 as convert };
}
export namespace ignore_iaszone_attreport {
    const cluster_310: string;
    export { cluster_310 as cluster };
    const type_310: string[];
    export { type_310 as type };
    export function convert_310(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_310 as convert };
}
export namespace ignore_iaszone_statuschange {
    const cluster_311: string;
    export { cluster_311 as cluster };
    const type_311: string;
    export { type_311 as type };
    export function convert_311(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_311 as convert };
}
export namespace ignore_iaszone_report {
    const cluster_312: string;
    export { cluster_312 as cluster };
    const type_312: string[];
    export { type_312 as type };
    export function convert_312(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_312 as convert };
}
export namespace ignore_iasace_commandgetpanelstatus {
    const cluster_313: string;
    export { cluster_313 as cluster };
    const type_313: string[];
    export { type_313 as type };
    export function convert_313(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_313 as convert };
}
export namespace ignore_genIdentify {
    const cluster_314: string;
    export { cluster_314 as cluster };
    const type_314: string[];
    export { type_314 as type };
    export function convert_314(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_314 as convert };
}
export namespace ignore_command_on {
    const cluster_315: string;
    export { cluster_315 as cluster };
    const type_315: string;
    export { type_315 as type };
    export function convert_315(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_315 as convert };
}
export namespace ignore_command_off {
    const cluster_316: string;
    export { cluster_316 as cluster };
    const type_316: string;
    export { type_316 as type };
    export function convert_316(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_316 as convert };
}
export namespace ignore_command_step {
    const cluster_317: string;
    export { cluster_317 as cluster };
    const type_317: string;
    export { type_317 as type };
    export function convert_317(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_317 as convert };
}
export namespace ignore_command_stop {
    const cluster_318: string;
    export { cluster_318 as cluster };
    const type_318: string;
    export { type_318 as type };
    export function convert_318(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_318 as convert };
}
export namespace ignore_poll_ctrl {
    const cluster_319: string;
    export { cluster_319 as cluster };
    const type_319: string[];
    export { type_319 as type };
    export function convert_319(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_319 as convert };
}
export namespace ignore_genLevelCtrl_report {
    const cluster_320: string;
    export { cluster_320 as cluster };
    const type_320: string[];
    export { type_320 as type };
    export function convert_320(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_320 as convert };
}
export namespace ignore_genOta {
    const cluster_321: string;
    export { cluster_321 as cluster };
    const type_321: string[];
    export { type_321 as type };
    export function convert_321(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_321 as convert };
}
export namespace ignore_haDiagnostic {
    const cluster_322: string;
    export { cluster_322 as cluster };
    const type_322: string[];
    export { type_322 as type };
    export function convert_322(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_322 as convert };
}
export namespace ignore_zclversion_read {
    const cluster_323: string;
    export { cluster_323 as cluster };
    const type_323: string;
    export { type_323 as type };
    export function convert_323(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_323 as convert };
}
export namespace ignore_time_read {
    const cluster_324: string;
    export { cluster_324 as cluster };
    const type_324: string;
    export { type_324 as type };
    export function convert_324(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_324 as convert };
}
export namespace ignore_tuya_set_time {
    const cluster_325: string;
    export { cluster_325 as cluster };
    const type_325: string[];
    export { type_325 as type };
    export function convert_325(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_325 as convert };
}
export namespace ignore_tuya_raw {
    const cluster_326: string;
    export { cluster_326 as cluster };
    const type_326: string[];
    export { type_326 as type };
    export function convert_326(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_326 as convert };
}
export namespace ignore_metering {
    const cluster_327: string;
    export { cluster_327 as cluster };
    const type_327: string[];
    export { type_327 as type };
    export function convert_327(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_327 as convert };
}
export namespace ignore_electrical_measurement {
    const cluster_328: string;
    export { cluster_328 as cluster };
    const type_328: string[];
    export { type_328 as type };
    export function convert_328(model: any, msg: any, publish: any, options: any, meta: any): any;
    export { convert_328 as convert };
}
//# sourceMappingURL=fromZigbee.d.ts.map