declare const _exports: ({
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            linkquality: any;
        };
    }[];
    toZigbee: {
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
            state: {
                [x: number]: any;
            };
        }>;
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    }[];
    exposes: any[];
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => any;
    }[];
    toZigbee: {
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<void>;
    }[];
    exposes: any[];
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => any;
    } | FromZigbeeConverter)[];
    toZigbee: ({
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
            state?: undefined;
        } | {
            state: {
                state: any;
            };
        }>;
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    } | {
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<void>;
    } | {
        key: string[];
        options: exposes.Numeric[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
            state?: undefined;
        } | {
            state: {
                state: any;
            };
        } | {
            state: {};
            readAfterWriteTime: number;
        }>;
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    })[];
    exposes: (device: any, options: any) => any[];
    meta: {
        multiEndpoint: boolean;
        tuyaThermostatPreset: {
            tuya_thermostat_weekly_schedule_1: FromZigbeeConverter;
            tuya_alecto_smoke: FromZigbeeConverter;
            WXKG11LM_click: FromZigbeeConverter;
            SmartButton_skip: FromZigbeeConverter;
            konke_click: FromZigbeeConverter;
            xiaomi_action_click_multistate: FromZigbeeConverter;
            WXKG12LM_action_click_multistate: FromZigbeeConverter;
            terncy_raw: FromZigbeeConverter;
            CCTSwitch_D0001_on_off: FromZigbeeConverter;
            ptvo_switch_buttons: FromZigbeeConverter;
            ZGRC013_brightness_onoff: FromZigbeeConverter;
            ZGRC013_brightness_stop: FromZigbeeConverter;
            ZGRC013_scene: FromZigbeeConverter;
            ZGRC013_cmdOn: FromZigbeeConverter;
            ZGRC013_cmdOff: FromZigbeeConverter;
            ZGRC013_brightness: FromZigbeeConverter;
            CTR_U_scene: FromZigbeeConverter;
            st_button_state: FromZigbeeConverter;
            QBKG11LM_click: FromZigbeeConverter;
            QBKG12LM_click: FromZigbeeConverter;
            QBKG03LM_QBKG12LM_click: FromZigbeeConverter;
            QBKG04LM_QBKG11LM_click: FromZigbeeConverter;
            cover_stop: FromZigbeeConverter;
            cover_open: FromZigbeeConverter;
            cover_close: FromZigbeeConverter;
            WXKG03LM_click: FromZigbeeConverter;
            TS0218_click: FromZigbeeConverter;
            xiaomi_on_off_action: FromZigbeeConverter;
            WXKG02LM_click: FromZigbeeConverter;
            WXKG02LM_click_multistate: FromZigbeeConverter;
            WXKG01LM_click: FromZigbeeConverter;
            scenes_recall_click: FromZigbeeConverter;
            AV2010_34_click: FromZigbeeConverter;
            E1743_brightness_down: FromZigbeeConverter;
            E1743_brightness_up: FromZigbeeConverter;
            E1743_brightness_stop: FromZigbeeConverter;
            genOnOff_cmdOn: FromZigbeeConverter;
            genOnOff_cmdOff: FromZigbeeConverter;
            RM01_on_click: FromZigbeeConverter;
            RM01_off_click: FromZigbeeConverter;
            RM01_down_hold: FromZigbeeConverter;
            RM01_up_hold: FromZigbeeConverter;
            RM01_stop: FromZigbeeConverter;
            xiaomi_multistate_action: FromZigbeeConverter;
            E1744_play_pause: FromZigbeeConverter;
            E1744_skip: FromZigbeeConverter;
            cmd_move: FromZigbeeConverter;
            cmd_move_with_onoff: FromZigbeeConverter;
            cmd_stop: FromZigbeeConverter;
            cmd_stop_with_onoff: FromZigbeeConverter;
            cmd_move_to_level_with_onoff: FromZigbeeConverter;
            immax_07046L_arm: FromZigbeeConverter;
            KEF1PA_arm: FromZigbeeConverter;
            QBKG25LM_click: FromZigbeeConverter;
            QBKG03LM_buttons: FromZigbeeConverter;
            CTR_U_brightness_updown_click: FromZigbeeConverter;
            CTR_U_brightness_updown_hold: FromZigbeeConverter;
            CTR_U_brightness_updown_release: FromZigbeeConverter;
            osram_lightify_switch_cmdOn: FromZigbeeConverter;
            osram_lightify_switch_cmdOff: FromZigbeeConverter;
            osram_lightify_switch_cmdMoveWithOnOff: FromZigbeeConverter;
            osram_lightify_switch_AC0251100NJ_cmdStop: FromZigbeeConverter;
            osram_lightify_switch_cmdMove: FromZigbeeConverter;
            osram_lightify_switch_cmdMoveHue: FromZigbeeConverter;
            osram_lightify_switch_cmdMoveToSaturation: FromZigbeeConverter;
            osram_lightify_switch_cmdMoveToLevelWithOnOff: FromZigbeeConverter;
            osram_lightify_switch_cmdMoveToColorTemp: FromZigbeeConverter;
            osram_lightify_switch_73743_cmdStop: FromZigbeeConverter;
            osram_lightify_switch_AB371860355_cmdOn: FromZigbeeConverter;
            osram_lightify_switch_AB371860355_cmdOff: FromZigbeeConverter;
            osram_lightify_switch_AB371860355_cmdStepColorTemp: FromZigbeeConverter;
            osram_lightify_switch_AB371860355_cmdMoveWithOnOff: FromZigbeeConverter;
            osram_lightify_switch_AB371860355_cmdMove: FromZigbeeConverter;
            osram_lightify_switch_AB371860355_cmdStop: FromZigbeeConverter;
            osram_lightify_switch_AB371860355_cmdMoveHue: FromZigbeeConverter;
            osram_lightify_switch_AB371860355_cmdMoveSat: FromZigbeeConverter;
            insta_scene_click: FromZigbeeConverter;
            insta_down_hold: FromZigbeeConverter;
            insta_up_hold: FromZigbeeConverter;
            insta_stop: FromZigbeeConverter;
            tint404011_brightness_updown_click: FromZigbeeConverter;
            tint404011_brightness_updown_hold: FromZigbeeConverter;
            tint404011_brightness_updown_release: FromZigbeeConverter;
            tint404011_move_to_color_temp: FromZigbeeConverter;
            tint404011_move_to_color: FromZigbeeConverter;
            heiman_smart_controller_armmode: FromZigbeeConverter;
            LZL4B_onoff: FromZigbeeConverter;
            eria_81825_updown: FromZigbeeConverter;
            ZYCT202_stop: FromZigbeeConverter;
            ZYCT202_up_down: FromZigbeeConverter;
            STS_PRS_251_beeping: FromZigbeeConverter;
            dimmer_passthru_brightness: FromZigbeeConverter;
            bitron_thermostat_att_report: FromZigbeeConverter;
            thermostat_att_report: FromZigbeeConverter;
            stelpro_thermostat: FromZigbeeConverter;
            viessmann_thermostat_att_report: FromZigbeeConverter;
            eurotronic_thermostat: FromZigbeeConverter;
            wiser_thermostat: FromZigbeeConverter;
            hvac_user_interface: FromZigbeeConverter;
            thermostat_weekly_schedule_rsp: FromZigbeeConverter;
            terncy_knob: FromZigbeeConverter;
            wiser_itrv_battery: FromZigbeeConverter;
            ubisys_c4_scenes: FromZigbeeConverter;
            ubisys_c4_onoff: FromZigbeeConverter;
            ubisys_c4_level: FromZigbeeConverter;
            ubisys_c4_cover: FromZigbeeConverter;
            hue_dimmer_switch: FromZigbeeConverter;
            blitzwolf_occupancy_with_timeout: FromZigbeeConverter;
            moes_thermostat: FromZigbeeConverter;
            moesS_thermostat: FromZigbeeConverter;
            tuya_air_quality: FromZigbeeConverter;
            tuya_CO: FromZigbeeConverter;
            connecte_thermostat: FromZigbeeConverter;
            saswell_thermostat: FromZigbeeConverter;
            evanell_thermostat: FromZigbeeConverter;
            etop_thermostat: FromZigbeeConverter;
            tuya_thermostat: FromZigbeeConverter;
            tuya_dimmer: FromZigbeeConverter;
            tuya_motion_sensor: FromZigbeeConverter;
            tuya_smart_vibration_sensor: FromZigbeeConverter;
            matsee_garage_door_opener: FromZigbeeConverter;
            moes_thermostat_tv: FromZigbeeConverter;
            hoch_din: FromZigbeeConverter;
            tuya_light_wz5: FromZigbeeConverter;
            ZMAM02_cover: FromZigbeeConverter;
            tm081: FromZigbeeConverter;
            tuya_remote: FromZigbeeConverter;
            tuya_smart_human_presense_sensor: FromZigbeeConverter;
            ZG204ZL_lms: FromZigbeeConverter;
            moes_cover: FromZigbeeConverter;
            tuya_temperature_humidity_sensor: FromZigbeeConverter;
            nous_lcd_temperature_humidity_sensor: FromZigbeeConverter;
            tuya_illuminance_temperature_humidity_sensor: FromZigbeeConverter;
            tuya_illuminance_sensor: FromZigbeeConverter;
            hy_thermostat: FromZigbeeConverter;
            neo_nas_pd07: FromZigbeeConverter;
            neo_t_h_alarm: FromZigbeeConverter;
            neo_alarm: FromZigbeeConverter;
            ZB006X_settings: FromZigbeeConverter;
            tuya_cover: FromZigbeeConverter;
            moes_switch: FromZigbeeConverter;
            tuya_water_leak: FromZigbeeConverter;
            wls100z_water_leak: FromZigbeeConverter;
            silvercrest_smart_led_string: FromZigbeeConverter;
            frankever_valve: FromZigbeeConverter;
            tuya_woox_smoke: FromZigbeeConverter;
            tuya_switch: FromZigbeeConverter;
            tuya_dinrail_switch: FromZigbeeConverter;
            ZVG1: FromZigbeeConverter;
            ZB003X: FromZigbeeConverter;
            tuya_thermostat_weekly_schedule_2: FromZigbeeConverter;
            tuya_data_point_dump: FromZigbeeConverter;
            javis_microwave_sensor: FromZigbeeConverter;
            SLUXZB: FromZigbeeConverter;
        };
    };
    endpoint: (device: any) => any[];
    configure: (device: any, coordinatorEndpoint: any, logger: any, options: any) => Promise<void>;
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: {
        cluster: string;
        type: string[];
        options: exposes.Binary[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {};
    }[];
    meta: {
        multiEndpoint: boolean;
    };
    extend: {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
    exposes: (exposes.Enum | exposes.Switch)[];
    endpoint: (device: any) => {
        left: number;
        right: number;
    };
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: {
        cluster: string;
        type: string[];
        options: exposes.Binary[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {};
    }[];
    meta: {
        multiEndpoint: boolean;
    };
    extend: {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
    exposes: (exposes.Enum | exposes.Switch)[];
    endpoint: (device: any) => {
        bottom_left: number;
        bottom_right: number;
        top_left: number;
        top_right: number;
    };
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            [x: string]: any;
            state: string;
            cpu_temperature: any;
            external_temperature: any;
            external_humidity: any;
            s0_counts: any;
            adc_volt: any;
            dig_input: any;
            reason: any;
        };
    }[];
    toZigbee: ({
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
            state?: undefined;
        } | {
            state: {
                state: any;
            };
        }>;
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    } | {
        key: string[];
        options: (exposes.Numeric | exposes.Binary)[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
            state: {
                color_mode: any;
                color: any;
                color_temp: any;
            };
            readAfterWriteTime: number;
        }>;
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    } | {
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<void>;
    })[];
    exposes: exposes.Switch[];
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: {
        cluster: string;
        type: string;
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            action: any;
        };
    }[];
    toZigbee: undefined[];
    exposes: exposes.Enum[];
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            battery: any;
            voltage: number;
            battery_low: boolean;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            [x: number]: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            soil_moisture: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            illuminance: any;
            illuminance_lux: any;
        };
    })[];
    toZigbee: undefined[];
    meta: {
        multiEndpoint: boolean;
    };
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
    exposes: exposes.Numeric[];
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            battery: any;
            voltage: number;
            battery_low: boolean;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            [x: number]: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            humidity: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            soil_moisture: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            illuminance: any;
            illuminance_lux: any;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            report_delay: any;
        };
    })[];
    toZigbee: {
        key: string[];
        convertSet: (entity: any, key: any, rawValue: any, meta: any) => Promise<{
            state: {
                [x: number]: any;
            };
        }>;
    }[];
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
    exposes: any[];
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            battery: any;
            voltage: number;
            battery_low: boolean;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            [x: number]: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            humidity: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            illuminance: any;
            illuminance_lux: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            pressure: any;
        };
    })[];
    toZigbee: undefined[];
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
    exposes: exposes.Numeric[];
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string[];
        options: exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            [x: number]: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            humidity: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            illuminance: any;
            illuminance_lux: any;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            co2: any;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            auto_brightness: string;
            forced_recalibration: string;
            factory_reset_co2: string;
            long_chart_period: string;
            set_altitude: any;
            manual_forced_recalibration: any;
            light_indicator: string;
            light_indicator_level: any;
        };
    } | {
        cluster: string;
        type: string;
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            temperature_offset: any;
        };
    } | {
        cluster: string;
        type: string;
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            humidity_offset: any;
        };
    })[];
    toZigbee: ({
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
            state: {
                local_time: number;
            };
        }>;
    } | {
        key: string[];
        convertSet: (entity: any, key: any, rawValue: any, meta: any) => Promise<{
            state: {
                [x: number]: any;
            };
        }>;
    })[];
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
    exposes: any[];
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string[];
        options: exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            [x: number]: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            humidity: any;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            co2: any;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            auto_brightness: string;
            forced_recalibration: string;
            factory_reset_co2: string;
            long_chart_period: string;
            set_altitude: any;
            manual_forced_recalibration: any;
            light_indicator: string;
            light_indicator_level: any;
        };
    } | {
        cluster: string;
        type: string;
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            temperature_offset: any;
        };
    } | {
        cluster: string;
        type: string;
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            humidity_offset: any;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            high_temperature: any;
            low_temperature: any;
            enable_temperature: string;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            high_humidity: any;
            low_humidity: any;
            enable_humidity: string;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            high_gas: any;
            low_gas: any;
            enable_gas: string;
        };
    })[];
    toZigbee: {
        key: string[];
        convertSet: (entity: any, key: any, rawValue: any, meta: any) => Promise<{
            state: {
                [x: number]: any;
            };
        }>;
    }[];
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
    exposes: any[];
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            battery: any;
            voltage: number;
            battery_low: boolean;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            [x: number]: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            humidity: any;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            report_delay: any;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            high_temperature: any;
            low_temperature: any;
            enable_temperature: string;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            high_humidity: any;
            low_humidity: any;
            enable_humidity: string;
        };
    })[];
    toZigbee: {
        key: string[];
        convertSet: (entity: any, key: any, rawValue: any, meta: any) => Promise<{
            state: {
                [x: number]: any;
            };
        }>;
    }[];
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
    exposes: any[];
})[];
export = _exports;
import exposes = require("../lib/exposes");
//# sourceMappingURL=custom_devices_diy.d.ts.map