export declare function _switch(options?: {}): {
    exposes: any[];
    fromZigbee: any[];
    toZigbee: any[];
};
export { _switch as switch };
export declare function light_onoff_brightness(options?: {}): {
    exposes: any[];
    fromZigbee: any[];
    toZigbee: any[];
};
export declare function light_onoff_brightness_colortemp(options?: {}): {
    exposes: any[];
    fromZigbee: any[];
    toZigbee: any[];
};
export declare function light_onoff_brightness_color(options?: {}): {
    exposes: any[];
    fromZigbee: any[];
    toZigbee: any[];
};
export declare function light_onoff_brightness_colortemp_color(options?: {}): {
    exposes: any[];
    fromZigbee: any[];
    toZigbee: any[];
};
//# sourceMappingURL=extend.d.ts.map