import { ZnpCommandStatus } from './common';
declare function getChannelMask(channels: number[]): number[];
declare function statusDescription(code: ZnpCommandStatus): string;
export { getChannelMask, statusDescription };
//# sourceMappingURL=utils.d.ts.map