"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const DBG = {
    debugThreshold: {
        CRITICAL: 1,
        ERROR: 2,
        INFORMATION: 3,
        TRACE: 4
    },
    componentId: {
        OSAL: 0,
        MTEL: 1,
        MTSPCI: 2,
        NWK: 3,
        NWKIF: 4,
        MACCB: 5,
        MAC: 6,
        APP: 7,
        TEST: 8,
        RTG: 9,
        DATA: 11
    },
};
exports.default = DBG;
//# sourceMappingURL=dbg.js.map