export const OneJanuary2000: number;
export namespace repInterval {
    const MAX: number;
    const HOUR: number;
    const MINUTES_30: number;
    const MINUTES_15: number;
    const MINUTES_10: number;
    const MINUTES_5: number;
    const MINUTE: number;
}
export const defaultBindGroup: 901;
export const thermostatControlSequenceOfOperations: {
    0: string;
    1: string;
    2: string;
    3: string;
    4: string;
    5: string;
};
export const thermostatProgrammingOperationModes: {
    0: string;
    1: string;
    3: string;
    4: string;
};
export const thermostatSystemModes: {
    0: string;
    1: string;
    3: string;
    4: string;
    5: string;
    6: string;
    7: string;
    8: string;
    9: string;
};
export const thermostatRunningStates: {
    0: string;
    1: string;
    2: string;
    4: string;
    5: string;
    6: string;
    8: string;
    9: string;
    A: string;
    D: string;
    10: string;
    12: string;
    14: string;
    15: string;
    22: string;
};
export const thermostatRunningMode: {
    0: string;
    3: string;
    4: string;
};
export const thermostatAcLouverPositions: {
    0: string;
    1: string;
    2: string;
    3: string;
    4: string;
    5: string;
};
export const thermostatScheduleMode: {
    0: string;
    1: string;
};
export const thermostatDayOfWeek: {
    0: string;
    1: string;
    2: string;
    3: string;
    4: string;
    5: string;
    6: string;
    7: string;
};
export namespace fanMode {
    const off: number;
    const low: number;
    const medium: number;
    const high: number;
    const on: number;
    const auto: number;
    const smart: number;
}
export const temperatureDisplayMode: {
    0: string;
    1: string;
};
export const danfossAdaptionRunControl: {
    0: string;
    1: string;
    2: string;
};
export const danfossAdaptionRunStatus: {
    0: string;
    1: string;
    2: string;
    4: string;
};
export const danfossWindowOpen: {
    0: string;
    1: string;
    2: string;
    3: string;
    4: string;
};
export const danfossRoomStatusCode: {
    0: string;
    257: string;
    513: string;
    1025: string;
    2049: string;
};
export const danfossOutputStatus: {
    0: string;
    1: string;
};
export const danfossSystemStatusWater: {
    0: string;
    1: string;
};
export const danfossSystemStatusCode: {
    0: string;
    257: string;
    513: string;
    1025: string;
    2049: string;
    4097: string;
    8193: string;
    16385: string;
    32769: string;
    258: string;
};
export const danfossMultimasterRole: {
    0: string;
    1: string;
    2: string;
    3: string;
};
export const develcoInterfaceMode: {
    0: string;
    1: string;
    2: string;
    256: string;
    257: string;
    258: string;
    259: string;
    260: string;
};
export const keypadLockoutMode: {
    0: string;
    1: string;
    2: string;
    3: string;
    4: string;
    5: string;
};
export const lockSourceName: {
    0: string;
    1: string;
    2: string;
    3: string;
};
export const armMode: {
    0: string;
    1: string;
    2: string;
    3: string;
    4: string;
    5: string;
    6: string;
    7: string;
    8: string;
    9: string;
    10: string;
};
export const armNotification: {
    0: string;
    1: string;
    2: string;
    3: string;
    4: string;
    5: string;
    6: string;
};
export const colorModeLookup: {
    [x: number]: string;
};
export namespace ColorMode {
    const HS: number;
    const XY: number;
    const ColorTemp: number;
}
export const lockSoundVolume: string[];
export const lockUserStatus: {
    0: string;
    1: string;
    3: string;
};
export const easyCodeTouchActions: {
    0: string;
    1: string;
    2: string;
    512: string;
    513: string;
    520: string;
    521: string;
    528: string;
    529: string;
    768: string;
    769: string;
    65293: string;
    65294: string;
};
export const wiserDimmerControlMode: {
    0: string;
    1: string;
    2: string;
    3: string;
};
//# sourceMappingURL=constants.d.ts.map