declare const _exports: {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: any[];
    toZigbee: any[];
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
    exposes: (exposes.Numeric | exposes.Light)[];
}[];
export = _exports;
import exposes = require("../lib/exposes");
//# sourceMappingURL=micromatic.d.ts.map