const extend = require('../lib/extend');
module.exports = [
    {
        zigbeeModel: ['Connected A-19 60W Equivalent ', 'Connected A-19 60W Equivalent   '],
        model: 'B00TN589ZG',
        vendor: 'CREE',
        description: 'Connected bulb',
        extend: extend.light_onoff_brightness(),
    },
];
//# sourceMappingURL=cree.js.map