"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ZnpVersion = void 0;
var ZnpVersion;
(function (ZnpVersion) {
    ZnpVersion[ZnpVersion["zStack12"] = 0] = "zStack12";
    ZnpVersion[ZnpVersion["zStack3x0"] = 1] = "zStack3x0";
    ZnpVersion[ZnpVersion["zStack30x"] = 2] = "zStack30x";
})(ZnpVersion || (ZnpVersion = {}));
exports.ZnpVersion = ZnpVersion;
//# sourceMappingURL=tstype.js.map