export namespace fzZosung {
    namespace zosung_send_ir_code_01 {
        const cluster: string;
        const type: string[];
        function convert(model: any, msg: any, publish: any, options: any, meta: any): void;
    }
    namespace zosung_send_ir_code_02 {
        const cluster_1: string;
        export { cluster_1 as cluster };
        const type_1: string[];
        export { type_1 as type };
        export function convert_1(model: any, msg: any, publish: any, options: any, meta: any): Promise<void>;
        export { convert_1 as convert };
    }
    namespace zosung_send_ir_code_04 {
        const cluster_2: string;
        export { cluster_2 as cluster };
        const type_2: string[];
        export { type_2 as type };
        export function convert_2(model: any, msg: any, publish: any, options: any, meta: any): Promise<void>;
        export { convert_2 as convert };
    }
    namespace zosung_send_ir_code_00 {
        const cluster_3: string;
        export { cluster_3 as cluster };
        const type_3: string[];
        export { type_3 as type };
        export function convert_3(model: any, msg: any, publish: any, options: any, meta: any): Promise<void>;
        export { convert_3 as convert };
    }
    namespace zosung_send_ir_code_03 {
        const cluster_4: string;
        export { cluster_4 as cluster };
        const type_4: string[];
        export { type_4 as type };
        export function convert_4(model: any, msg: any, publish: any, options: any, meta: any): Promise<void>;
        export { convert_4 as convert };
    }
    namespace zosung_send_ir_code_05 {
        const cluster_5: string;
        export { cluster_5 as cluster };
        const type_5: string[];
        export { type_5 as type };
        export function convert_5(model: any, msg: any, publish: any, options: any, meta: any): Promise<{
            learned_ir_code: any;
        }>;
        export { convert_5 as convert };
    }
}
export namespace tzZosung {
    namespace zosung_ir_code_to_send {
        const key: string[];
        function convertSet(entity: any, key: any, value: any, meta: any): Promise<void>;
    }
    namespace zosung_learn_ir_code {
        const key_1: string[];
        export { key_1 as key };
        export function convertSet_1(entity: any, key: any, value: any, meta: any): Promise<void>;
        export { convertSet_1 as convertSet };
    }
}
export namespace presetsZosung {
    function learn_ir_code(): any;
    function learned_ir_code(): any;
    function ir_code_to_send(): any;
}
//# sourceMappingURL=zosung.d.ts.map