declare const _exports: ({
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
    exposes: exposes.Switch[];
    meta: {
        multiEndpoint: boolean;
    };
    endpoint: (device: any) => {
        bottom_left: number;
        bottom_right: number;
        top_left: number;
        top_right: number;
        center: number;
    };
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            [x: number]: boolean;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            battery: number;
            voltage: number;
        };
    })[];
    toZigbee: undefined[];
    exposes: exposes.Numeric[];
    endpoint: (device: any) => {
        btn_1: number;
        btn_2: number;
        btn_3: number;
        btn_4: number;
        btn_5: number;
        btn_6: number;
        btn_7: number;
        btn_8: number;
        btn_9: number;
        btn_10: number;
        btn_11: number;
        btn_12: number;
        btn_13: number;
        btn_14: number;
        btn_15: number;
        btn_16: number;
        btn_17: number;
        btn_18: number;
        btn_19: number;
        btn_20: number;
    };
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            battery: number;
            voltage: number;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            contact: boolean;
        };
    })[];
    exposes: (exposes.Numeric | exposes.Binary)[];
    toZigbee: undefined[];
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            state: string;
            cpu_temperature: any;
            power: any;
            current: any;
            action: string;
        };
    }[];
    toZigbee: {
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
            state?: undefined;
        } | {
            state: {
                state: any;
            };
        }>;
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    }[];
    exposes: (exposes.Numeric | exposes.Enum | exposes.Switch)[];
    endpoint: (device: any) => {
        default: number;
    };
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            battery: any;
            voltage: number;
            battery_low: boolean;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            action: string;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            [x: string]: string;
        };
    })[];
    exposes: (exposes.Numeric | exposes.Enum)[];
    toZigbee: {
        key: string[];
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
            state: {
                [x: string]: any;
            };
        }>;
    }[];
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
    endpoint: (device: any) => {
        button_1: number;
        button_2: number;
        button_3: number;
        button_4: number;
        button_5: number;
        button_6: number;
        button_7: number;
        button_8: number;
    };
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string;
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            action: any;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            radioactive_events_per_minute: any;
            radiation_dose_per_hour: any;
        };
    } | {
        cluster: string;
        type: string;
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            led_feedback: string;
            buzzer_feedback: string;
            sensitivity: any;
            sensors_count: any;
            sensors_type: string;
            alert_threshold: any;
        };
    })[];
    exposes: any[];
    toZigbee: {
        key: string[];
        convertSet: (entity: any, key: any, rawValue: any, meta: any) => Promise<{
            state: {
                [x: number]: any;
            };
        }>;
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    }[];
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => any;
    } | FromZigbeeConverter)[];
    extend: {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
    exposes: exposes.Switch[];
    meta: {
        multiEndpoint: boolean;
    };
    endpoint: (device: any) => {
        l1: number;
        l2: number;
        l3: number;
        l4: number;
        l5: number;
        l6: number;
        l7: number;
        l8: number;
    };
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string[];
        options: exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            [x: number]: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Binary[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {};
    })[];
    toZigbee: {
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
            state?: undefined;
        } | {
            state: {
                state: any;
            };
        }>;
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    }[];
    exposes: (exposes.Numeric | exposes.Switch)[];
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            battery: any;
            voltage: number;
            battery_low: boolean;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            [x: number]: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            humidity: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            soil_moisture: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            illuminance: any;
            illuminance_lux: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            pressure: any;
        };
    })[];
    toZigbee: undefined[];
    meta: {
        multiEndpoint: boolean;
    };
    endpoint: (device: any) => {
        bme: number;
        ds: number;
    };
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
    exposes: exposes.Numeric[];
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string[];
        options: exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            [x: number]: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            humidity: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            pressure: any;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            co2: number;
        };
    } | {
        cluster: string;
        type: string;
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            led_feedback: string;
            enable_abc: string;
            threshold1: any;
            threshold2: any;
        };
    } | {
        cluster: string;
        type: string;
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            temperature_offset: any;
        };
    } | {
        cluster: string;
        type: string;
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            pressure_offset: any;
        };
    } | {
        cluster: string;
        type: string;
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            humidity_offset: any;
        };
    })[];
    toZigbee: {
        key: string[];
        convertSet: (entity: any, key: any, rawValue: any, meta: any) => Promise<{
            state: {
                [x: number]: any;
            };
        }>;
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    }[];
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
    exposes: any[];
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            battery: any;
            voltage: number;
            battery_low: boolean;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            state: string;
            mode: string;
            sound: string;
            time_ring: any;
            time_talk: any;
            time_open: any;
            time_bell: any;
            time_report: any;
        };
    })[];
    toZigbee: {
        key: string[];
        convertSet: (entity: any, key: any, rawValue: any, meta: any) => Promise<{
            state: {
                [x: number]: any;
            };
        }>;
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    }[];
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
    exposes: any[];
})[];
export = _exports;
import exposes = require("../lib/exposes");
//# sourceMappingURL=diyruz.d.ts.map