export = lookup;
declare const lookup: {
    1000: {
        x: number;
        y: number;
    };
    1010: {
        x: number;
        y: number;
    };
    1020: {
        x: number;
        y: number;
    };
    1030: {
        x: number;
        y: number;
    };
    1040: {
        x: number;
        y: number;
    };
    1050: {
        x: number;
        y: number;
    };
    1060: {
        x: number;
        y: number;
    };
    1070: {
        x: number;
        y: number;
    };
    1080: {
        x: number;
        y: number;
    };
    1090: {
        x: number;
        y: number;
    };
    1100: {
        x: number;
        y: number;
    };
    1110: {
        x: number;
        y: number;
    };
    1120: {
        x: number;
        y: number;
    };
    1130: {
        x: number;
        y: number;
    };
    1140: {
        x: number;
        y: number;
    };
    1150: {
        x: number;
        y: number;
    };
    1160: {
        x: number;
        y: number;
    };
    1170: {
        x: number;
        y: number;
    };
    1180: {
        x: number;
        y: number;
    };
    1190: {
        x: number;
        y: number;
    };
    1200: {
        x: number;
        y: number;
    };
    1210: {
        x: number;
        y: number;
    };
    1220: {
        x: number;
        y: number;
    };
    1230: {
        x: number;
        y: number;
    };
    1240: {
        x: number;
        y: number;
    };
    1250: {
        x: number;
        y: number;
    };
    1260: {
        x: number;
        y: number;
    };
    1270: {
        x: number;
        y: number;
    };
    1280: {
        x: number;
        y: number;
    };
    1290: {
        x: number;
        y: number;
    };
    1300: {
        x: number;
        y: number;
    };
    1310: {
        x: number;
        y: number;
    };
    1320: {
        x: number;
        y: number;
    };
    1330: {
        x: number;
        y: number;
    };
    1340: {
        x: number;
        y: number;
    };
    1350: {
        x: number;
        y: number;
    };
    1360: {
        x: number;
        y: number;
    };
    1370: {
        x: number;
        y: number;
    };
    1380: {
        x: number;
        y: number;
    };
    1390: {
        x: number;
        y: number;
    };
    1400: {
        x: number;
        y: number;
    };
    1410: {
        x: number;
        y: number;
    };
    1420: {
        x: number;
        y: number;
    };
    1430: {
        x: number;
        y: number;
    };
    1440: {
        x: number;
        y: number;
    };
    1450: {
        x: number;
        y: number;
    };
    1460: {
        x: number;
        y: number;
    };
    1470: {
        x: number;
        y: number;
    };
    1480: {
        x: number;
        y: number;
    };
    1490: {
        x: number;
        y: number;
    };
    1500: {
        x: number;
        y: number;
    };
    1510: {
        x: number;
        y: number;
    };
    1520: {
        x: number;
        y: number;
    };
    1530: {
        x: number;
        y: number;
    };
    1540: {
        x: number;
        y: number;
    };
    1550: {
        x: number;
        y: number;
    };
    1560: {
        x: number;
        y: number;
    };
    1570: {
        x: number;
        y: number;
    };
    1580: {
        x: number;
        y: number;
    };
    1590: {
        x: number;
        y: number;
    };
    1600: {
        x: number;
        y: number;
    };
    1610: {
        x: number;
        y: number;
    };
    1620: {
        x: number;
        y: number;
    };
    1630: {
        x: number;
        y: number;
    };
    1640: {
        x: number;
        y: number;
    };
    1650: {
        x: number;
        y: number;
    };
    1660: {
        x: number;
        y: number;
    };
    1670: {
        x: number;
        y: number;
    };
    1680: {
        x: number;
        y: number;
    };
    1690: {
        x: number;
        y: number;
    };
    1700: {
        x: number;
        y: number;
    };
    1710: {
        x: number;
        y: number;
    };
    1720: {
        x: number;
        y: number;
    };
    1730: {
        x: number;
        y: number;
    };
    1740: {
        x: number;
        y: number;
    };
    1750: {
        x: number;
        y: number;
    };
    1760: {
        x: number;
        y: number;
    };
    1770: {
        x: number;
        y: number;
    };
    1780: {
        x: number;
        y: number;
    };
    1790: {
        x: number;
        y: number;
    };
    1800: {
        x: number;
        y: number;
    };
    1810: {
        x: number;
        y: number;
    };
    1820: {
        x: number;
        y: number;
    };
    1830: {
        x: number;
        y: number;
    };
    1840: {
        x: number;
        y: number;
    };
    1850: {
        x: number;
        y: number;
    };
    1860: {
        x: number;
        y: number;
    };
    1870: {
        x: number;
        y: number;
    };
    1880: {
        x: number;
        y: number;
    };
    1890: {
        x: number;
        y: number;
    };
    1900: {
        x: number;
        y: number;
    };
    1910: {
        x: number;
        y: number;
    };
    1920: {
        x: number;
        y: number;
    };
    1930: {
        x: number;
        y: number;
    };
    1940: {
        x: number;
        y: number;
    };
    1950: {
        x: number;
        y: number;
    };
    1960: {
        x: number;
        y: number;
    };
    1970: {
        x: number;
        y: number;
    };
    1980: {
        x: number;
        y: number;
    };
    1990: {
        x: number;
        y: number;
    };
    2000: {
        x: number;
        y: number;
    };
    2010: {
        x: number;
        y: number;
    };
    2020: {
        x: number;
        y: number;
    };
    2030: {
        x: number;
        y: number;
    };
    2040: {
        x: number;
        y: number;
    };
    2050: {
        x: number;
        y: number;
    };
    2060: {
        x: number;
        y: number;
    };
    2070: {
        x: number;
        y: number;
    };
    2080: {
        x: number;
        y: number;
    };
    2090: {
        x: number;
        y: number;
    };
    2100: {
        x: number;
        y: number;
    };
    2110: {
        x: number;
        y: number;
    };
    2120: {
        x: number;
        y: number;
    };
    2130: {
        x: number;
        y: number;
    };
    2140: {
        x: number;
        y: number;
    };
    2150: {
        x: number;
        y: number;
    };
    2160: {
        x: number;
        y: number;
    };
    2170: {
        x: number;
        y: number;
    };
    2180: {
        x: number;
        y: number;
    };
    2190: {
        x: number;
        y: number;
    };
    2200: {
        x: number;
        y: number;
    };
    2210: {
        x: number;
        y: number;
    };
    2220: {
        x: number;
        y: number;
    };
    2230: {
        x: number;
        y: number;
    };
    2240: {
        x: number;
        y: number;
    };
    2250: {
        x: number;
        y: number;
    };
    2260: {
        x: number;
        y: number;
    };
    2270: {
        x: number;
        y: number;
    };
    2280: {
        x: number;
        y: number;
    };
    2290: {
        x: number;
        y: number;
    };
    2300: {
        x: number;
        y: number;
    };
    2310: {
        x: number;
        y: number;
    };
    2320: {
        x: number;
        y: number;
    };
    2330: {
        x: number;
        y: number;
    };
    2340: {
        x: number;
        y: number;
    };
    2350: {
        x: number;
        y: number;
    };
    2360: {
        x: number;
        y: number;
    };
    2370: {
        x: number;
        y: number;
    };
    2380: {
        x: number;
        y: number;
    };
    2390: {
        x: number;
        y: number;
    };
    2400: {
        x: number;
        y: number;
    };
    2410: {
        x: number;
        y: number;
    };
    2420: {
        x: number;
        y: number;
    };
    2430: {
        x: number;
        y: number;
    };
    2440: {
        x: number;
        y: number;
    };
    2450: {
        x: number;
        y: number;
    };
    2460: {
        x: number;
        y: number;
    };
    2470: {
        x: number;
        y: number;
    };
    2480: {
        x: number;
        y: number;
    };
    2490: {
        x: number;
        y: number;
    };
    2500: {
        x: number;
        y: number;
    };
    2510: {
        x: number;
        y: number;
    };
    2520: {
        x: number;
        y: number;
    };
    2530: {
        x: number;
        y: number;
    };
    2540: {
        x: number;
        y: number;
    };
    2550: {
        x: number;
        y: number;
    };
    2560: {
        x: number;
        y: number;
    };
    2570: {
        x: number;
        y: number;
    };
    2580: {
        x: number;
        y: number;
    };
    2590: {
        x: number;
        y: number;
    };
    2600: {
        x: number;
        y: number;
    };
    2610: {
        x: number;
        y: number;
    };
    2620: {
        x: number;
        y: number;
    };
    2630: {
        x: number;
        y: number;
    };
    2640: {
        x: number;
        y: number;
    };
    2650: {
        x: number;
        y: number;
    };
    2660: {
        x: number;
        y: number;
    };
    2670: {
        x: number;
        y: number;
    };
    2680: {
        x: number;
        y: number;
    };
    2690: {
        x: number;
        y: number;
    };
    2700: {
        x: number;
        y: number;
    };
    2710: {
        x: number;
        y: number;
    };
    2720: {
        x: number;
        y: number;
    };
    2730: {
        x: number;
        y: number;
    };
    2740: {
        x: number;
        y: number;
    };
    2750: {
        x: number;
        y: number;
    };
    2760: {
        x: number;
        y: number;
    };
    2770: {
        x: number;
        y: number;
    };
    2780: {
        x: number;
        y: number;
    };
    2790: {
        x: number;
        y: number;
    };
    2800: {
        x: number;
        y: number;
    };
    2810: {
        x: number;
        y: number;
    };
    2820: {
        x: number;
        y: number;
    };
    2830: {
        x: number;
        y: number;
    };
    2840: {
        x: number;
        y: number;
    };
    2850: {
        x: number;
        y: number;
    };
    2860: {
        x: number;
        y: number;
    };
    2870: {
        x: number;
        y: number;
    };
    2880: {
        x: number;
        y: number;
    };
    2890: {
        x: number;
        y: number;
    };
    2900: {
        x: number;
        y: number;
    };
    2910: {
        x: number;
        y: number;
    };
    2920: {
        x: number;
        y: number;
    };
    2930: {
        x: number;
        y: number;
    };
    2940: {
        x: number;
        y: number;
    };
    2950: {
        x: number;
        y: number;
    };
    2960: {
        x: number;
        y: number;
    };
    2970: {
        x: number;
        y: number;
    };
    2980: {
        x: number;
        y: number;
    };
    2990: {
        x: number;
        y: number;
    };
    3000: {
        x: number;
        y: number;
    };
    3010: {
        x: number;
        y: number;
    };
    3020: {
        x: number;
        y: number;
    };
    3030: {
        x: number;
        y: number;
    };
    3040: {
        x: number;
        y: number;
    };
    3050: {
        x: number;
        y: number;
    };
    3060: {
        x: number;
        y: number;
    };
    3070: {
        x: number;
        y: number;
    };
    3080: {
        x: number;
        y: number;
    };
    3090: {
        x: number;
        y: number;
    };
    3100: {
        x: number;
        y: number;
    };
    3110: {
        x: number;
        y: number;
    };
    3120: {
        x: number;
        y: number;
    };
    3130: {
        x: number;
        y: number;
    };
    3140: {
        x: number;
        y: number;
    };
    3150: {
        x: number;
        y: number;
    };
    3160: {
        x: number;
        y: number;
    };
    3170: {
        x: number;
        y: number;
    };
    3180: {
        x: number;
        y: number;
    };
    3190: {
        x: number;
        y: number;
    };
    3200: {
        x: number;
        y: number;
    };
    3210: {
        x: number;
        y: number;
    };
    3220: {
        x: number;
        y: number;
    };
    3230: {
        x: number;
        y: number;
    };
    3240: {
        x: number;
        y: number;
    };
    3250: {
        x: number;
        y: number;
    };
    3260: {
        x: number;
        y: number;
    };
    3270: {
        x: number;
        y: number;
    };
    3280: {
        x: number;
        y: number;
    };
    3290: {
        x: number;
        y: number;
    };
    3300: {
        x: number;
        y: number;
    };
    3310: {
        x: number;
        y: number;
    };
    3320: {
        x: number;
        y: number;
    };
    3330: {
        x: number;
        y: number;
    };
    3340: {
        x: number;
        y: number;
    };
    3350: {
        x: number;
        y: number;
    };
    3360: {
        x: number;
        y: number;
    };
    3370: {
        x: number;
        y: number;
    };
    3380: {
        x: number;
        y: number;
    };
    3390: {
        x: number;
        y: number;
    };
    3400: {
        x: number;
        y: number;
    };
    3410: {
        x: number;
        y: number;
    };
    3420: {
        x: number;
        y: number;
    };
    3430: {
        x: number;
        y: number;
    };
    3440: {
        x: number;
        y: number;
    };
    3450: {
        x: number;
        y: number;
    };
    3460: {
        x: number;
        y: number;
    };
    3470: {
        x: number;
        y: number;
    };
    3480: {
        x: number;
        y: number;
    };
    3490: {
        x: number;
        y: number;
    };
    3500: {
        x: number;
        y: number;
    };
    3510: {
        x: number;
        y: number;
    };
    3520: {
        x: number;
        y: number;
    };
    3530: {
        x: number;
        y: number;
    };
    3540: {
        x: number;
        y: number;
    };
    3550: {
        x: number;
        y: number;
    };
    3560: {
        x: number;
        y: number;
    };
    3570: {
        x: number;
        y: number;
    };
    3580: {
        x: number;
        y: number;
    };
    3590: {
        x: number;
        y: number;
    };
    3600: {
        x: number;
        y: number;
    };
    3610: {
        x: number;
        y: number;
    };
    3620: {
        x: number;
        y: number;
    };
    3630: {
        x: number;
        y: number;
    };
    3640: {
        x: number;
        y: number;
    };
    3650: {
        x: number;
        y: number;
    };
    3660: {
        x: number;
        y: number;
    };
    3670: {
        x: number;
        y: number;
    };
    3680: {
        x: number;
        y: number;
    };
    3690: {
        x: number;
        y: number;
    };
    3700: {
        x: number;
        y: number;
    };
    3710: {
        x: number;
        y: number;
    };
    3720: {
        x: number;
        y: number;
    };
    3730: {
        x: number;
        y: number;
    };
    3740: {
        x: number;
        y: number;
    };
    3750: {
        x: number;
        y: number;
    };
    3760: {
        x: number;
        y: number;
    };
    3770: {
        x: number;
        y: number;
    };
    3780: {
        x: number;
        y: number;
    };
    3790: {
        x: number;
        y: number;
    };
    3800: {
        x: number;
        y: number;
    };
    3810: {
        x: number;
        y: number;
    };
    3820: {
        x: number;
        y: number;
    };
    3830: {
        x: number;
        y: number;
    };
    3840: {
        x: number;
        y: number;
    };
    3850: {
        x: number;
        y: number;
    };
    3860: {
        x: number;
        y: number;
    };
    3870: {
        x: number;
        y: number;
    };
    3880: {
        x: number;
        y: number;
    };
    3890: {
        x: number;
        y: number;
    };
    3900: {
        x: number;
        y: number;
    };
    3910: {
        x: number;
        y: number;
    };
    3920: {
        x: number;
        y: number;
    };
    3930: {
        x: number;
        y: number;
    };
    3940: {
        x: number;
        y: number;
    };
    3950: {
        x: number;
        y: number;
    };
    3960: {
        x: number;
        y: number;
    };
    3970: {
        x: number;
        y: number;
    };
    3980: {
        x: number;
        y: number;
    };
    3990: {
        x: number;
        y: number;
    };
    4000: {
        x: number;
        y: number;
    };
    4010: {
        x: number;
        y: number;
    };
    4020: {
        x: number;
        y: number;
    };
    4030: {
        x: number;
        y: number;
    };
    4040: {
        x: number;
        y: number;
    };
    4050: {
        x: number;
        y: number;
    };
    4060: {
        x: number;
        y: number;
    };
    4070: {
        x: number;
        y: number;
    };
    4080: {
        x: number;
        y: number;
    };
    4090: {
        x: number;
        y: number;
    };
    4100: {
        x: number;
        y: number;
    };
    4110: {
        x: number;
        y: number;
    };
    4120: {
        x: number;
        y: number;
    };
    4130: {
        x: number;
        y: number;
    };
    4140: {
        x: number;
        y: number;
    };
    4150: {
        x: number;
        y: number;
    };
    4160: {
        x: number;
        y: number;
    };
    4170: {
        x: number;
        y: number;
    };
    4180: {
        x: number;
        y: number;
    };
    4190: {
        x: number;
        y: number;
    };
    4200: {
        x: number;
        y: number;
    };
    4210: {
        x: number;
        y: number;
    };
    4220: {
        x: number;
        y: number;
    };
    4230: {
        x: number;
        y: number;
    };
    4240: {
        x: number;
        y: number;
    };
    4250: {
        x: number;
        y: number;
    };
    4260: {
        x: number;
        y: number;
    };
    4270: {
        x: number;
        y: number;
    };
    4280: {
        x: number;
        y: number;
    };
    4290: {
        x: number;
        y: number;
    };
    4300: {
        x: number;
        y: number;
    };
    4310: {
        x: number;
        y: number;
    };
    4320: {
        x: number;
        y: number;
    };
    4330: {
        x: number;
        y: number;
    };
    4340: {
        x: number;
        y: number;
    };
    4350: {
        x: number;
        y: number;
    };
    4360: {
        x: number;
        y: number;
    };
    4370: {
        x: number;
        y: number;
    };
    4380: {
        x: number;
        y: number;
    };
    4390: {
        x: number;
        y: number;
    };
    4400: {
        x: number;
        y: number;
    };
    4410: {
        x: number;
        y: number;
    };
    4420: {
        x: number;
        y: number;
    };
    4430: {
        x: number;
        y: number;
    };
    4440: {
        x: number;
        y: number;
    };
    4450: {
        x: number;
        y: number;
    };
    4460: {
        x: number;
        y: number;
    };
    4470: {
        x: number;
        y: number;
    };
    4480: {
        x: number;
        y: number;
    };
    4490: {
        x: number;
        y: number;
    };
    4500: {
        x: number;
        y: number;
    };
    4510: {
        x: number;
        y: number;
    };
    4520: {
        x: number;
        y: number;
    };
    4530: {
        x: number;
        y: number;
    };
    4540: {
        x: number;
        y: number;
    };
    4550: {
        x: number;
        y: number;
    };
    4560: {
        x: number;
        y: number;
    };
    4570: {
        x: number;
        y: number;
    };
    4580: {
        x: number;
        y: number;
    };
    4590: {
        x: number;
        y: number;
    };
    4600: {
        x: number;
        y: number;
    };
    4610: {
        x: number;
        y: number;
    };
    4620: {
        x: number;
        y: number;
    };
    4630: {
        x: number;
        y: number;
    };
    4640: {
        x: number;
        y: number;
    };
    4650: {
        x: number;
        y: number;
    };
    4660: {
        x: number;
        y: number;
    };
    4670: {
        x: number;
        y: number;
    };
    4680: {
        x: number;
        y: number;
    };
    4690: {
        x: number;
        y: number;
    };
    4700: {
        x: number;
        y: number;
    };
    4710: {
        x: number;
        y: number;
    };
    4720: {
        x: number;
        y: number;
    };
    4730: {
        x: number;
        y: number;
    };
    4740: {
        x: number;
        y: number;
    };
    4750: {
        x: number;
        y: number;
    };
    4760: {
        x: number;
        y: number;
    };
    4770: {
        x: number;
        y: number;
    };
    4780: {
        x: number;
        y: number;
    };
    4790: {
        x: number;
        y: number;
    };
    4800: {
        x: number;
        y: number;
    };
    4810: {
        x: number;
        y: number;
    };
    4820: {
        x: number;
        y: number;
    };
    4830: {
        x: number;
        y: number;
    };
    4840: {
        x: number;
        y: number;
    };
    4850: {
        x: number;
        y: number;
    };
    4860: {
        x: number;
        y: number;
    };
    4870: {
        x: number;
        y: number;
    };
    4880: {
        x: number;
        y: number;
    };
    4890: {
        x: number;
        y: number;
    };
    4900: {
        x: number;
        y: number;
    };
    4910: {
        x: number;
        y: number;
    };
    4920: {
        x: number;
        y: number;
    };
    4930: {
        x: number;
        y: number;
    };
    4940: {
        x: number;
        y: number;
    };
    4950: {
        x: number;
        y: number;
    };
    4960: {
        x: number;
        y: number;
    };
    4970: {
        x: number;
        y: number;
    };
    4980: {
        x: number;
        y: number;
    };
    4990: {
        x: number;
        y: number;
    };
    5000: {
        x: number;
        y: number;
    };
    5010: {
        x: number;
        y: number;
    };
    5020: {
        x: number;
        y: number;
    };
    5030: {
        x: number;
        y: number;
    };
    5040: {
        x: number;
        y: number;
    };
    5050: {
        x: number;
        y: number;
    };
    5060: {
        x: number;
        y: number;
    };
    5070: {
        x: number;
        y: number;
    };
    5080: {
        x: number;
        y: number;
    };
    5090: {
        x: number;
        y: number;
    };
    5100: {
        x: number;
        y: number;
    };
    5110: {
        x: number;
        y: number;
    };
    5120: {
        x: number;
        y: number;
    };
    5130: {
        x: number;
        y: number;
    };
    5140: {
        x: number;
        y: number;
    };
    5150: {
        x: number;
        y: number;
    };
    5160: {
        x: number;
        y: number;
    };
    5170: {
        x: number;
        y: number;
    };
    5180: {
        x: number;
        y: number;
    };
    5190: {
        x: number;
        y: number;
    };
    5200: {
        x: number;
        y: number;
    };
    5210: {
        x: number;
        y: number;
    };
    5220: {
        x: number;
        y: number;
    };
    5230: {
        x: number;
        y: number;
    };
    5240: {
        x: number;
        y: number;
    };
    5250: {
        x: number;
        y: number;
    };
    5260: {
        x: number;
        y: number;
    };
    5270: {
        x: number;
        y: number;
    };
    5280: {
        x: number;
        y: number;
    };
    5290: {
        x: number;
        y: number;
    };
    5300: {
        x: number;
        y: number;
    };
    5310: {
        x: number;
        y: number;
    };
    5320: {
        x: number;
        y: number;
    };
    5330: {
        x: number;
        y: number;
    };
    5340: {
        x: number;
        y: number;
    };
    5350: {
        x: number;
        y: number;
    };
    5360: {
        x: number;
        y: number;
    };
    5370: {
        x: number;
        y: number;
    };
    5380: {
        x: number;
        y: number;
    };
    5390: {
        x: number;
        y: number;
    };
    5400: {
        x: number;
        y: number;
    };
    5410: {
        x: number;
        y: number;
    };
    5420: {
        x: number;
        y: number;
    };
    5430: {
        x: number;
        y: number;
    };
    5440: {
        x: number;
        y: number;
    };
    5450: {
        x: number;
        y: number;
    };
    5460: {
        x: number;
        y: number;
    };
    5470: {
        x: number;
        y: number;
    };
    5480: {
        x: number;
        y: number;
    };
    5490: {
        x: number;
        y: number;
    };
    5500: {
        x: number;
        y: number;
    };
    5510: {
        x: number;
        y: number;
    };
    5520: {
        x: number;
        y: number;
    };
    5530: {
        x: number;
        y: number;
    };
    5540: {
        x: number;
        y: number;
    };
    5550: {
        x: number;
        y: number;
    };
    5560: {
        x: number;
        y: number;
    };
    5570: {
        x: number;
        y: number;
    };
    5580: {
        x: number;
        y: number;
    };
    5590: {
        x: number;
        y: number;
    };
    5600: {
        x: number;
        y: number;
    };
    5610: {
        x: number;
        y: number;
    };
    5620: {
        x: number;
        y: number;
    };
    5630: {
        x: number;
        y: number;
    };
    5640: {
        x: number;
        y: number;
    };
    5650: {
        x: number;
        y: number;
    };
    5660: {
        x: number;
        y: number;
    };
    5670: {
        x: number;
        y: number;
    };
    5680: {
        x: number;
        y: number;
    };
    5690: {
        x: number;
        y: number;
    };
    5700: {
        x: number;
        y: number;
    };
    5710: {
        x: number;
        y: number;
    };
    5720: {
        x: number;
        y: number;
    };
    5730: {
        x: number;
        y: number;
    };
    5740: {
        x: number;
        y: number;
    };
    5750: {
        x: number;
        y: number;
    };
    5760: {
        x: number;
        y: number;
    };
    5770: {
        x: number;
        y: number;
    };
    5780: {
        x: number;
        y: number;
    };
    5790: {
        x: number;
        y: number;
    };
    5800: {
        x: number;
        y: number;
    };
    5810: {
        x: number;
        y: number;
    };
    5820: {
        x: number;
        y: number;
    };
    5830: {
        x: number;
        y: number;
    };
    5840: {
        x: number;
        y: number;
    };
    5850: {
        x: number;
        y: number;
    };
    5860: {
        x: number;
        y: number;
    };
    5870: {
        x: number;
        y: number;
    };
    5880: {
        x: number;
        y: number;
    };
    5890: {
        x: number;
        y: number;
    };
    5900: {
        x: number;
        y: number;
    };
    5910: {
        x: number;
        y: number;
    };
    5920: {
        x: number;
        y: number;
    };
    5930: {
        x: number;
        y: number;
    };
    5940: {
        x: number;
        y: number;
    };
    5950: {
        x: number;
        y: number;
    };
    5960: {
        x: number;
        y: number;
    };
    5970: {
        x: number;
        y: number;
    };
    5980: {
        x: number;
        y: number;
    };
    5990: {
        x: number;
        y: number;
    };
    6000: {
        x: number;
        y: number;
    };
    6010: {
        x: number;
        y: number;
    };
    6020: {
        x: number;
        y: number;
    };
    6030: {
        x: number;
        y: number;
    };
    6040: {
        x: number;
        y: number;
    };
    6050: {
        x: number;
        y: number;
    };
    6060: {
        x: number;
        y: number;
    };
    6070: {
        x: number;
        y: number;
    };
    6080: {
        x: number;
        y: number;
    };
    6090: {
        x: number;
        y: number;
    };
    6100: {
        x: number;
        y: number;
    };
    6110: {
        x: number;
        y: number;
    };
    6120: {
        x: number;
        y: number;
    };
    6130: {
        x: number;
        y: number;
    };
    6140: {
        x: number;
        y: number;
    };
    6150: {
        x: number;
        y: number;
    };
    6160: {
        x: number;
        y: number;
    };
    6170: {
        x: number;
        y: number;
    };
    6180: {
        x: number;
        y: number;
    };
    6190: {
        x: number;
        y: number;
    };
    6200: {
        x: number;
        y: number;
    };
    6210: {
        x: number;
        y: number;
    };
    6220: {
        x: number;
        y: number;
    };
    6230: {
        x: number;
        y: number;
    };
    6240: {
        x: number;
        y: number;
    };
    6250: {
        x: number;
        y: number;
    };
    6260: {
        x: number;
        y: number;
    };
    6270: {
        x: number;
        y: number;
    };
    6280: {
        x: number;
        y: number;
    };
    6290: {
        x: number;
        y: number;
    };
    6300: {
        x: number;
        y: number;
    };
    6310: {
        x: number;
        y: number;
    };
    6320: {
        x: number;
        y: number;
    };
    6330: {
        x: number;
        y: number;
    };
    6340: {
        x: number;
        y: number;
    };
    6350: {
        x: number;
        y: number;
    };
    6360: {
        x: number;
        y: number;
    };
    6370: {
        x: number;
        y: number;
    };
    6380: {
        x: number;
        y: number;
    };
    6390: {
        x: number;
        y: number;
    };
    6400: {
        x: number;
        y: number;
    };
    6410: {
        x: number;
        y: number;
    };
    6420: {
        x: number;
        y: number;
    };
    6430: {
        x: number;
        y: number;
    };
    6440: {
        x: number;
        y: number;
    };
    6450: {
        x: number;
        y: number;
    };
    6460: {
        x: number;
        y: number;
    };
    6470: {
        x: number;
        y: number;
    };
    6480: {
        x: number;
        y: number;
    };
    6490: {
        x: number;
        y: number;
    };
    6500: {
        x: number;
        y: number;
    };
    6510: {
        x: number;
        y: number;
    };
    6520: {
        x: number;
        y: number;
    };
    6530: {
        x: number;
        y: number;
    };
    6540: {
        x: number;
        y: number;
    };
    6550: {
        x: number;
        y: number;
    };
    6560: {
        x: number;
        y: number;
    };
    6570: {
        x: number;
        y: number;
    };
    6580: {
        x: number;
        y: number;
    };
    6590: {
        x: number;
        y: number;
    };
    6600: {
        x: number;
        y: number;
    };
    6610: {
        x: number;
        y: number;
    };
    6620: {
        x: number;
        y: number;
    };
    6630: {
        x: number;
        y: number;
    };
    6640: {
        x: number;
        y: number;
    };
    6650: {
        x: number;
        y: number;
    };
    6660: {
        x: number;
        y: number;
    };
    6670: {
        x: number;
        y: number;
    };
    6680: {
        x: number;
        y: number;
    };
    6690: {
        x: number;
        y: number;
    };
    6700: {
        x: number;
        y: number;
    };
    6710: {
        x: number;
        y: number;
    };
    6720: {
        x: number;
        y: number;
    };
    6730: {
        x: number;
        y: number;
    };
    6740: {
        x: number;
        y: number;
    };
    6750: {
        x: number;
        y: number;
    };
    6760: {
        x: number;
        y: number;
    };
    6770: {
        x: number;
        y: number;
    };
    6780: {
        x: number;
        y: number;
    };
    6790: {
        x: number;
        y: number;
    };
    6800: {
        x: number;
        y: number;
    };
    6810: {
        x: number;
        y: number;
    };
    6820: {
        x: number;
        y: number;
    };
    6830: {
        x: number;
        y: number;
    };
    6840: {
        x: number;
        y: number;
    };
    6850: {
        x: number;
        y: number;
    };
    6860: {
        x: number;
        y: number;
    };
    6870: {
        x: number;
        y: number;
    };
    6880: {
        x: number;
        y: number;
    };
    6890: {
        x: number;
        y: number;
    };
    6900: {
        x: number;
        y: number;
    };
    6910: {
        x: number;
        y: number;
    };
    6920: {
        x: number;
        y: number;
    };
    6930: {
        x: number;
        y: number;
    };
    6940: {
        x: number;
        y: number;
    };
    6950: {
        x: number;
        y: number;
    };
    6960: {
        x: number;
        y: number;
    };
    6970: {
        x: number;
        y: number;
    };
    6980: {
        x: number;
        y: number;
    };
    6990: {
        x: number;
        y: number;
    };
    7000: {
        x: number;
        y: number;
    };
    7010: {
        x: number;
        y: number;
    };
    7020: {
        x: number;
        y: number;
    };
    7030: {
        x: number;
        y: number;
    };
    7040: {
        x: number;
        y: number;
    };
    7050: {
        x: number;
        y: number;
    };
    7060: {
        x: number;
        y: number;
    };
    7070: {
        x: number;
        y: number;
    };
    7080: {
        x: number;
        y: number;
    };
    7090: {
        x: number;
        y: number;
    };
    7100: {
        x: number;
        y: number;
    };
    7110: {
        x: number;
        y: number;
    };
    7120: {
        x: number;
        y: number;
    };
    7130: {
        x: number;
        y: number;
    };
    7140: {
        x: number;
        y: number;
    };
    7150: {
        x: number;
        y: number;
    };
    7160: {
        x: number;
        y: number;
    };
    7170: {
        x: number;
        y: number;
    };
    7180: {
        x: number;
        y: number;
    };
    7190: {
        x: number;
        y: number;
    };
    7200: {
        x: number;
        y: number;
    };
    7210: {
        x: number;
        y: number;
    };
    7220: {
        x: number;
        y: number;
    };
    7230: {
        x: number;
        y: number;
    };
    7240: {
        x: number;
        y: number;
    };
    7250: {
        x: number;
        y: number;
    };
    7260: {
        x: number;
        y: number;
    };
    7270: {
        x: number;
        y: number;
    };
    7280: {
        x: number;
        y: number;
    };
    7290: {
        x: number;
        y: number;
    };
    7300: {
        x: number;
        y: number;
    };
    7310: {
        x: number;
        y: number;
    };
    7320: {
        x: number;
        y: number;
    };
    7330: {
        x: number;
        y: number;
    };
    7340: {
        x: number;
        y: number;
    };
    7350: {
        x: number;
        y: number;
    };
    7360: {
        x: number;
        y: number;
    };
    7370: {
        x: number;
        y: number;
    };
    7380: {
        x: number;
        y: number;
    };
    7390: {
        x: number;
        y: number;
    };
    7400: {
        x: number;
        y: number;
    };
    7410: {
        x: number;
        y: number;
    };
    7420: {
        x: number;
        y: number;
    };
    7430: {
        x: number;
        y: number;
    };
    7440: {
        x: number;
        y: number;
    };
    7450: {
        x: number;
        y: number;
    };
    7460: {
        x: number;
        y: number;
    };
    7470: {
        x: number;
        y: number;
    };
    7480: {
        x: number;
        y: number;
    };
    7490: {
        x: number;
        y: number;
    };
    7500: {
        x: number;
        y: number;
    };
    7510: {
        x: number;
        y: number;
    };
    7520: {
        x: number;
        y: number;
    };
    7530: {
        x: number;
        y: number;
    };
    7540: {
        x: number;
        y: number;
    };
    7550: {
        x: number;
        y: number;
    };
    7560: {
        x: number;
        y: number;
    };
    7570: {
        x: number;
        y: number;
    };
    7580: {
        x: number;
        y: number;
    };
    7590: {
        x: number;
        y: number;
    };
    7600: {
        x: number;
        y: number;
    };
    7610: {
        x: number;
        y: number;
    };
    7620: {
        x: number;
        y: number;
    };
    7630: {
        x: number;
        y: number;
    };
    7640: {
        x: number;
        y: number;
    };
    7650: {
        x: number;
        y: number;
    };
    7660: {
        x: number;
        y: number;
    };
    7670: {
        x: number;
        y: number;
    };
    7680: {
        x: number;
        y: number;
    };
    7690: {
        x: number;
        y: number;
    };
    7700: {
        x: number;
        y: number;
    };
    7710: {
        x: number;
        y: number;
    };
    7720: {
        x: number;
        y: number;
    };
    7730: {
        x: number;
        y: number;
    };
    7740: {
        x: number;
        y: number;
    };
    7750: {
        x: number;
        y: number;
    };
    7760: {
        x: number;
        y: number;
    };
    7770: {
        x: number;
        y: number;
    };
    7780: {
        x: number;
        y: number;
    };
    7790: {
        x: number;
        y: number;
    };
    7800: {
        x: number;
        y: number;
    };
    7810: {
        x: number;
        y: number;
    };
    7820: {
        x: number;
        y: number;
    };
    7830: {
        x: number;
        y: number;
    };
    7840: {
        x: number;
        y: number;
    };
    7850: {
        x: number;
        y: number;
    };
    7860: {
        x: number;
        y: number;
    };
    7870: {
        x: number;
        y: number;
    };
    7880: {
        x: number;
        y: number;
    };
    7890: {
        x: number;
        y: number;
    };
    7900: {
        x: number;
        y: number;
    };
    7910: {
        x: number;
        y: number;
    };
    7920: {
        x: number;
        y: number;
    };
    7930: {
        x: number;
        y: number;
    };
    7940: {
        x: number;
        y: number;
    };
    7950: {
        x: number;
        y: number;
    };
    7960: {
        x: number;
        y: number;
    };
    7970: {
        x: number;
        y: number;
    };
    7980: {
        x: number;
        y: number;
    };
    7990: {
        x: number;
        y: number;
    };
    8000: {
        x: number;
        y: number;
    };
    8010: {
        x: number;
        y: number;
    };
    8020: {
        x: number;
        y: number;
    };
    8030: {
        x: number;
        y: number;
    };
    8040: {
        x: number;
        y: number;
    };
    8050: {
        x: number;
        y: number;
    };
    8060: {
        x: number;
        y: number;
    };
    8070: {
        x: number;
        y: number;
    };
    8080: {
        x: number;
        y: number;
    };
    8090: {
        x: number;
        y: number;
    };
    8100: {
        x: number;
        y: number;
    };
    8110: {
        x: number;
        y: number;
    };
    8120: {
        x: number;
        y: number;
    };
    8130: {
        x: number;
        y: number;
    };
    8140: {
        x: number;
        y: number;
    };
    8150: {
        x: number;
        y: number;
    };
    8160: {
        x: number;
        y: number;
    };
    8170: {
        x: number;
        y: number;
    };
    8180: {
        x: number;
        y: number;
    };
    8190: {
        x: number;
        y: number;
    };
    8200: {
        x: number;
        y: number;
    };
    8210: {
        x: number;
        y: number;
    };
    8220: {
        x: number;
        y: number;
    };
    8230: {
        x: number;
        y: number;
    };
    8240: {
        x: number;
        y: number;
    };
    8250: {
        x: number;
        y: number;
    };
    8260: {
        x: number;
        y: number;
    };
    8270: {
        x: number;
        y: number;
    };
    8280: {
        x: number;
        y: number;
    };
    8290: {
        x: number;
        y: number;
    };
    8300: {
        x: number;
        y: number;
    };
    8310: {
        x: number;
        y: number;
    };
    8320: {
        x: number;
        y: number;
    };
    8330: {
        x: number;
        y: number;
    };
    8340: {
        x: number;
        y: number;
    };
    8350: {
        x: number;
        y: number;
    };
    8360: {
        x: number;
        y: number;
    };
    8370: {
        x: number;
        y: number;
    };
    8380: {
        x: number;
        y: number;
    };
    8390: {
        x: number;
        y: number;
    };
    8400: {
        x: number;
        y: number;
    };
    8410: {
        x: number;
        y: number;
    };
    8420: {
        x: number;
        y: number;
    };
    8430: {
        x: number;
        y: number;
    };
    8440: {
        x: number;
        y: number;
    };
    8450: {
        x: number;
        y: number;
    };
    8460: {
        x: number;
        y: number;
    };
    8470: {
        x: number;
        y: number;
    };
    8480: {
        x: number;
        y: number;
    };
    8490: {
        x: number;
        y: number;
    };
    8500: {
        x: number;
        y: number;
    };
    8510: {
        x: number;
        y: number;
    };
    8520: {
        x: number;
        y: number;
    };
    8530: {
        x: number;
        y: number;
    };
    8540: {
        x: number;
        y: number;
    };
    8550: {
        x: number;
        y: number;
    };
    8560: {
        x: number;
        y: number;
    };
    8570: {
        x: number;
        y: number;
    };
    8580: {
        x: number;
        y: number;
    };
    8590: {
        x: number;
        y: number;
    };
    8600: {
        x: number;
        y: number;
    };
    8610: {
        x: number;
        y: number;
    };
    8620: {
        x: number;
        y: number;
    };
    8630: {
        x: number;
        y: number;
    };
    8640: {
        x: number;
        y: number;
    };
    8650: {
        x: number;
        y: number;
    };
    8660: {
        x: number;
        y: number;
    };
    8670: {
        x: number;
        y: number;
    };
    8680: {
        x: number;
        y: number;
    };
    8690: {
        x: number;
        y: number;
    };
    8700: {
        x: number;
        y: number;
    };
    8710: {
        x: number;
        y: number;
    };
    8720: {
        x: number;
        y: number;
    };
    8730: {
        x: number;
        y: number;
    };
    8740: {
        x: number;
        y: number;
    };
    8750: {
        x: number;
        y: number;
    };
    8760: {
        x: number;
        y: number;
    };
    8770: {
        x: number;
        y: number;
    };
    8780: {
        x: number;
        y: number;
    };
    8790: {
        x: number;
        y: number;
    };
    8800: {
        x: number;
        y: number;
    };
    8810: {
        x: number;
        y: number;
    };
    8820: {
        x: number;
        y: number;
    };
    8830: {
        x: number;
        y: number;
    };
    8840: {
        x: number;
        y: number;
    };
    8850: {
        x: number;
        y: number;
    };
    8860: {
        x: number;
        y: number;
    };
    8870: {
        x: number;
        y: number;
    };
    8880: {
        x: number;
        y: number;
    };
    8890: {
        x: number;
        y: number;
    };
    8900: {
        x: number;
        y: number;
    };
    8910: {
        x: number;
        y: number;
    };
    8920: {
        x: number;
        y: number;
    };
    8930: {
        x: number;
        y: number;
    };
    8940: {
        x: number;
        y: number;
    };
    8950: {
        x: number;
        y: number;
    };
    8960: {
        x: number;
        y: number;
    };
    8970: {
        x: number;
        y: number;
    };
    8980: {
        x: number;
        y: number;
    };
    8990: {
        x: number;
        y: number;
    };
    9000: {
        x: number;
        y: number;
    };
    9010: {
        x: number;
        y: number;
    };
    9020: {
        x: number;
        y: number;
    };
    9030: {
        x: number;
        y: number;
    };
    9040: {
        x: number;
        y: number;
    };
    9050: {
        x: number;
        y: number;
    };
    9060: {
        x: number;
        y: number;
    };
    9070: {
        x: number;
        y: number;
    };
    9080: {
        x: number;
        y: number;
    };
    9090: {
        x: number;
        y: number;
    };
    9100: {
        x: number;
        y: number;
    };
    9110: {
        x: number;
        y: number;
    };
    9120: {
        x: number;
        y: number;
    };
    9130: {
        x: number;
        y: number;
    };
    9140: {
        x: number;
        y: number;
    };
    9150: {
        x: number;
        y: number;
    };
    9160: {
        x: number;
        y: number;
    };
    9170: {
        x: number;
        y: number;
    };
    9180: {
        x: number;
        y: number;
    };
    9190: {
        x: number;
        y: number;
    };
    9200: {
        x: number;
        y: number;
    };
    9210: {
        x: number;
        y: number;
    };
    9220: {
        x: number;
        y: number;
    };
    9230: {
        x: number;
        y: number;
    };
    9240: {
        x: number;
        y: number;
    };
    9250: {
        x: number;
        y: number;
    };
    9260: {
        x: number;
        y: number;
    };
    9270: {
        x: number;
        y: number;
    };
    9280: {
        x: number;
        y: number;
    };
    9290: {
        x: number;
        y: number;
    };
    9300: {
        x: number;
        y: number;
    };
    9310: {
        x: number;
        y: number;
    };
    9320: {
        x: number;
        y: number;
    };
    9330: {
        x: number;
        y: number;
    };
    9340: {
        x: number;
        y: number;
    };
    9350: {
        x: number;
        y: number;
    };
    9360: {
        x: number;
        y: number;
    };
    9370: {
        x: number;
        y: number;
    };
    9380: {
        x: number;
        y: number;
    };
    9390: {
        x: number;
        y: number;
    };
    9400: {
        x: number;
        y: number;
    };
    9410: {
        x: number;
        y: number;
    };
    9420: {
        x: number;
        y: number;
    };
    9430: {
        x: number;
        y: number;
    };
    9440: {
        x: number;
        y: number;
    };
    9450: {
        x: number;
        y: number;
    };
    9460: {
        x: number;
        y: number;
    };
    9470: {
        x: number;
        y: number;
    };
    9480: {
        x: number;
        y: number;
    };
    9490: {
        x: number;
        y: number;
    };
    9500: {
        x: number;
        y: number;
    };
    9510: {
        x: number;
        y: number;
    };
    9520: {
        x: number;
        y: number;
    };
    9530: {
        x: number;
        y: number;
    };
    9540: {
        x: number;
        y: number;
    };
    9550: {
        x: number;
        y: number;
    };
    9560: {
        x: number;
        y: number;
    };
    9570: {
        x: number;
        y: number;
    };
    9580: {
        x: number;
        y: number;
    };
    9590: {
        x: number;
        y: number;
    };
    9600: {
        x: number;
        y: number;
    };
    9610: {
        x: number;
        y: number;
    };
    9620: {
        x: number;
        y: number;
    };
    9630: {
        x: number;
        y: number;
    };
    9640: {
        x: number;
        y: number;
    };
    9650: {
        x: number;
        y: number;
    };
    9660: {
        x: number;
        y: number;
    };
    9670: {
        x: number;
        y: number;
    };
    9680: {
        x: number;
        y: number;
    };
    9690: {
        x: number;
        y: number;
    };
    9700: {
        x: number;
        y: number;
    };
    9710: {
        x: number;
        y: number;
    };
    9720: {
        x: number;
        y: number;
    };
    9730: {
        x: number;
        y: number;
    };
    9740: {
        x: number;
        y: number;
    };
    9750: {
        x: number;
        y: number;
    };
    9760: {
        x: number;
        y: number;
    };
    9770: {
        x: number;
        y: number;
    };
    9780: {
        x: number;
        y: number;
    };
    9790: {
        x: number;
        y: number;
    };
    9800: {
        x: number;
        y: number;
    };
    9810: {
        x: number;
        y: number;
    };
    9820: {
        x: number;
        y: number;
    };
    9830: {
        x: number;
        y: number;
    };
    9840: {
        x: number;
        y: number;
    };
    9850: {
        x: number;
        y: number;
    };
    9860: {
        x: number;
        y: number;
    };
    9870: {
        x: number;
        y: number;
    };
    9880: {
        x: number;
        y: number;
    };
    9890: {
        x: number;
        y: number;
    };
    9900: {
        x: number;
        y: number;
    };
    9910: {
        x: number;
        y: number;
    };
    9920: {
        x: number;
        y: number;
    };
    9930: {
        x: number;
        y: number;
    };
    9940: {
        x: number;
        y: number;
    };
    9950: {
        x: number;
        y: number;
    };
    9960: {
        x: number;
        y: number;
    };
    9970: {
        x: number;
        y: number;
    };
    9980: {
        x: number;
        y: number;
    };
    9990: {
        x: number;
        y: number;
    };
    10000: {
        x: number;
        y: number;
    };
    10010: {
        x: number;
        y: number;
    };
    10020: {
        x: number;
        y: number;
    };
    10030: {
        x: number;
        y: number;
    };
    10040: {
        x: number;
        y: number;
    };
    10050: {
        x: number;
        y: number;
    };
    10060: {
        x: number;
        y: number;
    };
    10070: {
        x: number;
        y: number;
    };
    10080: {
        x: number;
        y: number;
    };
    10090: {
        x: number;
        y: number;
    };
    10100: {
        x: number;
        y: number;
    };
    10110: {
        x: number;
        y: number;
    };
    10120: {
        x: number;
        y: number;
    };
    10130: {
        x: number;
        y: number;
    };
    10140: {
        x: number;
        y: number;
    };
    10150: {
        x: number;
        y: number;
    };
    10160: {
        x: number;
        y: number;
    };
    10170: {
        x: number;
        y: number;
    };
    10180: {
        x: number;
        y: number;
    };
    10190: {
        x: number;
        y: number;
    };
    10200: {
        x: number;
        y: number;
    };
    10210: {
        x: number;
        y: number;
    };
    10220: {
        x: number;
        y: number;
    };
    10230: {
        x: number;
        y: number;
    };
    10240: {
        x: number;
        y: number;
    };
    10250: {
        x: number;
        y: number;
    };
    10260: {
        x: number;
        y: number;
    };
    10270: {
        x: number;
        y: number;
    };
    10280: {
        x: number;
        y: number;
    };
    10290: {
        x: number;
        y: number;
    };
    10300: {
        x: number;
        y: number;
    };
    10310: {
        x: number;
        y: number;
    };
    10320: {
        x: number;
        y: number;
    };
    10330: {
        x: number;
        y: number;
    };
    10340: {
        x: number;
        y: number;
    };
    10350: {
        x: number;
        y: number;
    };
    10360: {
        x: number;
        y: number;
    };
    10370: {
        x: number;
        y: number;
    };
    10380: {
        x: number;
        y: number;
    };
    10390: {
        x: number;
        y: number;
    };
    10400: {
        x: number;
        y: number;
    };
    10410: {
        x: number;
        y: number;
    };
    10420: {
        x: number;
        y: number;
    };
    10430: {
        x: number;
        y: number;
    };
    10440: {
        x: number;
        y: number;
    };
    10450: {
        x: number;
        y: number;
    };
    10460: {
        x: number;
        y: number;
    };
    10470: {
        x: number;
        y: number;
    };
    10480: {
        x: number;
        y: number;
    };
    10490: {
        x: number;
        y: number;
    };
    10500: {
        x: number;
        y: number;
    };
    10510: {
        x: number;
        y: number;
    };
    10520: {
        x: number;
        y: number;
    };
    10530: {
        x: number;
        y: number;
    };
    10540: {
        x: number;
        y: number;
    };
    10550: {
        x: number;
        y: number;
    };
    10560: {
        x: number;
        y: number;
    };
    10570: {
        x: number;
        y: number;
    };
    10580: {
        x: number;
        y: number;
    };
    10590: {
        x: number;
        y: number;
    };
    10600: {
        x: number;
        y: number;
    };
    10610: {
        x: number;
        y: number;
    };
    10620: {
        x: number;
        y: number;
    };
    10630: {
        x: number;
        y: number;
    };
    10640: {
        x: number;
        y: number;
    };
    10650: {
        x: number;
        y: number;
    };
    10660: {
        x: number;
        y: number;
    };
    10670: {
        x: number;
        y: number;
    };
    10680: {
        x: number;
        y: number;
    };
    10690: {
        x: number;
        y: number;
    };
    10700: {
        x: number;
        y: number;
    };
    10710: {
        x: number;
        y: number;
    };
    10720: {
        x: number;
        y: number;
    };
    10730: {
        x: number;
        y: number;
    };
    10740: {
        x: number;
        y: number;
    };
    10750: {
        x: number;
        y: number;
    };
    10760: {
        x: number;
        y: number;
    };
    10770: {
        x: number;
        y: number;
    };
    10780: {
        x: number;
        y: number;
    };
    10790: {
        x: number;
        y: number;
    };
    10800: {
        x: number;
        y: number;
    };
    10810: {
        x: number;
        y: number;
    };
    10820: {
        x: number;
        y: number;
    };
    10830: {
        x: number;
        y: number;
    };
    10840: {
        x: number;
        y: number;
    };
    10850: {
        x: number;
        y: number;
    };
    10860: {
        x: number;
        y: number;
    };
    10870: {
        x: number;
        y: number;
    };
    10880: {
        x: number;
        y: number;
    };
    10890: {
        x: number;
        y: number;
    };
    10900: {
        x: number;
        y: number;
    };
    10910: {
        x: number;
        y: number;
    };
    10920: {
        x: number;
        y: number;
    };
    10930: {
        x: number;
        y: number;
    };
    10940: {
        x: number;
        y: number;
    };
    10950: {
        x: number;
        y: number;
    };
    10960: {
        x: number;
        y: number;
    };
    10970: {
        x: number;
        y: number;
    };
    10980: {
        x: number;
        y: number;
    };
    10990: {
        x: number;
        y: number;
    };
    11000: {
        x: number;
        y: number;
    };
    11010: {
        x: number;
        y: number;
    };
    11020: {
        x: number;
        y: number;
    };
    11030: {
        x: number;
        y: number;
    };
    11040: {
        x: number;
        y: number;
    };
    11050: {
        x: number;
        y: number;
    };
    11060: {
        x: number;
        y: number;
    };
    11070: {
        x: number;
        y: number;
    };
    11080: {
        x: number;
        y: number;
    };
    11090: {
        x: number;
        y: number;
    };
    11100: {
        x: number;
        y: number;
    };
    11110: {
        x: number;
        y: number;
    };
    11120: {
        x: number;
        y: number;
    };
    11130: {
        x: number;
        y: number;
    };
    11140: {
        x: number;
        y: number;
    };
    11150: {
        x: number;
        y: number;
    };
    11160: {
        x: number;
        y: number;
    };
    11170: {
        x: number;
        y: number;
    };
    11180: {
        x: number;
        y: number;
    };
    11190: {
        x: number;
        y: number;
    };
    11200: {
        x: number;
        y: number;
    };
    11210: {
        x: number;
        y: number;
    };
    11220: {
        x: number;
        y: number;
    };
    11230: {
        x: number;
        y: number;
    };
    11240: {
        x: number;
        y: number;
    };
    11250: {
        x: number;
        y: number;
    };
    11260: {
        x: number;
        y: number;
    };
    11270: {
        x: number;
        y: number;
    };
    11280: {
        x: number;
        y: number;
    };
    11290: {
        x: number;
        y: number;
    };
    11300: {
        x: number;
        y: number;
    };
    11310: {
        x: number;
        y: number;
    };
    11320: {
        x: number;
        y: number;
    };
    11330: {
        x: number;
        y: number;
    };
    11340: {
        x: number;
        y: number;
    };
    11350: {
        x: number;
        y: number;
    };
    11360: {
        x: number;
        y: number;
    };
    11370: {
        x: number;
        y: number;
    };
    11380: {
        x: number;
        y: number;
    };
    11390: {
        x: number;
        y: number;
    };
    11400: {
        x: number;
        y: number;
    };
    11410: {
        x: number;
        y: number;
    };
    11420: {
        x: number;
        y: number;
    };
    11430: {
        x: number;
        y: number;
    };
    11440: {
        x: number;
        y: number;
    };
    11450: {
        x: number;
        y: number;
    };
    11460: {
        x: number;
        y: number;
    };
    11470: {
        x: number;
        y: number;
    };
    11480: {
        x: number;
        y: number;
    };
    11490: {
        x: number;
        y: number;
    };
    11500: {
        x: number;
        y: number;
    };
    11510: {
        x: number;
        y: number;
    };
    11520: {
        x: number;
        y: number;
    };
    11530: {
        x: number;
        y: number;
    };
    11540: {
        x: number;
        y: number;
    };
    11550: {
        x: number;
        y: number;
    };
    11560: {
        x: number;
        y: number;
    };
    11570: {
        x: number;
        y: number;
    };
    11580: {
        x: number;
        y: number;
    };
    11590: {
        x: number;
        y: number;
    };
    11600: {
        x: number;
        y: number;
    };
    11610: {
        x: number;
        y: number;
    };
    11620: {
        x: number;
        y: number;
    };
    11630: {
        x: number;
        y: number;
    };
    11640: {
        x: number;
        y: number;
    };
    11650: {
        x: number;
        y: number;
    };
    11660: {
        x: number;
        y: number;
    };
    11670: {
        x: number;
        y: number;
    };
    11680: {
        x: number;
        y: number;
    };
    11690: {
        x: number;
        y: number;
    };
    11700: {
        x: number;
        y: number;
    };
    11710: {
        x: number;
        y: number;
    };
    11720: {
        x: number;
        y: number;
    };
    11730: {
        x: number;
        y: number;
    };
    11740: {
        x: number;
        y: number;
    };
    11750: {
        x: number;
        y: number;
    };
    11760: {
        x: number;
        y: number;
    };
    11770: {
        x: number;
        y: number;
    };
    11780: {
        x: number;
        y: number;
    };
    11790: {
        x: number;
        y: number;
    };
    11800: {
        x: number;
        y: number;
    };
    11810: {
        x: number;
        y: number;
    };
    11820: {
        x: number;
        y: number;
    };
    11830: {
        x: number;
        y: number;
    };
    11840: {
        x: number;
        y: number;
    };
    11850: {
        x: number;
        y: number;
    };
    11860: {
        x: number;
        y: number;
    };
    11870: {
        x: number;
        y: number;
    };
    11880: {
        x: number;
        y: number;
    };
    11890: {
        x: number;
        y: number;
    };
    11900: {
        x: number;
        y: number;
    };
    11910: {
        x: number;
        y: number;
    };
    11920: {
        x: number;
        y: number;
    };
    11930: {
        x: number;
        y: number;
    };
    11940: {
        x: number;
        y: number;
    };
    11950: {
        x: number;
        y: number;
    };
    11960: {
        x: number;
        y: number;
    };
    11970: {
        x: number;
        y: number;
    };
    11980: {
        x: number;
        y: number;
    };
    11990: {
        x: number;
        y: number;
    };
    12000: {
        x: number;
        y: number;
    };
    12010: {
        x: number;
        y: number;
    };
    12020: {
        x: number;
        y: number;
    };
    12030: {
        x: number;
        y: number;
    };
    12040: {
        x: number;
        y: number;
    };
    12050: {
        x: number;
        y: number;
    };
    12060: {
        x: number;
        y: number;
    };
    12070: {
        x: number;
        y: number;
    };
    12080: {
        x: number;
        y: number;
    };
    12090: {
        x: number;
        y: number;
    };
    12100: {
        x: number;
        y: number;
    };
    12110: {
        x: number;
        y: number;
    };
    12120: {
        x: number;
        y: number;
    };
    12130: {
        x: number;
        y: number;
    };
    12140: {
        x: number;
        y: number;
    };
    12150: {
        x: number;
        y: number;
    };
    12160: {
        x: number;
        y: number;
    };
    12170: {
        x: number;
        y: number;
    };
    12180: {
        x: number;
        y: number;
    };
    12190: {
        x: number;
        y: number;
    };
    12200: {
        x: number;
        y: number;
    };
    12210: {
        x: number;
        y: number;
    };
    12220: {
        x: number;
        y: number;
    };
    12230: {
        x: number;
        y: number;
    };
    12240: {
        x: number;
        y: number;
    };
    12250: {
        x: number;
        y: number;
    };
    12260: {
        x: number;
        y: number;
    };
    12270: {
        x: number;
        y: number;
    };
    12280: {
        x: number;
        y: number;
    };
    12290: {
        x: number;
        y: number;
    };
    12300: {
        x: number;
        y: number;
    };
    12310: {
        x: number;
        y: number;
    };
    12320: {
        x: number;
        y: number;
    };
    12330: {
        x: number;
        y: number;
    };
    12340: {
        x: number;
        y: number;
    };
    12350: {
        x: number;
        y: number;
    };
    12360: {
        x: number;
        y: number;
    };
    12370: {
        x: number;
        y: number;
    };
    12380: {
        x: number;
        y: number;
    };
    12390: {
        x: number;
        y: number;
    };
    12400: {
        x: number;
        y: number;
    };
    12410: {
        x: number;
        y: number;
    };
    12420: {
        x: number;
        y: number;
    };
    12430: {
        x: number;
        y: number;
    };
    12440: {
        x: number;
        y: number;
    };
    12450: {
        x: number;
        y: number;
    };
    12460: {
        x: number;
        y: number;
    };
    12470: {
        x: number;
        y: number;
    };
    12480: {
        x: number;
        y: number;
    };
    12490: {
        x: number;
        y: number;
    };
    12500: {
        x: number;
        y: number;
    };
    12510: {
        x: number;
        y: number;
    };
    12520: {
        x: number;
        y: number;
    };
    12530: {
        x: number;
        y: number;
    };
    12540: {
        x: number;
        y: number;
    };
    12550: {
        x: number;
        y: number;
    };
    12560: {
        x: number;
        y: number;
    };
    12570: {
        x: number;
        y: number;
    };
    12580: {
        x: number;
        y: number;
    };
    12590: {
        x: number;
        y: number;
    };
    12600: {
        x: number;
        y: number;
    };
    12610: {
        x: number;
        y: number;
    };
    12620: {
        x: number;
        y: number;
    };
    12630: {
        x: number;
        y: number;
    };
    12640: {
        x: number;
        y: number;
    };
    12650: {
        x: number;
        y: number;
    };
    12660: {
        x: number;
        y: number;
    };
    12670: {
        x: number;
        y: number;
    };
    12680: {
        x: number;
        y: number;
    };
    12690: {
        x: number;
        y: number;
    };
    12700: {
        x: number;
        y: number;
    };
    12710: {
        x: number;
        y: number;
    };
    12720: {
        x: number;
        y: number;
    };
    12730: {
        x: number;
        y: number;
    };
    12740: {
        x: number;
        y: number;
    };
    12750: {
        x: number;
        y: number;
    };
    12760: {
        x: number;
        y: number;
    };
    12770: {
        x: number;
        y: number;
    };
    12780: {
        x: number;
        y: number;
    };
    12790: {
        x: number;
        y: number;
    };
    12800: {
        x: number;
        y: number;
    };
    12810: {
        x: number;
        y: number;
    };
    12820: {
        x: number;
        y: number;
    };
    12830: {
        x: number;
        y: number;
    };
    12840: {
        x: number;
        y: number;
    };
    12850: {
        x: number;
        y: number;
    };
    12860: {
        x: number;
        y: number;
    };
    12870: {
        x: number;
        y: number;
    };
    12880: {
        x: number;
        y: number;
    };
    12890: {
        x: number;
        y: number;
    };
    12900: {
        x: number;
        y: number;
    };
    12910: {
        x: number;
        y: number;
    };
    12920: {
        x: number;
        y: number;
    };
    12930: {
        x: number;
        y: number;
    };
    12940: {
        x: number;
        y: number;
    };
    12950: {
        x: number;
        y: number;
    };
    12960: {
        x: number;
        y: number;
    };
    12970: {
        x: number;
        y: number;
    };
    12980: {
        x: number;
        y: number;
    };
    12990: {
        x: number;
        y: number;
    };
    13000: {
        x: number;
        y: number;
    };
    13010: {
        x: number;
        y: number;
    };
    13020: {
        x: number;
        y: number;
    };
    13030: {
        x: number;
        y: number;
    };
    13040: {
        x: number;
        y: number;
    };
    13050: {
        x: number;
        y: number;
    };
    13060: {
        x: number;
        y: number;
    };
    13070: {
        x: number;
        y: number;
    };
    13080: {
        x: number;
        y: number;
    };
    13090: {
        x: number;
        y: number;
    };
    13100: {
        x: number;
        y: number;
    };
    13110: {
        x: number;
        y: number;
    };
    13120: {
        x: number;
        y: number;
    };
    13130: {
        x: number;
        y: number;
    };
    13140: {
        x: number;
        y: number;
    };
    13150: {
        x: number;
        y: number;
    };
    13160: {
        x: number;
        y: number;
    };
    13170: {
        x: number;
        y: number;
    };
    13180: {
        x: number;
        y: number;
    };
    13190: {
        x: number;
        y: number;
    };
    13200: {
        x: number;
        y: number;
    };
    13210: {
        x: number;
        y: number;
    };
    13220: {
        x: number;
        y: number;
    };
    13230: {
        x: number;
        y: number;
    };
    13240: {
        x: number;
        y: number;
    };
    13250: {
        x: number;
        y: number;
    };
    13260: {
        x: number;
        y: number;
    };
    13270: {
        x: number;
        y: number;
    };
    13280: {
        x: number;
        y: number;
    };
    13290: {
        x: number;
        y: number;
    };
    13300: {
        x: number;
        y: number;
    };
    13310: {
        x: number;
        y: number;
    };
    13320: {
        x: number;
        y: number;
    };
    13330: {
        x: number;
        y: number;
    };
    13340: {
        x: number;
        y: number;
    };
    13350: {
        x: number;
        y: number;
    };
    13360: {
        x: number;
        y: number;
    };
    13370: {
        x: number;
        y: number;
    };
    13380: {
        x: number;
        y: number;
    };
    13390: {
        x: number;
        y: number;
    };
    13400: {
        x: number;
        y: number;
    };
    13410: {
        x: number;
        y: number;
    };
    13420: {
        x: number;
        y: number;
    };
    13430: {
        x: number;
        y: number;
    };
    13440: {
        x: number;
        y: number;
    };
    13450: {
        x: number;
        y: number;
    };
    13460: {
        x: number;
        y: number;
    };
    13470: {
        x: number;
        y: number;
    };
    13480: {
        x: number;
        y: number;
    };
    13490: {
        x: number;
        y: number;
    };
    13500: {
        x: number;
        y: number;
    };
    13510: {
        x: number;
        y: number;
    };
    13520: {
        x: number;
        y: number;
    };
    13530: {
        x: number;
        y: number;
    };
    13540: {
        x: number;
        y: number;
    };
    13550: {
        x: number;
        y: number;
    };
    13560: {
        x: number;
        y: number;
    };
    13570: {
        x: number;
        y: number;
    };
    13580: {
        x: number;
        y: number;
    };
    13590: {
        x: number;
        y: number;
    };
    13600: {
        x: number;
        y: number;
    };
    13610: {
        x: number;
        y: number;
    };
    13620: {
        x: number;
        y: number;
    };
    13630: {
        x: number;
        y: number;
    };
    13640: {
        x: number;
        y: number;
    };
    13650: {
        x: number;
        y: number;
    };
    13660: {
        x: number;
        y: number;
    };
    13670: {
        x: number;
        y: number;
    };
    13680: {
        x: number;
        y: number;
    };
    13690: {
        x: number;
        y: number;
    };
    13700: {
        x: number;
        y: number;
    };
    13710: {
        x: number;
        y: number;
    };
    13720: {
        x: number;
        y: number;
    };
    13730: {
        x: number;
        y: number;
    };
    13740: {
        x: number;
        y: number;
    };
    13750: {
        x: number;
        y: number;
    };
    13760: {
        x: number;
        y: number;
    };
    13770: {
        x: number;
        y: number;
    };
    13780: {
        x: number;
        y: number;
    };
    13790: {
        x: number;
        y: number;
    };
    13800: {
        x: number;
        y: number;
    };
    13810: {
        x: number;
        y: number;
    };
    13820: {
        x: number;
        y: number;
    };
    13830: {
        x: number;
        y: number;
    };
    13840: {
        x: number;
        y: number;
    };
    13850: {
        x: number;
        y: number;
    };
    13860: {
        x: number;
        y: number;
    };
    13870: {
        x: number;
        y: number;
    };
    13880: {
        x: number;
        y: number;
    };
    13890: {
        x: number;
        y: number;
    };
    13900: {
        x: number;
        y: number;
    };
    13910: {
        x: number;
        y: number;
    };
    13920: {
        x: number;
        y: number;
    };
    13930: {
        x: number;
        y: number;
    };
    13940: {
        x: number;
        y: number;
    };
    13950: {
        x: number;
        y: number;
    };
    13960: {
        x: number;
        y: number;
    };
    13970: {
        x: number;
        y: number;
    };
    13980: {
        x: number;
        y: number;
    };
    13990: {
        x: number;
        y: number;
    };
    14000: {
        x: number;
        y: number;
    };
    14010: {
        x: number;
        y: number;
    };
    14020: {
        x: number;
        y: number;
    };
    14030: {
        x: number;
        y: number;
    };
    14040: {
        x: number;
        y: number;
    };
    14050: {
        x: number;
        y: number;
    };
    14060: {
        x: number;
        y: number;
    };
    14070: {
        x: number;
        y: number;
    };
    14080: {
        x: number;
        y: number;
    };
    14090: {
        x: number;
        y: number;
    };
    14100: {
        x: number;
        y: number;
    };
    14110: {
        x: number;
        y: number;
    };
    14120: {
        x: number;
        y: number;
    };
    14130: {
        x: number;
        y: number;
    };
    14140: {
        x: number;
        y: number;
    };
    14150: {
        x: number;
        y: number;
    };
    14160: {
        x: number;
        y: number;
    };
    14170: {
        x: number;
        y: number;
    };
    14180: {
        x: number;
        y: number;
    };
    14190: {
        x: number;
        y: number;
    };
    14200: {
        x: number;
        y: number;
    };
    14210: {
        x: number;
        y: number;
    };
    14220: {
        x: number;
        y: number;
    };
    14230: {
        x: number;
        y: number;
    };
    14240: {
        x: number;
        y: number;
    };
    14250: {
        x: number;
        y: number;
    };
    14260: {
        x: number;
        y: number;
    };
    14270: {
        x: number;
        y: number;
    };
    14280: {
        x: number;
        y: number;
    };
    14290: {
        x: number;
        y: number;
    };
    14300: {
        x: number;
        y: number;
    };
    14310: {
        x: number;
        y: number;
    };
    14320: {
        x: number;
        y: number;
    };
    14330: {
        x: number;
        y: number;
    };
    14340: {
        x: number;
        y: number;
    };
    14350: {
        x: number;
        y: number;
    };
    14360: {
        x: number;
        y: number;
    };
    14370: {
        x: number;
        y: number;
    };
    14380: {
        x: number;
        y: number;
    };
    14390: {
        x: number;
        y: number;
    };
    14400: {
        x: number;
        y: number;
    };
    14410: {
        x: number;
        y: number;
    };
    14420: {
        x: number;
        y: number;
    };
    14430: {
        x: number;
        y: number;
    };
    14440: {
        x: number;
        y: number;
    };
    14450: {
        x: number;
        y: number;
    };
    14460: {
        x: number;
        y: number;
    };
    14470: {
        x: number;
        y: number;
    };
    14480: {
        x: number;
        y: number;
    };
    14490: {
        x: number;
        y: number;
    };
    14500: {
        x: number;
        y: number;
    };
    14510: {
        x: number;
        y: number;
    };
    14520: {
        x: number;
        y: number;
    };
    14530: {
        x: number;
        y: number;
    };
    14540: {
        x: number;
        y: number;
    };
    14550: {
        x: number;
        y: number;
    };
    14560: {
        x: number;
        y: number;
    };
    14570: {
        x: number;
        y: number;
    };
    14580: {
        x: number;
        y: number;
    };
    14590: {
        x: number;
        y: number;
    };
    14600: {
        x: number;
        y: number;
    };
    14610: {
        x: number;
        y: number;
    };
    14620: {
        x: number;
        y: number;
    };
    14630: {
        x: number;
        y: number;
    };
    14640: {
        x: number;
        y: number;
    };
    14650: {
        x: number;
        y: number;
    };
    14660: {
        x: number;
        y: number;
    };
    14670: {
        x: number;
        y: number;
    };
    14680: {
        x: number;
        y: number;
    };
    14690: {
        x: number;
        y: number;
    };
    14700: {
        x: number;
        y: number;
    };
    14710: {
        x: number;
        y: number;
    };
    14720: {
        x: number;
        y: number;
    };
    14730: {
        x: number;
        y: number;
    };
    14740: {
        x: number;
        y: number;
    };
    14750: {
        x: number;
        y: number;
    };
    14760: {
        x: number;
        y: number;
    };
    14770: {
        x: number;
        y: number;
    };
    14780: {
        x: number;
        y: number;
    };
    14790: {
        x: number;
        y: number;
    };
    14800: {
        x: number;
        y: number;
    };
    14810: {
        x: number;
        y: number;
    };
    14820: {
        x: number;
        y: number;
    };
    14830: {
        x: number;
        y: number;
    };
    14840: {
        x: number;
        y: number;
    };
    14850: {
        x: number;
        y: number;
    };
    14860: {
        x: number;
        y: number;
    };
    14870: {
        x: number;
        y: number;
    };
    14880: {
        x: number;
        y: number;
    };
    14890: {
        x: number;
        y: number;
    };
    14900: {
        x: number;
        y: number;
    };
    14910: {
        x: number;
        y: number;
    };
    14920: {
        x: number;
        y: number;
    };
    14930: {
        x: number;
        y: number;
    };
    14940: {
        x: number;
        y: number;
    };
    14950: {
        x: number;
        y: number;
    };
    14960: {
        x: number;
        y: number;
    };
    14970: {
        x: number;
        y: number;
    };
    14980: {
        x: number;
        y: number;
    };
    14990: {
        x: number;
        y: number;
    };
    15000: {
        x: number;
        y: number;
    };
    15010: {
        x: number;
        y: number;
    };
    15020: {
        x: number;
        y: number;
    };
    15030: {
        x: number;
        y: number;
    };
    15040: {
        x: number;
        y: number;
    };
    15050: {
        x: number;
        y: number;
    };
    15060: {
        x: number;
        y: number;
    };
    15070: {
        x: number;
        y: number;
    };
    15080: {
        x: number;
        y: number;
    };
    15090: {
        x: number;
        y: number;
    };
    15100: {
        x: number;
        y: number;
    };
    15110: {
        x: number;
        y: number;
    };
    15120: {
        x: number;
        y: number;
    };
    15130: {
        x: number;
        y: number;
    };
    15140: {
        x: number;
        y: number;
    };
    15150: {
        x: number;
        y: number;
    };
    15160: {
        x: number;
        y: number;
    };
    15170: {
        x: number;
        y: number;
    };
    15180: {
        x: number;
        y: number;
    };
    15190: {
        x: number;
        y: number;
    };
    15200: {
        x: number;
        y: number;
    };
    15210: {
        x: number;
        y: number;
    };
    15220: {
        x: number;
        y: number;
    };
    15230: {
        x: number;
        y: number;
    };
    15240: {
        x: number;
        y: number;
    };
    15250: {
        x: number;
        y: number;
    };
    15260: {
        x: number;
        y: number;
    };
    15270: {
        x: number;
        y: number;
    };
    15280: {
        x: number;
        y: number;
    };
    15290: {
        x: number;
        y: number;
    };
    15300: {
        x: number;
        y: number;
    };
    15310: {
        x: number;
        y: number;
    };
    15320: {
        x: number;
        y: number;
    };
    15330: {
        x: number;
        y: number;
    };
    15340: {
        x: number;
        y: number;
    };
    15350: {
        x: number;
        y: number;
    };
    15360: {
        x: number;
        y: number;
    };
    15370: {
        x: number;
        y: number;
    };
    15380: {
        x: number;
        y: number;
    };
    15390: {
        x: number;
        y: number;
    };
    15400: {
        x: number;
        y: number;
    };
    15410: {
        x: number;
        y: number;
    };
    15420: {
        x: number;
        y: number;
    };
    15430: {
        x: number;
        y: number;
    };
    15440: {
        x: number;
        y: number;
    };
    15450: {
        x: number;
        y: number;
    };
    15460: {
        x: number;
        y: number;
    };
    15470: {
        x: number;
        y: number;
    };
    15480: {
        x: number;
        y: number;
    };
    15490: {
        x: number;
        y: number;
    };
    15500: {
        x: number;
        y: number;
    };
    15510: {
        x: number;
        y: number;
    };
    15520: {
        x: number;
        y: number;
    };
    15530: {
        x: number;
        y: number;
    };
    15540: {
        x: number;
        y: number;
    };
    15550: {
        x: number;
        y: number;
    };
    15560: {
        x: number;
        y: number;
    };
    15570: {
        x: number;
        y: number;
    };
    15580: {
        x: number;
        y: number;
    };
    15590: {
        x: number;
        y: number;
    };
    15600: {
        x: number;
        y: number;
    };
    15610: {
        x: number;
        y: number;
    };
    15620: {
        x: number;
        y: number;
    };
    15630: {
        x: number;
        y: number;
    };
    15640: {
        x: number;
        y: number;
    };
    15650: {
        x: number;
        y: number;
    };
    15660: {
        x: number;
        y: number;
    };
    15670: {
        x: number;
        y: number;
    };
    15680: {
        x: number;
        y: number;
    };
    15690: {
        x: number;
        y: number;
    };
    15700: {
        x: number;
        y: number;
    };
    15710: {
        x: number;
        y: number;
    };
    15720: {
        x: number;
        y: number;
    };
    15730: {
        x: number;
        y: number;
    };
    15740: {
        x: number;
        y: number;
    };
    15750: {
        x: number;
        y: number;
    };
    15760: {
        x: number;
        y: number;
    };
    15770: {
        x: number;
        y: number;
    };
    15780: {
        x: number;
        y: number;
    };
    15790: {
        x: number;
        y: number;
    };
    15800: {
        x: number;
        y: number;
    };
    15810: {
        x: number;
        y: number;
    };
    15820: {
        x: number;
        y: number;
    };
    15830: {
        x: number;
        y: number;
    };
    15840: {
        x: number;
        y: number;
    };
    15850: {
        x: number;
        y: number;
    };
    15860: {
        x: number;
        y: number;
    };
    15870: {
        x: number;
        y: number;
    };
    15880: {
        x: number;
        y: number;
    };
    15890: {
        x: number;
        y: number;
    };
    15900: {
        x: number;
        y: number;
    };
    15910: {
        x: number;
        y: number;
    };
    15920: {
        x: number;
        y: number;
    };
    15930: {
        x: number;
        y: number;
    };
    15940: {
        x: number;
        y: number;
    };
    15950: {
        x: number;
        y: number;
    };
    15960: {
        x: number;
        y: number;
    };
    15970: {
        x: number;
        y: number;
    };
    15980: {
        x: number;
        y: number;
    };
    15990: {
        x: number;
        y: number;
    };
    16000: {
        x: number;
        y: number;
    };
    16010: {
        x: number;
        y: number;
    };
    16020: {
        x: number;
        y: number;
    };
    16030: {
        x: number;
        y: number;
    };
    16040: {
        x: number;
        y: number;
    };
    16050: {
        x: number;
        y: number;
    };
    16060: {
        x: number;
        y: number;
    };
    16070: {
        x: number;
        y: number;
    };
    16080: {
        x: number;
        y: number;
    };
    16090: {
        x: number;
        y: number;
    };
    16100: {
        x: number;
        y: number;
    };
    16110: {
        x: number;
        y: number;
    };
    16120: {
        x: number;
        y: number;
    };
    16130: {
        x: number;
        y: number;
    };
    16140: {
        x: number;
        y: number;
    };
    16150: {
        x: number;
        y: number;
    };
    16160: {
        x: number;
        y: number;
    };
    16170: {
        x: number;
        y: number;
    };
    16180: {
        x: number;
        y: number;
    };
    16190: {
        x: number;
        y: number;
    };
    16200: {
        x: number;
        y: number;
    };
    16210: {
        x: number;
        y: number;
    };
    16220: {
        x: number;
        y: number;
    };
    16230: {
        x: number;
        y: number;
    };
    16240: {
        x: number;
        y: number;
    };
    16250: {
        x: number;
        y: number;
    };
    16260: {
        x: number;
        y: number;
    };
    16270: {
        x: number;
        y: number;
    };
    16280: {
        x: number;
        y: number;
    };
    16290: {
        x: number;
        y: number;
    };
    16300: {
        x: number;
        y: number;
    };
    16310: {
        x: number;
        y: number;
    };
    16320: {
        x: number;
        y: number;
    };
    16330: {
        x: number;
        y: number;
    };
    16340: {
        x: number;
        y: number;
    };
    16350: {
        x: number;
        y: number;
    };
    16360: {
        x: number;
        y: number;
    };
    16370: {
        x: number;
        y: number;
    };
    16380: {
        x: number;
        y: number;
    };
    16390: {
        x: number;
        y: number;
    };
    16400: {
        x: number;
        y: number;
    };
    16410: {
        x: number;
        y: number;
    };
    16420: {
        x: number;
        y: number;
    };
    16430: {
        x: number;
        y: number;
    };
    16440: {
        x: number;
        y: number;
    };
    16450: {
        x: number;
        y: number;
    };
    16460: {
        x: number;
        y: number;
    };
    16470: {
        x: number;
        y: number;
    };
    16480: {
        x: number;
        y: number;
    };
    16490: {
        x: number;
        y: number;
    };
    16500: {
        x: number;
        y: number;
    };
    16510: {
        x: number;
        y: number;
    };
    16520: {
        x: number;
        y: number;
    };
    16530: {
        x: number;
        y: number;
    };
    16540: {
        x: number;
        y: number;
    };
    16550: {
        x: number;
        y: number;
    };
    16560: {
        x: number;
        y: number;
    };
    16570: {
        x: number;
        y: number;
    };
    16580: {
        x: number;
        y: number;
    };
    16590: {
        x: number;
        y: number;
    };
    16600: {
        x: number;
        y: number;
    };
    16610: {
        x: number;
        y: number;
    };
    16620: {
        x: number;
        y: number;
    };
    16630: {
        x: number;
        y: number;
    };
    16640: {
        x: number;
        y: number;
    };
    16650: {
        x: number;
        y: number;
    };
    16660: {
        x: number;
        y: number;
    };
    16670: {
        x: number;
        y: number;
    };
    16680: {
        x: number;
        y: number;
    };
    16690: {
        x: number;
        y: number;
    };
    16700: {
        x: number;
        y: number;
    };
    16710: {
        x: number;
        y: number;
    };
    16720: {
        x: number;
        y: number;
    };
    16730: {
        x: number;
        y: number;
    };
    16740: {
        x: number;
        y: number;
    };
    16750: {
        x: number;
        y: number;
    };
    16760: {
        x: number;
        y: number;
    };
    16770: {
        x: number;
        y: number;
    };
    16780: {
        x: number;
        y: number;
    };
    16790: {
        x: number;
        y: number;
    };
    16800: {
        x: number;
        y: number;
    };
    16810: {
        x: number;
        y: number;
    };
    16820: {
        x: number;
        y: number;
    };
    16830: {
        x: number;
        y: number;
    };
    16840: {
        x: number;
        y: number;
    };
    16850: {
        x: number;
        y: number;
    };
    16860: {
        x: number;
        y: number;
    };
    16870: {
        x: number;
        y: number;
    };
    16880: {
        x: number;
        y: number;
    };
    16890: {
        x: number;
        y: number;
    };
    16900: {
        x: number;
        y: number;
    };
    16910: {
        x: number;
        y: number;
    };
    16920: {
        x: number;
        y: number;
    };
    16930: {
        x: number;
        y: number;
    };
    16940: {
        x: number;
        y: number;
    };
    16950: {
        x: number;
        y: number;
    };
    16960: {
        x: number;
        y: number;
    };
    16970: {
        x: number;
        y: number;
    };
    16980: {
        x: number;
        y: number;
    };
    16990: {
        x: number;
        y: number;
    };
    17000: {
        x: number;
        y: number;
    };
    17010: {
        x: number;
        y: number;
    };
    17020: {
        x: number;
        y: number;
    };
    17030: {
        x: number;
        y: number;
    };
    17040: {
        x: number;
        y: number;
    };
    17050: {
        x: number;
        y: number;
    };
    17060: {
        x: number;
        y: number;
    };
    17070: {
        x: number;
        y: number;
    };
    17080: {
        x: number;
        y: number;
    };
    17090: {
        x: number;
        y: number;
    };
    17100: {
        x: number;
        y: number;
    };
    17110: {
        x: number;
        y: number;
    };
    17120: {
        x: number;
        y: number;
    };
    17130: {
        x: number;
        y: number;
    };
    17140: {
        x: number;
        y: number;
    };
    17150: {
        x: number;
        y: number;
    };
    17160: {
        x: number;
        y: number;
    };
    17170: {
        x: number;
        y: number;
    };
    17180: {
        x: number;
        y: number;
    };
    17190: {
        x: number;
        y: number;
    };
    17200: {
        x: number;
        y: number;
    };
    17210: {
        x: number;
        y: number;
    };
    17220: {
        x: number;
        y: number;
    };
    17230: {
        x: number;
        y: number;
    };
    17240: {
        x: number;
        y: number;
    };
    17250: {
        x: number;
        y: number;
    };
    17260: {
        x: number;
        y: number;
    };
    17270: {
        x: number;
        y: number;
    };
    17280: {
        x: number;
        y: number;
    };
    17290: {
        x: number;
        y: number;
    };
    17300: {
        x: number;
        y: number;
    };
    17310: {
        x: number;
        y: number;
    };
    17320: {
        x: number;
        y: number;
    };
    17330: {
        x: number;
        y: number;
    };
    17340: {
        x: number;
        y: number;
    };
    17350: {
        x: number;
        y: number;
    };
    17360: {
        x: number;
        y: number;
    };
    17370: {
        x: number;
        y: number;
    };
    17380: {
        x: number;
        y: number;
    };
    17390: {
        x: number;
        y: number;
    };
    17400: {
        x: number;
        y: number;
    };
    17410: {
        x: number;
        y: number;
    };
    17420: {
        x: number;
        y: number;
    };
    17430: {
        x: number;
        y: number;
    };
    17440: {
        x: number;
        y: number;
    };
    17450: {
        x: number;
        y: number;
    };
    17460: {
        x: number;
        y: number;
    };
    17470: {
        x: number;
        y: number;
    };
    17480: {
        x: number;
        y: number;
    };
    17490: {
        x: number;
        y: number;
    };
    17500: {
        x: number;
        y: number;
    };
    17510: {
        x: number;
        y: number;
    };
    17520: {
        x: number;
        y: number;
    };
    17530: {
        x: number;
        y: number;
    };
    17540: {
        x: number;
        y: number;
    };
    17550: {
        x: number;
        y: number;
    };
    17560: {
        x: number;
        y: number;
    };
    17570: {
        x: number;
        y: number;
    };
    17580: {
        x: number;
        y: number;
    };
    17590: {
        x: number;
        y: number;
    };
    17600: {
        x: number;
        y: number;
    };
    17610: {
        x: number;
        y: number;
    };
    17620: {
        x: number;
        y: number;
    };
    17630: {
        x: number;
        y: number;
    };
    17640: {
        x: number;
        y: number;
    };
    17650: {
        x: number;
        y: number;
    };
    17660: {
        x: number;
        y: number;
    };
    17670: {
        x: number;
        y: number;
    };
    17680: {
        x: number;
        y: number;
    };
    17690: {
        x: number;
        y: number;
    };
    17700: {
        x: number;
        y: number;
    };
    17710: {
        x: number;
        y: number;
    };
    17720: {
        x: number;
        y: number;
    };
    17730: {
        x: number;
        y: number;
    };
    17740: {
        x: number;
        y: number;
    };
    17750: {
        x: number;
        y: number;
    };
    17760: {
        x: number;
        y: number;
    };
    17770: {
        x: number;
        y: number;
    };
    17780: {
        x: number;
        y: number;
    };
    17790: {
        x: number;
        y: number;
    };
    17800: {
        x: number;
        y: number;
    };
    17810: {
        x: number;
        y: number;
    };
    17820: {
        x: number;
        y: number;
    };
    17830: {
        x: number;
        y: number;
    };
    17840: {
        x: number;
        y: number;
    };
    17850: {
        x: number;
        y: number;
    };
    17860: {
        x: number;
        y: number;
    };
    17870: {
        x: number;
        y: number;
    };
    17880: {
        x: number;
        y: number;
    };
    17890: {
        x: number;
        y: number;
    };
    17900: {
        x: number;
        y: number;
    };
    17910: {
        x: number;
        y: number;
    };
    17920: {
        x: number;
        y: number;
    };
    17930: {
        x: number;
        y: number;
    };
    17940: {
        x: number;
        y: number;
    };
    17950: {
        x: number;
        y: number;
    };
    17960: {
        x: number;
        y: number;
    };
    17970: {
        x: number;
        y: number;
    };
    17980: {
        x: number;
        y: number;
    };
    17990: {
        x: number;
        y: number;
    };
    18000: {
        x: number;
        y: number;
    };
    18010: {
        x: number;
        y: number;
    };
    18020: {
        x: number;
        y: number;
    };
    18030: {
        x: number;
        y: number;
    };
    18040: {
        x: number;
        y: number;
    };
    18050: {
        x: number;
        y: number;
    };
    18060: {
        x: number;
        y: number;
    };
    18070: {
        x: number;
        y: number;
    };
    18080: {
        x: number;
        y: number;
    };
    18090: {
        x: number;
        y: number;
    };
    18100: {
        x: number;
        y: number;
    };
    18110: {
        x: number;
        y: number;
    };
    18120: {
        x: number;
        y: number;
    };
    18130: {
        x: number;
        y: number;
    };
    18140: {
        x: number;
        y: number;
    };
    18150: {
        x: number;
        y: number;
    };
    18160: {
        x: number;
        y: number;
    };
    18170: {
        x: number;
        y: number;
    };
    18180: {
        x: number;
        y: number;
    };
    18190: {
        x: number;
        y: number;
    };
    18200: {
        x: number;
        y: number;
    };
    18210: {
        x: number;
        y: number;
    };
    18220: {
        x: number;
        y: number;
    };
    18230: {
        x: number;
        y: number;
    };
    18240: {
        x: number;
        y: number;
    };
    18250: {
        x: number;
        y: number;
    };
    18260: {
        x: number;
        y: number;
    };
    18270: {
        x: number;
        y: number;
    };
    18280: {
        x: number;
        y: number;
    };
    18290: {
        x: number;
        y: number;
    };
    18300: {
        x: number;
        y: number;
    };
    18310: {
        x: number;
        y: number;
    };
    18320: {
        x: number;
        y: number;
    };
    18330: {
        x: number;
        y: number;
    };
    18340: {
        x: number;
        y: number;
    };
    18350: {
        x: number;
        y: number;
    };
    18360: {
        x: number;
        y: number;
    };
    18370: {
        x: number;
        y: number;
    };
    18380: {
        x: number;
        y: number;
    };
    18390: {
        x: number;
        y: number;
    };
    18400: {
        x: number;
        y: number;
    };
    18410: {
        x: number;
        y: number;
    };
    18420: {
        x: number;
        y: number;
    };
    18430: {
        x: number;
        y: number;
    };
    18440: {
        x: number;
        y: number;
    };
    18450: {
        x: number;
        y: number;
    };
    18460: {
        x: number;
        y: number;
    };
    18470: {
        x: number;
        y: number;
    };
    18480: {
        x: number;
        y: number;
    };
    18490: {
        x: number;
        y: number;
    };
    18500: {
        x: number;
        y: number;
    };
    18510: {
        x: number;
        y: number;
    };
    18520: {
        x: number;
        y: number;
    };
    18530: {
        x: number;
        y: number;
    };
    18540: {
        x: number;
        y: number;
    };
    18550: {
        x: number;
        y: number;
    };
    18560: {
        x: number;
        y: number;
    };
    18570: {
        x: number;
        y: number;
    };
    18580: {
        x: number;
        y: number;
    };
    18590: {
        x: number;
        y: number;
    };
    18600: {
        x: number;
        y: number;
    };
    18610: {
        x: number;
        y: number;
    };
    18620: {
        x: number;
        y: number;
    };
    18630: {
        x: number;
        y: number;
    };
    18640: {
        x: number;
        y: number;
    };
    18650: {
        x: number;
        y: number;
    };
    18660: {
        x: number;
        y: number;
    };
    18670: {
        x: number;
        y: number;
    };
    18680: {
        x: number;
        y: number;
    };
    18690: {
        x: number;
        y: number;
    };
    18700: {
        x: number;
        y: number;
    };
    18710: {
        x: number;
        y: number;
    };
    18720: {
        x: number;
        y: number;
    };
    18730: {
        x: number;
        y: number;
    };
    18740: {
        x: number;
        y: number;
    };
    18750: {
        x: number;
        y: number;
    };
    18760: {
        x: number;
        y: number;
    };
    18770: {
        x: number;
        y: number;
    };
    18780: {
        x: number;
        y: number;
    };
    18790: {
        x: number;
        y: number;
    };
    18800: {
        x: number;
        y: number;
    };
    18810: {
        x: number;
        y: number;
    };
    18820: {
        x: number;
        y: number;
    };
    18830: {
        x: number;
        y: number;
    };
    18840: {
        x: number;
        y: number;
    };
    18850: {
        x: number;
        y: number;
    };
    18860: {
        x: number;
        y: number;
    };
    18870: {
        x: number;
        y: number;
    };
    18880: {
        x: number;
        y: number;
    };
    18890: {
        x: number;
        y: number;
    };
    18900: {
        x: number;
        y: number;
    };
    18910: {
        x: number;
        y: number;
    };
    18920: {
        x: number;
        y: number;
    };
    18930: {
        x: number;
        y: number;
    };
    18940: {
        x: number;
        y: number;
    };
    18950: {
        x: number;
        y: number;
    };
    18960: {
        x: number;
        y: number;
    };
    18970: {
        x: number;
        y: number;
    };
    18980: {
        x: number;
        y: number;
    };
    18990: {
        x: number;
        y: number;
    };
    19000: {
        x: number;
        y: number;
    };
    19010: {
        x: number;
        y: number;
    };
    19020: {
        x: number;
        y: number;
    };
    19030: {
        x: number;
        y: number;
    };
    19040: {
        x: number;
        y: number;
    };
    19050: {
        x: number;
        y: number;
    };
    19060: {
        x: number;
        y: number;
    };
    19070: {
        x: number;
        y: number;
    };
    19080: {
        x: number;
        y: number;
    };
    19090: {
        x: number;
        y: number;
    };
    19100: {
        x: number;
        y: number;
    };
    19110: {
        x: number;
        y: number;
    };
    19120: {
        x: number;
        y: number;
    };
    19130: {
        x: number;
        y: number;
    };
    19140: {
        x: number;
        y: number;
    };
    19150: {
        x: number;
        y: number;
    };
    19160: {
        x: number;
        y: number;
    };
    19170: {
        x: number;
        y: number;
    };
    19180: {
        x: number;
        y: number;
    };
    19190: {
        x: number;
        y: number;
    };
    19200: {
        x: number;
        y: number;
    };
    19210: {
        x: number;
        y: number;
    };
    19220: {
        x: number;
        y: number;
    };
    19230: {
        x: number;
        y: number;
    };
    19240: {
        x: number;
        y: number;
    };
    19250: {
        x: number;
        y: number;
    };
    19260: {
        x: number;
        y: number;
    };
    19270: {
        x: number;
        y: number;
    };
    19280: {
        x: number;
        y: number;
    };
    19290: {
        x: number;
        y: number;
    };
    19300: {
        x: number;
        y: number;
    };
    19310: {
        x: number;
        y: number;
    };
    19320: {
        x: number;
        y: number;
    };
    19330: {
        x: number;
        y: number;
    };
    19340: {
        x: number;
        y: number;
    };
    19350: {
        x: number;
        y: number;
    };
    19360: {
        x: number;
        y: number;
    };
    19370: {
        x: number;
        y: number;
    };
    19380: {
        x: number;
        y: number;
    };
    19390: {
        x: number;
        y: number;
    };
    19400: {
        x: number;
        y: number;
    };
    19410: {
        x: number;
        y: number;
    };
    19420: {
        x: number;
        y: number;
    };
    19430: {
        x: number;
        y: number;
    };
    19440: {
        x: number;
        y: number;
    };
    19450: {
        x: number;
        y: number;
    };
    19460: {
        x: number;
        y: number;
    };
    19470: {
        x: number;
        y: number;
    };
    19480: {
        x: number;
        y: number;
    };
    19490: {
        x: number;
        y: number;
    };
    19500: {
        x: number;
        y: number;
    };
    19510: {
        x: number;
        y: number;
    };
    19520: {
        x: number;
        y: number;
    };
    19530: {
        x: number;
        y: number;
    };
    19540: {
        x: number;
        y: number;
    };
    19550: {
        x: number;
        y: number;
    };
    19560: {
        x: number;
        y: number;
    };
    19570: {
        x: number;
        y: number;
    };
    19580: {
        x: number;
        y: number;
    };
    19590: {
        x: number;
        y: number;
    };
    19600: {
        x: number;
        y: number;
    };
    19610: {
        x: number;
        y: number;
    };
    19620: {
        x: number;
        y: number;
    };
    19630: {
        x: number;
        y: number;
    };
    19640: {
        x: number;
        y: number;
    };
    19650: {
        x: number;
        y: number;
    };
    19660: {
        x: number;
        y: number;
    };
    19670: {
        x: number;
        y: number;
    };
    19680: {
        x: number;
        y: number;
    };
    19690: {
        x: number;
        y: number;
    };
    19700: {
        x: number;
        y: number;
    };
    19710: {
        x: number;
        y: number;
    };
    19720: {
        x: number;
        y: number;
    };
    19730: {
        x: number;
        y: number;
    };
    19740: {
        x: number;
        y: number;
    };
    19750: {
        x: number;
        y: number;
    };
    19760: {
        x: number;
        y: number;
    };
    19770: {
        x: number;
        y: number;
    };
    19780: {
        x: number;
        y: number;
    };
    19790: {
        x: number;
        y: number;
    };
    19800: {
        x: number;
        y: number;
    };
    19810: {
        x: number;
        y: number;
    };
    19820: {
        x: number;
        y: number;
    };
    19830: {
        x: number;
        y: number;
    };
    19840: {
        x: number;
        y: number;
    };
    19850: {
        x: number;
        y: number;
    };
    19860: {
        x: number;
        y: number;
    };
    19870: {
        x: number;
        y: number;
    };
    19880: {
        x: number;
        y: number;
    };
    19890: {
        x: number;
        y: number;
    };
    19900: {
        x: number;
        y: number;
    };
    19910: {
        x: number;
        y: number;
    };
    19920: {
        x: number;
        y: number;
    };
    19930: {
        x: number;
        y: number;
    };
    19940: {
        x: number;
        y: number;
    };
    19950: {
        x: number;
        y: number;
    };
    19960: {
        x: number;
        y: number;
    };
    19970: {
        x: number;
        y: number;
    };
    19980: {
        x: number;
        y: number;
    };
    19990: {
        x: number;
        y: number;
    };
    20000: {
        x: number;
        y: number;
    };
};
//# sourceMappingURL=kelvinToXy.d.ts.map