export declare const Endpoints: {
    endpoint: number;
    appprofid: number;
    appdeviceid: number;
    appdevver: number;
    appnuminclusters: number;
    appinclusterlist: number[];
    appnumoutclusters: number;
    appoutclusterlist: number[];
    latencyreq: number;
}[];
//# sourceMappingURL=endpoints.d.ts.map