declare const _exports: {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    exposes: any[];
    toZigbee: ({
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
            state: {
                power_on_behavior: any;
            };
        }>;
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    } | {
        key: string[];
        convertGet: (entity: any, key: any, meta: any) => Promise<{
            state: any;
        }>;
        convertSet: any;
    } | {
        key: string[];
        convertSet: (entity: any, key: any, values: any, meta: any) => Promise<{
            state: {
                [x: number]: any;
            };
        }>;
    } | {
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
            state: {
                state: any;
            };
        } | {
            state?: undefined;
        } | {
            state: {
                state: string;
                brightness?: undefined;
            };
            readAfterWriteTime: number;
        } | {
            state: {
                state: string;
                brightness: number;
            };
            readAfterWriteTime: number;
        }>;
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    })[];
    fromZigbee: {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => any;
    }[];
    ota: typeof import("../lib/ota/inovelli");
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
}[];
export = _exports;
//# sourceMappingURL=inovelli.d.ts.map