/**
 * Interface implementation
 */
export function isUpdateAvailable(device: any, logger: any, requestPayload?: any): Promise<any>;
export function updateToLatest(device: any, logger: any, onProgress: any): Promise<any>;
//# sourceMappingURL=ledvance.d.ts.map