"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function assertString(input) {
    if (typeof input !== 'string') {
        throw new Error('Input must be a string!');
    }
}
exports.default = assertString;
//# sourceMappingURL=assertString.js.map