"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StructuredIndicatorType = void 0;
var StructuredIndicatorType;
(function (StructuredIndicatorType) {
    StructuredIndicatorType[StructuredIndicatorType["WriteWhole"] = 0] = "WriteWhole";
    StructuredIndicatorType[StructuredIndicatorType["Add"] = 16] = "Add";
    StructuredIndicatorType[StructuredIndicatorType["Remove"] = 32] = "Remove";
})(StructuredIndicatorType || (StructuredIndicatorType = {}));
exports.StructuredIndicatorType = StructuredIndicatorType;
//# sourceMappingURL=tstype.js.map