declare const _exports: {
    fingerprint: {
        modelID: string;
        manufacturerName: string;
    }[];
    model: string;
    vendor: string;
    description: string;
    whiteLabel: {
        vendor: string;
        model: string;
    }[];
    fromZigbee: ({
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => any;
    } | FromZigbeeConverter)[];
    toZigbee: ToZigbeeConverter[];
    onEvent: (type: any, data: any, device: any) => Promise<void>;
    meta: {
        thermostat: {
            weeklyScheduleMaxTransitions: number;
            weeklyScheduleSupportedModes: number[];
            weeklyScheduleConversion: string;
        };
    };
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
    exposes: any[];
}[];
export = _exports;
//# sourceMappingURL=saswell.d.ts.map