/// <reference types="node" />
import { Struct } from "../struct";
/**
 * Creates a channel list struct.
 *
 * @param data Data to initialize structure with.
 */
export declare const channelList: (data?: Buffer) => import("../struct").BuiltStruct<Struct & Record<"channelList", number>>;
//# sourceMappingURL=channel-list.d.ts.map