declare const _exports: ({
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    extend: any;
    ota: typeof import("../lib/ota/ledvance");
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    extend: any;
    ota: typeof import("../lib/ota/ledvance");
    exposes: (exposes.Enum | exposes.Light)[];
} | {
    zigbeeModel: string[];
    model: string;
    description: string;
    vendor: string;
    extend: {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
    whiteLabel: {
        vendor: string;
        model: string;
    }[];
    ota: typeof import("../lib/ota/ledvance");
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    extend: any;
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    extend: any;
    meta: {
        disableDefaultResponse: boolean;
    };
    ota: typeof import("../lib/ota/ledvance");
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string;
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            occupancy: boolean;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => any;
    })[];
    toZigbee: undefined[];
    meta: {
        battery: {
            voltageToPercentage: {
                min: number;
                max: number;
            };
        };
    };
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
    exposes: (exposes.Numeric | exposes.Binary)[];
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            battery: any;
            voltage: number;
            battery_low: boolean;
        };
    } | FromZigbeeConverter)[];
    exposes: (exposes.Numeric | exposes.Enum)[];
    toZigbee: undefined[];
    meta: {
        battery: {
            voltageToPercentage: string;
        };
    };
    ota: typeof import("../lib/ota/ledvance");
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
} | {
    fingerprint: {
        modelID: string;
        endpoints: {
            ID: number;
        }[];
    }[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: any[];
    extend: any;
    exposes: any[];
    ota: {
        getImageMeta: (current: any, logger: any, device: any) => Promise<{
            fileVersion: any;
            fileSize: any;
            url: any;
            sha512: any;
            force: any;
        }>;
        isUpdateAvailable: (device: any, logger: any, requestPayload?: any) => Promise<any>;
        updateToLatest: (device: any, logger: any, onProgress: any) => Promise<any>;
        useIndexOverride: (indexFileName: any) => void;
        setDataDir: (dir: any) => void;
    };
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
    onEvent: (type: any, data: any, device: any) => Promise<void>;
} | {
    fingerprint: {
        modelID: string;
        endpoints: {
            ID: number;
        }[];
    }[];
    model: string;
    vendor: string;
    description: string;
    extend: any;
    exposes: exposes.Light[];
    ota: {
        getImageMeta: (current: any, logger: any, device: any) => Promise<{
            fileVersion: any;
            fileSize: any;
            url: any;
            sha512: any;
            force: any;
        }>;
        isUpdateAvailable: (device: any, logger: any, requestPayload?: any) => Promise<any>;
        updateToLatest: (device: any, logger: any, onProgress: any) => Promise<any>;
        useIndexOverride: (indexFileName: any) => void;
        setDataDir: (dir: any) => void;
    };
    endpoint: (device: any) => {
        l1: number;
        l2: number;
    };
    meta: {
        multiEndpoint: boolean;
    };
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
} | {
    fingerprint: {
        modelID: string;
        endpoints: {
            ID: number;
        }[];
    }[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: any[];
    extend: any;
    exposes: (exposes.Enum | exposes.Light)[];
    ota: {
        getImageMeta: (current: any, logger: any, device: any) => Promise<{
            fileVersion: any;
            fileSize: any;
            url: any;
            sha512: any;
            force: any;
        }>;
        isUpdateAvailable: (device: any, logger: any, requestPayload?: any) => Promise<any>;
        updateToLatest: (device: any, logger: any, onProgress: any) => Promise<any>;
        useIndexOverride: (indexFileName: any) => void;
        setDataDir: (dir: any) => void;
    };
    endpoint: (device: any) => {
        l1: number;
        l2: number;
        s1: number;
    };
    meta: {
        multiEndpoint: boolean;
    };
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
    onEvent: (type: any, data: any, device: any) => Promise<void>;
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    meta: {
        multiEndpoint: boolean;
    };
    endpoint: (device: any) => {
        l1: number;
        l2: number;
        l3: number;
        l4: number;
    };
    fromZigbee: {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            [x: number]: any;
        };
    }[];
    exposes: exposes.Enum[];
    toZigbee: undefined[];
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
})[];
export = _exports;
import exposes = require("../lib/exposes");
//# sourceMappingURL=osram.d.ts.map