export const upgradeFileIdentifier: Buffer;
export function isUpdateAvailable(device: any, logger: any, isNewImageAvailable: any, requestPayload: any, getImageMeta?: any): Promise<any>;
export function parseImage(buffer: any): {
    header: {
        otaUpgradeFileIdentifier: any;
        otaHeaderVersion: any;
        otaHeaderLength: any;
        otaHeaderFieldControl: any;
        manufacturerCode: any;
        imageType: any;
        fileVersion: any;
        zigbeeStackVersion: any;
        otaHeaderString: any;
        totalImageSize: any;
    };
    elements: {
        tagID: any;
        length: any;
        data: any;
    }[];
    raw: any;
};
export function validateImageData(image: any): void;
export function isNewImageAvailable(current: any, logger: any, device: any, getImageMeta: any): Promise<{
    available: number;
    currentFileVersion: any;
    otaFileVersion: any;
}>;
export function updateToLatest(device: any, logger: any, onProgress: any, getNewImage: any, getImageMeta?: any, downloadImage?: any): Promise<any>;
export function getNewImage(current: any, logger: any, device: any, getImageMeta: any, downloadImage: any): Promise<{
    header: {
        otaUpgradeFileIdentifier: any;
        otaHeaderVersion: any;
        otaHeaderLength: any;
        otaHeaderFieldControl: any;
        manufacturerCode: any;
        imageType: any;
        fileVersion: any;
        zigbeeStackVersion: any;
        otaHeaderString: any;
        totalImageSize: any;
    };
    elements: {
        tagID: any;
        length: any;
        data: any;
    }[];
    raw: any;
}>;
export function getAxios(): any;
//# sourceMappingURL=common.d.ts.map