declare const _exports: ({
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
    whiteLabel: {
        vendor: string;
        model: string;
    }[];
} | {
    zigbeeModel: string[];
    fingerprint: {
        type: string;
        manufacturerName: string;
        modelID: string;
        powerSource: string;
        endpoints: {
            ID: number;
            profileID: number;
            deviceID: number;
            inputClusters: number[];
            outputClusters: number[];
        }[];
    }[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string;
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            action: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Composite[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            action: any;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            action: string;
        };
    })[];
    toZigbee: undefined[];
    exposes: exposes.Enum[];
} | {
    fingerprint: {
        type: string;
        manufacturerName: string;
        modelID: string;
        endpoints: {
            ID: number;
            profileID: number;
            deviceID: number;
            inputClusters: number[];
            outputClusters: number[];
        }[];
    }[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
} | {
    fingerprint: {
        type: string;
        manufacturerName: string;
        modelID: string;
        endpoints: {
            ID: number;
            profileID: number;
            deviceID: number;
            inputClusters: number[];
            outputClusters: number[];
        }[];
    }[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
    whiteLabel: {
        vendor: string;
        model: string;
    }[];
} | {
    zigbeeModel: string[];
    fingerprint: {
        type: string;
        manufacturerName: string;
        modelID: string;
        endpoints: {
            ID: number;
            profileID: number;
            deviceID: number;
            inputClusters: number[];
            outputClusters: number[];
        }[];
    }[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
    whiteLabel: {
        vendor: string;
        model: string;
    }[];
})[];
export = _exports;
import exposes = require("../lib/exposes");
//# sourceMappingURL=awox.d.ts.map