import { GlobOptions } from 'glob';
import { RimrafAsyncOptions, RimrafSyncOptions } from './index.js';
export declare const optArg: (opt?: RimrafAsyncOptions) => (RimrafAsyncOptions & {
    glob: GlobOptions & {
        withFileTypes: false;
    };
}) | (RimrafAsyncOptions & {
    glob: undefined;
});
export declare const optArgSync: (opt?: RimrafSyncOptions) => (RimrafSyncOptions & {
    glob: GlobOptions & {
        withFileTypes: false;
    };
}) | (RimrafSyncOptions & {
    glob: undefined;
});
//# sourceMappingURL=opt-arg.d.ts.map