"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/* istanbul ignore file */
/* eslint-disable */
class Frame {
    toBuffer() {
        return Buffer.alloc(0);
    }
    static fromBuffer(buffer) {
        return new Frame();
    }
}
exports.default = Frame;
//# sourceMappingURL=frame.js.map