declare const _exports: ({
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
    ota: typeof import("../lib/ota/ledvance");
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    extend: any;
    ota: typeof import("../lib/ota/ledvance");
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    extend: any;
})[];
export = _exports;
//# sourceMappingURL=ledvance.d.ts.map