const extend = require('../lib/extend');
module.exports = [
    {
        zigbeeModel: ['SE-SW'],
        model: 'SEHAZB-DR-SWITCH-2',
        vendor: 'SolarEdge',
        description: 'Smart energy switch',
        extend: extend.switch(),
    },
];
//# sourceMappingURL=solaredge.js.map