declare const _exports: ({
    fingerprint: {
        modelID: string;
        manufacturerName: string;
    }[];
    model: string;
    vendor: string;
    description: string;
    onEvent: (type: any, data: any, device: any) => Promise<void>;
    fromZigbee: ({
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => any;
    } | FromZigbeeConverter)[];
    toZigbee: ToZigbeeConverter[];
    exposes: any[];
} | {
    fingerprint: {
        modelID: string;
        manufacturerName: string;
    }[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: {
        cluster: string;
        type: string;
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            occupancy: boolean;
            tamper: boolean;
            battery_low: boolean;
        };
    }[];
    toZigbee: undefined[];
    exposes: exposes.Binary[];
})[];
export = _exports;
import exposes = require("../lib/exposes");
//# sourceMappingURL=rtx.d.ts.map