declare const _exports: {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string;
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            action: any;
            action_user: any;
            action_source: any;
            action_source_name: any;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            state: string;
            lock_state: string;
            auto_relock_time: any;
            sound_volume: string;
            door_state: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Binary[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            users: {};
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            battery: any;
            voltage: number;
            battery_low: boolean;
        };
    })[];
    toZigbee: ({
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
            readAfterWriteTime: number;
        }>;
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    } | {
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<void>;
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    })[];
    meta: {
        pinCodeCount: number;
    };
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
    onEvent: (type: any, data: any, device: any) => Promise<void>;
    exposes: (exposes.Numeric | exposes.Enum | exposes.Composite | exposes.Lock)[];
}[];
export = _exports;
import exposes = require("../lib/exposes");
//# sourceMappingURL=weiser.d.ts.map