"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Events = void 0;
var Events;
(function (Events) {
    Events["networkAddress"] = "networkAddress";
    Events["deviceJoined"] = "deviceJoined";
    Events["zclData"] = "zclData";
    Events["rawData"] = "rawData";
    Events["disconnected"] = "disconnected";
    Events["deviceAnnounce"] = "deviceAnnounce";
    Events["deviceLeave"] = "deviceLeave";
})(Events || (Events = {}));
exports.Events = Events;
//# sourceMappingURL=events.js.map