declare const _default: {
    Centralite: number;
    Philips: number;
    Sinope: number;
    Stelpro: number;
    Ubisys: number;
    LegrandNetatmo: number;
    SmartThings: number;
    Heiman: number;
    Develco: number;
    SprutDevice: number;
    Bosch: number;
    PANASONIC_RF4CE: number;
    SONY_RF4CE: number;
    SAMSUNG_RF4CE: number;
    PHILIPS_RF4CE: number;
    FREESCALE_RF4CE: number;
    OKI_SEMI_RF4CE: number;
    TI_RF4CE: number;
    /** Cirronet */
    CIRRONET: number;
    /** Chipcon */
    CHIPCON: number;
    /** Ember */
    EMBER: number;
    /** National Tech */
    NTS: number;
    /** Freescale */
    FREESCALE: number;
    /** IPCom */
    IPCOM: number;
    /** San Juan Software */
    SAN_JUAN: number;
    /** TUV */
    TUV: number;
    /** CompXs */
    COMPXS: number;
    /** BM SpA */
    BM: number;
    /** AwarePoint */
    AWAREPOINT: number;
    /** Philips */
    PHILIPS: number;
    /** Luxoft */
    LUXOFT: number;
    /** Korvin */
    KORWIN: number;
    /** One RF */
    _1_RF: number;
    /** Software Technology Group */
    STG: number;
    /** Telegesis */
    TELEGESIS: number;
    /** Visionic */
    VISIONIC: number;
    /** Insta */
    INSTA: number;
    /** Atalum */
    ATALUM: number;
    /** Atmel */
    ATMEL: number;
    /** Develco */
    DEVELCO: number;
    HONEYWELL1: number;
    /** RadioPulse */
    RADIO_PULSE: number;
    /** Renesas */
    RENESAS: number;
    /** Xanadu Wireless */
    XANADU: number;
    /** NEC Engineering */
    NEC: number;
    /** Yamatake */
    YAMATAKE: number;
    /** Tendril */
    TENDRIL: number;
    /** Assa Abloy */
    ASSA: number;
    /** Maxstream */
    MAXSTREAM: number;
    /** Neurocom */
    NEUROCOM: number;
    /** Institute for Information Industry */
    III: number;
    /** Vantage Controls */
    VANTAGE: number;
    /** iControl */
    ICONTROL: number;
    /** Raymarine */
    RAYMARINE: number;
    /** LS Research */
    LSR: number;
    /** Onity */
    ONITY: number;
    /** Mono Products */
    MONO: number;
    /** RF Tech */
    RFT: number;
    /** Itron */
    ITRON: number;
    /** Tritech */
    TRITECH: number;
    /** Embedit */
    EMBEDIT: number;
    /** S3C */
    S3C: number;
    /** Siemens */
    SIEMENS: number;
    /** Mindtech */
    MINDTECH: number;
    /** LG Electronics */
    LGE: number;
    /** Mitsubishi */
    MITSUBISHI: number;
    /** Johnson Controls */
    JOHNSON: number;
    /** PRI */
    PRI: number;
    /** Knick */
    KNICK: number;
    /** Viconics */
    VICONICS: number;
    /** Flexipanel */
    FLEXIPANEL: number;
    /** Piasim Corporation */
    PIASIM: number;
    /** Trane */
    TRANE: number;
    /** Jennic */
    JENNIC: number;
    /** Living Independently */
    LIG: number;
    /** AlertMe */
    ALERTME: number;
    /** Daintree */
    DAINTREE: number;
    /** Aiji */
    AIJI: number;
    /** Telecom Italia */
    TEL_ITALIA: number;
    /** Mikrokrets */
    MIKROKRETS: number;
    /** Oki Semi */
    OKI_SEMI: number;
    /** Newport Electronics */
    NEWPORT: number;
    /** Control4 */
    C4: number;
    /** STMicro */
    STM: number;
    /** Ad-Sol Nissin */
    ASN: number;
    /** DCSI */
    DCSI: number;
    /** France Telecom */
    FRANCE_TEL: number;
    /** muNet */
    MUNET: number;
    /** Autani */
    AUTANI: number;
    /** Colorado vNet */
    COL_VNET: number;
    /** Aerocomm */
    AEROCOMM: number;
    /** Silicon Labs */
    SI_LABS: number;
    /** Inncom */
    INNCOM: number;
    /** Cannon */
    CANNON: number;
    /** Synapse */
    SYNAPSE: number;
    /** Fisher Pierce/Sunrise */
    FPS: number;
    /** CentraLite */
    CLS: number;
    /** Crane */
    CRANE: number;
    /** Mobilarm */
    MOBILARM: number;
    /** iMonitor */
    IMONITOR: number;
    /** Bartech */
    BARTECH: number;
    /** Meshnetics */
    MESHNETICS: number;
    /** LS Industrial */
    LS_IND: number;
    /** Cason */
    CASON: number;
    /** Wireless Glue */
    WLESS_GLUE: number;
    /** Elster */
    ELSTER: number;
    /** SMS Tec */
    SMS_TEC: number;
    /** Onset Computer */
    ONSET: number;
    /** Riga Development */
    RIGA: number;
    /** Energate */
    ENERGATE: number;
    /** ConMed Linvatec */
    CONMED: number;
    /** PowerMand */
    POWERMAND: number;
    /** Schneider Electric */
    SCHNEIDER: number;
    /** Eaton */
    EATON: number;
    /** Telular */
    TELULAR: number;
    /** Delphi Medical */
    DELPHI: number;
    /** EpiSensor */
    EPISENSOR: number;
    /** Landis+Gyr */
    LANDIS_GYR: number;
    /** Kaba Group */
    KABA: number;
    /** Shure */
    SHURE: number;
    /** Comverge */
    COMVERGE: number;
    /** DBS Lodging */
    DBS_LODGING: number;
    /** Energy Aware */
    ENERGY_AWARE: number;
    /** Hidalgo */
    HIDALGO: number;
    /** Air2App */
    AIR2APP: number;
    /** AMX */
    AMX: number;
    /** EDMI Pty */
    EDMI: number;
    /** Cyan Ltd */
    CYAN: number;
    /** System SPA */
    SYS_SPA: number;
    /** Telit */
    TELIT: number;
    /** Kaga Electronics */
    KAGA: number;
    /** 4-noks s.r.l. */
    _4_NOKS: number;
    /** Certicom */
    CERTICOM: number;
    /** Gridpoint */
    GRIDPOINT: number;
    /** Profile Systems */
    PROFILE_SYS: number;
    /** Compacta International */
    COMPACTA: number;
    /** Freestyle Technology */
    FREESTYLE: number;
    /** Alektrona */
    ALEKTRONA: number;
    /** Computime */
    COMPUTIME: number;
    /** Remote Technologies */
    REMOTE_TECH: number;
    /** Wavecom */
    WAVECOM: number;
    /** Energy Optimizers */
    ENERGY: number;
    /** GE */
    GE: number;
    /** Jetlun */
    JETLUN: number;
    /** Cipher Systems */
    CIPHER: number;
    /** Corporate Systems Eng */
    CORPORATE: number;
    /** ecobee */
    ECOBEE: number;
    /** SMK */
    SMK: number;
    /** Meshworks Wireless */
    MESHWORKS: number;
    /** Ellips B.V. */
    ELLIPS: number;
    /** Secure electrans */
    SECURE: number;
    /** CEDO */
    CEDO: number;
    /** Toshiba */
    TOSHIBA: number;
    /** Digi International */
    DIGI: number;
    /** Ubilogix */
    UBILOGIX: number;
    /** Echelon */
    ECHELON: number;
    /** Green Energy Options */
    GREEN_ENERGY: number;
    /** Silver Spring Networks */
    SILVER_SPRING: number;
    /** Black & Decker */
    BLACK: number;
    /** Aztech AssociatesInc. */
    AZTECH_ASSOC: number;
    /** A&D Co */
    A_AND_D: number;
    /** Rainforest Automation */
    RAINFOREST: number;
    /** Carrier Electronics */
    CARRIER: number;
    /** SyChip/Murata */
    SYCHIP: number;
    /** OpenPeak */
    OPEN_PEAK: number;
    /** Passive Systems */
    PASSIVE: number;
    /** MMBResearch */
    MMB: number;
    /** Leviton */
    LEVITON: number;
    /** Korea Electric Power Data Network */
    KOREA_ELEC: number;
    COMCAST1: number;
    /** NEC Electronics */
    NEC_ELEC: number;
    /** Netvox */
    NETVOX: number;
    /** U-Control */
    UCONTROL: number;
    /** Embedia Technologies */
    EMBEDIA: number;
    /** Sensus */
    SENSUS: number;
    /** SunriseTechnologies */
    SUNRISE: number;
    /** MemtechCorp */
    MEMTECH: number;
    /** Freebox */
    FREEBOX: number;
    /** M2 Labs */
    M2_LABS: number;
    /** BritishGas */
    BRITISH_GAS: number;
    /** Sentec */
    SENTEC: number;
    /** Navetas */
    NAVETAS: number;
    /** Lightspeed Technologies */
    LIGHTSPEED: number;
    /** Oki Electric */
    OKI: number;
    /** Sistemas Inteligentes */
    SISTEMAS: number;
    /** Dometic */
    DOMETIC: number;
    /** Alps */
    APLS: number;
    /** EnergyHub */
    ENERGY_HUB: number;
    /** Kamstrup */
    KAMSTRUP: number;
    /** EchoStar */
    ECHOSTAR: number;
    /** EnerNOC */
    ENERNOC: number;
    /** Eltav */
    ELTAV: number;
    /** Belkin */
    BELKIN: number;
    /** XStreamHD Wireless */
    XSTREAMHD: number;
    /** Saturn South */
    SATURN_SOUTH: number;
    /** GreenTrapOnline */
    GREENTRAP: number;
    /** SmartSynch */
    SMARTSYNCH: number;
    /** Nyce Control */
    NYCE: number;
    /** ICM Controls */
    ICM_CONTROLS: number;
    /** Millennium Electronics */
    MILLENNIUM: number;
    /** Motorola */
    MOTOROLA: number;
    /** EmersonWhite-Rodgers */
    EMERSON: number;
    /** Radio Thermostat */
    RADIO_THERMOSTAT: number;
    /** OMRONCorporation */
    OMRON: number;
    /** GiiNii GlobalLimited */
    GIINII: number;
    /** Fujitsu GeneralLimited */
    FUJITSU: number;
    /** Peel Technologies */
    PEEL: number;
    /** Accent */
    ACCENT: number;
    /** ByteSnap Design */
    BYTESNAP: number;
    /** NEC TOKIN Corporation */
    NEC_TOKIN: number;
    /** G4S JusticeServices */
    G4S_JUSTICE: number;
    /** Trilliant Networks */
    TRILLIANT: number;
    /** Electrolux Italia */
    ELECTROLUX: number;
    /** OnzoLtd */
    ONZO: number;
    /** EnTekSystems */
    ENTEK: number;
    PHILIPS2: number;
    /** MainstreamEngineering */
    MAINSTREAM: number;
    /** IndesitCompany */
    INDESIT: number;
    /** THINKECO */
    THINKECO: number;
    /** 2D2C */
    _2D2C: number;
    /** GreenPeak */
    GREENPEAK: number;
    /** InterCEL */
    INTERCEL: number;
    /** LG Electronics */
    LG: number;
    /** Mitsumi Electric */
    MITSUMI1: number;
    /** Mitsumi Electric */
    MITSUMI2: number;
    /** Zentrum Mikroelektronik Dresden */
    ZENTRUM: number;
    /** Nest Labs */
    NEST: number;
    /** Exegin Technologies */
    EXEGIN: number;
    HONEYWELL2: number;
    /** Takahata Precision */
    TAKAHATA: number;
    /** Sumitomo Electric Networks */
    SUMITOMO: number;
    /** GE Energy */
    GE_ENERGY: number;
    /** GE Appliances */
    GE_APPLIANCES: number;
    /** Radiocrafts AS */
    RADIOCRAFTS: number;
    /** Ceiva */
    CEIVA: number;
    /** TEC CO Co., Ltd */
    TEC_CO: number;
    /** Chameleon Technology (UK) Ltd */
    CHAMELEON: number;
    /** Samsung */
    SAMSUNG: number;
    /** ruwido austria gmbh */
    RUWIDO: number;
    HUAWEI_1: number;
    HUAWEI_2: number;
    /** Greenwave Reality */
    GREENWAVE: number;
    /** BGlobal Metering Ltd */
    BGLOBAL: number;
    /** Mindteck */
    MINDTECK: number;
    /** Ingersoll-Rand */
    INGERSOLL_RAND: number;
    /** Dius Computing Pty Ltd */
    DIUS: number;
    /** Embedded Automation, Inc. */
    EMBEDDED: number;
    /** ABB */
    ABB: number;
    /** Sony */
    SONY: number;
    /** Genus Power Infrastructures Limited */
    GENUS: number;
    UNIVERSAL1: number;
    UNIVERSAL2: number;
    /** Metrum Technologies, LLC */
    METRUM: number;
    /** Cisco */
    CISCO: number;
    /** Ubisys technologies GmbH */
    UBISYS: number;
    /** Consert */
    CONSERT: number;
    /** Crestron Electronics */
    CRESTRON: number;
    /** Enphase Energy */
    ENPHASE: number;
    /** Invensys Controls */
    INVENSYS: number;
    /** Mueller Systems, LLC */
    MUELLER: number;
    /** AAC Technologies Holding */
    AAC_TECH: number;
    /** U-NEXT Co., Ltd */
    U_NEXT: number;
    /** Steelcase Inc. */
    STEELCASE: number;
    /** Telematics Wireless */
    TELEMATICS: number;
    /** Samil Power Co., Ltd */
    SAMIL: number;
    /** Pace Plc */
    PACE: number;
    /** Osborne Coinage Co. */
    OSBORNE: number;
    /** Powerwatch */
    POWERWATCH: number;
    /** CANDELED GmbH */
    CANDELED: number;
    /** FlexGrid S.R.L */
    FLEXGRID: number;
    /** Humax */
    HUMAX: number;
    /** Universal Devices */
    UNIVERSAL: number;
    /** Advanced Energy */
    ADVANCED_ENERGY: number;
    /** BEGA Gantenbrink-Leuchten */
    BEGA: number;
    /** Brunel University */
    BRUNEL: number;
    /** Panasonic R&D Center Singapore */
    PANASONIC: number;
    /** eSystems Research */
    ESYSTEMS: number;
    /** Panamax */
    PANAMAX: number;
    /** Physical Graph Corporation */
    PHYSICAL: number;
    /** EM-Lite Ltd. */
    EM_LITE: number;
    /** Osram Sylvania */
    OSRAM: number;
    /** 2 Save Energy Ltd. */
    _2_SAVE: number;
    /** Planet Innovation Products Pty Ltd */
    PLANET: number;
    /** Ambient Devices, Inc. */
    AMBIENT: number;
    /** Profalux */
    PROFALUX: number;
    /** Billion Electric Company (BEC) */
    BILLION: number;
    /** Embertec Pty Ltd */
    EMBERTEC: number;
    /** IT Watchdogs */
    IT_WATCHDOGS: number;
    /** Reloc */
    RELOC: number;
    /** Intel Corporation */
    INTEL: number;
    /** Trend Electronics Limited */
    TREND: number;
    /** Moxa */
    MOXA: number;
    /** QEES */
    QEES: number;
    /** SAYME Wireless Sensor Networks */
    SAYME: number;
    /** Pentair Aquatic Systems */
    PENTAIR: number;
    /** Orbit Irrigation */
    ORBIT: number;
    /** California Eastern Laboratories */
    CALIFORNIA: number;
    COMCAST2: number;
    /** IDT Technology Limited */
    IDT: number;
    /** Pixela */
    PIXELA: number;
    /** TiVo */
    TIVO: number;
    /** Fidure */
    FIDURE: number;
    /** Marvell Semiconductor */
    MARVELL: number;
    /** Wasion Group */
    WASION: number;
    /** Jasco Products */
    JASCO: number;
    /** Shenzhen Kaifa Technology */
    SHENZHEN: number;
    /** Netcomm Wireless */
    NETCOMM: number;
    /** Define Instruments */
    DEFINE: number;
    /** In Home Displays */
    IN_HOME_DISP: number;
    /** Miele & Cie. KG */
    MIELE: number;
    /** Televes S.A. */
    TELEVES: number;
    /** Labelec */
    LABELEC: number;
    /** China Electronics Standardization Institute */
    CHINA_ELEC: number;
    /** Vectorform */
    VECTORFORM: number;
    /** Busch-Jaeger Elektro */
    BUSCH_JAEGER: number;
    /** Redpine Signals */
    REDPINE: number;
    /** Bridges Electronic Technology */
    BRIDGES: number;
    /** Sercomm */
    SERCOMM: number;
    /** WSH GmbH wirsindheller */
    WSH: number;
    /** Bosch Security Systems */
    BOSCH: number;
    /** eZEX Corporation */
    EZEX: number;
    /** Dresden Elektronik Ingenieurtechnik GmbH */
    DRESDEN: number;
    /** MEAZON S.A. */
    MEAZON: number;
    /** Crow Electronic Engineering */
    CROW: number;
    /** Harvard Engineering */
    HARVARD: number;
    /** Andson(Beijing) Technology */
    ANDSON: number;
    /** Adhoco AG */
    ADHOCO: number;
    /** Waxman Consumer Products Group */
    WAXMAN: number;
    /** Owon Technology */
    OWON: number;
    /** Hitron Technologies */
    HITRON: number;
    /** Scemtec Steuerungstechnik GmbH */
    SCEMTEC: number;
    /** Webee */
    WEBEE: number;
    /** Grid2Home */
    GRID2HOME: number;
    /** Telink Micro */
    TELINK: number;
    /** Jasmine Systems */
    JASMINE: number;
    /** Bidgely */
    BIDGELY: number;
    /** Lutron */
    LUTRON: number;
    /** IJENKO */
    IJENKO: number;
    /** Starfield Electronic */
    STARFIELD: number;
    /** TCP */
    TCP: number;
    /** Rogers Communications Partnership */
    ROGERS: number;
    /** Cree */
    CREE: number;
    /** Robert Bosch LLC */
    ROBERT_BOSCH_LLC: number;
    /** Ibis Networks */
    IBIS: number;
    /** Quirky */
    QUIRKY: number;
    /** Efergy Technologies */
    EFERGY: number;
    /** Smartlabs */
    SMARTLABS: number;
    /** Everspring Industry */
    EVERSPRING: number;
    /** Swann Communications */
    SWANN: number;
    /** Soneter */
    SONETER: number;
    /** Samsung SDS */
    SAMSUNG_SDS: number;
    /** Uniband Electronic Corporation */
    UNIBAND_ELECTRO: number;
    /** Accton Technology Corporation */
    ACCTON_TECHNOLOGY: number;
    /** Bosch Thermotechnik GmbH */
    BOSCH_THERMOTECH: number;
    /** Wincor Nixdorf Inc. */
    WINCOR_NIXDORF: number;
    /** Ohsung Electronics */
    OHSUNG_ELECTRO: number;
    /** Zen Within, Inc. */
    ZEN_WITHIN: number;
    /** Tech4home, Lda. */
    TECH_4_HOME: number;
    /** Nanoleaf */
    NANOLEAF: number;
    /** Keen Home, Inc. */
    KEEN_HOME: number;
    /** Poly-Control APS */
    POLY_CONTROL: number;
    /** Eastfield Lighting Co., Ltd Shenzhen */
    EASTFIELD_LIGHT: number;
    /** IP Datatel, Inc. */
    IP_DATATEL: number;
    /** Lumi United Techology, Ltd Shenzhen */
    LUMI_UNITED_TECH: number;
    /** Sengled Optoelectronics Corp */
    SENGLED_OPTOELEC: number;
    /** Remote Solution Co., Ltd. */
    REMOTE_SOLUTION: number;
    /** ABB Genway Xiamen Electrical Equipment Co., Ltd. */
    ABB_GENWAY_XIAMEN: number;
    /** Zhejiang Rexense Tech */
    ZHEJIANG_REXENSE: number;
    /** ForEE Technology */
    FOREE_TECHNOLOGY: number;
    /** Open Access Technology Intl. */
    OPEN_ACCESS_TECH: number;
    /** INNR Lighting BV */
    INNR_LIGHTNING: number;
    /** Techworld Industries */
    TECHWORLD: number;
    /** Leedarson Lighting Co., Ltd. */
    LEEDARSON_LIGHT: number;
    /** Arzel Zoning */
    ARZEL_ZONING: number;
    /** Holley Technology */
    HOLLEY_TECH: number;
    /** Beldon Technologies */
    BELDON_TECH: number;
    /** Flextronics */
    FLEXTRONICS: number;
    /** Shenzhen Meian */
    SHENZHEN_MEIAN: number;
    /** Lowes */
    LOWES: number;
    /** Sigma Connectivity */
    SIGMA_CONNECT: number;
    /** Wulian */
    WULIAN: number;
    /** Plugwise B.V. */
    PLUGWISE_BV: number;
    /** Titan Products */
    TITAN_PRODUCTS: number;
    /** Ecospectral */
    ECOSPECTRAL: number;
    /** D-Link */
    D_LINK: number;
    /** Technicolor Home USA */
    TECHNICOLOR_HOME: number;
    /** Opple Lighting */
    OPPLE_LIGHTING: number;
    /** Wistron NeWeb Corp. */
    WISTRON_NEWEB: number;
    /** QMotion Shades */
    QMOTION_SHADES: number;
    /** Insta Elektro GmbH */
    INSTA_ELEKTRO: number;
    /** Shanghai Vancount */
    SHANGHAI_VANCOUNT: number;
    /** Ikea of Sweden */
    IKEA_OF_SWEDEN: number;
    /** RT-RK */
    RT_RK: number;
    /** Shenzhen Feibit */
    SHENZHEN_FEIBIT: number;
    /** EuControls */
    EU_CONTROLS: number;
    /** Telkonet */
    TELKONET: number;
    /** Thermal Solution Resources */
    THERMAL_SOLUTION: number;
    /** PomCube */
    POM_CUBE: number;
    /** Ei Electronics */
    EI_ELECTRONICS: number;
    /** Optoga */
    OPTOGA: number;
    /** Stelpro */
    STELPRO: number;
    /** Lynxus Technologies Corp. */
    LYNXUS_TECH: number;
    /** Semiconductor Components */
    SEMICONDUCTOR_COM: number;
    /** TP-Link */
    TP_LINK: number;
    /** LEDVANCE LLC. */
    LEDVANCE_LLC: number;
    /** Nortek */
    NORTEK: number;
    /** iRevo/Assa Abbloy Korea */
    IREVO_ASSA_ABBLOY: number;
    /** Midea */
    MIDEA: number;
    /** ZF Friedrichshafen */
    ZF_FRIEDRICHSHAF: number;
    /** Checkit */
    CHECKIT: number;
    /** Aclara */
    ACLARA: number;
    /** Nokia */
    NOKIA: number;
    /** Goldcard High-tech Co., Ltd. */
    GOLDCARD_HIGHTECH: number;
    /** George Wilson Industries Ltd. */
    GEORGE_WILSON: number;
    /** EASY SAVER CO.,INC */
    EASY_SAVER_CO: number;
    /** ZTE Corporation */
    ZTE_CORPORATION: number;
    /** ARRIS */
    ARRIS: number;
    /** Reliance BIG TV */
    RELIANCE_BIG_TV: number;
    /** Insight Energy Ventures/Powerley */
    INSIGHT_ENERGY: number;
    /** Thomas Research Products (Hubbell Lighting Inc.) */
    THOMAS_RESEARCH: number;
    /** Li Seng Technology */
    LI_SENG_TECH: number;
    /** System Level Solutions Inc. */
    SYSTEM_LEVEL_SOLU: number;
    /** Matrix Labs */
    MATRIX_LABS: number;
    /** Sinope Technologies */
    SINOPE_TECH: number;
    /** Jiuzhou Greeble */
    JIUZHOU_GREEBLE: number;
    /** Guangzhou Lanvee Tech. Co. Ltd. */
    GUANGZHOU_LANVEE: number;
    /** Venstar */
    VENSTAR: number;
    /** SLV */
    SLV: number;
    /** Halo Smart Labs */
    HALO_SMART_LABS: number;
    /** Scout Security Inc. */
    SCOUT_SECURITY: number;
    /** Alibaba China Inc. */
    ALIBABA_CHINA: number;
    /** Resolution Products, Inc. */
    RESOLUTION_PROD: number;
    /** Smartlok Inc. */
    SMARTLOK_INC: number;
    /** Lux Products Corp. */
    LUX_PRODUCTS_CORP: number;
    /** Vimar SpA */
    VIMAR_SPA: number;
    /** Universal Lighting Technologies */
    UNIVERSAL_LIGHT: number;
    /** Robert Bosch, GmbH */
    ROBERT_BOSCH_GMBH: number;
    /** Accenture */
    ACCENTURE: number;
    /** Heiman Technology Co., Ltd. */
    HEIMAN_TECHNOLOGY: number;
    /** Shenzhen HOMA Technology Co., Ltd. */
    SHENZHEN_HOMA: number;
    /** Vision-Electronics Technology */
    VISION_ELECTRO: number;
    /** Lenovo */
    LENOVO: number;
    /** Presciense R&D */
    PRESCIENSE_RD: number;
    /** Shenzhen Seastar Intelligence Co., Ltd. */
    SHENZHEN_SEASTAR: number;
    /** Sensative AB */
    SENSATIVE_AB: number;
    /** SolarEdge */
    SOLAREDGE: number;
    /** Zipato */
    ZIPATO: number;
    /** China Fire & Security Sensing Manufacturing (iHorn) */
    CHINA_FIRE_SEC: number;
    /** Quby BV */
    QUBY_BV: number;
    /** Hangzhou Roombanker Technology Co., Ltd. */
    HANGZHOU_ROOMBANK: number;
    /** Amazon Lab126 */
    AMAZON_LAB126: number;
    /** Paulmann Licht GmbH */
    PAULMANN_LICHT: number;
    /** Shenzhen Orvibo Electronics Co. Ltd. */
    SHENZHEN_ORVIBO: number;
    /** TCI Telecommunications */
    TCI_TELECOMM: number;
    /** Mueller-Licht International Inc. */
    MUELLER_LICHT_INT: number;
    /** Aurora Limited */
    AURORA_LIMITED: number;
    /** SmartDCC */
    SMART_DCC: number;
    /** Shanghai UMEinfo Co. Ltd. */
    SHANGHAI_UMEINFO: number;
    /** carbonTRACK */
    CARBON_TRACK: number;
    /** Somfy */
    SOMFY: number;
    /** Viessmann Elektronik GmbH */
    VIESSMAN_ELEKTRO: number;
    /** Hildebrand Technology Ltd */
    HILDEBRAND_TECH: number;
    /** Onkyo Technology Corporation */
    ONKYO_TECH: number;
    /** Shenzhen Sunricher Technology Ltd. */
    SHENZHEN_SUNRICH: number;
    /** Xiu Xiu Technology Co., Ltd */
    XIU_XIU_TECH: number;
    /** Zumtobel Group */
    ZUMTOBEL_GROUP: number;
    /** Shenzhen Kaadas Intelligent Technology Co. Ltd */
    SHENZHEN_KAADAS: number;
    /** Shanghai Xiaoyan Technology Co. Ltd */
    SHANGHAI_XIAOYAN: number;
    /** Cypress Semiconductor */
    CYPRESS_SEMICOND: number;
    /** XAL GmbH */
    XAL_GMBH: number;
    /** Inergy Systems LLC */
    INERGY_SYSTEMS: number;
    /** Alfred Karcher GmbH & Co KG */
    ALFRED_KARCHER: number;
    /** Adurolight Manufacturing */
    ADUROLIGHT_MANU: number;
    /** Groupe Muller */
    GROUPE_MULLER: number;
    /** V-Mark Enterprises Inc. */
    V_MARK_ENTERPRI: number;
    /** Lead Energy AG */
    LEAD_ENERGY_AG: number;
    /** UIOT Group */
    UIOT_GROUP: number;
    /** Axxess Industries Inc. */
    AXXESS_INDUSTRIES: number;
    /** Third Reality Inc. */
    THIRD_REALITY_INC: number;
    /** DSR Corporation */
    DSR_CORPORATION: number;
    /** Guangzhou Vensi Intelligent Technology Co. Ltd. */
    GUANGZHOU_VENSI: number;
    /** Schlage Lock (Allegion) */
    SCHLAGE_LOCK_ALL: number;
    /** Net2Grid */
    NET2GRID: number;
    /** Airam Electric Oy Ab */
    AIRAM_ELECTRIC: number;
    /** IMMAX WPB CZ */
    IMMAX_WPB_CZ: number;
    /** ZIV Automation */
    ZIV_AUTOMATION: number;
    /** HangZhou iMagicTechnology Co., Ltd */
    HANGZHOU_IMAGIC: number;
    /** Xiamen Leelen Technology Co. Ltd. */
    XIAMEN_LEELEN: number;
    /** Overkiz SAS */
    OVERKIZ_SAS: number;
    /** Flonidan A/S */
    FLONIDAN: number;
    /** HDL Automation Co., Ltd. */
    HDL_AUTOATION: number;
    /** Ardomus Networks Corporation */
    ARDOMUS_NETWORKS: number;
    /** Samjin Co., Ltd. */
    SAMJIN_CO: number;
    /** Sprue Aegis PLC */
    SPRUE_AEGIS_PLC: number;
    /** Indra Sistemas, S.A. */
    INDRA_SISTEMAS: number;
    /** Shenzhen JBT Smart Lighting Co., Ltd. */
    JBT_SMART_LIGHT: number;
    /** GE Lighting & Current */
    GE_LIGHTING_CURRE: number;
    /** Danfoss A/S */
    DANFOSS: number;
    /** NIVISS PHP Sp. z o.o. Sp.k. */
    NIVISS_PHP_SP: number;
    /** Shenzhen Fengliyuan Energy Conservating Technology Co. Ltd */
    FENGLIYUAN_ENERGY: number;
    /** NEXELEC */
    NEXELEC: number;
    /** Sichuan Behome Prominent Technology Co., Ltd */
    SICHUAN_BEHOME_PR: number;
    /** Fujian Star-net Communication Co., Ltd. */
    FUJIAN_STARNET: number;
    /** Toshiba Visual Solutions Corporation */
    TOSHIBA_VISUAL_SO: number;
    /** Latchable, Inc. */
    LATCHABLE_INC: number;
    /** L&S Deutschland GmbH */
    LS_DEUTSCHLAND: number;
    /** Gledopto Co., Ltd. */
    GLEDOPTO_CO_LTD: number;
    /** The Home Depot */
    THE_HOME_DEPOT: number;
    /** Neonlite International Ltd. */
    NEONLITE_INTERNAT: number;
    /** Arlo Technologies, Inc. */
    ARLO_TECHNOLOGIES: number;
    /** Xingluo Technology Co., Ltd. */
    XINGLUO_TECH: number;
    /** Simon Electric (China) Co., Ltd. */
    SIMON_ELECTRIC_CH: number;
    /** Hangzhou Greatstar Industrial Co., Ltd. */
    HANGZHOU_GREATSTA: number;
    /** Sequentric Energy Systems, LLC */
    SEQUENTRIC_ENERGY: number;
    /** Solum Co., Ltd. */
    SOLUM_CO_LTD: number;
    /** Eaglerise Electric & Electronic (China) Co., Ltd. */
    EAGLERISE_ELEC: number;
    /** Fantem Technologies (Shenzhen) Co., Ltd. */
    FANTEM_TECH: number;
    /** Yunding Network Technology (Beijing) Co., Ltd. */
    YUNDING_NETWORK: number;
    /** Atlantic Group */
    ATLANTIC_GROUP: number;
    /** Xiamen Intretech, Inc. */
    XIAMEN_INTRETECH: number;
    /** Tuya Global Inc. */
    TUYA_GLOBAL_INC: number;
    /** Xiamen Dnake Intelligent Technology Co., Ltd */
    XIAMEN_DNAKE_INTE: number;
    /** Niko nv */
    NIKO_NV: number;
    /** Emporia Energy */
    EMPORIA_ENERGY: number;
    /** Sikom AS */
    SIKOM_AS: number;
    /** AXIS Labs, Inc. */
    AXIS_LABS_INC: number;
    /** Current Products Corporation */
    CURRENT_PRODUCTS: number;
    /** MeteRSit SRL */
    METERSIT_SRL: number;
    /** HORNBACH Baumarkt AG */
    HORNBACH_BAUMARKT: number;
    /** DiCEworld s.r.l. a socio unico */
    DICEWORLD_SRL_A: number;
    /** ARC Technology Co., Ltd */
    ARC_TECHNOLOGY: number;
    /** Hangzhou Konke Information Technology Co., Ltd. */
    KONKE_INFORMATION: number;
    /** SALTO Systems S.L. */
    SALTO_SYSTEMS_SL: number;
    /** Shenzhen Shyugj Technology Co., Ltd */
    SHYUGJ_TECHNOLOGY: number;
    /** Brayden Automation Corporation */
    BRAYDEN_AUTOMA: number;
    /** Environexus Pty. Ltd. */
    ENVIRONEXUS_PTY: number;
    /** Eltra nv/sa */
    ELTRA_NV_SA: number;
    /** Xiaomi Communications Co., Ltd. */
    XIAMOMI_COMMUNI: number;
    /** Shanghai Shuncom Electronic Technology Co., Ltd. */
    SHUNCOM_ELECTRON: number;
    /** Voltalis S.A */
    VOLTALIS_SA: number;
    /** FEELUX Co., Ltd. */
    FEELUX_CO_LTD: number;
    /** SmartPlus Inc. */
    SMARTPLUS_INC: number;
    /** Halemeier GmbH */
    HALEMEIER_GMBH: number;
    /** Trust International BBV */
    TRUST_INTL: number;
    /** Duke Energy Business Services LLC */
    DUKE_ENERGY: number;
    /** Calix, Inc. */
    CALIX: number;
    /** ADEO */
    ADEO: number;
    /** ELKO */
    ELKO: number;
    /** Sprut.device */
    SPRUT_DEVICE: number;
};
export default _default;
//# sourceMappingURL=manufacturerCode.d.ts.map