declare const _exports: ({
    zigbeeModel: string[];
    model: string;
    vendor: string;
    whiteLabel: {
        vendor: string;
        model: string;
    }[];
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string[];
        options: (definition: any) => exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            power: any;
            energy: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Binary[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {};
    })[];
    toZigbee: {
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
            state?: undefined;
        } | {
            state: {
                state: any;
            };
        }>;
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    }[];
    exposes: (exposes.Numeric | exposes.Switch)[];
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string;
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            occupancy: boolean;
            tamper: boolean;
            battery_low: boolean;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => any;
    })[];
    toZigbee: undefined[];
    exposes: (exposes.Numeric | exposes.Binary)[];
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string[];
        options: (definition: any) => exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            power: any;
            energy: any;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            energy_l1: number;
            energy_l2: number;
            energy_l3: number;
            reactive_energy_l1: number;
            reactive_energy_l2: number;
            reactive_energy_l3: number;
            power_l1: any;
            power_l2: any;
            power_l3: any;
            reactive_power_l1: any;
            reactive_power_l2: any;
            reactive_power_l3: any;
            voltage_l1: number;
            voltage_l2: number;
            voltage_l3: number;
            current_l1: number;
            current_l2: number;
            current_l3: number;
            frequency: any;
            reactive_energy_sum: any;
        };
    })[];
    toZigbee: undefined[];
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
    meta: {
        publishDuplicateTransaction: boolean;
    };
    exposes: any[];
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {};
    } | FromZigbeeConverter)[];
    toZigbee: {
        key: string[];
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    }[];
    exposes: any[];
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
})[];
export = _exports;
import exposes = require("../lib/exposes");
//# sourceMappingURL=owon.d.ts.map