declare const _exports: ({
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: any[];
    toZigbee: any[];
    exposes: (exposes.Light | exposes.Fan)[];
    meta: {
        disableDefaultResponse: boolean;
    };
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
})[];
export = _exports;
import exposes = require("../lib/exposes");
//# sourceMappingURL=hampton_bay.d.ts.map