declare const _exports: {
    fingerprint: {
        modelID: string;
        manufacturerName: string;
    }[];
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    toZigbee: undefined[];
    fromZigbee: ({
        cluster: string;
        type: string[];
        options: exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            [x: number]: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            humidity: any;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            voltage: any;
            battery: number;
        };
    })[];
    exposes: exposes.Numeric[];
    meta: {
        battery: {
            voltageToPercentage: string;
        };
    };
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
}[];
export = _exports;
import exposes = require("../lib/exposes");
//# sourceMappingURL=plaid.d.ts.map