declare const _exports: {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
}[];
export = _exports;
//# sourceMappingURL=alchemy.d.ts.map