"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Controller = void 0;
const controller_1 = __importDefault(require("./controller"));
exports.Controller = controller_1.default;
//# sourceMappingURL=index.js.map