declare namespace tuyaExposes {
    export function lightType(): any;
    export function lightBrightnessWithMinMax(): exposes.Light;
    export function lightBrightness(): exposes.Light;
    export function countdown(): any;
    export function _switch(): exposes.Switch;
    export { _switch as switch };
    export function selfTest(): any;
    export function selfTestResult(): any;
    export function faultAlarm(): any;
    export function silence(): any;
    export function frostProtection(extraNote?: string): any;
    export function errorStatus(): any;
    export function scheduleAllDays(access: any, format: any): any[];
    export function temperatureUnit(): any;
    export function temperatureCalibration(): any;
    export function humidityCalibration(): any;
    export function gasValue(): any;
    export function energyWithPhase(phase: any): any;
    export function voltageWithPhase(phase: any): any;
    export function powerWithPhase(phase: any): any;
    export function currentWithPhase(phase: any): any;
    export function powerFactorWithPhase(phase: any): any;
    export function switchType(): any;
    export function backlightModeLowMediumHigh(): any;
    export function backlightModeOffNormalInverted(): any;
    export function backlightModeOffOn(): any;
    export function indicatorMode(): any;
    export function indicatorModeNoneRelayPos(): any;
    export function powerOutageMemory(): any;
    export function batteryState(): any;
    export function doNotDisturb(): any;
    export function colorPowerOnBehavior(): any;
}
declare namespace tuyaExtend {
    export function _switch_1(options?: {}): {
        exposes: any;
        fromZigbee: {
            cluster: string;
            type: string[];
            convert: (model: any, msg: any, publish: any, options: any, meta: any) => any;
        }[];
        toZigbee: {
            key: string[];
            convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
                state?: undefined;
            } | {
                state: {
                    state: any;
                };
            }>;
            convertGet: (entity: any, key: any, meta: any) => Promise<void>;
        }[];
    };
    export { _switch_1 as switch };
    export function light_onoff_brightness_colortemp_color(options?: {}): {
        meta: {
            applyRedFix: boolean;
            enhancedHue: boolean;
        };
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
    export function light_onoff_brightness_colortemp(options?: {}): {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
    export function light_onoff_brightness_color(options?: {}): {
        meta: {
            applyRedFix: boolean;
            enhancedHue: boolean;
        };
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
    export function light_onoff_brightness(options?: {}): {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
}
declare namespace tuyaTz {
    namespace power_on_behavior_1 {
        const key: string[];
        function convertSet(entity: any, key: any, value: any, meta: any): Promise<{
            state: {
                [x: number]: any;
            };
        }>;
        function convertGet(entity: any, key: any, meta: any): Promise<void>;
    }
    namespace power_on_behavior_2 {
        const key_1: string[];
        export { key_1 as key };
        export function convertSet_1(entity: any, key: any, value: any, meta: any): Promise<{
            state: {
                power_on_behavior: any;
            };
        }>;
        export { convertSet_1 as convertSet };
        export function convertGet_1(entity: any, key: any, meta: any): Promise<void>;
        export { convertGet_1 as convertGet };
    }
    namespace switch_type {
        const key_2: string[];
        export { key_2 as key };
        export function convertSet_2(entity: any, key: any, value: any, meta: any): Promise<{
            state: {
                switch_type: any;
            };
        }>;
        export { convertSet_2 as convertSet };
        export function convertGet_2(entity: any, key: any, meta: any): Promise<void>;
        export { convertGet_2 as convertGet };
    }
    namespace backlight_indicator_mode_1 {
        const key_3: string[];
        export { key_3 as key };
        export function convertSet_3(entity: any, key: any, value: any, meta: any): Promise<{
            state: {
                [x: number]: any;
            };
        }>;
        export { convertSet_3 as convertSet };
        export function convertGet_3(entity: any, key: any, meta: any): Promise<void>;
        export { convertGet_3 as convertGet };
    }
    namespace backlight_indicator_mode_2 {
        const key_4: string[];
        export { key_4 as key };
        export function convertSet_4(entity: any, key: any, value: any, meta: any): Promise<{
            state: {
                [x: number]: any;
            };
        }>;
        export { convertSet_4 as convertSet };
        export function convertGet_4(entity: any, key: any, meta: any): Promise<void>;
        export { convertGet_4 as convertGet };
    }
    namespace child_lock {
        const key_5: string[];
        export { key_5 as key };
        export function convertSet_5(entity: any, key: any, value: any, meta: any): Promise<void>;
        export { convertSet_5 as convertSet };
    }
    namespace min_brightness {
        const key_6: string[];
        export { key_6 as key };
        export function convertSet_6(entity: any, key: any, value: any, meta: any): Promise<{
            state: {
                min_brightness: any;
            };
        }>;
        export { convertSet_6 as convertSet };
        export function convertGet_5(entity: any, key: any, meta: any): Promise<void>;
        export { convertGet_5 as convertGet };
    }
    namespace color_power_on_behavior {
        const key_7: string[];
        export { key_7 as key };
        export function convertSet_7(entity: any, key: any, value: any, meta: any): Promise<{
            state: {
                color_power_on_behavior: any;
            };
        }>;
        export { convertSet_7 as convertSet };
    }
    namespace datapoints {
        const key_8: string[];
        export { key_8 as key };
        export function convertSet_8(entity: any, key: any, value: any, meta: any): Promise<{
            state: {};
        }>;
        export { convertSet_8 as convertSet };
    }
    namespace do_not_disturb {
        const key_9: string[];
        export { key_9 as key };
        export function convertSet_9(entity: any, key: any, value: any, meta: any): Promise<{
            state: {
                do_not_disturb: any;
            };
        }>;
        export { convertSet_9 as convertSet };
    }
}
declare namespace tuyaFz {
    export namespace gateway_connection_status {
        const cluster: string;
        const type: string[];
        function convert(model: any, msg: any, publish: any, options: any, meta: any): Promise<void>;
    }
    export namespace power_on_behavior_1_1 {
        const cluster_1: string;
        export { cluster_1 as cluster };
        const type_1: string[];
        export { type_1 as type };
        export function convert_1(model: any, msg: any, publish: any, options: any, meta: any): {
            [x: number]: any;
        };
        export { convert_1 as convert };
    }
    export { power_on_behavior_1_1 as power_on_behavior_1 };
    export namespace power_on_behavior_2_1 {
        const cluster_2: string;
        export { cluster_2 as cluster };
        const type_2: string[];
        export { type_2 as type };
        export function convert_2(model: any, msg: any, publish: any, options: any, meta: any): {
            [x: number]: any;
        };
        export { convert_2 as convert };
    }
    export { power_on_behavior_2_1 as power_on_behavior_2 };
    export namespace power_outage_memory {
        const cluster_3: string;
        export { cluster_3 as cluster };
        const type_3: string[];
        export { type_3 as type };
        export function convert_3(model: any, msg: any, publish: any, options: any, meta: any): {
            [x: number]: any;
        };
        export { convert_3 as convert };
    }
    export namespace switch_type_1 {
        const cluster_4: string;
        export { cluster_4 as cluster };
        const type_4: string[];
        export { type_4 as type };
        export function convert_4(model: any, msg: any, publish: any, options: any, meta: any): {
            switch_type: any;
        };
        export { convert_4 as convert };
    }
    export { switch_type_1 as switch_type };
    export namespace backlight_mode_low_medium_high {
        const cluster_5: string;
        export { cluster_5 as cluster };
        const type_5: string[];
        export { type_5 as type };
        export function convert_5(model: any, msg: any, publish: any, options: any, meta: any): {
            backlight_mode: any;
        };
        export { convert_5 as convert };
    }
    export namespace backlight_mode_off_normal_inverted {
        const cluster_6: string;
        export { cluster_6 as cluster };
        const type_6: string[];
        export { type_6 as type };
        export function convert_6(model: any, msg: any, publish: any, options: any, meta: any): {
            backlight_mode: any;
        };
        export { convert_6 as convert };
    }
    export namespace backlight_mode_off_on {
        const cluster_7: string;
        export { cluster_7 as cluster };
        const type_7: string[];
        export { type_7 as type };
        export function convert_7(model: any, msg: any, publish: any, options: any, meta: any): {
            backlight_mode: any;
        };
        export { convert_7 as convert };
    }
    export namespace indicator_mode {
        const cluster_8: string;
        export { cluster_8 as cluster };
        const type_8: string[];
        export { type_8 as type };
        export function convert_8(model: any, msg: any, publish: any, options: any, meta: any): {
            indicator_mode: any;
        };
        export { convert_8 as convert };
    }
    export namespace child_lock_1 {
        const cluster_9: string;
        export { cluster_9 as cluster };
        const type_9: string[];
        export { type_9 as type };
        export function convert_9(model: any, msg: any, publish: any, options: any, meta: any): {
            child_lock: string;
        };
        export { convert_9 as convert };
    }
    export { child_lock_1 as child_lock };
    export namespace min_brightness_1 {
        const cluster_10: string;
        export { cluster_10 as cluster };
        const type_10: string[];
        export { type_10 as type };
        export function convert_10(model: any, msg: any, publish: any, options: any, meta: any): {
            [x: number]: number;
        };
        export { convert_10 as convert };
    }
    export { min_brightness_1 as min_brightness };
    export namespace datapoints_1 {
        const cluster_11: string;
        export { cluster_11 as cluster };
        const type_11: string[];
        export { type_11 as type };
        export function options(definition: any): exposes.Numeric[];
        export function convert_11(model: any, msg: any, publish: any, options: any, meta: any): {};
        export { convert_11 as convert };
    }
    export { datapoints_1 as datapoints };
}
export namespace skip {
    function stateOnAndBrightnessPresent(meta: any): boolean;
}
export function configureMagicPacket(device: any, coordinatorEndpoint: any, logger: any): Promise<void>;
export function fingerprint(modelID: any, manufacturerNames: any): any;
export function whitelabel(vendor: any, model: any, description: any, manufacturerNames: any): {
    vendor: any;
    model: any;
    description: any;
    fingerprint: any;
};
declare class Enum extends Base {
}
declare class Bitmap extends Base {
}
export namespace valueConverter {
    export namespace trueFalse0 {
        function from(v: any): boolean;
    }
    export namespace trueFalse1 { }
    export namespace trueFalseInvert {
        export function to(v: any): boolean;
        export function from_1(v: any): boolean;
        export { from_1 as from };
    }
    export namespace trueFalseEnum0 { }
    export namespace onOff {
        export function to_1(v: any): any;
        export { to_1 as to };
        export function from_2(v: any): string;
        export { from_2 as from };
    }
    export namespace powerOnBehavior { }
    export namespace lightType_1 { }
    export { lightType_1 as lightType };
    export namespace countdown_1 {
        export function to_2(v: any): any;
        export { to_2 as to };
        export function from_3(v: any): any;
        export { from_3 as from };
    }
    export { countdown_1 as countdown };
    export namespace scale0_254to0_1000 {
        export function to_3(v: any): number;
        export { to_3 as to };
        export function from_4(v: any): number;
        export { from_4 as from };
    }
    export namespace scale0_1to0_1000 { }
    export namespace divideBy100 {
        export function to_4(v: any): number;
        export { to_4 as to };
        export function from_5(v: any): number;
        export { from_5 as from };
    }
    export namespace temperatureUnit_1 { }
    export { temperatureUnit_1 as temperatureUnit };
    export namespace batteryState_1 { }
    export { batteryState_1 as batteryState };
    export namespace divideBy10 { }
    export namespace divideBy1000 { }
    export namespace raw { }
    export namespace setLimit {
        export function to_5(v: any): any;
        export { to_5 as to };
        export function from_6(v: any): any;
        export { from_6 as from };
    }
    export namespace coverPosition {
        export function to_6(v: any, meta: any): Promise<any>;
        export { to_6 as to };
        export function from_7(v: any, meta: any, options: any): any;
        export { from_7 as from };
    }
    export namespace plus1 {
        export function from_8(v: any): any;
        export { from_8 as from };
        export function to_7(v: any): number;
        export { to_7 as to };
    }
    export function _static(value: any): {
        from: (v: any) => any;
    };
    export { _static as static };
    export namespace phaseVariant1 {
        export function from_9(v: any): {
            voltage: number;
            current: number;
        };
        export { from_9 as from };
    }
    export namespace phaseVariant2 {
        export function from_10(v: any): {
            voltage: number;
            current: number;
            power: number;
        };
        export { from_10 as from };
    }
    export function phaseVariant2WithPhase(phase: any): {
        from: (v: any) => {
            [x: string]: number;
        };
    };
    export namespace threshold {
        export function from_11(v: any): {
            threshold_1_protection: any;
            threshold_1: any;
            threshold_1_value: number;
            threshold_2_protection: any;
            threshold_2: any;
            threshold_2_value: number;
        };
        export { from_11 as from };
    }
    export namespace selfTestResult_1 { }
    export { selfTestResult_1 as selfTestResult };
    export namespace lockUnlock { }
    export namespace localTempCalibration1 {
        export function from_12(v: any): number;
        export { from_12 as from };
        export function to_8(v: any): any;
        export { to_8 as to };
    }
    export namespace localTempCalibration2 {
        export function from_13(v: any): any;
        export { from_13 as from };
        export function to_9(v: any): any;
        export { to_9 as to };
    }
    export namespace thermostatHolidayStartStop {
        export function from_14(v: any): string;
        export { from_14 as from };
        export function to_10(v: any): any;
        export { to_10 as to };
    }
    export namespace thermostatScheduleDaySingleDP {
        export function from_15(v: any): string;
        export { from_15 as from };
        export function to_11(v: any, meta: any): any[];
        export { to_11 as to };
    }
    export namespace thermostatScheduleDayMultiDP {
        export function from_16(v: any): string;
        export { from_16 as from };
        export function to_12(v: any): number[];
        export { to_12 as to };
    }
    export function thermostatScheduleDayMultiDPWithDayNumber(dayNum: any): {
        from: (v: any) => string;
        to: (v: any) => number[];
    };
    export namespace TV02SystemMode {
        export function to_13(v: any, meta: any): Promise<void>;
        export { to_13 as to };
        export function from_17(v: any): {
            system_mode: string;
            heating_stop: string;
        };
        export { from_17 as from };
    }
    export namespace TV02FrostProtection {
        export function to_14(v: any, meta: any): Promise<void>;
        export { to_14 as to };
        export function from_18(v: any): {
            frost_protection: string;
        };
        export { from_18 as from };
    }
    export namespace inverse {
        export function to_15(v: any): boolean;
        export { to_15 as to };
        export function from_19(v: any): boolean;
        export { from_19 as from };
    }
    export namespace onOffNotStrict {
        export function from_20(v: any): "ON" | "OFF";
        export { from_20 as from };
        export function to_16(v: any): boolean;
        export { to_16 as to };
    }
    export namespace errorOrBatteryLow {
        export function from_21(v: any): {
            battery_low: boolean;
            error?: undefined;
        } | {
            error: any;
            battery_low?: undefined;
        };
        export { from_21 as from };
    }
}
export namespace valueConverterBasic {
    export function lookup(map: any): {
        to: (v: any) => any;
        from: (v: any) => string;
    };
    export function scale(min1: any, max1: any, min2: any, max2: any): {
        to: (v: any) => number;
        from: (v: any) => number;
    };
    export function raw_1(): {
        to: (v: any) => any;
        from: (v: any) => any;
    };
    export { raw_1 as raw };
    export function divideBy(value: any): {
        to: (v: any) => number;
        from: (v: any) => number;
    };
    export function trueFalse(valueTrue: any): {
        from: (v: any) => boolean;
    };
}
export function sendDataPoint(entity: any, dpValue: any, cmd: any, seq?: any): Promise<any>;
export function sendDataPoints(entity: any, dpValues: any, cmd: any, seq?: any): Promise<any>;
export function sendDataPointValue(entity: any, dp: any, value: any, cmd: any, seq?: any): Promise<any>;
export function sendDataPointBool(entity: any, dp: any, value: any, cmd: any, seq?: any): Promise<any>;
export function sendDataPointEnum(entity: any, dp: any, value: any, cmd: any, seq?: any): Promise<any>;
export function sendDataPointBitmap(entity: any, dp: any, value: any, cmd: any, seq?: any): Promise<any>;
export function sendDataPointRaw(entity: any, dp: any, value: any, cmd: any, seq?: any): Promise<any>;
export function sendDataPointStringBuffer(entity: any, dp: any, value: any, cmd: any, seq?: any): Promise<any>;
export function firstDpValue(msg: any, meta: any, converterName: any): any;
export function getDataValue(dpValue: any): any;
export function getTypeName(dpValue: any): string;
export function getDataPointNames(dpValue: any): string[];
export namespace dataTypes {
    const raw_2: number;
    export { raw_2 as raw };
    export const bool: number;
    export const value: number;
    export const string: number;
    const _enum_1: number;
    export { _enum_1 as enum };
    const bitmap_1: number;
    export { bitmap_1 as bitmap };
}
export namespace dataPoints {
    export const state: number;
    export const heatingSetpoint: number;
    const coverPosition_1: number;
    export { coverPosition_1 as coverPosition };
    export const dimmerLevel: number;
    export const dimmerMinLevel: number;
    export const localTemp: number;
    export const coverArrived: number;
    export const occupancy: number;
    export const mode: number;
    export const fanMode: number;
    export const dimmerMaxLevel: number;
    export const motorDirection: number;
    export const config: number;
    export const childLock: number;
    export const coverChange: number;
    export const runningState: number;
    export const valveDetection: number;
    export const battery: number;
    export const tempCalibration: number;
    export const waterLeak: number;
    export const minTemp: number;
    export const maxTemp: number;
    export const windowDetection: number;
    export const boostTime: number;
    export const coverSpeed: number;
    export const forceMode: number;
    export const comfortTemp: number;
    export const ecoTemp: number;
    export const valvePos: number;
    export const batteryLow: number;
    export const weekFormat: number;
    export const scheduleWorkday: number;
    export const scheduleHoliday: number;
    export const awayTemp: number;
    export const windowOpen: number;
    export const autoLock: number;
    export const awayDays: number;
    export const eardaDimmerLevel: number;
    export const siterwellWindowDetection: number;
    export const moesHold: number;
    export const moesScheduleEnable: number;
    export const moesHeatingSetpoint: number;
    export const moesMaxTempLimit: number;
    export const moesMaxTemp: number;
    export const moesDeadZoneTemp: number;
    export const moesLocalTemp: number;
    export const moesMinTempLimit: number;
    export const moesTempCalibration: number;
    export const moesValve: number;
    export const moesChildLock: number;
    export const moesSensor: number;
    export const moesSchedule: number;
    export const etopErrorStatus: number;
    export const moesSsystemMode: number;
    export const moesSheatingSetpoint: number;
    export const moesSlocalTemp: number;
    export const moesSboostHeating: number;
    export const moesSboostHeatingCountdown: number;
    export const moesSreset: number;
    export const moesSwindowDetectionFunktion_A2: number;
    export const moesSwindowDetection: number;
    export const moesSchildLock: number;
    export const moesSbattery: number;
    export const moesSschedule: number;
    export const moesSvalvePosition: number;
    export const moesSboostHeatingCountdownTimeSet: number;
    export const moesScompensationTempSet: number;
    export const moesSecoMode: number;
    export const moesSecoModeTempSet: number;
    export const moesSmaxTempSet: number;
    export const moesSminTempSet: number;
    export const moesCoverCalibration: number;
    export const moesCoverBacklight: number;
    export const moesCoverMotorReversal: number;
    export const neoOccupancy: number;
    export const neoPowerType: number;
    export const neoMelody: number;
    export const neoDuration: number;
    export const neoTamper: number;
    export const neoAlarm: number;
    export const neoTemp: number;
    export const neoTempScale: number;
    export const neoHumidity: number;
    export const neoMinTemp: number;
    export const neoMaxTemp: number;
    export const neoMinHumidity: number;
    export const neoMaxHumidity: number;
    export const neoUnknown2: number;
    export const neoTempAlarm: number;
    export const neoTempHumidityAlarm: number;
    export const neoHumidityAlarm: number;
    export const neoUnknown3: number;
    export const neoVolume: number;
    export const neoAOBattPerc: number;
    export const neoAOMelody: number;
    export const neoAODuration: number;
    export const neoAOAlarm: number;
    export const neoAOVolume: number;
    export const saswellHeating: number;
    export const saswellWindowDetection: number;
    export const saswellFrostDetection: number;
    export const saswellTempCalibration: number;
    export const saswellChildLock: number;
    export const saswellState: number;
    export const saswellLocalTemp: number;
    export const saswellHeatingSetpoint: number;
    export const saswellValvePos: number;
    export const saswellBatteryLow: number;
    export const saswellAwayMode: number;
    export const saswellScheduleMode: number;
    export const saswellScheduleEnable: number;
    export const saswellScheduleSet: number;
    export const saswellSetpointHistoryDay: number;
    export const saswellTimeSync: number;
    export const saswellSetpointHistoryWeek: number;
    export const saswellSetpointHistoryMonth: number;
    export const saswellSetpointHistoryYear: number;
    export const saswellLocalHistoryDay: number;
    export const saswellLocalHistoryWeek: number;
    export const saswellLocalHistoryMonth: number;
    export const saswellLocalHistoryYear: number;
    export const saswellMotorHistoryDay: number;
    export const saswellMotorHistoryWeek: number;
    export const saswellMotorHistoryMonth: number;
    export const saswellMotorHistoryYear: number;
    export const saswellScheduleSunday: number;
    export const saswellScheduleMonday: number;
    export const saswellScheduleTuesday: number;
    export const saswellScheduleWednesday: number;
    export const saswellScheduleThursday: number;
    export const saswellScheduleFriday: number;
    export const saswellScheduleSaturday: number;
    export const saswellAntiScaling: number;
    export const hyHeating: number;
    export const hyExternalTemp: number;
    export const hyAwayDays: number;
    export const hyAwayTemp: number;
    export const hyMaxTempProtection: number;
    export const hyMinTempProtection: number;
    export const hyTempCalibration: number;
    export const hyHysteresis: number;
    export const hyProtectionHysteresis: number;
    export const hyProtectionMaxTemp: number;
    export const hyProtectionMinTemp: number;
    export const hyMaxTemp: number;
    export const hyMinTemp: number;
    export const hySensor: number;
    export const hyPowerOnBehavior: number;
    export const hyWeekFormat: number;
    export const hyWorkdaySchedule1: number;
    export const hyWorkdaySchedule2: number;
    export const hyHolidaySchedule1: number;
    export const hyHolidaySchedule2: number;
    export const hyState: number;
    export const hyHeatingSetpoint: number;
    export const hyLocalTemp: number;
    export const hyMode: number;
    export const hyChildLock: number;
    export const hyAlarm: number;
    export const silvercrestChangeMode: number;
    export const silvercrestSetBrightness: number;
    export const silvercrestSetColorTemp: number;
    export const silvercrestSetColor: number;
    export const silvercrestSetEffect: number;
    export const fantemPowerSupplyMode: number;
    export const fantemReportingTime: number;
    export const fantemExtSwitchType: number;
    export const fantemTempCalibration: number;
    export const fantemHumidityCalibration: number;
    export const fantemLoadDetectionMode: number;
    export const fantemLuxCalibration: number;
    export const fantemExtSwitchStatus: number;
    export const fantemTemp: number;
    export const fantemHumidity: number;
    export const fantemMotionEnable: number;
    export const fantemControlMode: number;
    export const fantemBattery: number;
    export const fantemLedEnable: number;
    export const fantemReportingEnable: number;
    export const fantemLoadType: number;
    export const fantemLoadDimmable: number;
    export const wooxSwitch: number;
    export const wooxBattery: number;
    export const wooxSmokeTest: number;
    export const frankEverTimer: number;
    export const frankEverTreshold: number;
    export const dinrailPowerMeterTotalEnergy: number;
    export const dinrailPowerMeterCurrent: number;
    export const dinrailPowerMeterPower: number;
    export const dinrailPowerMeterVoltage: number;
    export const dinrailPowerMeterTotalEnergy2: number;
    export const dinrailPowerMeterPower2: number;
    export const tuyaSabCO2: number;
    export const tuyaSabTemp: number;
    export const tuyaSabHumidity: number;
    export const tuyaSabVOC: number;
    export const tuyaSabFormaldehyd: number;
    export const tuyaSahkMP25: number;
    export const tuyaSahkCO2: number;
    export const tuyaSahkFormaldehyd: number;
    export const tuyaSabCOalarm: number;
    export const tuyaSabCO: number;
    export const moes105DimmerState1: number;
    export const moes105DimmerLevel1: number;
    export const moes105DimmerState2: number;
    export const moes105DimmerLevel2: number;
    export const trsPresenceState: number;
    export const trsSensitivity: number;
    export const trsMotionState: number;
    export const trsIlluminanceLux: number;
    export const trsDetectionData: number;
    export const trsScene: number;
    export const trsMotionDirection: number;
    export const trsMotionSpeed: number;
    export const trsfPresenceState: number;
    export const trsfSensitivity: number;
    export const trsfMotionState: number;
    export const trsfIlluminanceLux: number;
    export const trsfTumbleSwitch: number;
    export const trsfTumbleAlarmTime: number;
    export const trsfScene: number;
    export const trsfMotionDirection: number;
    export const trsfMotionSpeed: number;
    export const trsfFallDownStatus: number;
    export const trsfStaticDwellAlarm: number;
    export const trsfFallSensitivity: number;
    export const msVSensitivity: number;
    export const msOSensitivity: number;
    export const msVacancyDelay: number;
    export const msMode: number;
    export const msVacantConfirmTime: number;
    export const msReferenceLuminance: number;
    export const msLightOnLuminancePrefer: number;
    export const msLightOffLuminancePrefer: number;
    export const msLuminanceLevel: number;
    export const msLedStatus: number;
    export const tvMode: number;
    export const tvWindowDetection: number;
    export const tvFrostDetection: number;
    export const tvHeatingSetpoint: number;
    export const tvLocalTemp: number;
    export const tvTempCalibration: number;
    export const tvWorkingDay: number;
    export const tvHolidayTemp: number;
    export const tvBattery: number;
    export const tvChildLock: number;
    export const tvErrorStatus: number;
    export const tvHolidayMode: number;
    export const tvBoostTime: number;
    export const tvOpenWindowTemp: number;
    export const tvComfortTemp: number;
    export const tvEcoTemp: number;
    export const tvWeekSchedule: number;
    export const tvHeatingStop: number;
    export const tvMondaySchedule: number;
    export const tvWednesdaySchedule: number;
    export const tvFridaySchedule: number;
    export const tvSundaySchedule: number;
    export const tvTuesdaySchedule: number;
    export const tvThursdaySchedule: number;
    export const tvSaturdaySchedule: number;
    export const tvBoostMode: number;
    export const hochCountdownTimer: number;
    export const hochFaultCode: number;
    export const hochRelayStatus: number;
    export const hochChildLock: number;
    export const hochVoltage: number;
    export const hochCurrent: number;
    export const hochActivePower: number;
    export const hochLeakageCurrent: number;
    export const hochTemperature: number;
    export const hochRemainingEnergy: number;
    export const hochRechargeEnergy: number;
    export const hochCostParameters: number;
    export const hochLeakageParameters: number;
    export const hochVoltageThreshold: number;
    export const hochCurrentThreshold: number;
    export const hochTemperatureThreshold: number;
    export const hochTotalActivePower: number;
    export const hochEquipmentNumberType: number;
    export const hochClearEnergy: number;
    export const hochLocking: number;
    export const hochTotalReverseActivePower: number;
    export const hochHistoricalVoltage: number;
    export const hochHistoricalCurrent: number;
    export const nousTemperature: number;
    export const nousHumidity: number;
    export const nousBattery: number;
    export const nousTempUnitConvert: number;
    export const nousMaxTemp: number;
    export const nousMinTemp: number;
    export const nousMaxHumi: number;
    export const nousMinHumi: number;
    export const nousTempAlarm: number;
    export const nousHumiAlarm: number;
    export const nousHumiSensitivity: number;
    export const nousTempSensitivity: number;
    export const nousTempReportInterval: number;
    export const nousHumiReportInterval: number;
    export const tthTemperature: number;
    export const tthHumidity: number;
    export const tthBatteryLevel: number;
    export const tthBattery: number;
    export const thitBatteryPercentage: number;
    export const thitIlluminanceLux: number;
    export const tIlluminanceLux: number;
    export const thitHumidity: number;
    export const thitTemperature: number;
    export const tuyaVibration: number;
    export const wlsWaterLeak: number;
    export const wlsBatteryPercentage: number;
    export const evanellMode: number;
    export const evanellHeatingSetpoint: number;
    export const evanellLocalTemp: number;
    export const evanellBattery: number;
    export const evanellChildLock: number;
    export const AM02Control: number;
    export const AM02PercentControl: number;
    export const AM02PercentState: number;
    export const AM02Mode: number;
    export const AM02Direction: number;
    export const AM02WorkState: number;
    export const AM02CountdownLeft: number;
    export const AM02TimeTotal: number;
    export const AM02SituationSet: number;
    export const AM02Fault: number;
    export const AM02Border: number;
    export const AM02MotorWorkingMode: number;
    export const AM02AddRemoter: number;
    export const garageDoorTrigger: number;
    export const garageDoorContact: number;
    export const garageDoorStatus: number;
    export const moesSwitchPowerOnBehavior: number;
    export const moesSwitchIndicateLight: number;
    export const x5hState: number;
    export const x5hMode: number;
    export const x5hWorkingStatus: number;
    export const x5hSound: number;
    export const x5hFrostProtection: number;
    export const x5hSetTemp: number;
    export const x5hSetTempCeiling: number;
    export const x5hCurrentTemp: number;
    export const x5hTempCorrection: number;
    export const x5hWeeklyProcedure: number;
    export const x5hWorkingDaySetting: number;
    export const x5hFactoryReset: number;
    export const x5hChildLock: number;
    export const x5hSensorSelection: number;
    export const x5hFaultAlarm: number;
    export const x5hTempDiff: number;
    export const x5hProtectionTempLimit: number;
    export const x5hOutputReverse: number;
    export const x5hBackplaneBrightness: number;
    export const connecteState: number;
    export const connecteMode: number;
    export const connecteHeatingSetpoint: number;
    export const connecteLocalTemp: number;
    export const connecteTempCalibration: number;
    export const connecteChildLock: number;
    export const connecteTempFloor: number;
    export const connecteSensorType: number;
    export const connecteHysteresis: number;
    export const connecteRunningState: number;
    export const connecteTempProgram: number;
    export const connecteOpenWindow: number;
    export const connecteMaxProtectTemp: number;
    export const tshpsPresenceState: number;
    export const tshpscSensitivity: number;
    export const tshpsMinimumRange: number;
    export const tshpsMaximumRange: number;
    export const tshpsTargetDistance: number;
    export const tshpsDetectionDelay: number;
    export const tshpsFadingTime: number;
    export const tshpsIlluminanceLux: number;
    export const tshpsCLI: number;
    export const tshpsSelfTest: number;
    export const lmsState: number;
    export const lmsBattery: number;
    export const lmsSensitivity: number;
    export const lmsKeepTime: number;
    export const lmsIlluminance: number;
    export const alectoSmokeState: number;
    export const alectoSmokeValue: number;
    export const alectoSelfChecking: number;
    export const alectoCheckingResult: number;
    export const alectoSmokeTest: number;
    export const alectoLifecycle: number;
    export const alectoBatteryState: number;
    export const alectoBatteryPercentage: number;
    export const alectoSilence: number;
    export const bacFanMode: number;
    export const HPSZInductionState: number;
    export const HPSZPresenceTime: number;
    export const HPSZLeavingTime: number;
    export const HPSZLEDState: number;
}
export function dpValueFromIntValue(dp: any, value: any): {
    dp: any;
    datatype: number;
    data: number[];
};
export function dpValueFromBool(dp: any, value: any): {
    dp: any;
    datatype: number;
    data: number[];
};
export function dpValueFromEnum(dp: any, value: any): {
    dp: any;
    datatype: number;
    data: any[];
};
export function dpValueFromStringBuffer(dp: any, stringBuffer: any): {
    dp: any;
    datatype: number;
    data: any;
};
export function dpValueFromRaw(dp: any, rawBuffer: any): {
    dp: any;
    datatype: number;
    data: any;
};
export function dpValueFromBitmap(dp: any, bitmapBuffer: any): {
    dp: any;
    datatype: number;
    data: any;
};
export function convertDecimalValueTo4ByteHexArray(value: any): number[];
export function convertDecimalValueTo2ByteHexArray(value: any): number[];
export function onEventSetTime(type: any, data: any, device: any): Promise<void>;
export function onEventSetLocalTime(type: any, data: any, device: any): Promise<void>;
export function onEventMeasurementPoll(type: any, data: any, device: any, options: any, electricalMeasurement?: boolean, metering?: boolean): Promise<void>;
export function convertStringToHexArray(value: any): any[];
export function isCoverInverted(manufacturerName: any): boolean;
export function getCoverStateEnums(manufacturerName: any): any;
export const thermostatSystemModes3: {
    0: string;
    1: string;
    2: string;
};
export const thermostatSystemModes2: {
    0: string;
    1: string;
    2: string;
    3: string;
    4: string;
};
export const thermostatSystemModes: {
    0: string;
    1: string;
    2: string;
    3: string;
    4: string;
    5: string;
    6: string;
};
export const thermostatWeekFormat: {
    0: string;
    1: string;
    2: string;
};
export const thermostatPresets: {
    0: string;
    1: string;
    2: string;
    3: string;
    4: string;
    5: string;
    6: string;
};
export const thermostatScheduleMode: {
    1: string;
    2: string;
    3: string;
    4: string;
};
export const fanModes: {
    0: string;
    1: string;
    2: string;
    3: string;
};
export namespace msLookups {
    const OSensitivity: {
        0: string;
        1: string;
        2: string;
    };
    const VSensitivity: {
        0: string;
        1: string;
        2: string;
    };
    const Mode: {
        0: string;
        1: string;
        2: string;
        3: string;
    };
}
export namespace ZMLookups {
    const AM02Mode_1: {
        0: string;
        1: string;
    };
    export { AM02Mode_1 as AM02Mode };
    const AM02Control_1: {
        0: string;
        1: string;
        2: string;
        3: string;
    };
    export { AM02Control_1 as AM02Control };
    const AM02Direction_1: {
        0: string;
        1: string;
    };
    export { AM02Direction_1 as AM02Direction };
    const AM02WorkState_1: {
        0: string;
        1: string;
    };
    export { AM02WorkState_1 as AM02WorkState };
    const AM02Border_1: {
        0: string;
        1: string;
        2: string;
    };
    export { AM02Border_1 as AM02Border };
    export const AM02Situation: {
        0: string;
        1: string;
    };
    const AM02MotorWorkingMode_1: {
        0: string;
        1: string;
    };
    export { AM02MotorWorkingMode_1 as AM02MotorWorkingMode };
}
export namespace moesSwitch {
    const powerOnBehavior_1: {
        0: string;
        1: string;
        2: string;
    };
    export { powerOnBehavior_1 as powerOnBehavior };
    export const indicateLight: {
        0: string;
        1: string;
        2: string;
        3: string;
    };
}
import exposes = require("./exposes");
declare class Base {
    constructor(value: any);
    value: any;
    valueOf(): any;
}
export declare function _enum(value: any): Enum;
export declare function bitmap(value: any): Bitmap;
import tzDataPoints = tuyaTz.datapoints;
import fzDataPoints = tuyaFz.datapoints;
export { tuyaExposes as exposes, tuyaExtend as extend, tuyaTz as tz, tuyaFz as fz, _enum as enum, tzDataPoints, fzDataPoints };
//# sourceMappingURL=tuya.d.ts.map