const extend = require('../lib/extend');
module.exports = [
    {
        zigbeeModel: ['NIV-ZC-OFD'],
        model: 'PS-ZIGBEE-SMART-CONTROLER-1CH-DIMMABLE',
        vendor: 'Niviss',
        description: 'Zigbee smart controller',
        extend: extend.light_onoff_brightness(),
    },
];
//# sourceMappingURL=niviss.js.map