declare const _exports: ({
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: undefined[];
    toZigbee: undefined[];
    exposes: undefined[];
})[];
export = _exports;
//# sourceMappingURL=slv.d.ts.map