declare const _exports: ({
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            battery: any;
            voltage: number;
            battery_low: boolean;
        };
    } | {
        cluster: string;
        type: string;
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            action: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Composite[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            action: any;
        };
    })[];
    exposes: (exposes.Numeric | exposes.Enum)[];
    toZigbee: undefined[];
    meta: {
        multiEndpoint: boolean;
        battery: {
            dontDividePercentage: boolean;
        };
    };
    endpoint: (device: any) => {
        ep1: number;
        ep2: number;
        ep3: number;
        ep4: number;
    };
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
})[];
export = _exports;
import exposes = require("../lib/exposes");
//# sourceMappingURL=evn.d.ts.map