const extend = require('../lib/extend');
module.exports = [
    {
        zigbeeModel: ['CS-Z-CZ-2402'],
        model: 'CS-Z-CZ-2402',
        vendor: 'DNAKE',
        description: 'Smart socket',
        extend: extend.switch(),
    },
];
//# sourceMappingURL=dnake.js.map