"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GreenPowerEvents = void 0;
;
var GreenPowerEvents;
(function (GreenPowerEvents) {
    GreenPowerEvents["deviceJoined"] = "deviceJoined";
})(GreenPowerEvents || (GreenPowerEvents = {}));
exports.GreenPowerEvents = GreenPowerEvents;
//# sourceMappingURL=tstype.js.map