export declare const FLAG = 126;
export declare const ESCAPE = 125;
export declare const CANCEL = 26;
export declare const XON = 17;
export declare const XOFF = 19;
export declare const SUBSTITUTE = 24;
export declare const STUFF = 32;
export declare const RANDOMIZE_START = 66;
export declare const RANDOMIZE_SEQ = 184;
export declare const RESERVED: number[];
//# sourceMappingURL=consts.d.ts.map