declare function joinPath(file: string): string;
declare function getPath(): string;
declare function testingOnlyReload(): void;
declare const _default: {
    joinPath: typeof joinPath;
    getPath: typeof getPath;
    testingOnlyReload: typeof testingOnlyReload;
};
export default _default;
//# sourceMappingURL=data.d.ts.map