"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const powerSource = {
    0: 'Unknown',
    1: 'Mains (single phase)',
    2: 'Mains (3 phase)',
    3: 'Battery',
    4: 'DC Source',
    5: 'Emergency mains constantly powered',
    6: 'Emergency mains and transfer switch'
};
exports.default = powerSource;
//# sourceMappingURL=powerSource.js.map