declare const _exports: {
    fingerprint: {
        modelID: string;
        manufacturerName: string;
    }[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: FromZigbeeConverter[];
    toZigbee: ToZigbeeConverter[];
    onEvent: (type: any, data: any, device: any) => Promise<void>;
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
    exposes: any[];
}[];
export = _exports;
//# sourceMappingURL=connecte.d.ts.map