declare const _exports: ({
    fingerprint: {
        modelID: string;
        manufacturerName: string;
    }[];
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
    exposes: exposes.Switch[];
    meta: {
        multiEndpoint: boolean;
    };
    endpoint: (device: any) => {
        l1: number;
        l2: number;
        l3: number;
        l4: number;
        l5: number;
    };
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
} | {
    zigbeeModel: string[];
    model: string;
    description: string;
    vendor: string;
    extend: {
        exposes: any;
        fromZigbee: {
            cluster: string;
            type: string[];
            convert: (model: any, msg: any, publish: any, options: any, meta: any) => any;
        }[];
        toZigbee: {
            key: string[];
            convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
                state?: undefined;
            } | {
                state: {
                    state: any;
                };
            }>;
            convertGet: (entity: any, key: any, meta: any) => Promise<void>;
        }[];
    };
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
    exposes: exposes.Switch[];
    endpoint: (device: any) => {
        l1: number;
        l2: number;
    };
    meta: {
        multiEndpoint: boolean;
    };
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
} | {
    fingerprint: {
        modelID: string;
        manufacturerName: string;
    }[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
} | {
    fingerprint: {
        modelID: string;
        manufacturerName: string;
    }[];
    model: string;
    description: string;
    vendor: string;
    extend: {
        exposes: any;
        fromZigbee: {
            cluster: string;
            type: string[];
            convert: (model: any, msg: any, publish: any, options: any, meta: any) => any;
        }[];
        toZigbee: {
            key: string[];
            convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
                state?: undefined;
            } | {
                state: {
                    state: any;
                };
            }>;
            convertGet: (entity: any, key: any, meta: any) => Promise<void>;
        }[];
    };
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
    options: exposes.Numeric[];
    onEvent: (type: any, data: any, device: any, options: any, electricalMeasurement?: boolean, metering?: boolean) => Promise<void>;
} | {
    fingerprint: {
        modelID: string;
        manufacturerName: string;
    }[];
    model: string;
    description: string;
    vendor: string;
    extend: {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
    fromZigbee: {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => any;
    }[];
    toZigbee: ({
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
            state?: undefined;
        } | {
            state: {
                state: any;
            };
        }>;
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    } | {
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
            state: {
                [x: number]: any;
            };
        }>;
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    })[];
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
    options: exposes.Numeric[];
    exposes: any[];
    endpoint: (device: any) => {
        l1: number;
        l2: number;
        l3: number;
    };
    onEvent: (type: any, data: any, device: any, options: any, electricalMeasurement?: boolean, metering?: boolean) => Promise<void>;
})[];
export = _exports;
import exposes = require("../lib/exposes");
//# sourceMappingURL=lellki.d.ts.map