declare class ZclTransactionSequenceNumber {
    private static number;
    static next(): number;
}
export default ZclTransactionSequenceNumber;
//# sourceMappingURL=zclTransactionSequenceNumber.d.ts.map