const tuya = require('../lib/tuya');
module.exports = [
    {
        fingerprint: [{ modelID: 'ZB-CL01', manufacturerName: 'YSRSAI' }],
        zigbeeModel: ['ZB-CL03', 'FB56-ZCW20FB1.2'],
        model: 'YSR-MINI-01_rgbcct',
        vendor: 'YSRSAI',
        description: 'Zigbee LED controller (RGB+CCT)',
        extend: tuya.extend.light_onoff_brightness_colortemp_color({ colorTempRange: [160, 370] }),
    },
    {
        zigbeeModel: ['ZB-CT01'],
        model: 'YSR-MINI-01_wwcw',
        vendor: 'YSRSAI',
        description: 'Zigbee LED controller (WW/CW)',
        extend: tuya.extend.light_onoff_brightness_colortemp_color(),
    },
    {
        zigbeeModel: ['ZB-DL01'],
        model: 'YSR-MINI-01_dimmer',
        vendor: 'YSRSAI',
        description: 'Zigbee LED controller (Dimmer)',
        extend: tuya.extend.light_onoff_brightness(),
    },
];
//# sourceMappingURL=ysrsai.js.map