declare const _exports: {
    fingerprint: {
        modelID: string;
        manufacturerName: string;
    }[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        meta: {
            applyRedFix: boolean;
            enhancedHue: boolean;
        };
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
}[];
export = _exports;
//# sourceMappingURL=ozsmartthings.d.ts.map