declare const AF: {
    interpanCtl: {
        CTL: number;
        SET: number;
        REG: number;
        CHK: number;
    };
    networkLatencyReq: {
        NO_LATENCY_REQS: number;
        FAST_BEACONS: number;
        SLOW_BEACONS: number;
    };
    options: {
        PREPROCESS: number;
        LIMIT_CONCENTRATOR: number;
        ACK_REQUEST: number;
        DISCV_ROUTE: number;
        EN_SECURITY: number;
        SKIP_ROUTING: number;
    };
    DEFAULT_RADIUS: number;
};
export default AF;
//# sourceMappingURL=af.d.ts.map