declare const _exports: ({
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        fromZigbee: ({
            cluster: string;
            type: string;
            convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
                action: any;
                action_user: any;
                action_source: any;
                action_source_name: any;
            };
        } | {
            cluster: string;
            type: string[];
            convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
                state: string;
                lock_state: string;
                auto_relock_time: any;
                sound_volume: string;
                door_state: any;
            };
        } | {
            cluster: string;
            type: string[];
            options: exposes.Binary[];
            convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
                users: {};
            };
        } | {
            cluster: string;
            type: string[];
            convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
                battery: any;
                voltage: number;
                battery_low: boolean;
            };
        })[];
        toZigbee: ({
            key: string[];
            convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
                readAfterWriteTime: number;
            }>;
            convertGet: (entity: any, key: any, meta: any) => Promise<void>;
        } | {
            key: string[];
            convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
                state: {
                    auto_relock_time: any;
                };
            }>;
            convertGet: (entity: any, key: any, meta: any) => Promise<void>;
        } | {
            key: string[];
            convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
                state: {
                    sound_volume: any;
                };
            }>;
            convertGet: (entity: any, key: any, meta: any) => Promise<void>;
        } | {
            key: string[];
            convertSet: (entity: any, key: any, value: any, meta: any) => Promise<void>;
            convertGet: (entity: any, key: any, meta: any) => Promise<void>;
        })[];
        meta: any;
        exposes: (exposes.Numeric | exposes.Binary | exposes.Enum | exposes.Composite | exposes.Lock)[];
        configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
    };
} | {
    fingerprint: {
        type: string;
        manufacturerName: string;
        manufacturerID: number;
        powerSource: string;
        endpoints: {
            ID: number;
            profileID: number;
            deviceID: number;
            inputClusters: number[];
            outputClusters: undefined[];
        }[];
    }[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            state: string;
            lock_state: string;
            auto_relock_time: any;
            sound_volume: string;
            door_state: any;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => Promise<{
            action: string;
        }>;
    })[];
    toZigbee: {
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
            readAfterWriteTime: number;
        }>;
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    }[];
    exposes: (exposes.Enum | exposes.Lock)[];
})[];
export = _exports;
import exposes = require("../lib/exposes");
//# sourceMappingURL=yale.d.ts.map