declare const _exports: {
    fingerprint: {
        modelID: string;
        manufacturerName: string;
    }[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
    fromZigbee: ({
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => any;
    } | {
        cluster: string;
        type: string;
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => any;
    })[];
}[];
export = _exports;
//# sourceMappingURL=sohan_electric.d.ts.map