export function readColorCapabilities(endpoint: any): Promise<void>;
export function readColorTempMinMax(endpoint: any): Promise<void>;
export function readColorAttributes(entity: any, meta: any, additionalAttributes?: any[]): any[];
export function findColorTempRange(entity: any, logger: any): any[];
export function clampColorTemp(colorTemp: any, colorTempMin: any, colorTempMax: any, logger: any): any;
export function configure(device: any, coordinatorEndpoint: any, logger: any, readColorTempMinMaxAttribute: any): Promise<void>;
//# sourceMappingURL=light.d.ts.map