declare const DBG: {
    debugThreshold: {
        CRITICAL: number;
        ERROR: number;
        INFORMATION: number;
        TRACE: number;
    };
    componentId: {
        OSAL: number;
        MTEL: number;
        MTSPCI: number;
        NWK: number;
        NWKIF: number;
        MACCB: number;
        MAC: number;
        APP: number;
        TEST: number;
        RTG: number;
        DATA: number;
    };
};
export default DBG;
//# sourceMappingURL=dbg.d.ts.map