export declare enum ADDRESS_MODE {
    bound = 0,
    group = 1,
    short = 2,
    ieee = 3,
    broadcast = 4,
    no_transmit = 5,
    bound_no_ack = 6,
    short_no_ack = 7,
    ieee_no_ack = 8,
    bound_non_blocking = 9,
    bound_non_blocking_no_ack = 10
}
export declare enum DEVICE_TYPE {
    coordinator = 0,
    router = 1,
    legacy_router = 2
}
export declare enum BOOLEAN {
    false = 0,
    true = 1
}
export declare enum LOG_LEVEL {
    "EMERG" = 0,
    "ALERT" = 1,
    "CRIT " = 2,
    "ERROR" = 3,
    "WARN " = 4,
    "NOT  " = 5,
    "INFO " = 6,
    "DEBUG" = 7
}
export declare enum NODE_LOGICAL_TYPE {
    coordinator = 0,
    router = 1,
    end_device = 2
}
export declare enum STATUS {
    E_SL_MSG_STATUS_SUCCESS = 0,
    E_SL_MSG_STATUS_INCORRECT_PARAMETERS = 1,
    E_SL_MSG_STATUS_UNHANDLED_COMMAND = 2,
    E_SL_MSG_STATUS_BUSY = 3,
    E_SL_MSG_STATUS_STACK_ALREADY_STARTED = 4
}
export declare enum PERMIT_JOIN_STATUS {
    on = 1,
    off = 0
}
export declare enum NETWORK_JOIN_STATUS {
    joined_existing_network = 0,
    formed_new_network = 1,
    failed_128 = 128,
    failed_129 = 129,
    failed_130 = 130,
    failed_131 = 131,
    failed_132 = 132,
    failed_133 = 133,
    failed_134 = 134,
    failed_135 = 135,
    failed_136 = 136,
    failed_137 = 137,
    failed_138 = 138,
    failed_139 = 139,
    failed_140 = 140,
    failed_141 = 141,
    failed_142 = 142,
    failed_143 = 143,
    failed_144 = 144,
    failed_145 = 145,
    failed_146 = 146,
    failed_147 = 147,
    failed_148 = 148,
    failed_149 = 149,
    failed_150 = 150,
    failed_151 = 151,
    failed_152 = 152,
    failed_153 = 153,
    failed_154 = 154,
    failed_155 = 155,
    failed_156 = 156,
    failed_157 = 157,
    failed_158 = 158,
    failed_159 = 159,
    failed_160 = 160,
    failed_161 = 161,
    failed_162 = 162,
    failed_163 = 163,
    failed_164 = 164,
    failed_165 = 165,
    failed_166 = 166,
    failed_167 = 167,
    failed_168 = 168,
    failed_169 = 169,
    failed_170 = 170,
    failed_171 = 171,
    failed_172 = 172,
    failed_173 = 173,
    failed_174 = 174,
    failed_175 = 175,
    failed_176 = 176,
    failed_177 = 177,
    failed_178 = 178,
    failed_179 = 179,
    failed_180 = 180,
    failed_181 = 181,
    failed_182 = 182,
    failed_183 = 183,
    failed_184 = 184,
    failed_185 = 185,
    failed_186 = 186,
    failed_187 = 187,
    failed_188 = 188,
    failed_189 = 189,
    failed_190 = 190,
    failed_191 = 191,
    failed_192 = 192,
    failed_193 = 193,
    failed_194 = 194,
    failed_195 = 195,
    failed_196 = 196,
    failed_197 = 197,
    failed_198 = 198,
    failed_199 = 199,
    failed_200 = 200,
    failed_201 = 201,
    failed_202 = 202,
    failed_203 = 203,
    failed_204 = 204,
    failed_205 = 205,
    failed_206 = 206,
    failed_207 = 207,
    failed_208 = 208,
    failed_209 = 209,
    failed_210 = 210,
    failed_211 = 211,
    failed_212 = 212,
    failed_213 = 213,
    failed_214 = 214,
    failed_215 = 215,
    failed_216 = 216,
    failed_217 = 217,
    failed_218 = 218,
    failed_219 = 219,
    failed_220 = 220,
    failed_221 = 221,
    failed_222 = 222,
    failed_223 = 223,
    failed_224 = 224,
    failed_225 = 225,
    failed_226 = 226,
    failed_227 = 227,
    failed_228 = 228,
    failed_229 = 229,
    failed_230 = 230,
    failed_231 = 231,
    failed_232 = 232,
    failed_233 = 233,
    failed_234 = 234,
    failed_235 = 235,
    failed_236 = 236,
    failed_237 = 237,
    failed_238 = 238,
    failed_239 = 239,
    failed_240 = 240,
    failed_241 = 241,
    failed_242 = 242,
    failed_243 = 243,
    failed_244 = 244
}
export declare enum ON_OFF_STATUS {
    on = 1,
    off = 0
}
export declare enum RESTART_STATUS {
    startup = 0,
    nfn_start = 2,
    running = 6
}
export declare enum ZiGateCommandCode {
    GetNetworkState = 9,
    RawMode = 2,
    SetExtendedPANID = 32,
    SetChannelMask = 33,
    GetVersion = 16,
    Reset = 17,
    ErasePersistentData = 18,
    RemoveDevice = 38,
    PermitJoin = 73,
    RawAPSDataRequest = 1328,
    GetTimeServer = 23,
    SetTimeServer = 22,
    PermitJoinStatus = 20,
    GetDevicesList = 21,
    StartNetwork = 36,
    StartNetworkScan = 37,
    SetCertification = 25,
    Bind = 48,
    UnBind = 49,
    OnOff = 146,
    OnOffTimed = 147,
    ActiveEndpoint = 69,
    AttributeDiscovery = 320,
    AttributeRead = 256,
    AttributeWrite = 272,
    DescriptorComplex = 1329,
    NodeDescriptor = 66,
    PowerDescriptor = 68,
    SimpleDescriptor = 67,
    SetDeviceType = 35,
    IEEEAddress = 65,
    LED = 24,
    SetTXpower = 2054,
    ManagementLeaveRequest = 71,
    ManagementLQI = 78,
    SetSecurityStateKey = 34,
    AddGroup = 96
}
export declare enum ZiGateMessageCode {
    DeviceAnnounce = 77,
    Status = 32768,
    LOG = 32769,
    DataIndication = 32770,
    NodeClusterList = 32771,
    NodeAttributeList = 32772,
    NodeCommandIDList = 32773,
    SimpleDescriptorResponse = 32835,
    NetworkState = 32777,
    VersionList = 32784,
    APSDataACK = 32785,
    APSDataConfirm = 32786,
    APSDataConfirmFailed = 34562,
    NetworkJoined = 32804,
    LeaveIndication = 32840,
    RouterDiscoveryConfirm = 34561,
    PermitJoinStatus = 32788,
    GetTimeServer = 32791,
    ManagementLQIResponse = 32846,
    ManagementLeaveResponse = 32839,
    PDMEvent = 32821,
    PDMLoaded = 770,
    RestartNonFactoryNew = 32774,
    RestartFactoryNew = 32775,
    ExtendedStatusCallBack = 39321,
    AddGroupResponse = 32864
}
export type ZiGateObjectPayload = any;
export declare enum ZPSNwkKeyState {
    ZPS_ZDO_NO_NETWORK_KEY = 0,
    ZPS_ZDO_PRECONFIGURED_LINK_KEY = 1,
    ZPS_ZDO_DISTRIBUTED_LINK_KEY = 2,
    ZPS_ZDO_PRECONFIGURED_INSTALLATION_CODE = 3
}
export declare enum ZPSNwkKeyType {
    ZPS_APS_UNIQUE_LINK_KEY = 0,
    ZPS_APS_GLOBAL_LINK_KEY = 1
}
export declare enum PDMEventType {
    E_PDM_SYSTEM_EVENT_WEAR_COUNT_TRIGGER_VALUE_REACHED = 0,
    E_PDM_SYSTEM_EVENT_DESCRIPTOR_SAVE_FAILED = 1,
    E_PDM_SYSTEM_EVENT_PDM_NOT_ENOUGH_SPACE = 2,
    E_PDM_SYSTEM_EVENT_LARGEST_RECORD_FULL_SAVE_NO_LONGER_POSSIBLE = 3,
    E_PDM_SYSTEM_EVENT_SEGMENT_DATA_CHECKSUM_FAIL = 4,
    E_PDM_SYSTEM_EVENT_SEGMENT_SAVE_OK = 5,
    E_PDM_SYSTEM_EVENT_EEPROM_SEGMENT_HEADER_REPAIRED = 6,
    E_PDM_SYSTEM_EVENT_SYSTEM_INTERNAL_BUFFER_WEAR_COUNT_SWAP = 7,
    E_PDM_SYSTEM_EVENT_SYSTEM_DUPLICATE_FILE_SEGMENT_DETECTED = 8,
    E_PDM_SYSTEM_EVENT_SYSTEM_ERROR = 9,
    E_PDM_SYSTEM_EVENT_SEGMENT_PREWRITE = 10,
    E_PDM_SYSTEM_EVENT_SEGMENT_POSTWRITE = 11,
    E_PDM_SYSTEM_EVENT_SEQUENCE_DUPLICATE_DETECTED = 12,
    E_PDM_SYSTEM_EVENT_SEQUENCE_VERIFY_FAIL = 13,
    E_PDM_SYSTEM_EVENT_PDM_SMART_SAVE = 14,
    E_PDM_SYSTEM_EVENT_PDM_FULL_SAVE = 15
}
declare const coordinatorEndpoints: any;
export { coordinatorEndpoints };
//# sourceMappingURL=constants.d.ts.map