export function payload(attribute: any, min: any, max: any, change: any, overrides: any): {
    attribute: any;
    minimumReportInterval: any;
    maximumReportInterval: any;
    reportableChange: any;
}[];
export function bind(endpoint: any, target: any, clusters: any): Promise<void>;
export function readEletricalMeasurementMultiplierDivisors(endpoint: any, readFrequencyAttrs?: boolean): Promise<void>;
export function readMeteringMultiplierDivisor(endpoint: any): Promise<void>;
export declare function currentPositionLiftPercentage(endpoint: any, overrides: any): Promise<void>;
export declare function currentPositionTiltPercentage(endpoint: any, overrides: any): Promise<void>;
export declare function batteryPercentageRemaining(endpoint: any, overrides: any): Promise<void>;
export declare function batteryVoltage(endpoint: any, overrides: any): Promise<void>;
export declare function batteryAlarmState(endpoint: any, overrides: any): Promise<void>;
export declare function onOff(endpoint: any, overrides: any): Promise<void>;
export declare function lockState(endpoint: any, overrides: any): Promise<void>;
export declare function doorState(endpoint: any, overrides: any): Promise<void>;
export declare function brightness(endpoint: any, overrides: any): Promise<void>;
export declare function colorTemperature(endpoint: any, overrides: any): Promise<void>;
export declare function occupancy(endpoint: any, overrides: any): Promise<void>;
export declare function temperature(endpoint: any, overrides: any): Promise<void>;
export declare function co2(endpoint: any, overrides: any): Promise<void>;
export declare function deviceTemperature(endpoint: any, overrides: any): Promise<void>;
export declare function pressure(endpoint: any, overrides: any): Promise<void>;
export declare function pressureExtended(endpoint: any, overrides: any): Promise<void>;
export declare function illuminance(endpoint: any, overrides: any): Promise<void>;
export declare function instantaneousDemand(endpoint: any, overrides: any): Promise<void>;
export declare function currentSummDelivered(endpoint: any, overrides: any): Promise<void>;
export declare function currentSummReceived(endpoint: any, overrides: any): Promise<void>;
export declare function thermostatSystemMode(endpoint: any, overrides: any): Promise<void>;
export declare function humidity(endpoint: any, overrides: any): Promise<void>;
export declare function thermostatKeypadLockMode(endpoint: any, overrides: any): Promise<void>;
export declare function thermostatTemperature(endpoint: any, overrides: any): Promise<void>;
export declare function thermostatTemperatureCalibration(endpoint: any, overrides: any): Promise<void>;
export declare function thermostatOccupiedHeatingSetpoint(endpoint: any, overrides: any): Promise<void>;
export declare function thermostatUnoccupiedHeatingSetpoint(endpoint: any, overrides: any): Promise<void>;
export declare function thermostatOccupiedCoolingSetpoint(endpoint: any, overrides: any): Promise<void>;
export declare function thermostatUnoccupiedCoolingSetpoint(endpoint: any, overrides: any): Promise<void>;
export declare function thermostatPIHeatingDemand(endpoint: any, overrides: any): Promise<void>;
export declare function thermostatRunningState(endpoint: any, overrides: any): Promise<void>;
export declare function thermostatRunningMode(endpoint: any, overrides: any): Promise<void>;
export declare function thermostatOccupancy(endpoint: any, overrides: any): Promise<void>;
export declare function thermostatTemperatureSetpointHold(endpoint: any, overrides: any): Promise<void>;
export declare function thermostatTemperatureSetpointHoldDuration(endpoint: any, overrides: any): Promise<void>;
export declare function thermostatAcLouverPosition(endpoint: any, overrides: any): Promise<void>;
export declare function presentValue(endpoint: any, overrides: any): Promise<void>;
export declare function activePower(endpoint: any, overrides: any): Promise<void>;
export declare function reactivePower(endpoint: any, overrides: any): Promise<void>;
export declare function apparentPower(endpoint: any, overrides: any): Promise<void>;
export declare function rmsCurrent(endpoint: any, overrides: any): Promise<void>;
export declare function rmsVoltage(endpoint: any, overrides: any): Promise<void>;
export declare function powerFactor(endpoint: any, overrides: any): Promise<void>;
export declare function fanMode(endpoint: any, overrides: any): Promise<void>;
export declare function soil_moisture(endpoint: any, overrides: any): Promise<void>;
export declare function acFrequency(endpoint: any, overrides: any): Promise<void>;
//# sourceMappingURL=reporting.d.ts.map