declare const _exports: {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            linkquality: any;
        };
    }[];
    toZigbee: undefined[];
    exposes: undefined[];
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
}[];
export = _exports;
//# sourceMappingURL=tubeszb.d.ts.map