import debug from 'debug';
declare const Debug: (suffix: string) => {
    log: debug.Debugger;
    error: debug.Debugger;
    info: debug.Debugger;
};
export { Debug };
//# sourceMappingURL=debug.d.ts.map