declare const _exports: ({
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    whiteLabel: {
        vendor: string;
        model: string;
    }[];
    fromZigbee: ({
        cluster: string;
        type: string;
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            action: any;
        };
    } | FromZigbeeConverter)[];
    exposes: exposes.Enum[];
    toZigbee: undefined[];
    ota: {
        getImageMeta: (current: any, logger: any, device: any) => Promise<{
            fileVersion: any;
            fileSize: any;
            url: any;
            sha512: any;
            force: any;
        }>;
        isUpdateAvailable: (device: any, logger: any, requestPayload?: any) => Promise<any>;
        updateToLatest: (device: any, logger: any, onProgress: any) => Promise<any>;
        useIndexOverride: (indexFileName: any) => void;
        setDataDir: (dir: any) => void;
    };
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string;
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            action: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Binary[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {};
    })[];
    toZigbee: ({
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<void>;
    } | {
        key: string[];
        options: exposes.Binary[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
            state: {
                [x: string]: any;
            };
        }>;
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    })[];
    exposes: exposes.Cover[];
    endpoint: (device: any) => {
        default: number;
    };
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
} | {
    fingerprint: {
        manufacturerName: string;
        modelID: string;
        endpoints: ({
            ID: number;
            profileID: number;
            deviceID: number;
            inputClusters: number[];
            outputClusters: number[];
        } | {
            ID: number;
            profileID: number;
            deviceID: number;
        })[];
    }[];
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string[];
        options: exposes.Binary[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {};
    } | {
        cluster: string;
        type: string;
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            action: any;
        };
    })[];
    toZigbee: {
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
            state?: undefined;
        } | {
            state: {
                state: any;
            };
        }>;
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    }[];
    exposes: exposes.Switch[];
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
} | {
    fingerprint: {
        manufacturerName: string;
        modelID: string;
        endpoints: ({
            ID: number;
            profileID: number;
            deviceID: number;
            inputClusters: number[];
            outputClusters: number[];
        } | {
            ID: number;
            profileID: number;
            deviceID: number;
        })[];
    }[];
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string;
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            action: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Composite[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            action: any;
        };
    })[];
    toZigbee: undefined[];
    exposes: exposes.Enum[];
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
    meta: {
        multiEndpoint: boolean;
    };
    endpoint: (device: any) => {
        e1: number;
        e2: number;
        cover: number;
    };
})[];
export = _exports;
import exposes = require("../lib/exposes");
//# sourceMappingURL=insta.d.ts.map