"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var FrameType;
(function (FrameType) {
    FrameType[FrameType["GLOBAL"] = 0] = "GLOBAL";
    FrameType[FrameType["SPECIFIC"] = 1] = "SPECIFIC";
})(FrameType || (FrameType = {}));
exports.default = FrameType;
//# sourceMappingURL=frameType.js.map