import exposes = require("../lib/exposes");
export namespace read {
    const key: string[];
    function convertSet(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            [x: number]: any;
        };
    }>;
}
export namespace write {
    const key_1: string[];
    export { key_1 as key };
    export function convertSet_1(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_1 as convertSet };
}
export namespace command {
    const key_2: string[];
    export { key_2 as key };
    export function convertSet_2(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_2 as convertSet };
}
export namespace factory_reset {
    const key_3: string[];
    export { key_3 as key };
    export function convertSet_3(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_3 as convertSet };
}
export namespace identify {
    const key_4: string[];
    export { key_4 as key };
    export function convertSet_4(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_4 as convertSet };
}
export namespace arm_mode {
    const key_5: string[];
    export { key_5 as key };
    export function convertSet_5(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_5 as convertSet };
}
export namespace battery_percentage_remaining {
    const key_6: string[];
    export { key_6 as key };
    export function convertGet(entity: any, key: any, meta: any): Promise<void>;
}
export namespace battery_voltage {
    const key_7: string[];
    export { key_7 as key };
    export function convertGet_1(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_1 as convertGet };
}
export namespace power_on_behavior {
    const key_8: string[];
    export { key_8 as key };
    export function convertSet_6(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            power_on_behavior: any;
        };
    }>;
    export { convertSet_6 as convertSet };
    export function convertGet_2(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_2 as convertGet };
}
export namespace light_color_mode {
    const key_9: string[];
    export { key_9 as key };
    export function convertGet_3(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_3 as convertGet };
}
export namespace light_color_options {
    const key_10: string[];
    export { key_10 as key };
    export function convertSet_7(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            color_options: any;
        };
    }>;
    export { convertSet_7 as convertSet };
    export function convertGet_4(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_4 as convertGet };
}
export namespace lock {
    const key_11: string[];
    export { key_11 as key };
    export function convertSet_8(entity: any, key: any, value: any, meta: any): Promise<{
        readAfterWriteTime: number;
    }>;
    export { convertSet_8 as convertSet };
    export function convertGet_5(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_5 as convertGet };
}
export namespace lock_auto_relock_time {
    const key_12: string[];
    export { key_12 as key };
    export function convertSet_9(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            auto_relock_time: any;
        };
    }>;
    export { convertSet_9 as convertSet };
    export function convertGet_6(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_6 as convertGet };
}
export namespace lock_sound_volume {
    const key_13: string[];
    export { key_13 as key };
    export function convertSet_10(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            sound_volume: any;
        };
    }>;
    export { convertSet_10 as convertSet };
    export function convertGet_7(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_7 as convertGet };
}
export namespace pincode_lock {
    const key_14: string[];
    export { key_14 as key };
    export function convertSet_11(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_11 as convertSet };
    export function convertGet_8(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_8 as convertGet };
}
export namespace lock_userstatus {
    const key_15: string[];
    export { key_15 as key };
    export function convertSet_12(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_12 as convertSet };
    export function convertGet_9(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_9 as convertGet };
}
export namespace on_off {
    const key_16: string[];
    export { key_16 as key };
    export function convertSet_13(entity: any, key: any, value: any, meta: any): Promise<{
        state?: undefined;
    } | {
        state: {
            state: any;
        };
    }>;
    export { convertSet_13 as convertSet };
    export function convertGet_10(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_10 as convertGet };
}
export namespace cover_via_brightness {
    const key_17: string[];
    export { key_17 as key };
    export const options: exposes.Binary[];
    export function convertSet_14(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            position: any;
        };
        readAfterWriteTime: number;
    }>;
    export { convertSet_14 as convertSet };
    export function convertGet_11(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_11 as convertGet };
}
export namespace warning {
    const key_18: string[];
    export { key_18 as key };
    export function convertSet_15(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_15 as convertSet };
}
export namespace ias_max_duration {
    const key_19: string[];
    export { key_19 as key };
    export function convertSet_16(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            max_duration: any;
        };
    }>;
    export { convertSet_16 as convertSet };
    export function convertGet_12(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_12 as convertGet };
}
export namespace warning_simple {
    const key_20: string[];
    export { key_20 as key };
    export function convertSet_17(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_17 as convertSet };
}
export namespace squawk {
    const key_21: string[];
    export { key_21 as key };
    export function convertSet_18(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_18 as convertSet };
}
export namespace cover_state {
    const key_22: string[];
    export { key_22 as key };
    export function convertSet_19(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_19 as convertSet };
}
export namespace cover_position_tilt {
    const key_23: string[];
    export { key_23 as key };
    const options_1: exposes.Binary[];
    export { options_1 as options };
    export function convertSet_20(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            [x: string]: any;
        };
    }>;
    export { convertSet_20 as convertSet };
    export function convertGet_13(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_13 as convertGet };
}
export namespace occupancy_timeout {
    const key_24: string[];
    export { key_24 as key };
    export function convertSet_21(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            occupancy_timeout: any;
        };
    }>;
    export { convertSet_21 as convertSet };
    export function convertGet_14(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_14 as convertGet };
}
export namespace level_config {
    const key_25: string[];
    export { key_25 as key };
    export function convertSet_22(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            level_config: {};
        };
    }>;
    export { convertSet_22 as convertSet };
    export function convertGet_15(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_15 as convertGet };
}
export namespace ballast_config {
    const key_26: string[];
    export { key_26 as key };
    export function convertSet_23(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_23 as convertSet };
    export function convertGet_16(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_16 as convertGet };
}
export namespace light_brightness_step {
    const key_27: string[];
    export { key_27 as key };
    const options_2: exposes.Numeric[];
    export { options_2 as options };
    export function convertSet_24(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            brightness: any;
            state: string;
        };
    }>;
    export { convertSet_24 as convertSet };
}
export namespace light_brightness_move {
    const key_28: string[];
    export { key_28 as key };
    export function convertSet_25(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            brightness: any;
            state: string;
        };
    }>;
    export { convertSet_25 as convertSet };
}
export namespace light_colortemp_step {
    const key_29: string[];
    export { key_29 as key };
    const options_3: exposes.Numeric[];
    export { options_3 as options };
    export function convertSet_26(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_26 as convertSet };
}
export namespace light_colortemp_move {
    const key_30: string[];
    export { key_30 as key };
    export function convertSet_27(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_27 as convertSet };
}
export namespace light_color_and_colortemp_via_color {
    const key_31: string[];
    export { key_31 as key };
    const options_4: (exposes.Numeric | exposes.Binary)[];
    export { options_4 as options };
    export function convertSet_28(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            color_mode: any;
            color: any;
            color_temp: any;
        };
        readAfterWriteTime: number;
    }>;
    export { convertSet_28 as convertSet };
    export function convertGet_17(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_17 as convertGet };
}
export namespace light_hue_saturation_step {
    const key_32: string[];
    export { key_32 as key };
    const options_5: exposes.Numeric[];
    export { options_5 as options };
    export function convertSet_29(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_29 as convertSet };
}
export namespace light_hue_saturation_move {
    const key_33: string[];
    export { key_33 as key };
    export function convertSet_30(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_30 as convertSet };
}
export namespace light_onoff_brightness {
    const key_34: string[];
    export { key_34 as key };
    const options_6: exposes.Numeric[];
    export { options_6 as options };
    export function convertSet_31(entity: any, key: any, value: any, meta: any): Promise<{
        state?: undefined;
    } | {
        state: {
            state: any;
        };
    } | {
        state: {};
        readAfterWriteTime: number;
    }>;
    export { convertSet_31 as convertSet };
    export function convertGet_18(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_18 as convertGet };
}
export namespace light_colortemp {
    const key_35: string[];
    export { key_35 as key };
    const options_7: (exposes.Numeric | exposes.Binary)[];
    export { options_7 as options };
    export function convertSet_32(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            color_mode: any;
            color: any;
            color_temp: any;
        };
        readAfterWriteTime: number;
    }>;
    export { convertSet_32 as convertSet };
    export function convertGet_19(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_19 as convertGet };
}
export namespace light_colortemp_startup {
    const key_36: string[];
    export { key_36 as key };
    export function convertSet_33(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            color_temp_startup: any;
        };
    }>;
    export { convertSet_33 as convertSet };
    export function convertGet_20(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_20 as convertGet };
}
export namespace light_color {
    const key_37: string[];
    export { key_37 as key };
    const options_8: (exposes.Numeric | exposes.Binary)[];
    export { options_8 as options };
    export function convertSet_34(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            color_mode: any;
            color: any;
            color_temp: any;
        };
        readAfterWriteTime: number;
    }>;
    export { convertSet_34 as convertSet };
    export function convertGet_21(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_21 as convertGet };
}
export namespace light_color_colortemp {
    const key_38: string[];
    export { key_38 as key };
    const options_9: (exposes.Numeric | exposes.Binary)[];
    export { options_9 as options };
    export function convertSet_35(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            color_mode: any;
            color: any;
            color_temp: any;
        };
        readAfterWriteTime: number;
    }>;
    export { convertSet_35 as convertSet };
    export function convertGet_22(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_22 as convertGet };
}
export namespace effect {
    const key_39: string[];
    export { key_39 as key };
    export function convertSet_36(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_36 as convertSet };
}
export namespace thermostat_remote_sensing {
    const key_40: string[];
    export { key_40 as key };
    export function convertSet_37(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_37 as convertSet };
    export function convertGet_23(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_23 as convertGet };
}
export namespace thermostat_weekly_schedule {
    const key_41: string[];
    export { key_41 as key };
    export function convertSet_38(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_38 as convertSet };
    export function convertGet_24(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_24 as convertGet };
}
export namespace thermostat_system_mode {
    const key_42: string[];
    export { key_42 as key };
    export function convertSet_39(entity: any, key: any, value: any, meta: any): Promise<{
        readAfterWriteTime: number;
        state: {
            system_mode: any;
        };
    }>;
    export { convertSet_39 as convertSet };
    export function convertGet_25(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_25 as convertGet };
}
export namespace thermostat_control_sequence_of_operation {
    const key_43: string[];
    export { key_43 as key };
    export function convertSet_40(entity: any, key: any, value: any, meta: any): Promise<{
        readAfterWriteTime: number;
        state: {
            control_sequence_of_operation: any;
        };
    }>;
    export { convertSet_40 as convertSet };
    export function convertGet_26(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_26 as convertGet };
}
export namespace thermostat_programming_operation_mode {
    const key_44: string[];
    export { key_44 as key };
    export function convertSet_41(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            programming_operation_mode: any;
        };
    }>;
    export { convertSet_41 as convertSet };
    export function convertGet_27(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_27 as convertGet };
}
export namespace thermostat_temperature_display_mode {
    const key_45: string[];
    export { key_45 as key };
    export function convertSet_42(entity: any, key: any, value: any, meta: any): Promise<{
        readAfterWriteTime: number;
        state: {
            temperature_display_mode: any;
        };
    }>;
    export { convertSet_42 as convertSet };
    export function convertGet_28(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_28 as convertGet };
}
export namespace thermostat_keypad_lockout {
    const key_46: string[];
    export { key_46 as key };
    export function convertSet_43(entity: any, key: any, value: any, meta: any): Promise<{
        readAfterWriteTime: number;
        state: {
            keypad_lockout: any;
        };
    }>;
    export { convertSet_43 as convertSet };
    export function convertGet_29(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_29 as convertGet };
}
export namespace thermostat_temperature_setpoint_hold {
    const key_47: string[];
    export { key_47 as key };
    export function convertSet_44(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_44 as convertSet };
    export function convertGet_30(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_30 as convertGet };
}
export namespace thermostat_temperature_setpoint_hold_duration {
    const key_48: string[];
    export { key_48 as key };
    export function convertSet_45(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_45 as convertSet };
    export function convertGet_31(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_31 as convertGet };
}
export namespace fan_mode {
    const key_49: string[];
    export { key_49 as key };
    export function convertSet_46(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            fan_mode: any;
            fan_state: string;
        };
    }>;
    export { convertSet_46 as convertSet };
    export function convertGet_32(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_32 as convertGet };
}
export namespace thermostat_local_temperature {
    const key_50: string[];
    export { key_50 as key };
    export function convertGet_33(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_33 as convertGet };
}
export namespace thermostat_outdoor_temperature {
    const key_51: string[];
    export { key_51 as key };
    export function convertGet_34(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_34 as convertGet };
}
export namespace thermostat_local_temperature_calibration {
    const key_52: string[];
    export { key_52 as key };
    export function convertSet_47(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            local_temperature_calibration: any;
        };
    }>;
    export { convertSet_47 as convertSet };
    export function convertGet_35(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_35 as convertGet };
}
export namespace thermostat_occupancy {
    const key_53: string[];
    export { key_53 as key };
    export function convertGet_36(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_36 as convertGet };
}
export namespace thermostat_clear_weekly_schedule {
    const key_54: string[];
    export { key_54 as key };
    export function convertSet_48(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_48 as convertSet };
}
export namespace thermostat_pi_heating_demand {
    const key_55: string[];
    export { key_55 as key };
    export function convertGet_37(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_37 as convertGet };
}
export namespace thermostat_running_state {
    const key_56: string[];
    export { key_56 as key };
    export function convertGet_38(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_38 as convertGet };
}
export namespace thermostat_occupied_heating_setpoint {
    const key_57: string[];
    export { key_57 as key };
    const options_10: exposes.Enum[];
    export { options_10 as options };
    export function convertSet_49(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            occupied_heating_setpoint: any;
        };
    }>;
    export { convertSet_49 as convertSet };
    export function convertGet_39(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_39 as convertGet };
}
export namespace thermostat_unoccupied_heating_setpoint {
    const key_58: string[];
    export { key_58 as key };
    const options_11: exposes.Enum[];
    export { options_11 as options };
    export function convertSet_50(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            unoccupied_heating_setpoint: any;
        };
    }>;
    export { convertSet_50 as convertSet };
    export function convertGet_40(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_40 as convertGet };
}
export namespace thermostat_occupied_cooling_setpoint {
    const key_59: string[];
    export { key_59 as key };
    const options_12: exposes.Enum[];
    export { options_12 as options };
    export function convertSet_51(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            occupied_cooling_setpoint: any;
        };
    }>;
    export { convertSet_51 as convertSet };
    export function convertGet_41(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_41 as convertGet };
}
export namespace thermostat_unoccupied_cooling_setpoint {
    const key_60: string[];
    export { key_60 as key };
    const options_13: exposes.Enum[];
    export { options_13 as options };
    export function convertSet_52(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            unoccupied_cooling_setpoint: any;
        };
    }>;
    export { convertSet_52 as convertSet };
    export function convertGet_42(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_42 as convertGet };
}
export namespace thermostat_setpoint_raise_lower {
    const key_61: string[];
    export { key_61 as key };
    export function convertSet_53(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_53 as convertSet };
}
export namespace thermostat_relay_status_log {
    const key_62: string[];
    export { key_62 as key };
    export function convertGet_43(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_43 as convertGet };
}
export namespace thermostat_running_mode {
    const key_63: string[];
    export { key_63 as key };
    export function convertGet_44(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_44 as convertGet };
}
export namespace thermostat_min_heat_setpoint_limit {
    const key_64: string[];
    export { key_64 as key };
    export function convertSet_54(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            min_heat_setpoint_limit: any;
        };
    }>;
    export { convertSet_54 as convertSet };
    export function convertGet_45(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_45 as convertGet };
}
export namespace thermostat_max_heat_setpoint_limit {
    const key_65: string[];
    export { key_65 as key };
    export function convertSet_55(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            max_heat_setpoint_limit: any;
        };
    }>;
    export { convertSet_55 as convertSet };
    export function convertGet_46(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_46 as convertGet };
}
export namespace thermostat_min_cool_setpoint_limit {
    const key_66: string[];
    export { key_66 as key };
    export function convertSet_56(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            min_cool_setpoint_limit: any;
        };
    }>;
    export { convertSet_56 as convertSet };
    export function convertGet_47(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_47 as convertGet };
}
export namespace thermostat_max_cool_setpoint_limit {
    const key_67: string[];
    export { key_67 as key };
    export function convertSet_57(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            max_cool_setpoint_limit: any;
        };
    }>;
    export { convertSet_57 as convertSet };
    export function convertGet_48(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_48 as convertGet };
}
export namespace thermostat_ac_louver_position {
    const key_68: string[];
    export { key_68 as key };
    export function convertSet_58(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            ac_louver_position: any;
        };
    }>;
    export { convertSet_58 as convertSet };
    export function convertGet_49(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_49 as convertGet };
}
export namespace electrical_measurement_power {
    const key_69: string[];
    export { key_69 as key };
    export function convertGet_50(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_50 as convertGet };
}
export namespace metering_power {
    const key_70: string[];
    export { key_70 as key };
    export function convertGet_51(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_51 as convertGet };
}
export namespace currentsummdelivered {
    const key_71: string[];
    export { key_71 as key };
    export function convertGet_52(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_52 as convertGet };
}
export namespace frequency {
    const key_72: string[];
    export { key_72 as key };
    export function convertGet_53(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_53 as convertGet };
}
export namespace electrical_measurement_power_reactive {
    const key_73: string[];
    export { key_73 as key };
    export function convertGet_54(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_54 as convertGet };
}
export namespace powerfactor {
    const key_74: string[];
    export { key_74 as key };
    export function convertGet_55(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_55 as convertGet };
}
export namespace acvoltage {
    const key_75: string[];
    export { key_75 as key };
    export function convertGet_56(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_56 as convertGet };
}
export namespace accurrent {
    const key_76: string[];
    export { key_76 as key };
    export function convertGet_57(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_57 as convertGet };
}
export namespace temperature {
    const key_77: string[];
    export { key_77 as key };
    export function convertGet_58(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_58 as convertGet };
}
export namespace illuminance {
    const key_78: string[];
    export { key_78 as key };
    export function convertGet_59(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_59 as convertGet };
}
export namespace elko_load {
    const key_79: string[];
    export { key_79 as key };
    export function convertSet_59(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            load: any;
        };
    }>;
    export { convertSet_59 as convertSet };
    export function convertGet_60(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_60 as convertGet };
}
export namespace elko_display_text {
    const key_80: string[];
    export { key_80 as key };
    export function convertSet_60(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            display_text: any;
        };
    }>;
    export { convertSet_60 as convertSet };
    export function convertGet_61(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_61 as convertGet };
}
export namespace elko_power_status {
    const key_81: string[];
    export { key_81 as key };
    export function convertSet_61(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            system_mode: any;
        };
    }>;
    export { convertSet_61 as convertSet };
    export function convertGet_62(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_62 as convertGet };
}
export namespace elko_external_temp {
    const key_82: string[];
    export { key_82 as key };
    export function convertGet_63(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_63 as convertGet };
}
export namespace elko_mean_power {
    const key_83: string[];
    export { key_83 as key };
    export function convertGet_64(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_64 as convertGet };
}
export namespace elko_child_lock {
    const key_84: string[];
    export { key_84 as key };
    export function convertSet_62(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            child_lock: any;
        };
    }>;
    export { convertSet_62 as convertSet };
    export function convertGet_65(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_65 as convertGet };
}
export namespace elko_frost_guard {
    const key_85: string[];
    export { key_85 as key };
    export function convertSet_63(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            frost_guard: any;
        };
    }>;
    export { convertSet_63 as convertSet };
    export function convertGet_66(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_66 as convertGet };
}
export namespace elko_night_switching {
    const key_86: string[];
    export { key_86 as key };
    export function convertSet_64(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            night_switching: any;
        };
    }>;
    export { convertSet_64 as convertSet };
    export function convertGet_67(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_67 as convertGet };
}
export namespace elko_relay_state {
    const key_87: string[];
    export { key_87 as key };
    export function convertGet_68(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_68 as convertGet };
}
export namespace elko_sensor_mode {
    const key_88: string[];
    export { key_88 as key };
    export function convertSet_65(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            sensor: any;
        };
    }>;
    export { convertSet_65 as convertSet };
}
export namespace elko_regulator_time {
    const key_89: string[];
    export { key_89 as key };
    export function convertSet_66(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            sensor: any;
        };
    }>;
    export { convertSet_66 as convertSet };
    export function convertGet_69(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_69 as convertGet };
}
export namespace elko_regulator_mode {
    const key_90: string[];
    export { key_90 as key };
    export function convertSet_67(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            regulator_mode: any;
        };
    }>;
    export { convertSet_67 as convertSet };
    export function convertGet_70(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_70 as convertGet };
}
export namespace elko_local_temperature_calibration {
    const key_91: string[];
    export { key_91 as key };
    export function convertSet_68(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            local_temperature_calibration: any;
        };
    }>;
    export { convertSet_68 as convertSet };
    export function convertGet_71(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_71 as convertGet };
}
export namespace elko_max_floor_temp {
    const key_92: string[];
    export { key_92 as key };
    export function convertSet_69(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            max_floor_temp: any;
        };
    }>;
    export { convertSet_69 as convertSet };
    export function convertGet_72(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_72 as convertGet };
}
export namespace livolo_socket_switch_on_off {
    const key_93: string[];
    export { key_93 as key };
    export function convertSet_70(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            state: string;
        };
        readAfterWriteTime: number;
    }>;
    export { convertSet_70 as convertSet };
    export function convertGet_73(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_73 as convertGet };
}
export namespace livolo_switch_on_off {
    const key_94: string[];
    export { key_94 as key };
    export function convertSet_71(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            state: string;
        };
        readAfterWriteTime: number;
    }>;
    export { convertSet_71 as convertSet };
    export function convertGet_74(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_74 as convertGet };
}
export namespace livolo_dimmer_level {
    const key_95: string[];
    export { key_95 as key };
    export function convertSet_72(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            brightness_percent: number;
            brightness: number;
            level: number;
        };
        readAfterWriteTime: number;
    }>;
    export { convertSet_72 as convertSet };
    export function convertGet_75(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_75 as convertGet };
}
export namespace livolo_cover_state {
    const key_96: string[];
    export { key_96 as key };
    export function convertSet_73(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            moving: boolean;
        };
        readAfterWriteTime: number;
    }>;
    export { convertSet_73 as convertSet };
}
export namespace livolo_cover_position {
    const key_97: string[];
    export { key_97 as key };
    export function convertSet_74(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            position: any;
            moving: boolean;
        };
        readAfterWriteTime: number;
    }>;
    export { convertSet_74 as convertSet };
}
export namespace livolo_cover_options {
    const key_98: string[];
    export { key_98 as key };
    export function convertSet_75(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_75 as convertSet };
}
export namespace gledopto_light_onoff_brightness {
    const key_99: string[];
    export { key_99 as key };
    const options_14: exposes.Numeric[];
    export { options_14 as options };
    export function convertSet_76(entity: any, key: any, value: any, meta: any): Promise<{
        state?: undefined;
    } | {
        state: {
            state: any;
        };
    } | {
        state: {};
        readAfterWriteTime: number;
    }>;
    export { convertSet_76 as convertSet };
    export function convertGet_76(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_76 as convertGet };
}
export namespace gledopto_light_colortemp {
    const key_100: string[];
    export { key_100 as key };
    const options_15: (exposes.Numeric | exposes.Binary)[];
    export { options_15 as options };
    export function convertSet_77(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            color_mode: any;
            color: any;
            color_temp: any;
        };
        readAfterWriteTime: number;
    }>;
    export { convertSet_77 as convertSet };
    export function convertGet_77(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_77 as convertGet };
}
export namespace gledopto_light_color {
    const key_101: string[];
    export { key_101 as key };
    const options_16: (exposes.Numeric | exposes.Binary)[];
    export { options_16 as options };
    export function convertSet_78(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            color_mode: any;
            color: any;
            color_temp: any;
        };
        readAfterWriteTime: number;
    }>;
    export { convertSet_78 as convertSet };
    export function convertGet_78(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_78 as convertGet };
}
export namespace gledopto_light_color_colortemp {
    const key_102: string[];
    export { key_102 as key };
    const options_17: (exposes.Numeric | exposes.Binary)[];
    export { options_17 as options };
    export function convertSet_79(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            color_mode: any;
            color: any;
            color_temp: any;
        };
        readAfterWriteTime: number;
    }>;
    export { convertSet_79 as convertSet };
    export function convertGet_79(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_79 as convertGet };
}
export namespace aqara_motion_sensitivity {
    const key_103: string[];
    export { key_103 as key };
    export function convertSet_80(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            motion_sensitivity: any;
        };
    }>;
    export { convertSet_80 as convertSet };
    export function convertGet_80(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_80 as convertGet };
}
export namespace RTCZCGQ11LM_presence {
    const key_104: string[];
    export { key_104 as key };
    export function convertGet_81(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_81 as convertGet };
}
export namespace RTCZCGQ11LM_monitoring_mode {
    const key_105: string[];
    export { key_105 as key };
    export function convertSet_81(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            monitoring_mode: any;
        };
    }>;
    export { convertSet_81 as convertSet };
    export function convertGet_82(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_82 as convertGet };
}
export namespace RTCZCGQ11LM_approach_distance {
    const key_106: string[];
    export { key_106 as key };
    export function convertSet_82(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            approach_distance: any;
        };
    }>;
    export { convertSet_82 as convertSet };
    export function convertGet_83(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_83 as convertGet };
}
export namespace RTCZCGQ11LM_reset_nopresence_status {
    const key_107: string[];
    export { key_107 as key };
    export function convertSet_83(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_83 as convertSet };
}
export namespace ZigUP_lock {
    const key_108: string[];
    export { key_108 as key };
    export function convertSet_84(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_84 as convertSet };
}
export namespace LS21001_alert_behaviour {
    const key_109: string[];
    export { key_109 as key };
    export function convertSet_85(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            alert_behaviour: any;
        };
    }>;
    export { convertSet_85 as convertSet };
}
export namespace xiaomi_switch_type {
    const key_110: string[];
    export { key_110 as key };
    export function convertSet_86(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            switch_type: any;
        };
    }>;
    export { convertSet_86 as convertSet };
    export function convertGet_84(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_84 as convertGet };
}
export namespace xiaomi_switch_power_outage_memory {
    const key_111: string[];
    export { key_111 as key };
    export function convertSet_87(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            power_outage_memory: any;
        };
    }>;
    export { convertSet_87 as convertSet };
    export function convertGet_85(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_85 as convertGet };
}
export namespace xiaomi_light_power_outage_memory {
    const key_112: string[];
    export { key_112 as key };
    export function convertSet_88(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            power_outage_memory: any;
        };
    }>;
    export { convertSet_88 as convertSet };
}
export namespace xiaomi_power {
    const key_113: string[];
    export { key_113 as key };
    export function convertGet_86(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_86 as convertGet };
}
export namespace xiaomi_auto_off {
    const key_114: string[];
    export { key_114 as key };
    export function convertSet_89(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            auto_off: any;
        };
    }>;
    export { convertSet_89 as convertSet };
    export function convertGet_87(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_87 as convertGet };
}
export namespace GZCGQ11LM_detection_period {
    const key_115: string[];
    export { key_115 as key };
    export function convertSet_90(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            detection_period: any;
        };
    }>;
    export { convertSet_90 as convertSet };
    export function convertGet_88(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_88 as convertGet };
}
export namespace aqara_detection_interval {
    const key_116: string[];
    export { key_116 as key };
    export function convertSet_91(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            detection_interval: any;
        };
    }>;
    export { convertSet_91 as convertSet };
    export function convertGet_89(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_89 as convertGet };
}
export namespace xiaomi_overload_protection {
    const key_117: string[];
    export { key_117 as key };
    export function convertSet_92(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            overload_protection: any;
        };
    }>;
    export { convertSet_92 as convertSet };
    export function convertGet_90(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_90 as convertGet };
}
export namespace aqara_switch_mode_switch {
    const key_118: string[];
    export { key_118 as key };
    export function convertSet_93(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            mode_switch: any;
        };
    }>;
    export { convertSet_93 as convertSet };
    export function convertGet_91(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_91 as convertGet };
}
export namespace xiaomi_button_switch_mode {
    const key_119: string[];
    export { key_119 as key };
    export function convertSet_94(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            button_switch_mode: any;
        };
    }>;
    export { convertSet_94 as convertSet };
    export function convertGet_92(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_92 as convertGet };
}
export namespace xiaomi_socket_button_lock {
    const key_120: string[];
    export { key_120 as key };
    export function convertSet_95(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            button_lock: any;
        };
    }>;
    export { convertSet_95 as convertSet };
    export function convertGet_93(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_93 as convertGet };
}
export namespace xiaomi_led_disabled_night {
    const key_121: string[];
    export { key_121 as key };
    export function convertSet_96(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            led_disabled_night: any;
        };
    }>;
    export { convertSet_96 as convertSet };
    export function convertGet_94(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_94 as convertGet };
}
export namespace xiaomi_flip_indicator_light {
    const key_122: string[];
    export { key_122 as key };
    export function convertSet_97(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            flip_indicator_light: any;
        };
    }>;
    export { convertSet_97 as convertSet };
    export function convertGet_95(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_95 as convertGet };
}
export namespace xiaomi_dimmer_mode {
    const key_123: string[];
    export { key_123 as key };
    export function convertSet_98(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            dimmer_mode: any;
        };
    }>;
    export { convertSet_98 as convertSet };
    export function convertGet_96(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertGet_96 as convertGet };
}
export namespace xiaomi_switch_operation_mode_basic {
    const key_124: string[];
    export { key_124 as key };
    export function convertSet_99(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            operation_mode: any;
        };
    }>;
    export { convertSet_99 as convertSet };
    export function convertGet_97(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_97 as convertGet };
}
export namespace xiaomi_switch_operation_mode_opple {
    const key_125: string[];
    export { key_125 as key };
    export function convertSet_100(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_100 as convertSet };
    export function convertGet_98(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_98 as convertGet };
}
export namespace xiaomi_switch_do_not_disturb {
    const key_126: string[];
    export { key_126 as key };
    export function convertSet_101(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            do_not_disturb: any;
        };
    }>;
    export { convertSet_101 as convertSet };
}
export namespace STS_PRS_251_beep {
    const key_127: string[];
    export { key_127 as key };
    export function convertSet_102(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_102 as convertSet };
}
export namespace xiaomi_curtain_options {
    const key_128: string[];
    export { key_128 as key };
    export function convertSet_103(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            options: any;
        };
    }>;
    export { convertSet_103 as convertSet };
    export function convertGet_99(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_99 as convertGet };
}
export namespace xiaomi_curtain_position_state {
    const key_129: string[];
    export { key_129 as key };
    const options_18: exposes.Binary[];
    export { options_18 as options };
    export function convertSet_104(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            state: string;
        };
    }>;
    export { convertSet_104 as convertSet };
    export function convertGet_100(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_100 as convertGet };
}
export namespace xiaomi_curtain_battery_voltage {
    const key_130: string[];
    export { key_130 as key };
    export function convertGet_101(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_101 as convertGet };
}
export namespace xiaomi_curtain_acn002_charging_status {
    const key_131: string[];
    export { key_131 as key };
    export function convertGet_102(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_102 as convertGet };
}
export namespace xiaomi_curtain_acn002_battery {
    const key_132: string[];
    export { key_132 as key };
    export function convertGet_103(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_103 as convertGet };
}
export namespace ledvance_commands {
    const key_133: string[];
    export { key_133 as key };
    export function convertSet_105(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_105 as convertSet };
}
export namespace SPZ01_power_outage_memory {
    const key_134: string[];
    export { key_134 as key };
    export function convertSet_106(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            power_outage_memory: any;
        };
    }>;
    export { convertSet_106 as convertSet };
}
export namespace tuya_relay_din_led_indicator {
    const key_135: string[];
    export { key_135 as key };
    export function convertSet_107(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            indicator_mode: any;
        };
    }>;
    export { convertSet_107 as convertSet };
}
export namespace kmpcil_res005_on_off {
    const key_136: string[];
    export { key_136 as key };
    export function convertSet_108(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            state: any;
        };
    }>;
    export { convertSet_108 as convertSet };
    export function convertGet_104(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_104 as convertGet };
}
export namespace light_onoff_restorable_brightness {
    const key_137: string[];
    export { key_137 as key };
    const options_19: exposes.Numeric[];
    export { options_19 as options };
    export function convertSet_109(entity: any, key: any, value: any, meta: any): Promise<{
        state?: undefined;
    } | {
        state: {
            state: any;
        };
    } | {
        state: {};
        readAfterWriteTime: number;
    }>;
    export { convertSet_109 as convertSet };
    export function convertGet_105(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_105 as convertGet };
}
export namespace JTQJBF01LMBW_JTYJGD01LMBW_sensitivity {
    const key_138: string[];
    export { key_138 as key };
    export function convertSet_110(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            sensitivity: any;
        };
    }>;
    export { convertSet_110 as convertSet };
}
export namespace JTQJBF01LMBW_JTYJGD01LMBW_selfest {
    const key_139: string[];
    export { key_139 as key };
    export function convertSet_111(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_111 as convertSet };
}
export namespace aqara_alarm {
    const key_140: string[];
    export { key_140 as key };
    export function convertGet_106(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_106 as convertGet };
}
export namespace aqara_density {
    const key_141: string[];
    export { key_141 as key };
    export function convertGet_107(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_107 as convertGet };
}
export namespace JTBZ01AQA_gas_sensitivity {
    const key_142: string[];
    export { key_142 as key };
    export function convertSet_112(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            gas_sensitivity: any;
        };
    }>;
    export { convertSet_112 as convertSet };
    export function convertGet_108(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_108 as convertGet };
}
export namespace aqara_selftest {
    const key_143: string[];
    export { key_143 as key };
    export function convertSet_113(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_113 as convertSet };
}
export namespace aqara_buzzer {
    const key_144: string[];
    export { key_144 as key };
    export function convertSet_114(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_114 as convertSet };
}
export namespace aqara_buzzer_manual {
    const key_145: string[];
    export { key_145 as key };
    export function convertGet_109(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_109 as convertGet };
}
export namespace JYGZ01AQ_heartbeat_indicator {
    const key_146: string[];
    export { key_146 as key };
    export function convertSet_115(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            heartbeat_indicator: any;
        };
    }>;
    export { convertSet_115 as convertSet };
    export function convertGet_110(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_110 as convertGet };
}
export namespace aqara_linkage_alarm {
    const key_147: string[];
    export { key_147 as key };
    export function convertSet_116(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            linkage_alarm: any;
        };
    }>;
    export { convertSet_116 as convertSet };
    export function convertGet_111(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_111 as convertGet };
}
export namespace JTBZ01AQA_state {
    const key_148: string[];
    export { key_148 as key };
    export function convertGet_112(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_112 as convertGet };
}
export namespace aqara_power_outage_count {
    const key_149: string[];
    export { key_149 as key };
    export function convertGet_113(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_113 as convertGet };
}
export namespace RTCGQ14LM_trigger_indicator {
    const key_150: string[];
    export { key_150 as key };
    export function convertSet_117(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            trigger_indicator: any;
        };
    }>;
    export { convertSet_117 as convertSet };
    export function convertGet_114(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_114 as convertGet };
}
export namespace LLKZMK11LM_interlock {
    const key_151: string[];
    export { key_151 as key };
    export function convertSet_118(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            interlock: any;
        };
    }>;
    export { convertSet_118 as convertSet };
}
export namespace DJT11LM_vibration_sensitivity {
    const key_152: string[];
    export { key_152 as key };
    export function convertSet_119(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            sensitivity: any;
        };
    }>;
    export { convertSet_119 as convertSet };
}
export namespace hue_wall_switch_device_mode {
    const key_153: string[];
    export { key_153 as key };
    export function convertSet_120(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_120 as convertSet };
    export function convertGet_115(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_115 as convertGet };
}
export namespace danfoss_thermostat_occupied_heating_setpoint {
    const key_154: string[];
    export { key_154 as key };
    export function convertSet_121(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_121 as convertSet };
    export function convertGet_116(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_116 as convertGet };
}
export namespace danfoss_thermostat_occupied_heating_setpoint_scheduled {
    const key_155: string[];
    export { key_155 as key };
    export function convertSet_122(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_122 as convertSet };
    export function convertGet_117(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_117 as convertGet };
}
export namespace danfoss_mounted_mode_active {
    const key_156: string[];
    export { key_156 as key };
    export function convertGet_118(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_118 as convertGet };
}
export namespace danfoss_mounted_mode_control {
    const key_157: string[];
    export { key_157 as key };
    export function convertSet_123(entity: any, key: any, value: any, meta: any): Promise<{
        readAfterWriteTime: number;
        state: {
            mounted_mode_control: any;
        };
    }>;
    export { convertSet_123 as convertSet };
    export function convertGet_119(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_119 as convertGet };
}
export namespace danfoss_thermostat_vertical_orientation {
    const key_158: string[];
    export { key_158 as key };
    export function convertSet_124(entity: any, key: any, value: any, meta: any): Promise<{
        readAfterWriteTime: number;
        state: {
            thermostat_vertical_orientation: any;
        };
    }>;
    export { convertSet_124 as convertSet };
    export function convertGet_120(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_120 as convertGet };
}
export namespace danfoss_external_measured_room_sensor {
    const key_159: string[];
    export { key_159 as key };
    export function convertSet_125(entity: any, key: any, value: any, meta: any): Promise<{
        readAfterWriteTime: number;
        state: {
            external_measured_room_sensor: any;
        };
    }>;
    export { convertSet_125 as convertSet };
    export function convertGet_121(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_121 as convertGet };
}
export namespace danfoss_radiator_covered {
    const key_160: string[];
    export { key_160 as key };
    export function convertSet_126(entity: any, key: any, value: any, meta: any): Promise<{
        readAfterWriteTime: number;
        state: {
            radiator_covered: any;
        };
    }>;
    export { convertSet_126 as convertSet };
    export function convertGet_122(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_122 as convertGet };
}
export namespace danfoss_viewing_direction {
    const key_161: string[];
    export { key_161 as key };
    export function convertSet_127(entity: any, key: any, value: any, meta: any): Promise<{
        readAfterWriteTime: number;
        state: {
            viewing_direction: any;
        };
    }>;
    export { convertSet_127 as convertSet };
    export function convertGet_123(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_123 as convertGet };
}
export namespace danfoss_algorithm_scale_factor {
    const key_162: string[];
    export { key_162 as key };
    export function convertSet_128(entity: any, key: any, value: any, meta: any): Promise<{
        readAfterWriteTime: number;
        state: {
            algorithm_scale_factor: any;
        };
    }>;
    export { convertSet_128 as convertSet };
    export function convertGet_124(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_124 as convertGet };
}
export namespace danfoss_heat_available {
    const key_163: string[];
    export { key_163 as key };
    export function convertSet_129(entity: any, key: any, value: any, meta: any): Promise<{
        readAfterWriteTime: number;
        state: {
            heat_available: any;
        };
    }>;
    export { convertSet_129 as convertSet };
    export function convertGet_125(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_125 as convertGet };
}
export namespace danfoss_heat_required {
    const key_164: string[];
    export { key_164 as key };
    export function convertGet_126(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_126 as convertGet };
}
export namespace danfoss_day_of_week {
    const key_165: string[];
    export { key_165 as key };
    export function convertSet_130(entity: any, key: any, value: any, meta: any): Promise<{
        readAfterWriteTime: number;
        state: {
            day_of_week: any;
        };
    }>;
    export { convertSet_130 as convertSet };
    export function convertGet_127(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_127 as convertGet };
}
export namespace danfoss_trigger_time {
    const key_166: string[];
    export { key_166 as key };
    export function convertSet_131(entity: any, key: any, value: any, meta: any): Promise<{
        readAfterWriteTime: number;
        state: {
            trigger_time: any;
        };
    }>;
    export { convertSet_131 as convertSet };
    export function convertGet_128(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_128 as convertGet };
}
export namespace danfoss_window_open_feature {
    const key_167: string[];
    export { key_167 as key };
    export function convertSet_132(entity: any, key: any, value: any, meta: any): Promise<{
        readAfterWriteTime: number;
        state: {
            window_open_feature: any;
        };
    }>;
    export { convertSet_132 as convertSet };
    export function convertGet_129(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_129 as convertGet };
}
export namespace danfoss_window_open_internal {
    const key_168: string[];
    export { key_168 as key };
    export function convertGet_130(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_130 as convertGet };
}
export namespace danfoss_window_open_external {
    const key_169: string[];
    export { key_169 as key };
    export function convertSet_133(entity: any, key: any, value: any, meta: any): Promise<{
        readAfterWriteTime: number;
        state: {
            window_open_external: any;
        };
    }>;
    export { convertSet_133 as convertSet };
    export function convertGet_131(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_131 as convertGet };
}
export namespace danfoss_load_balancing_enable {
    const key_170: string[];
    export { key_170 as key };
    export function convertSet_134(entity: any, key: any, value: any, meta: any): Promise<{
        readAfterWriteTime: number;
        state: {
            load_balancing_enable: any;
        };
    }>;
    export { convertSet_134 as convertSet };
    export function convertGet_132(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_132 as convertGet };
}
export namespace danfoss_load_room_mean {
    const key_171: string[];
    export { key_171 as key };
    export function convertSet_135(entity: any, key: any, value: any, meta: any): Promise<{
        readAfterWriteTime: number;
        state: {
            load_room_mean: any;
        };
    }>;
    export { convertSet_135 as convertSet };
    export function convertGet_133(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_133 as convertGet };
}
export namespace danfoss_load_estimate {
    const key_172: string[];
    export { key_172 as key };
    export function convertGet_134(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_134 as convertGet };
}
export namespace danfoss_preheat_status {
    const key_173: string[];
    export { key_173 as key };
    export function convertGet_135(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_135 as convertGet };
}
export namespace danfoss_adaptation_status {
    const key_174: string[];
    export { key_174 as key };
    export function convertGet_136(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_136 as convertGet };
}
export namespace danfoss_adaptation_settings {
    const key_175: string[];
    export { key_175 as key };
    export function convertSet_136(entity: any, key: any, value: any, meta: any): Promise<{
        readAfterWriteTime: number;
        state: {
            adaptation_run_settings: any;
        };
    }>;
    export { convertSet_136 as convertSet };
    export function convertGet_137(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_137 as convertGet };
}
export namespace danfoss_adaptation_control {
    const key_176: string[];
    export { key_176 as key };
    export function convertSet_137(entity: any, key: any, value: any, meta: any): Promise<{
        readAfterWriteTime: number;
        state: {
            adaptation_run_control: any;
        };
    }>;
    export { convertSet_137 as convertSet };
    export function convertGet_138(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_138 as convertGet };
}
export namespace danfoss_regulation_setpoint_offset {
    const key_177: string[];
    export { key_177 as key };
    export function convertSet_138(entity: any, key: any, value: any, meta: any): Promise<{
        readAfterWriteTime: number;
        state: {
            regulation_setpoint_offset: any;
        };
    }>;
    export { convertSet_138 as convertSet };
    export function convertGet_139(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_139 as convertGet };
}
export namespace danfoss_output_status {
    const key_178: string[];
    export { key_178 as key };
    export function convertGet_140(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_140 as convertGet };
}
export namespace danfoss_room_status_code {
    const key_179: string[];
    export { key_179 as key };
    export function convertGet_141(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_141 as convertGet };
}
export namespace danfoss_system_status_code {
    const key_180: string[];
    export { key_180 as key };
    export function convertGet_142(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_142 as convertGet };
}
export namespace danfoss_system_status_water {
    const key_181: string[];
    export { key_181 as key };
    export function convertGet_143(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_143 as convertGet };
}
export namespace danfoss_multimaster_role {
    const key_182: string[];
    export { key_182 as key };
    export function convertGet_144(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_144 as convertGet };
}
export namespace ZMCSW032D_cover_position {
    const key_183: string[];
    export { key_183 as key };
    export function convertSet_139(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            position: any;
        };
    }>;
    export { convertSet_139 as convertSet };
    export function convertGet_145(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_145 as convertGet };
}
export namespace namron_thermostat {
    const key_184: string[];
    export { key_184 as key };
    export function convertSet_140(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_140 as convertSet };
    export function convertGet_146(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_146 as convertGet };
}
export namespace namron_thermostat_child_lock {
    const key_185: string[];
    export { key_185 as key };
    export function convertSet_141(entity: any, key: any, value: any, meta: any): Promise<{
        readAfterWriteTime: number;
        state: {
            child_lock: any;
        };
    }>;
    export { convertSet_141 as convertSet };
    export function convertGet_147(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_147 as convertGet };
}
export namespace easycode_auto_relock {
    const key_186: string[];
    export { key_186 as key };
    export function convertSet_142(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            auto_relock: any;
        };
    }>;
    export { convertSet_142 as convertSet };
}
export namespace tuya_led_control {
    const key_187: string[];
    export { key_187 as key };
    const options_20: exposes.Binary[];
    export { options_20 as options };
    export function convertSet_143(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            brightness: number;
        };
        readAfterWriteTime?: undefined;
    } | {
        state: {
            color_mode: any;
            color: any;
            color_temp: any;
        };
        readAfterWriteTime: number;
    }>;
    export { convertSet_143 as convertSet };
    export function convertGet_148(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_148 as convertGet };
}
export namespace tuya_led_controller {
    const key_188: string[];
    export { key_188 as key };
    export function convertSet_144(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            state: any;
        };
    }>;
    export { convertSet_144 as convertSet };
    export function convertGet_149(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_149 as convertGet };
}
export namespace RM01_light_onoff_brightness {
    const key_189: string[];
    export { key_189 as key };
    const options_21: exposes.Numeric[];
    export { options_21 as options };
    export function convertSet_145(entity: any, key: any, value: any, meta: any): Promise<{
        state?: undefined;
    } | {
        state: {
            state: any;
        };
    } | {
        state: {};
        readAfterWriteTime: number;
    }>;
    export { convertSet_145 as convertSet };
    export function convertGet_150(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_150 as convertGet };
}
export namespace RM01_light_brightness_step {
    const options_22: exposes.Numeric[];
    export { options_22 as options };
    const key_190: string[];
    export { key_190 as key };
    export function convertSet_146(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            brightness: any;
            state: string;
        };
    }>;
    export { convertSet_146 as convertSet };
}
export namespace RM01_light_brightness_move {
    const key_191: string[];
    export { key_191 as key };
    export function convertSet_147(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            brightness: any;
            state: string;
        };
    }>;
    export { convertSet_147 as convertSet };
}
export namespace aqara_opple_operation_mode {
    const key_192: string[];
    export { key_192 as key };
    export function convertSet_148(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            operation_mode: any;
        };
    }>;
    export { convertSet_148 as convertSet };
    export function convertGet_151(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_151 as convertGet };
}
export namespace EMIZB_132_mode {
    const key_193: string[];
    export { key_193 as key };
    export function convertSet_149(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            interface_mode: any;
        };
    }>;
    export { convertSet_149 as convertSet };
}
export namespace eurotronic_thermostat_system_mode {
    const key_194: string[];
    export { key_194 as key };
    export function convertSet_150(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_150 as convertSet };
    export function convertGet_152(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_152 as convertGet };
}
export namespace eurotronic_host_flags {
    const key_195: string[];
    export { key_195 as key };
    export function convertSet_151(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_151 as convertSet };
    export function convertGet_153(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_153 as convertGet };
}
export namespace eurotronic_error_status {
    const key_196: string[];
    export { key_196 as key };
    export function convertGet_154(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_154 as convertGet };
}
export namespace eurotronic_current_heating_setpoint {
    const key_197: string[];
    export { key_197 as key };
    export function convertSet_152(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_152 as convertSet };
    export function convertGet_155(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_155 as convertGet };
}
export namespace eurotronic_valve_position {
    const key_198: string[];
    export { key_198 as key };
    export function convertSet_153(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            [x: number]: any;
        };
    }>;
    export { convertSet_153 as convertSet };
    export function convertGet_156(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_156 as convertGet };
}
export namespace eurotronic_trv_mode {
    const key_199: string[];
    export { key_199 as key };
    export function convertSet_154(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            [x: number]: any;
        };
    }>;
    export { convertSet_154 as convertSet };
    export function convertGet_157(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_157 as convertGet };
}
export namespace stelpro_thermostat_outdoor_temperature {
    const key_200: string[];
    export { key_200 as key };
    export function convertSet_155(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_155 as convertSet };
}
export namespace DTB190502A1_LED {
    const key_201: string[];
    export { key_201 as key };
    export function convertSet_156(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_156 as convertSet };
}
export namespace ptvo_switch_trigger {
    const key_202: string[];
    export { key_202 as key };
    export function convertSet_157(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_157 as convertSet };
}
export namespace ptvo_switch_uart {
    const key_203: string[];
    export { key_203 as key };
    export function convertSet_158(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_158 as convertSet };
}
export namespace ptvo_switch_analog_input {
    const key_204: string[];
    export { key_204 as key };
    export function convertGet_158(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_158 as convertGet };
    export function convertSet_159(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_159 as convertSet };
}
export namespace ptvo_switch_light_brightness {
    const key_205: string[];
    export { key_205 as key };
    const options_23: exposes.Numeric[];
    export { options_23 as options };
    export function convertSet_160(entity: any, key: any, value: any, meta: any): Promise<{
        state?: undefined;
    } | {
        state: {
            state: any;
        };
    } | {
        state: {};
        readAfterWriteTime: number;
    }>;
    export { convertSet_160 as convertSet };
    export function convertGet_159(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_159 as convertGet };
}
export namespace tint_scene {
    const key_206: string[];
    export { key_206 as key };
    export function convertSet_161(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_161 as convertSet };
}
export namespace bticino_4027C_cover_state {
    const key_207: string[];
    export { key_207 as key };
    const options_24: exposes.Binary[];
    export { options_24 as options };
    export function convertSet_162(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            position: number;
        };
        readAfterWriteTime: number;
    }>;
    export { convertSet_162 as convertSet };
}
export namespace bticino_4027C_cover_position {
    const key_208: string[];
    export { key_208 as key };
    const options_25: exposes.Binary[];
    export { options_25 as options };
    export function convertSet_163(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            position: any;
        };
        readAfterWriteTime: number;
    }>;
    export { convertSet_163 as convertSet };
    export function convertGet_160(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_160 as convertGet };
}
export namespace legrand_identify {
    const key_209: string[];
    export { key_209 as key };
    export function convertSet_164(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_164 as convertSet };
}
export namespace legrand_settingEnableLedInDark {
    const key_210: string[];
    export { key_210 as key };
    export function convertSet_165(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            led_in_dark: any;
        };
    }>;
    export { convertSet_165 as convertSet };
    export function convertGet_161(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_161 as convertGet };
}
export namespace legrand_settingEnableLedIfOn {
    const key_211: string[];
    export { key_211 as key };
    export function convertSet_166(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            led_if_on: any;
        };
    }>;
    export { convertSet_166 as convertSet };
    export function convertGet_162(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_162 as convertGet };
}
export namespace legrand_deviceMode {
    const key_212: string[];
    export { key_212 as key };
    export function convertSet_167(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            device_mode: any;
        };
    }>;
    export { convertSet_167 as convertSet };
    export function convertGet_163(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_163 as convertGet };
}
export namespace legrand_cableOutletMode {
    const key_213: string[];
    export { key_213 as key };
    export function convertSet_168(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            cable_outlet_mode: any;
        };
    }>;
    export { convertSet_168 as convertSet };
    export function convertGet_164(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_164 as convertGet };
}
export namespace legrand_powerAlarm {
    const key_214: string[];
    export { key_214 as key };
    export function convertSet_169(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_169 as convertSet };
    export function convertGet_165(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_165 as convertGet };
}
export namespace diyruz_freepad_on_off_config {
    const key_215: string[];
    export { key_215 as key };
    export function convertGet_166(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_166 as convertGet };
    export function convertSet_170(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            [x: string]: any;
        };
    }>;
    export { convertSet_170 as convertSet };
}
export namespace TYZB01_on_off {
    const key_216: string[];
    export { key_216 as key };
    export function convertSet_171(entity: any, key: any, value: any, meta: any): Promise<{
        state?: undefined;
    } | {
        state: {
            state: any;
        };
    }>;
    export { convertSet_171 as convertSet };
    export function convertGet_167(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_167 as convertGet };
}
export namespace diyruz_geiger_config {
    const key_217: string[];
    export { key_217 as key };
    export function convertSet_172(entity: any, key: any, rawValue: any, meta: any): Promise<{
        state: {
            [x: number]: any;
        };
    }>;
    export { convertSet_172 as convertSet };
    export function convertGet_168(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_168 as convertGet };
}
export namespace diyruz_airsense_config {
    const key_218: string[];
    export { key_218 as key };
    export function convertSet_173(entity: any, key: any, rawValue: any, meta: any): Promise<{
        state: {
            [x: number]: any;
        };
    }>;
    export { convertSet_173 as convertSet };
    export function convertGet_169(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_169 as convertGet };
}
export namespace diyruz_zintercom_config {
    const key_219: string[];
    export { key_219 as key };
    export function convertSet_174(entity: any, key: any, rawValue: any, meta: any): Promise<{
        state: {
            [x: number]: any;
        };
    }>;
    export { convertSet_174 as convertSet };
    export function convertGet_170(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_170 as convertGet };
}
export namespace power_source {
    const key_220: string[];
    export { key_220 as key };
    export function convertGet_171(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_171 as convertGet };
}
export namespace ts0201_temperature_humidity_alarm {
    const key_221: string[];
    export { key_221 as key };
    export function convertSet_175(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_175 as convertSet };
}
export namespace heiman_ir_remote {
    const key_222: string[];
    export { key_222 as key };
    export function convertSet_176(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_176 as convertSet };
}
export namespace scene_store {
    const key_223: string[];
    export { key_223 as key };
    export function convertSet_177(entity: any, key: any, value: any, meta: any): Promise<{
        state: {};
    }>;
    export { convertSet_177 as convertSet };
}
export namespace scene_recall {
    const key_224: string[];
    export { key_224 as key };
    export function convertSet_178(entity: any, key: any, value: any, meta: any): Promise<{
        membersState: {};
        state?: undefined;
    } | {
        state: any;
        membersState?: undefined;
    }>;
    export { convertSet_178 as convertSet };
}
export namespace scene_add {
    const key_225: string[];
    export { key_225 as key };
    export function convertSet_179(entity: any, key: any, value: any, meta: any): Promise<{
        state: {};
    }>;
    export { convertSet_179 as convertSet };
}
export namespace scene_remove {
    const key_226: string[];
    export { key_226 as key };
    export function convertSet_180(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_180 as convertSet };
}
export namespace scene_remove_all {
    const key_227: string[];
    export { key_227 as key };
    export function convertSet_181(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_181 as convertSet };
}
export namespace TS0003_curtain_switch {
    const key_228: string[];
    export { key_228 as key };
    export function convertSet_182(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_182 as convertSet };
    export function convertGet_172(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_172 as convertGet };
}
export namespace ts0216_duration {
    const key_229: string[];
    export { key_229 as key };
    export function convertSet_183(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_183 as convertSet };
    export function convertGet_173(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_173 as convertGet };
}
export namespace ts0216_volume {
    const key_230: string[];
    export { key_230 as key };
    export function convertSet_184(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_184 as convertSet };
    export function convertGet_174(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_174 as convertGet };
}
export namespace ts0216_alarm {
    const key_231: string[];
    export { key_231 as key };
    export function convertSet_185(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_185 as convertSet };
}
export namespace tuya_cover_calibration {
    const key_232: string[];
    export { key_232 as key };
    export function convertSet_186(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            calibration: any;
        };
    }>;
    export { convertSet_186 as convertSet };
    export function convertGet_175(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_175 as convertGet };
}
export namespace tuya_cover_reversal {
    const key_233: string[];
    export { key_233 as key };
    export function convertSet_187(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            motor_reversal: any;
        };
    }>;
    export { convertSet_187 as convertSet };
    export function convertGet_176(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_176 as convertGet };
}
export namespace moes_cover_calibration {
    const key_234: string[];
    export { key_234 as key };
    export function convertSet_188(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            calibration_time: any;
        };
    }>;
    export { convertSet_188 as convertSet };
    export function convertGet_177(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_177 as convertGet };
}
export namespace ZM35HQ_attr {
    const key_235: string[];
    export { key_235 as key };
    export function convertSet_189(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_189 as convertSet };
    export function convertGet_178(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_178 as convertGet };
}
export namespace TS0210_sensitivity {
    const key_236: string[];
    export { key_236 as key };
    export function convertSet_190(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            sensitivity: any;
        };
    }>;
    export { convertSet_190 as convertSet };
}
export namespace viessmann_window_open {
    const key_237: string[];
    export { key_237 as key };
    export function convertGet_179(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_179 as convertGet };
}
export namespace viessmann_window_open_force {
    const key_238: string[];
    export { key_238 as key };
    export function convertSet_191(entity: any, key: any, value: any, meta: any): Promise<{
        readAfterWriteTime: number;
        state: {
            window_open_force: boolean;
        };
    }>;
    export { convertSet_191 as convertSet };
    export function convertGet_180(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_180 as convertGet };
}
export namespace viessmann_assembly_mode {
    const key_239: string[];
    export { key_239 as key };
    export function convertGet_181(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_181 as convertGet };
}
export namespace dawondns_only_off {
    const key_240: string[];
    export { key_240 as key };
    export function convertSet_192(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_192 as convertSet };
    export function convertGet_182(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_182 as convertGet };
}
export namespace idlock_master_pin_mode {
    const key_241: string[];
    export { key_241 as key };
    export function convertSet_193(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            master_pin_mode: any;
        };
    }>;
    export { convertSet_193 as convertSet };
    export function convertGet_183(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_183 as convertGet };
}
export namespace idlock_rfid_enable {
    const key_242: string[];
    export { key_242 as key };
    export function convertSet_194(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            rfid_enable: any;
        };
    }>;
    export { convertSet_194 as convertSet };
    export function convertGet_184(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_184 as convertGet };
}
export namespace idlock_service_mode {
    const key_243: string[];
    export { key_243 as key };
    export function convertSet_195(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            service_mode: any;
        };
    }>;
    export { convertSet_195 as convertSet };
    export function convertGet_185(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_185 as convertGet };
}
export namespace idlock_lock_mode {
    const key_244: string[];
    export { key_244 as key };
    export function convertSet_196(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            lock_mode: any;
        };
    }>;
    export { convertSet_196 as convertSet };
    export function convertGet_186(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_186 as convertGet };
}
export namespace idlock_relock_enabled {
    const key_245: string[];
    export { key_245 as key };
    export function convertSet_197(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            relock_enabled: any;
        };
    }>;
    export { convertSet_197 as convertSet };
    export function convertGet_187(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_187 as convertGet };
}
export namespace schneider_pilot_mode {
    const key_246: string[];
    export { key_246 as key };
    export function convertSet_198(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            schneider_pilot_mode: any;
        };
    }>;
    export { convertSet_198 as convertSet };
    export function convertGet_188(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_188 as convertGet };
}
export namespace schneider_dimmer_mode {
    const key_247: string[];
    export { key_247 as key };
    export function convertSet_199(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            dimmer_mode: any;
        };
    }>;
    export { convertSet_199 as convertSet };
    export function convertGet_189(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_189 as convertGet };
}
export namespace wiser_dimmer_mode {
    const key_248: string[];
    export { key_248 as key };
    export function convertSet_200(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            dimmer_mode: any;
        };
    }>;
    export { convertSet_200 as convertSet };
    export function convertGet_190(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_190 as convertGet };
}
export namespace schneider_temperature_measured_value {
    const key_249: string[];
    export { key_249 as key };
    export function convertSet_201(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_201 as convertSet };
}
export namespace schneider_thermostat_system_mode {
    const key_250: string[];
    export { key_250 as key };
    export function convertSet_202(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            system_mode: any;
        };
    }>;
    export { convertSet_202 as convertSet };
}
export namespace schneider_thermostat_occupied_heating_setpoint {
    const key_251: string[];
    export { key_251 as key };
    export function convertSet_203(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            occupied_heating_setpoint: any;
        };
    }>;
    export { convertSet_203 as convertSet };
}
export namespace schneider_thermostat_control_sequence_of_operation {
    const key_252: string[];
    export { key_252 as key };
    export function convertSet_204(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            control_sequence_of_operation: any;
        };
    }>;
    export { convertSet_204 as convertSet };
}
export namespace schneider_thermostat_pi_heating_demand {
    const key_253: string[];
    export { key_253 as key };
    export function convertSet_205(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            pi_heating_demand: any;
        };
    }>;
    export { convertSet_205 as convertSet };
}
export namespace schneider_thermostat_keypad_lockout {
    const key_254: string[];
    export { key_254 as key };
    export function convertSet_206(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            keypad_lockout: any;
        };
    }>;
    export { convertSet_206 as convertSet };
}
export namespace ZNCJMB14LM {
    const key_255: string[];
    export { key_255 as key };
    export function convertSet_207(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            theme: any;
            standby_enabled?: undefined;
            beep_volume?: undefined;
            lcd_brightness?: undefined;
            language?: undefined;
            screen_saver_style?: undefined;
            standby_time?: undefined;
            font_size?: undefined;
            lcd_auto_brightness_enabled?: undefined;
            homepage?: undefined;
            screen_saver_enabled?: undefined;
            standby_lcd_brightness?: undefined;
            available_switches?: undefined;
        };
    } | {
        state: {
            standby_enabled: any;
            theme?: undefined;
            beep_volume?: undefined;
            lcd_brightness?: undefined;
            language?: undefined;
            screen_saver_style?: undefined;
            standby_time?: undefined;
            font_size?: undefined;
            lcd_auto_brightness_enabled?: undefined;
            homepage?: undefined;
            screen_saver_enabled?: undefined;
            standby_lcd_brightness?: undefined;
            available_switches?: undefined;
        };
    } | {
        state: {
            beep_volume: any;
            theme?: undefined;
            standby_enabled?: undefined;
            lcd_brightness?: undefined;
            language?: undefined;
            screen_saver_style?: undefined;
            standby_time?: undefined;
            font_size?: undefined;
            lcd_auto_brightness_enabled?: undefined;
            homepage?: undefined;
            screen_saver_enabled?: undefined;
            standby_lcd_brightness?: undefined;
            available_switches?: undefined;
        };
    } | {
        state: {
            lcd_brightness: any;
            theme?: undefined;
            standby_enabled?: undefined;
            beep_volume?: undefined;
            language?: undefined;
            screen_saver_style?: undefined;
            standby_time?: undefined;
            font_size?: undefined;
            lcd_auto_brightness_enabled?: undefined;
            homepage?: undefined;
            screen_saver_enabled?: undefined;
            standby_lcd_brightness?: undefined;
            available_switches?: undefined;
        };
    } | {
        state: {
            language: any;
            theme?: undefined;
            standby_enabled?: undefined;
            beep_volume?: undefined;
            lcd_brightness?: undefined;
            screen_saver_style?: undefined;
            standby_time?: undefined;
            font_size?: undefined;
            lcd_auto_brightness_enabled?: undefined;
            homepage?: undefined;
            screen_saver_enabled?: undefined;
            standby_lcd_brightness?: undefined;
            available_switches?: undefined;
        };
    } | {
        state: {
            screen_saver_style: any;
            theme?: undefined;
            standby_enabled?: undefined;
            beep_volume?: undefined;
            lcd_brightness?: undefined;
            language?: undefined;
            standby_time?: undefined;
            font_size?: undefined;
            lcd_auto_brightness_enabled?: undefined;
            homepage?: undefined;
            screen_saver_enabled?: undefined;
            standby_lcd_brightness?: undefined;
            available_switches?: undefined;
        };
    } | {
        state: {
            standby_time: any;
            theme?: undefined;
            standby_enabled?: undefined;
            beep_volume?: undefined;
            lcd_brightness?: undefined;
            language?: undefined;
            screen_saver_style?: undefined;
            font_size?: undefined;
            lcd_auto_brightness_enabled?: undefined;
            homepage?: undefined;
            screen_saver_enabled?: undefined;
            standby_lcd_brightness?: undefined;
            available_switches?: undefined;
        };
    } | {
        state: {
            font_size: any;
            theme?: undefined;
            standby_enabled?: undefined;
            beep_volume?: undefined;
            lcd_brightness?: undefined;
            language?: undefined;
            screen_saver_style?: undefined;
            standby_time?: undefined;
            lcd_auto_brightness_enabled?: undefined;
            homepage?: undefined;
            screen_saver_enabled?: undefined;
            standby_lcd_brightness?: undefined;
            available_switches?: undefined;
        };
    } | {
        state: {
            lcd_auto_brightness_enabled: any;
            theme?: undefined;
            standby_enabled?: undefined;
            beep_volume?: undefined;
            lcd_brightness?: undefined;
            language?: undefined;
            screen_saver_style?: undefined;
            standby_time?: undefined;
            font_size?: undefined;
            homepage?: undefined;
            screen_saver_enabled?: undefined;
            standby_lcd_brightness?: undefined;
            available_switches?: undefined;
        };
    } | {
        state: {
            homepage: any;
            theme?: undefined;
            standby_enabled?: undefined;
            beep_volume?: undefined;
            lcd_brightness?: undefined;
            language?: undefined;
            screen_saver_style?: undefined;
            standby_time?: undefined;
            font_size?: undefined;
            lcd_auto_brightness_enabled?: undefined;
            screen_saver_enabled?: undefined;
            standby_lcd_brightness?: undefined;
            available_switches?: undefined;
        };
    } | {
        state: {
            screen_saver_enabled: any;
            theme?: undefined;
            standby_enabled?: undefined;
            beep_volume?: undefined;
            lcd_brightness?: undefined;
            language?: undefined;
            screen_saver_style?: undefined;
            standby_time?: undefined;
            font_size?: undefined;
            lcd_auto_brightness_enabled?: undefined;
            homepage?: undefined;
            standby_lcd_brightness?: undefined;
            available_switches?: undefined;
        };
    } | {
        state: {
            standby_lcd_brightness: any;
            theme?: undefined;
            standby_enabled?: undefined;
            beep_volume?: undefined;
            lcd_brightness?: undefined;
            language?: undefined;
            screen_saver_style?: undefined;
            standby_time?: undefined;
            font_size?: undefined;
            lcd_auto_brightness_enabled?: undefined;
            homepage?: undefined;
            screen_saver_enabled?: undefined;
            available_switches?: undefined;
        };
    } | {
        state: {
            available_switches: any;
            theme?: undefined;
            standby_enabled?: undefined;
            beep_volume?: undefined;
            lcd_brightness?: undefined;
            language?: undefined;
            screen_saver_style?: undefined;
            standby_time?: undefined;
            font_size?: undefined;
            lcd_auto_brightness_enabled?: undefined;
            homepage?: undefined;
            screen_saver_enabled?: undefined;
            standby_lcd_brightness?: undefined;
        };
    } | {
        state: {};
    }>;
    export { convertSet_207 as convertSet };
}
export namespace ZNCLBL01LM_hooks_lock {
    const key_256: string[];
    export { key_256 as key };
    export function convertSet_208(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            [x: number]: any;
        };
    }>;
    export { convertSet_208 as convertSet };
}
export namespace ZNCLBL01LM_hooks_state {
    const key_257: string[];
    export { key_257 as key };
    export function convertGet_191(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_191 as convertGet };
}
export namespace ZNCLBL01LM_hand_open {
    const key_258: string[];
    export { key_258 as key };
    export function convertSet_209(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_209 as convertSet };
    export function convertGet_192(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_192 as convertGet };
}
export namespace ZNCLBL01LM_limits_calibration {
    const key_259: string[];
    export { key_259 as key };
    export function convertSet_210(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_210 as convertSet };
}
export namespace wiser_fip_setting {
    const key_260: string[];
    export { key_260 as key };
    export function convertSet_211(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            fip_setting: any;
        };
    }>;
    export { convertSet_211 as convertSet };
    export function convertGet_193(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_193 as convertGet };
}
export namespace wiser_hact_config {
    const key_261: string[];
    export { key_261 as key };
    export function convertSet_212(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            hact_config: any;
        };
    }>;
    export { convertSet_212 as convertSet };
    export function convertGet_194(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_194 as convertGet };
}
export namespace wiser_zone_mode {
    const key_262: string[];
    export { key_262 as key };
    export function convertSet_213(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            zone_mode: any;
        };
    }>;
    export { convertSet_213 as convertSet };
    export function convertGet_195(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_195 as convertGet };
}
export namespace wiser_vact_calibrate_valve {
    const key_263: string[];
    export { key_263 as key };
    export function convertSet_214(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            calibrate_valve: any;
        };
    }>;
    export { convertSet_214 as convertSet };
}
export namespace wiser_sed_zone_mode {
    const key_264: string[];
    export { key_264 as key };
    export function convertSet_215(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            zone_mode: any;
        };
    }>;
    export { convertSet_215 as convertSet };
}
export namespace wiser_sed_occupied_heating_setpoint {
    const key_265: string[];
    export { key_265 as key };
    export function convertSet_216(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            occupied_heating_setpoint: any;
        };
    }>;
    export { convertSet_216 as convertSet };
}
export namespace wiser_sed_thermostat_local_temperature_calibration {
    const key_266: string[];
    export { key_266 as key };
    export function convertSet_217(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            local_temperature_calibration: any;
        };
    }>;
    export { convertSet_217 as convertSet };
}
export namespace wiser_sed_thermostat_keypad_lockout {
    const key_267: string[];
    export { key_267 as key };
    export function convertSet_218(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            keypad_lockout: any;
        };
    }>;
    export { convertSet_218 as convertSet };
}
export namespace sihas_set_people {
    const key_268: string[];
    export { key_268 as key };
    export function convertSet_219(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_219 as convertSet };
    export function convertGet_196(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_196 as convertGet };
}
export namespace tuya_operation_mode {
    const key_269: string[];
    export { key_269 as key };
    export function convertSet_220(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            operation_mode: any;
        };
    }>;
    export { convertSet_220 as convertSet };
    export function convertGet_197(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_197 as convertGet };
}
export namespace xiaomi_switch_click_mode {
    const key_270: string[];
    export { key_270 as key };
    export function convertSet_221(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            click_mode: any;
        };
    }>;
    export { convertSet_221 as convertSet };
    export function convertGet_198(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_198 as convertGet };
}
export namespace led_on_motion {
    const key_271: string[];
    export { key_271 as key };
    export function convertSet_222(entity: any, key: any, value: any, meta: any): Promise<{
        state: {
            led_on_motion: any;
        };
    }>;
    export { convertSet_222 as convertSet };
    export function convertGet_199(entity: any, key: any, meta: any): Promise<void>;
    export { convertGet_199 as convertGet };
}
export namespace ignore_transition {
    const key_272: string[];
    export { key_272 as key };
    export const attr: any[];
    export function convertSet_223(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_223 as convertSet };
}
export namespace ignore_rate {
    const key_273: string[];
    export { key_273 as key };
    const attr_1: any[];
    export { attr_1 as attr };
    export function convertSet_224(entity: any, key: any, value: any, meta: any): Promise<void>;
    export { convertSet_224 as convertSet };
}
export function __clearStore__(): void;
//# sourceMappingURL=toZigbee.d.ts.map