declare const _exports: {
    fingerprint: {
        modelID: string;
        manufacturerName: string;
    }[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => any;
    } | FromZigbeeConverter)[];
    toZigbee: ToZigbeeConverter[];
    exposes: exposes.Cover[];
}[];
export = _exports;
import exposes = require("../lib/exposes");
//# sourceMappingURL=novo.d.ts.map