declare const _exports: ({
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    options: any[];
    exposes: (device: any, options: any) => (exposes.Numeric | exposes.Enum | exposes.Switch | exposes.Light)[];
    fromZigbee: {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => any;
    }[];
    toZigbee: ({
        key: string[];
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    } | {
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
            state: {
                brightness: any;
                state: string;
            };
        }>;
    } | {
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<void>;
    })[];
    meta: {
        multiEndpoint: boolean;
    };
    endpoint: (device: any) => {
        l1: number;
        l2: number;
        l3: number;
    };
    configure: (device: any, coordinatorEndpoint: any, logger: any, options: any) => Promise<void>;
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    options: any[];
    exposes: (device: any, options: any) => any[];
    fromZigbee: {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => any;
    }[];
    toZigbee: ({
        key: string[];
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    } | {
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
            state: {
                brightness: any;
                state: string;
            };
        }>;
    } | {
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<void>;
    })[];
    meta: {
        multiEndpoint: boolean;
    };
    endpoint: (device: any) => {
        l1: number;
        l2: number;
        l3: number;
        l4: number;
        l5: number;
        l6: number;
        l7: number;
    };
    configure: (device: any, coordinatorEndpoint: any, logger: any, options: any) => Promise<void>;
})[];
export = _exports;
import exposes = require("../lib/exposes");
//# sourceMappingURL=siglis.d.ts.map