import * as Models from "../../../models";
/**
 * Checks if two network options models match.
 *
 * @param opts1 First network options struct to check.
 * @param opts2 Second network options struct to check.
 */
export declare const compareNetworkOptions: (opts1: Models.NetworkOptions, opts2: Models.NetworkOptions, lenientExtendedPanIdMatching?: boolean) => boolean;
//# sourceMappingURL=network-options.d.ts.map