export function getImageMeta(current: any, logger: any, device: any): Promise<{
    fileVersion: any;
    fileSize: any;
    url: any;
    sha512: any;
    force: any;
}>;
/**
 * Interface implementation
 */
export function isUpdateAvailable(device: any, logger: any, requestPayload?: any): Promise<any>;
export function updateToLatest(device: any, logger: any, onProgress: any): Promise<any>;
export declare function useIndexOverride(indexFileName: any): void;
export declare function setDataDir(dir: any): void;
//# sourceMappingURL=zigbeeOTA.d.ts.map