const fz = require('../converters/fromZigbee');
const tz = require('../converters/toZigbee');
const exposes = require('../lib/exposes');
const reporting = require('../lib/reporting');
const e = exposes.presets;
module.exports = [
    {
        zigbeeModel: ['E-Wand'],
        model: 'CP180335E-01',
        vendor: 'Current Products Corp',
        description: 'Gen. 2 hybrid E-Wand',
        fromZigbee: [fz.cover_position_tilt, fz.battery],
        toZigbee: [tz.cover_state, tz.cover_position_tilt],
        meta: { coverStateFromTilt: true },
        configure: async (device, coordinatorEndpoint, logger) => {
            const endpoint = device.getEndpoint(1);
            await reporting.bind(endpoint, coordinatorEndpoint, ['genPowerCfg', 'closuresWindowCovering']);
            await reporting.batteryPercentageRemaining(endpoint);
            await reporting.currentPositionTiltPercentage(endpoint);
        },
        exposes: [e.battery(), e.cover_tilt()],
    },
];
//# sourceMappingURL=current_products_corp.js.map