"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.EZSPAdapter = void 0;
/* istanbul ignore file */
/* eslint-disable */
const ezspAdapter_1 = __importDefault(require("./ezspAdapter"));
exports.EZSPAdapter = ezspAdapter_1.default;
//# sourceMappingURL=index.js.map