declare const _exports: {
    zigbeeModel: string[];
    fingerprint: ({
        modelID: string;
        manufacturerName: string;
    } | {
        modelId: string;
        manufacturerName: string;
    })[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => any;
    } | FromZigbeeConverter)[];
    meta: {
        tuyaThermostatSystemMode: KeyValue;
        tuyaThermostatPreset: KeyValue;
        tuyaThermostatPresetToSystemMode: KeyValue;
    };
    toZigbee: ToZigbeeConverter[];
    whiteLabel: {
        vendor: string;
        description: string;
        model: string;
    }[];
    exposes: any[];
}[];
export = _exports;
//# sourceMappingURL=siterwell.d.ts.map