export function hasValue(entity: any, key: any): any;
export function getValue(entity: any, key: any, default_?: any): any;
export function putValue(entity: any, key: any, value: any): void;
export function clearValue(entity: any, key: any): void;
export function clear(): void;
//# sourceMappingURL=store.d.ts.map