const extend = require('../lib/extend');
module.exports = [
    {
        zigbeeModel: ['Bankamp Dimm-Leuchte'],
        model: '2189/1-xx',
        vendor: 'Bankamp',
        description: 'Ceiling light (e.g. Grazia, Grand)',
        extend: extend.light_onoff_brightness(),
    },
];
//# sourceMappingURL=bankamp.js.map