declare const _exports: {
    fingerprint: {
        type: string;
        manufacturerID: number;
        endpoints: {
            ID: number;
            profileID: number;
            deviceID: number;
            inputClusters: undefined[];
            outputClusters: undefined[];
        }[];
    }[];
    model: string;
    description: string;
    vendor: string;
    fromZigbee: undefined[];
    toZigbee: undefined[];
    exposes: undefined[];
}[];
export = _exports;
//# sourceMappingURL=digi.d.ts.map