declare const _exports: {
    fingerprint: {
        modelID: string;
        manufacturerName: string;
    }[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        exposes: any;
        fromZigbee: {
            cluster: string;
            type: string[];
            convert: (model: any, msg: any, publish: any, options: any, meta: any) => any;
        }[];
        toZigbee: {
            key: string[];
            convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
                state?: undefined;
            } | {
                state: {
                    state: any;
                };
            }>;
            convertGet: (entity: any, key: any, meta: any) => Promise<void>;
        }[];
    };
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
}[];
export = _exports;
//# sourceMappingURL=girier.d.ts.map