"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EzspNetworkScanType = exports.EmberApsOption = exports.EmberBindingType = exports.EmberMacPassthroughType = exports.EmberOutgoingMessageType = exports.EmberIncomingMessageType = exports.EmberNetworkStatus = exports.EmberNodeType = exports.EmberEventUnits = exports.EmberStatus = exports.EzspStatus = exports.EzspMfgTokenId = exports.EzspDecisionId = exports.EzspPolicyId = exports.EmberConfigTxPowerMode = exports.EzspEndpointFlags = exports.EzspExtendedValueId = exports.EzspValueId = exports.EzspConfigId = exports.Bool = exports.SecureEzspSessionId = exports.SecureEzspRandomNumber = exports.EmberGpKeyType = exports.EmberGpSecurityLevel = exports.SecureEzspSecurityLevel = exports.SecureEzspSecurityType = exports.EmberLibraryStatus = exports.EmberEUI64 = exports.EmberMulticastId = exports.EmberPanId = exports.EmberNodeId = exports.EmberRf4ceApplicationCapabilities = exports.EmberRf4ceNodeCapabilities = exports.EmberRf4ceTxOption = exports.NcpResetCode = exports.Bytes = exports.WordList = exports.fixed_list = exports.LVList = exports.list = exports.LVBytes = exports.uint64_t = exports.uint32_t = exports.uint24_t = exports.uint16_t = exports.uint8_t = exports.uint_t = exports.int8s = exports.serialize = exports.deserialize = void 0;
exports.EmberRf4ceApplicationInfo = exports.EmberRf4ceVendorInfo = exports.EmberTokTypeStackZllSecurity = exports.EmberTokTypeStackZllData = exports.EmberZllAddressAssignment = exports.EmberZllDeviceInfoRecord = exports.EmberZllInitialSecurityState = exports.EmberZllNetwork = exports.EmberZllSecurityAlgorithmData = exports.EmberNetworkInitStruct = exports.EmberKeyStruct = exports.EmberCurrentSecurityState = exports.EmberInitialSecurityState = exports.EmberRouteTableEntry = exports.EmberNeighborTableEntry = exports.EmberAesMmoHashContext = exports.EmberMessageDigest = exports.EmberSignature283k1Data = exports.EmberPrivateKey283k1Data = exports.EmberPublicKey283k1Data = exports.EmberCertificate283k1Data = exports.EmberSignatureData = exports.EmberSmacData = exports.EmberPrivateKeyData = exports.EmberPublicKeyData = exports.EmberCertificateData = exports.EmberKeyData = exports.EmberMulticastTableEntry = exports.EmberBindingTableEntry = exports.EmberApsFrame = exports.EmberZigbeeNetwork = exports.EmberNetworkParameters = exports.EzspStruct = exports.EmberZDOCmd = exports.EmberNetworkInitBitmask = exports.EzspSourceRouteOverheadInformation = exports.EzspZllNetworkOperation = exports.EmberZllKeyIndex = exports.EmberZllState = exports.EmberConcentratorType = exports.EmberZdoConfigurationFlags = exports.EmberJoinMethod = exports.EmberCounterType = exports.EmberKeyStatus = exports.EmberDeviceUpdate = exports.EmberKeyStructBitmask = exports.EmberKeyType = exports.EmberCurrentSecurityBitmask = exports.EmberInitialSecurityBitmask = exports.EmberJoinDecision = void 0;
exports.EmberRoutingTableEntry = exports.EmberRoutingTable = exports.EmberNeighbors = exports.EmberMultiAddress = exports.EmberSimpleDescriptor = exports.EmberNodeDescriptor = exports.EmberGpSinkListEntry = exports.EmberGpAddress = exports.EmberRf4cePairingTableEntry = void 0;
/* istanbul ignore file */
/* eslint-disable @typescript-eslint/explicit-module-boundary-types */
const basic_1 = require("./basic");
Object.defineProperty(exports, "int8s", { enumerable: true, get: function () { return basic_1.int8s; } });
Object.defineProperty(exports, "uint_t", { enumerable: true, get: function () { return basic_1.uint_t; } });
Object.defineProperty(exports, "uint8_t", { enumerable: true, get: function () { return basic_1.uint8_t; } });
Object.defineProperty(exports, "uint16_t", { enumerable: true, get: function () { return basic_1.uint16_t; } });
Object.defineProperty(exports, "uint24_t", { enumerable: true, get: function () { return basic_1.uint24_t; } });
Object.defineProperty(exports, "uint32_t", { enumerable: true, get: function () { return basic_1.uint32_t; } });
Object.defineProperty(exports, "uint64_t", { enumerable: true, get: function () { return basic_1.uint64_t; } });
Object.defineProperty(exports, "LVBytes", { enumerable: true, get: function () { return basic_1.LVBytes; } });
Object.defineProperty(exports, "list", { enumerable: true, get: function () { return basic_1.list; } });
Object.defineProperty(exports, "LVList", { enumerable: true, get: function () { return basic_1.LVList; } });
Object.defineProperty(exports, "fixed_list", { enumerable: true, get: function () { return basic_1.fixed_list; } });
Object.defineProperty(exports, "WordList", { enumerable: true, get: function () { return basic_1.WordList; } });
Object.defineProperty(exports, "Bytes", { enumerable: true, get: function () { return basic_1.Bytes; } });
const named_1 = require("./named");
Object.defineProperty(exports, "NcpResetCode", { enumerable: true, get: function () { return named_1.NcpResetCode; } });
Object.defineProperty(exports, "EmberRf4ceTxOption", { enumerable: true, get: function () { return named_1.EmberRf4ceTxOption; } });
Object.defineProperty(exports, "EmberRf4ceNodeCapabilities", { enumerable: true, get: function () { return named_1.EmberRf4ceNodeCapabilities; } });
Object.defineProperty(exports, "EmberRf4ceApplicationCapabilities", { enumerable: true, get: function () { return named_1.EmberRf4ceApplicationCapabilities; } });
Object.defineProperty(exports, "EmberNodeId", { enumerable: true, get: function () { return named_1.EmberNodeId; } });
Object.defineProperty(exports, "EmberPanId", { enumerable: true, get: function () { return named_1.EmberPanId; } });
Object.defineProperty(exports, "EmberMulticastId", { enumerable: true, get: function () { return named_1.EmberMulticastId; } });
Object.defineProperty(exports, "EmberEUI64", { enumerable: true, get: function () { return named_1.EmberEUI64; } });
Object.defineProperty(exports, "EmberLibraryStatus", { enumerable: true, get: function () { return named_1.EmberLibraryStatus; } });
Object.defineProperty(exports, "SecureEzspSecurityType", { enumerable: true, get: function () { return named_1.SecureEzspSecurityType; } });
Object.defineProperty(exports, "SecureEzspSecurityLevel", { enumerable: true, get: function () { return named_1.SecureEzspSecurityLevel; } });
Object.defineProperty(exports, "EmberGpSecurityLevel", { enumerable: true, get: function () { return named_1.EmberGpSecurityLevel; } });
Object.defineProperty(exports, "EmberGpKeyType", { enumerable: true, get: function () { return named_1.EmberGpKeyType; } });
Object.defineProperty(exports, "SecureEzspRandomNumber", { enumerable: true, get: function () { return named_1.SecureEzspRandomNumber; } });
Object.defineProperty(exports, "SecureEzspSessionId", { enumerable: true, get: function () { return named_1.SecureEzspSessionId; } });
Object.defineProperty(exports, "Bool", { enumerable: true, get: function () { return named_1.Bool; } });
Object.defineProperty(exports, "EzspConfigId", { enumerable: true, get: function () { return named_1.EzspConfigId; } });
Object.defineProperty(exports, "EzspValueId", { enumerable: true, get: function () { return named_1.EzspValueId; } });
Object.defineProperty(exports, "EzspExtendedValueId", { enumerable: true, get: function () { return named_1.EzspExtendedValueId; } });
Object.defineProperty(exports, "EzspEndpointFlags", { enumerable: true, get: function () { return named_1.EzspEndpointFlags; } });
Object.defineProperty(exports, "EmberConfigTxPowerMode", { enumerable: true, get: function () { return named_1.EmberConfigTxPowerMode; } });
Object.defineProperty(exports, "EzspPolicyId", { enumerable: true, get: function () { return named_1.EzspPolicyId; } });
Object.defineProperty(exports, "EzspDecisionId", { enumerable: true, get: function () { return named_1.EzspDecisionId; } });
Object.defineProperty(exports, "EzspMfgTokenId", { enumerable: true, get: function () { return named_1.EzspMfgTokenId; } });
Object.defineProperty(exports, "EzspStatus", { enumerable: true, get: function () { return named_1.EzspStatus; } });
Object.defineProperty(exports, "EmberStatus", { enumerable: true, get: function () { return named_1.EmberStatus; } });
Object.defineProperty(exports, "EmberEventUnits", { enumerable: true, get: function () { return named_1.EmberEventUnits; } });
Object.defineProperty(exports, "EmberNodeType", { enumerable: true, get: function () { return named_1.EmberNodeType; } });
Object.defineProperty(exports, "EmberNetworkStatus", { enumerable: true, get: function () { return named_1.EmberNetworkStatus; } });
Object.defineProperty(exports, "EmberIncomingMessageType", { enumerable: true, get: function () { return named_1.EmberIncomingMessageType; } });
Object.defineProperty(exports, "EmberOutgoingMessageType", { enumerable: true, get: function () { return named_1.EmberOutgoingMessageType; } });
Object.defineProperty(exports, "EmberMacPassthroughType", { enumerable: true, get: function () { return named_1.EmberMacPassthroughType; } });
Object.defineProperty(exports, "EmberBindingType", { enumerable: true, get: function () { return named_1.EmberBindingType; } });
Object.defineProperty(exports, "EmberApsOption", { enumerable: true, get: function () { return named_1.EmberApsOption; } });
Object.defineProperty(exports, "EzspNetworkScanType", { enumerable: true, get: function () { return named_1.EzspNetworkScanType; } });
Object.defineProperty(exports, "EmberJoinDecision", { enumerable: true, get: function () { return named_1.EmberJoinDecision; } });
Object.defineProperty(exports, "EmberInitialSecurityBitmask", { enumerable: true, get: function () { return named_1.EmberInitialSecurityBitmask; } });
Object.defineProperty(exports, "EmberCurrentSecurityBitmask", { enumerable: true, get: function () { return named_1.EmberCurrentSecurityBitmask; } });
Object.defineProperty(exports, "EmberKeyType", { enumerable: true, get: function () { return named_1.EmberKeyType; } });
Object.defineProperty(exports, "EmberKeyStructBitmask", { enumerable: true, get: function () { return named_1.EmberKeyStructBitmask; } });
Object.defineProperty(exports, "EmberDeviceUpdate", { enumerable: true, get: function () { return named_1.EmberDeviceUpdate; } });
Object.defineProperty(exports, "EmberKeyStatus", { enumerable: true, get: function () { return named_1.EmberKeyStatus; } });
Object.defineProperty(exports, "EmberCounterType", { enumerable: true, get: function () { return named_1.EmberCounterType; } });
Object.defineProperty(exports, "EmberJoinMethod", { enumerable: true, get: function () { return named_1.EmberJoinMethod; } });
Object.defineProperty(exports, "EmberZdoConfigurationFlags", { enumerable: true, get: function () { return named_1.EmberZdoConfigurationFlags; } });
Object.defineProperty(exports, "EmberConcentratorType", { enumerable: true, get: function () { return named_1.EmberConcentratorType; } });
Object.defineProperty(exports, "EmberZllState", { enumerable: true, get: function () { return named_1.EmberZllState; } });
Object.defineProperty(exports, "EmberZllKeyIndex", { enumerable: true, get: function () { return named_1.EmberZllKeyIndex; } });
Object.defineProperty(exports, "EzspZllNetworkOperation", { enumerable: true, get: function () { return named_1.EzspZllNetworkOperation; } });
Object.defineProperty(exports, "EzspSourceRouteOverheadInformation", { enumerable: true, get: function () { return named_1.EzspSourceRouteOverheadInformation; } });
Object.defineProperty(exports, "EmberNetworkInitBitmask", { enumerable: true, get: function () { return named_1.EmberNetworkInitBitmask; } });
Object.defineProperty(exports, "EmberZDOCmd", { enumerable: true, get: function () { return named_1.EmberZDOCmd; } });
const struct_1 = require("./struct");
Object.defineProperty(exports, "EzspStruct", { enumerable: true, get: function () { return struct_1.EzspStruct; } });
Object.defineProperty(exports, "EmberNetworkParameters", { enumerable: true, get: function () { return struct_1.EmberNetworkParameters; } });
Object.defineProperty(exports, "EmberZigbeeNetwork", { enumerable: true, get: function () { return struct_1.EmberZigbeeNetwork; } });
Object.defineProperty(exports, "EmberApsFrame", { enumerable: true, get: function () { return struct_1.EmberApsFrame; } });
Object.defineProperty(exports, "EmberBindingTableEntry", { enumerable: true, get: function () { return struct_1.EmberBindingTableEntry; } });
Object.defineProperty(exports, "EmberMulticastTableEntry", { enumerable: true, get: function () { return struct_1.EmberMulticastTableEntry; } });
Object.defineProperty(exports, "EmberKeyData", { enumerable: true, get: function () { return struct_1.EmberKeyData; } });
Object.defineProperty(exports, "EmberCertificateData", { enumerable: true, get: function () { return struct_1.EmberCertificateData; } });
Object.defineProperty(exports, "EmberPublicKeyData", { enumerable: true, get: function () { return struct_1.EmberPublicKeyData; } });
Object.defineProperty(exports, "EmberPrivateKeyData", { enumerable: true, get: function () { return struct_1.EmberPrivateKeyData; } });
Object.defineProperty(exports, "EmberSmacData", { enumerable: true, get: function () { return struct_1.EmberSmacData; } });
Object.defineProperty(exports, "EmberSignatureData", { enumerable: true, get: function () { return struct_1.EmberSignatureData; } });
Object.defineProperty(exports, "EmberCertificate283k1Data", { enumerable: true, get: function () { return struct_1.EmberCertificate283k1Data; } });
Object.defineProperty(exports, "EmberPublicKey283k1Data", { enumerable: true, get: function () { return struct_1.EmberPublicKey283k1Data; } });
Object.defineProperty(exports, "EmberPrivateKey283k1Data", { enumerable: true, get: function () { return struct_1.EmberPrivateKey283k1Data; } });
Object.defineProperty(exports, "EmberSignature283k1Data", { enumerable: true, get: function () { return struct_1.EmberSignature283k1Data; } });
Object.defineProperty(exports, "EmberMessageDigest", { enumerable: true, get: function () { return struct_1.EmberMessageDigest; } });
Object.defineProperty(exports, "EmberAesMmoHashContext", { enumerable: true, get: function () { return struct_1.EmberAesMmoHashContext; } });
Object.defineProperty(exports, "EmberNeighborTableEntry", { enumerable: true, get: function () { return struct_1.EmberNeighborTableEntry; } });
Object.defineProperty(exports, "EmberRouteTableEntry", { enumerable: true, get: function () { return struct_1.EmberRouteTableEntry; } });
Object.defineProperty(exports, "EmberInitialSecurityState", { enumerable: true, get: function () { return struct_1.EmberInitialSecurityState; } });
Object.defineProperty(exports, "EmberCurrentSecurityState", { enumerable: true, get: function () { return struct_1.EmberCurrentSecurityState; } });
Object.defineProperty(exports, "EmberKeyStruct", { enumerable: true, get: function () { return struct_1.EmberKeyStruct; } });
Object.defineProperty(exports, "EmberNetworkInitStruct", { enumerable: true, get: function () { return struct_1.EmberNetworkInitStruct; } });
Object.defineProperty(exports, "EmberZllSecurityAlgorithmData", { enumerable: true, get: function () { return struct_1.EmberZllSecurityAlgorithmData; } });
Object.defineProperty(exports, "EmberZllNetwork", { enumerable: true, get: function () { return struct_1.EmberZllNetwork; } });
Object.defineProperty(exports, "EmberZllInitialSecurityState", { enumerable: true, get: function () { return struct_1.EmberZllInitialSecurityState; } });
Object.defineProperty(exports, "EmberZllDeviceInfoRecord", { enumerable: true, get: function () { return struct_1.EmberZllDeviceInfoRecord; } });
Object.defineProperty(exports, "EmberZllAddressAssignment", { enumerable: true, get: function () { return struct_1.EmberZllAddressAssignment; } });
Object.defineProperty(exports, "EmberTokTypeStackZllData", { enumerable: true, get: function () { return struct_1.EmberTokTypeStackZllData; } });
Object.defineProperty(exports, "EmberTokTypeStackZllSecurity", { enumerable: true, get: function () { return struct_1.EmberTokTypeStackZllSecurity; } });
Object.defineProperty(exports, "EmberRf4ceVendorInfo", { enumerable: true, get: function () { return struct_1.EmberRf4ceVendorInfo; } });
Object.defineProperty(exports, "EmberRf4ceApplicationInfo", { enumerable: true, get: function () { return struct_1.EmberRf4ceApplicationInfo; } });
Object.defineProperty(exports, "EmberRf4cePairingTableEntry", { enumerable: true, get: function () { return struct_1.EmberRf4cePairingTableEntry; } });
Object.defineProperty(exports, "EmberGpAddress", { enumerable: true, get: function () { return struct_1.EmberGpAddress; } });
Object.defineProperty(exports, "EmberGpSinkListEntry", { enumerable: true, get: function () { return struct_1.EmberGpSinkListEntry; } });
Object.defineProperty(exports, "EmberNodeDescriptor", { enumerable: true, get: function () { return struct_1.EmberNodeDescriptor; } });
Object.defineProperty(exports, "EmberSimpleDescriptor", { enumerable: true, get: function () { return struct_1.EmberSimpleDescriptor; } });
Object.defineProperty(exports, "EmberMultiAddress", { enumerable: true, get: function () { return struct_1.EmberMultiAddress; } });
Object.defineProperty(exports, "EmberNeighbors", { enumerable: true, get: function () { return struct_1.EmberNeighbors; } });
Object.defineProperty(exports, "EmberRoutingTable", { enumerable: true, get: function () { return struct_1.EmberRoutingTable; } });
Object.defineProperty(exports, "EmberRoutingTableEntry", { enumerable: true, get: function () { return struct_1.EmberRoutingTableEntry; } });
/* eslint-disable-next-line @typescript-eslint/no-explicit-any*/
function deserialize(payload, schema) {
    const result = [];
    let value, data = payload;
    for (const type of schema) {
        [value, data] = type.deserialize(type, data);
        result.push(value);
    }
    return [result, data];
}
exports.deserialize = deserialize;
/* eslint-disable-next-line @typescript-eslint/no-explicit-any, @typescript-eslint/ban-types*/
function serialize(data, schema) {
    return Buffer.concat(schema.map((s, idx) => s.serialize(s, data[idx])));
}
exports.serialize = serialize;
//# sourceMappingURL=index.js.map