declare const _exports: ({
    fingerprint: {
        modelID: string;
        ieeeAddr: RegExp;
    }[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            action: any;
        };
    }[];
    toZigbee: undefined[];
    exposes: exposes.Enum[];
    whiteLabel: ({
        vendor: string;
        description: string;
        model: string;
    } | {
        vendor: string;
        model: string;
    })[];
} | {
    fingerprint: {
        modelID: string;
        ieeeAddr: RegExp;
    }[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            action: any;
        };
    }[];
    toZigbee: undefined[];
    exposes: exposes.Enum[];
})[];
export = _exports;
import exposes = require("../lib/exposes");
//# sourceMappingURL=enocean.d.ts.map