declare const _exports: {
    model: string;
    fingerprint: {
        modelID: string;
        manufacturerName: string;
    }[];
    exposes: any[];
    vendor: string;
    description: string;
    onEvent: (type: any, data: any, device: any) => Promise<void>;
    fromZigbee: {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            [x: string]: any;
        };
    }[];
    toZigbee: {
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
            state: {
                [x: string]: any;
            };
        }>;
    }[];
}[];
export = _exports;
//# sourceMappingURL=giex.d.ts.map