declare const _exports: ({
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
} | {
    fingerprint: {
        type: string;
        manufacturerName: string;
        modelID: string;
        endpoints: {
            ID: number;
            profileID: number;
            deviceID: number;
            inputClusters: number[];
            outputClusters: number[];
        }[];
    }[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        toZigbee: any[];
        exposes: any[];
        fromZigbee: any[];
    };
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        toZigbee: any[];
        exposes: any[];
        fromZigbee: any[];
    };
    meta: {
        disableDefaultResponse: boolean;
    };
} | {
    zigbeeModel: string[];
    fingerprint: {
        type: string;
        manufacturerName: string;
        modelID: string;
        endpoints: {
            ID: number;
            profileID: number;
            deviceID: number;
            inputClusters: number[];
            outputClusters: number[];
        }[];
    }[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        toZigbee: any[];
        exposes: any[];
        fromZigbee: any[];
    };
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    ota: {
        getImageMeta: (current: any, logger: any, device: any) => Promise<{
            fileVersion: any;
            fileSize: any;
            url: any;
            sha512: any;
            force: any;
        }>;
        isUpdateAvailable: (device: any, logger: any, requestPayload?: any) => Promise<any>;
        updateToLatest: (device: any, logger: any, onProgress: any) => Promise<any>;
        useIndexOverride: (indexFileName: any) => void;
        setDataDir: (dir: any) => void;
    };
    description: string;
    extend: {
        toZigbee: any[];
        exposes: any[];
        fromZigbee: any[];
    };
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    ota: {
        getImageMeta: (current: any, logger: any, device: any) => Promise<{
            fileVersion: any;
            fileSize: any;
            url: any;
            sha512: any;
            force: any;
        }>;
        isUpdateAvailable: (device: any, logger: any, requestPayload?: any) => Promise<any>;
        updateToLatest: (device: any, logger: any, onProgress: any) => Promise<any>;
        useIndexOverride: (indexFileName: any) => void;
        setDataDir: (dir: any) => void;
    };
    description: string;
    extend: {
        toZigbee: any[];
        exposes: any[];
        fromZigbee: any[];
    };
} | {
    fingerprint: {
        type: string;
        manufacturerName: string;
        modelID: string;
        endpoints: {
            ID: number;
            profileID: number;
            deviceID: number;
            inputClusters: number[];
            outputClusters: number[];
        }[];
    }[];
    model: string;
    meta: {
        disableDefaultResponse: (entity: any) => boolean;
    };
    vendor: string;
    description: string;
    extend: {
        toZigbee: any[];
        exposes: any[];
        fromZigbee: any[];
    };
} | {
    fingerprint: {
        type: string;
        manufacturerName: string;
        modelID: string;
        endpoints: {
            ID: number;
            profileID: number;
            deviceID: number;
            inputClusters: number[];
            outputClusters: number[];
        }[];
    }[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        toZigbee: any[];
        exposes: any[];
        fromZigbee: any[];
    };
    exposes: exposes.Light[];
    endpoint: (device: any) => {
        rgb: number;
        white: number;
    };
} | {
    fingerprint: {
        type: string;
        manufacturerName: string;
        modelID: string;
        endpoints: {
            ID: number;
            profileID: number;
            deviceID: number;
            inputClusters: number[];
            outputClusters: number[];
        }[];
    }[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        toZigbee: any[];
        exposes: any[];
        fromZigbee: any[];
    };
    exposes: exposes.Light[];
    meta: {
        disableDefaultResponse: (entity: any) => boolean;
    };
    endpoint: (device: any) => {
        rgb: number;
        cct: number;
    };
} | {
    fingerprint: {
        type: string;
        manufacturerName: string;
        modelID: string;
        endpoints: {
            ID: number;
            profileID: number;
            deviceID: number;
            inputClusters: number[];
            outputClusters: number[];
        }[];
    }[];
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        toZigbee: any[];
        exposes: any[];
        fromZigbee: any[];
    };
    meta: {
        disableDefaultResponse: boolean;
    };
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    ota: {
        getImageMeta: (current: any, logger: any, device: any) => Promise<{
            fileVersion: any;
            fileSize: any;
            url: any;
            sha512: any;
            force: any;
        }>;
        isUpdateAvailable: (device: any, logger: any, requestPayload?: any) => Promise<any>;
        updateToLatest: (device: any, logger: any, onProgress: any) => Promise<any>;
        useIndexOverride: (indexFileName: any) => void;
        setDataDir: (dir: any) => void;
    };
    description: string;
    whiteLabel: {
        vendor: string;
        model: string;
    }[];
    extend: {
        toZigbee: any[];
        exposes: any[];
        fromZigbee: any[];
    };
    meta: {
        disableDefaultResponse: boolean;
    };
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    ota: {
        getImageMeta: (current: any, logger: any, device: any) => Promise<{
            fileVersion: any;
            fileSize: any;
            url: any;
            sha512: any;
            force: any;
        }>;
        isUpdateAvailable: (device: any, logger: any, requestPayload?: any) => Promise<any>;
        updateToLatest: (device: any, logger: any, onProgress: any) => Promise<any>;
        useIndexOverride: (indexFileName: any) => void;
        setDataDir: (dir: any) => void;
    };
    description: string;
    extend: {
        toZigbee: any[];
        exposes: any[];
        fromZigbee: any[];
    };
    meta: {
        turnsOffAtBrightness1: boolean;
    };
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        toZigbee: any[];
        exposes: any[];
        fromZigbee: any[];
    };
    endpoint: (device: any) => {
        default: number;
    };
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        toZigbee: any[];
        exposes: any[];
        fromZigbee: any[];
    };
    meta: {
        turnsOffAtBrightness1: boolean;
    };
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        toZigbee: any[];
        exposes: any[];
        fromZigbee: any[];
    };
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
})[];
export = _exports;
import exposes = require("../lib/exposes");
//# sourceMappingURL=gledopto.d.ts.map