declare const _exports: ({
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            fan_mode: any;
            fan_state: string;
        };
    } | FromZigbeeConverter)[];
    toZigbee: ({
        key: string[];
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    } | {
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<void>;
    })[];
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
    exposes: any[];
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    meta: {
        disableDefaultResponse: boolean;
    };
    extend: {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
    fromZigbee: ({
        cluster: string;
        type: string[];
        options: exposes.Binary[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {};
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            ballast_status_non_operational: boolean;
            ballast_status_lamp_failure: boolean;
            ballast_minimum_level: any;
            ballast_maximum_level: any;
            ballast_power_on_level: any;
            ballast_power_on_fade_time: any;
            ballast_intrinsic_ballast_factor: any;
            ballast_ballast_factor_adjustment: any;
            ballast_lamp_quantity: any;
            ballast_lamp_type: any;
            ballast_lamp_manufacturer: any;
            ballast_lamp_rated_hours: any;
            ballast_lamp_burn_hours: any;
            ballast_lamp_alarm_lamp_burn_hours: boolean;
            ballast_lamp_burn_hours_trip_point: any;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            [x: number]: string;
        };
    })[];
    toZigbee: ({
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<void>;
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    } | {
        key: string[];
        options: exposes.Numeric[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
            state?: undefined;
        } | {
            state: {
                state: any;
            };
        } | {
            state: {};
            readAfterWriteTime: number;
        }>;
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    })[];
    exposes: any[];
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
})[];
export = _exports;
import exposes = require("../lib/exposes");
//# sourceMappingURL=leviton.d.ts.map