export const inovelli: typeof import("./inovelli");
export const ledvance: typeof import("./ledvance");
export const salus: typeof import("./salus");
export const lixee: typeof import("./lixee");
export const securifi: typeof import("./securifi");
export const tradfri: {
    isUpdateAvailable: (device: any, logger: any, requestPayload?: any) => Promise<any>;
    updateToLatest: (device: any, logger: any, onProgress: any) => Promise<any>;
    useTestURL: () => void;
};
export const ubisys: typeof import("./ubisys");
export const zigbeeOTA: {
    getImageMeta: (current: any, logger: any, device: any) => Promise<{
        fileVersion: any;
        fileSize: any;
        url: any;
        sha512: any;
        force: any;
    }>;
    isUpdateAvailable: (device: any, logger: any, requestPayload?: any) => Promise<any>;
    updateToLatest: (device: any, logger: any, onProgress: any) => Promise<any>;
    useIndexOverride: (indexFileName: any) => void;
    setDataDir: (dir: any) => void;
};
//# sourceMappingURL=index.d.ts.map