export interface LoggerStub {
    error: (message: string, ...meta: any[]) => void;
    warn: (message: string, ...meta: any[]) => void;
    info: (message: string, ...meta: any[]) => void;
    debug: (message: string, ...meta: any[]) => void;
}
//# sourceMappingURL=logger-stub.d.ts.map