declare const _exports: ({
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    exposes: (exposes.Numeric | exposes.Enum | exposes.Switch)[];
    fromZigbee: ({
        cluster: string;
        type: string[];
        options: (definition: any) => exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            power: any;
            energy: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Binary[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {};
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            [x: number]: any;
        };
    } | {
        cluster: string;
        type: string;
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            action: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Composite[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            action: any;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            configure_device_setup: any;
        };
    })[];
    toZigbee: {
        key: string[];
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    }[];
    endpoint: (device: any) => {
        l1: number;
        s1: number;
        meter: number;
    };
    meta: {
        multiEndpointEnforce: {
            power: number;
            energy: number;
        };
    };
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
    onEvent: (type: any, data: any, device: any) => Promise<void>;
    ota: typeof import("../lib/ota/ubisys");
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    exposes: (exposes.Numeric | exposes.Enum | exposes.Switch)[];
    fromZigbee: ({
        cluster: string;
        type: string[];
        options: (definition: any) => exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            power: any;
            energy: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Binary[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {};
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            [x: number]: any;
        };
    } | {
        cluster: string;
        type: string;
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            action: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Composite[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            action: any;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            configure_device_setup: any;
        };
    })[];
    toZigbee: {
        key: string[];
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    }[];
    endpoint: (device: any) => {
        l1: number;
        l2: number;
        s1: number;
        s2: number;
        meter: number;
    };
    meta: {
        multiEndpoint: boolean;
        multiEndpointEnforce: {
            power: number;
            energy: number;
        };
    };
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
    onEvent: (type: any, data: any, device: any) => Promise<void>;
    ota: typeof import("../lib/ota/ubisys");
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            [x: number]: any;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            level_config: {};
        };
    } | {
        cluster: string;
        type: string[];
        options: (definition: any) => exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            power: any;
            energy: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Binary[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {};
    } | {
        cluster: string;
        type: string;
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            action: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Composite[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            action: any;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            ballast_status_non_operational: boolean;
            ballast_status_lamp_failure: boolean;
            ballast_minimum_level: any;
            ballast_maximum_level: any;
            ballast_power_on_level: any;
            ballast_power_on_fade_time: any;
            ballast_intrinsic_ballast_factor: any;
            ballast_ballast_factor_adjustment: any;
            ballast_lamp_quantity: any;
            ballast_lamp_type: any;
            ballast_lamp_manufacturer: any;
            ballast_lamp_rated_hours: any;
            ballast_lamp_burn_hours: any;
            ballast_lamp_alarm_lamp_burn_hours: boolean;
            ballast_lamp_burn_hours_trip_point: any;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            capabilities_forward_phase_control: boolean;
            capabilities_reverse_phase_control: boolean;
            capabilities_reactance_discriminator: boolean;
            capabilities_configurable_curve: boolean;
            capabilities_overload_detection: boolean;
            status_forward_phase_control?: undefined;
            status_reverse_phase_control?: undefined;
            status_overload?: undefined;
            status_capacitive_load?: undefined;
            status_inductive_load?: undefined;
            mode_phase_control?: undefined;
        } | {
            status_forward_phase_control: boolean;
            status_reverse_phase_control: boolean;
            status_overload: boolean;
            status_capacitive_load: boolean;
            status_inductive_load: boolean;
            capabilities_forward_phase_control?: undefined;
            capabilities_reverse_phase_control?: undefined;
            capabilities_reactance_discriminator?: undefined;
            capabilities_configurable_curve?: undefined;
            capabilities_overload_detection?: undefined;
            mode_phase_control?: undefined;
        } | {
            mode_phase_control: any;
            capabilities_forward_phase_control?: undefined;
            capabilities_reverse_phase_control?: undefined;
            capabilities_reactance_discriminator?: undefined;
            capabilities_configurable_curve?: undefined;
            capabilities_overload_detection?: undefined;
            status_forward_phase_control?: undefined;
            status_reverse_phase_control?: undefined;
            status_overload?: undefined;
            status_capacitive_load?: undefined;
            status_inductive_load?: undefined;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            minimum_on_level: any;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            configure_device_setup: any;
        };
    })[];
    toZigbee: ({
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
            state: {
                brightness: any;
                state: string;
            };
        }>;
    } | {
        key: string[];
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    } | {
        key: string[];
        attr: any[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<void>;
    })[];
    exposes: any[];
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
    meta: {
        multiEndpoint: boolean;
        multiEndpointSkip: string[];
        multiEndpointEnforce: {
            power: number;
            energy: number;
        };
    };
    endpoint: (device: any) => {
        default: number;
        s1: number;
        s2: number;
        meter: number;
    };
    onEvent: (type: any, data: any, device: any) => Promise<void>;
    ota: typeof import("../lib/ota/ubisys");
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string[];
        options: (definition: any) => exposes.Numeric[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            power: any;
            energy: any;
        };
    } | {
        cluster: string;
        type: string[];
        options: exposes.Binary[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {};
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            configure_device_setup: any;
        };
    })[];
    toZigbee: ({
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<void>;
    } | {
        key: string[];
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    })[];
    exposes: (exposes.Numeric | exposes.Cover)[];
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
    endpoint: (device: any) => {
        default: number;
        meter: number;
    };
    meta: {
        multiEndpointEnforce: {
            power: number;
            energy: number;
        };
    };
    onEvent: (type: any, data: any, device: any) => Promise<void>;
    ota: typeof import("../lib/ota/ubisys");
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: (FromZigbeeConverter | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            configure_device_setup: any;
        };
    })[];
    toZigbee: {
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<void>;
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    }[];
    exposes: exposes.Enum[];
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
    meta: {
        multiEndpoint: boolean;
    };
    endpoint: (device: any) => {
        s1: number;
        s2: number;
        s3: number;
        s4: number;
        s5: number;
        s6: number;
    };
    ota: typeof import("../lib/ota/ubisys");
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    meta: {
        thermostat: {
            dontMapPIHeatingDemand: boolean;
        };
    };
    fromZigbee: {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {};
    }[];
    toZigbee: ({
        key: string[];
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    } | {
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<void>;
    })[];
    exposes: any[];
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
    ota: typeof import("../lib/ota/ubisys");
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            linkquality: any;
        };
    }[];
    toZigbee: undefined[];
    exposes: undefined[];
    ota: typeof import("../lib/ota/ubisys");
})[];
export = _exports;
import exposes = require("../lib/exposes");
//# sourceMappingURL=ubisys.d.ts.map