declare const _exports: ({
    fingerprint: {
        modelID: string;
        manufacturerName: string;
    }[];
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        meta: {
            applyRedFix: boolean;
            enhancedHue: boolean;
        };
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    extend: {
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
})[];
export = _exports;
//# sourceMappingURL=ysrsai.d.ts.map