declare enum DataType {
    noData = 0,
    data8 = 8,
    data16 = 9,
    data24 = 10,
    data32 = 11,
    data40 = 12,
    data48 = 13,
    data56 = 14,
    data64 = 15,
    boolean = 16,
    bitmap8 = 24,
    bitmap16 = 25,
    bitmap24 = 26,
    bitmap32 = 27,
    bitmap40 = 28,
    bitmap48 = 29,
    bitmap56 = 30,
    bitmap64 = 31,
    uint8 = 32,
    uint16 = 33,
    uint24 = 34,
    uint32 = 35,
    uint40 = 36,
    uint48 = 37,
    uint56 = 38,
    uint64 = 39,
    int8 = 40,
    int16 = 41,
    int24 = 42,
    int32 = 43,
    int48 = 45,
    enum8 = 48,
    enum16 = 49,
    singlePrec = 57,
    doublePrec = 58,
    octetStr = 65,
    charStr = 66,
    longOctetStr = 67,
    longCharStr = 68,
    array = 72,
    struct = 76,
    set = 80,
    bag = 81,
    tod = 224,
    date = 225,
    utc = 226,
    clusterId = 232,
    attrId = 233,
    bacOid = 234,
    ieeeAddr = 240,
    secKey = 241,
    unknown = 255,
    int40 = 44,
    int56 = 46,
    int64 = 47,
    semiPrec = 56
}
export default DataType;
//# sourceMappingURL=dataType.d.ts.map